/*!
 * surveyjs - Survey JavaScript library v2.2.2
 * Copyright (c) 2015-2025 Devsoft Baltic OÜ  - http://surveyjs.io/
 * License: MIT (http://www.opensource.org/licenses/mit-license.php)
 */

/* eslint-disable no-restricted-globals */
class DomWindowHelper {
    static isAvailable() {
        return "undefined" !== typeof window;
    }
    static isFileReaderAvailable() {
        if (!DomWindowHelper.isAvailable())
            return false;
        return !!window["FileReader"];
    }
    static getLocation() {
        if (!DomWindowHelper.isAvailable())
            return;
        return window.location;
    }
    static getVisualViewport() {
        if (!DomWindowHelper.isAvailable())
            return null;
        return window.visualViewport;
    }
    static getInnerWidth() {
        if (!DomWindowHelper.isAvailable())
            return;
        return window.innerWidth;
    }
    static getInnerHeight() {
        if (!DomWindowHelper.isAvailable())
            return null;
        return window.innerHeight;
    }
    static getDevicePixelRatio() {
        if (!DomWindowHelper.isAvailable())
            return null;
        return window.devicePixelRatio;
    }
    static getWindow() {
        if (!DomWindowHelper.isAvailable())
            return;
        return window;
    }
    static hasOwn(propertyName) {
        if (!DomWindowHelper.isAvailable())
            return;
        return propertyName in window;
    }
    static getSelection() {
        if (DomWindowHelper.isAvailable() && window.getSelection) {
            return window.getSelection();
        }
    }
    static requestAnimationFrame(callback) {
        if (DomWindowHelper.isAvailable()) {
            return window.requestAnimationFrame(callback);
        }
    }
    static addEventListener(type, listener) {
        if (!DomWindowHelper.isAvailable())
            return;
        window.addEventListener(type, listener);
    }
    static removeEventListener(type, listener) {
        if (!DomWindowHelper.isAvailable())
            return;
        window.removeEventListener(type, listener);
    }
    static matchMedia(mediaQueryString) {
        if (!DomWindowHelper.isAvailable() || typeof window.matchMedia === "undefined")
            return null;
        return window.matchMedia(mediaQueryString);
    }
}
class DomDocumentHelper {
    static isAvailable() {
        return "undefined" !== typeof document;
    }
    static getBody() {
        if (!DomDocumentHelper.isAvailable())
            return;
        return document.body;
    }
    static getDocumentElement() {
        if (!DomDocumentHelper.isAvailable())
            return;
        return document.documentElement;
    }
    static getDocument() {
        if (!DomDocumentHelper.isAvailable())
            return;
        return document;
    }
    static getCookie() {
        if (!DomDocumentHelper.isAvailable())
            return;
        return document.cookie;
    }
    static setCookie(newCookie) {
        if (!DomDocumentHelper.isAvailable())
            return;
        document.cookie = newCookie;
    }
    static activeElementBlur() {
        if (!DomDocumentHelper.isAvailable())
            return;
        const activeElement = document.activeElement;
        if (!!activeElement && !!activeElement.blur) {
            activeElement.blur();
        }
    }
    static createElement(tagName) {
        if (!DomDocumentHelper.isAvailable())
            return;
        return document.createElement(tagName);
    }
    static getComputedStyle(elt) {
        if (!DomDocumentHelper.isAvailable())
            return new CSSStyleDeclaration();
        return document.defaultView.getComputedStyle(elt);
    }
    static addEventListener(type, listener) {
        if (!DomDocumentHelper.isAvailable())
            return;
        document.addEventListener(type, listener);
    }
    static removeEventListener(type, listener) {
        if (!DomDocumentHelper.isAvailable())
            return;
        document.removeEventListener(type, listener);
    }
}

function createDate(reason, val) {
    if (!val)
        return new Date();
    if (!settings.storeUtcDates && typeof val === "string" && isISODateOnly(val)) {
        val += "T00:00:00";
    }
    const d = new Date(val);
    return settings.onDateCreated(d, reason, val);
}
function isISODateOnly(str) {
    if (str.indexOf("T") > 0)
        return false;
    if (!/\d{4}-\d{2}-\d{2}/.test(str))
        return false;
    return !isNaN(new Date(str).getTime());
}
class Helpers {
    /**
     * A static methods that returns true if a value undefined, null, empty string or empty array.
     * @param value
     */
    static isValueEmpty(value) {
        if (Array.isArray(value) && value.length === 0)
            return true;
        if (!!value && Helpers.isValueObject(value) && value.constructor === Object) {
            for (var key in value) {
                if (!Helpers.isValueEmpty(value[key]))
                    return false;
            }
            return true;
        }
        return !value && value !== 0 && value !== false;
    }
    static isValueUndefined(value) {
        return (value === undefined || value === null) || (typeof value === "number" && isNaN(value));
    }
    static isArrayContainsEqual(x, y) {
        if (!Array.isArray(x) || !Array.isArray(y))
            return false;
        if (x.length !== y.length)
            return false;
        for (var i = 0; i < x.length; i++) {
            var j = 0;
            for (; j < y.length; j++) {
                if (Helpers.isTwoValueEquals(x[i], y[j]))
                    break;
            }
            if (j === y.length)
                return false;
        }
        return true;
    }
    static checkIfArraysEqual(x, y, params) {
        if (!Array.isArray(x) || !Array.isArray(y))
            return false;
        if (x.length !== y.length)
            return false;
        const ignoreOrder = params.ignoreOrder !== undefined ? params.ignoreOrder : false;
        if (ignoreOrder) {
            var xSorted = [];
            var ySorted = [];
            for (var i = 0; i < x.length; i++) {
                xSorted.push(x[i]);
                ySorted.push(y[i]);
            }
            xSorted.sort();
            ySorted.sort();
            x = xSorted;
            y = ySorted;
        }
        for (var i = 0; i < x.length; i++) {
            if (!Helpers.checkIfValuesEqual(x[i], y[i], params))
                return false;
        }
        return true;
    }
    static isArraysEqual(x, y, ignoreOrder = false, caseSensitive, trimStrings) {
        return Helpers.checkIfArraysEqual(x, y, { ignoreOrder: ignoreOrder, caseSensitive: caseSensitive, trimStrings: trimStrings });
    }
    static compareStrings(x, y) {
        const normalize = settings.comparator.normalizeTextCallback;
        if (!!x)
            x = normalize(x, "compare").trim();
        if (!!y)
            y = normalize(y, "compare").trim();
        if (!x && !y)
            return 0;
        if (!x)
            return -1;
        if (!y)
            return 1;
        if (x === y)
            return 0;
        let digitIndex = -1;
        for (let i = 0; i < x.length && i < y.length; i++) {
            if (this.isCharDigit(x[i]) && this.isCharDigit(y[i])) {
                digitIndex = i;
                break;
            }
            if (x[i] !== y[i])
                break;
        }
        if (digitIndex > -1) {
            let nX = this.getNumberFromStr(x, digitIndex);
            let nY = this.getNumberFromStr(y, digitIndex);
            if (!Number.isNaN(nX) && !Number.isNaN(nY) && nX !== nY) {
                return nX > nY ? 1 : -1;
            }
        }
        return x > y ? 1 : -1;
    }
    static checkIfValuesEqual(x, y, params) {
        if (x === y)
            return true;
        if (Array.isArray(x) && x.length === 0 && typeof y === "undefined")
            return true;
        if (Array.isArray(y) && y.length === 0 && typeof x === "undefined")
            return true;
        if ((x === undefined || x === null) && y === "")
            return true;
        if ((y === undefined || y === null) && x === "")
            return true;
        const caseSensitive = params.caseSensitive !== undefined ? params.caseSensitive : settings.comparator.caseSensitive;
        const trimStrings = params.trimStrings !== undefined ? params.trimStrings : settings.comparator.trimStrings;
        if (typeof x === "string" && typeof y === "string") {
            const normalize = settings.comparator.normalizeTextCallback;
            x = normalize(x, "compare");
            y = normalize(y, "compare");
            if (trimStrings) {
                x = x.trim();
                y = y.trim();
            }
            if (!caseSensitive) {
                x = x.toLowerCase();
                y = y.toLowerCase();
            }
            return x === y;
        }
        if (x instanceof Date && y instanceof Date)
            return x.getTime() == y.getTime();
        const convertNumbers = !params.doNotConvertNumbers;
        if (convertNumbers && Helpers.isConvertibleToNumber(x) && Helpers.isConvertibleToNumber(y)) {
            if (parseInt(x) === parseInt(y) && parseFloat(x) === parseFloat(y)) {
                return true;
            }
        }
        if ((!Helpers.isValueEmpty(x) && Helpers.isValueEmpty(y)) ||
            (Helpers.isValueEmpty(x) && !Helpers.isValueEmpty(y)))
            return false;
        if ((x === true || x === false) && typeof y == "string") {
            return x.toString() === y.toLocaleLowerCase();
        }
        if ((y === true || y === false) && typeof x == "string") {
            return y.toString() === x.toLocaleLowerCase();
        }
        const isXObj = Helpers.isValueObject(x);
        const isYObj = Helpers.isValueObject(y);
        if (!isXObj && !isYObj && (convertNumbers || (typeof x !== "number" && typeof y !== "number")))
            return x == y;
        if (!isXObj || !isYObj)
            return false;
        if (x["equals"] && y["equals"])
            return x.equals(y);
        if (Array.isArray(x) && Array.isArray(y)) {
            return Helpers.checkIfArraysEqual(x, y, params);
        }
        for (var p in x) {
            if (!x.hasOwnProperty(p))
                continue;
            if (!y.hasOwnProperty(p))
                return false;
            if (!this.checkIfValuesEqual(x[p], y[p], params))
                return false;
        }
        for (p in y) {
            if (y.hasOwnProperty(p) && !x.hasOwnProperty(p))
                return false;
        }
        return true;
    }
    static isTwoValueEquals(x, y, ignoreOrder = false, caseSensitive, trimStrings) {
        return this.checkIfValuesEqual(x, y, { ignoreOrder: ignoreOrder, caseSensitive: caseSensitive, trimStrings: trimStrings });
    }
    static randomizeArray(array) {
        for (var i = array.length - 1; i > 0; i--) {
            var j = Math.floor(Math.random() * (i + 1));
            var temp = array[i];
            array[i] = array[j];
            array[j] = temp;
        }
        return array;
    }
    static getUnbindValue(value) {
        if (Array.isArray(value)) {
            const res = [];
            for (let i = 0; i < value.length; i++) {
                res.push(Helpers.getUnbindValue(value[i]));
            }
            return res;
        }
        if (!!value && Helpers.isValueObject(value) && !(value instanceof Date)) {
            return JSON.parse(JSON.stringify(value));
        }
        return value;
    }
    static createCopy(obj) {
        return this.createCopyWithPrefix(obj, undefined);
    }
    static createCopyWithPrefix(obj, prefix) {
        var res = {};
        if (!obj)
            return res;
        for (var key in obj) {
            const newKey = prefix ? prefix + key : key;
            res[newKey] = obj[key];
        }
        return res;
    }
    static isConvertibleToNumber(value) {
        return (value !== undefined &&
            value !== null &&
            !Array.isArray(value) &&
            !isNaN(value));
    }
    static isValueObject(val, excludeArray) {
        return val instanceof Object && (!excludeArray || !Array.isArray(val));
    }
    static isNumber(value) {
        return !isNaN(this.getNumber(value));
    }
    static getNumber(value) {
        const newValue = Helpers.getNumberCore(value);
        return settings.parseNumber(value, newValue);
    }
    static getNumberCore(value) {
        if (typeof value == "string") {
            value = value.trim();
            if (!value)
                return NaN;
            if (value.indexOf("0x") == 0) {
                if (value.length > 32)
                    return NaN;
                return parseInt(value);
            }
            if (value.length > 15 && Helpers.isDigitsOnly(value))
                return NaN;
            if (Helpers.isStringHasOperator(value))
                return NaN;
        }
        value = this.prepareStringToNumber(value);
        const res = parseFloat(value);
        if (isNaN(res) || !isFinite(value))
            return NaN;
        return res;
    }
    static isStringHasOperator(str) {
        if (str.lastIndexOf("-") > 0)
            return false;
        if (str.lastIndexOf("+") > 0)
            return false;
        const operators = "*^/%";
        for (let i = 0; i < operators.length; i++) {
            if (str.indexOf(operators[i]) > -1)
                return true;
        }
        return false;
    }
    static prepareStringToNumber(val) {
        if (typeof val !== "string" || !val)
            return val;
        let i = val.indexOf(",");
        if (i > -1 && val.indexOf(",", i + 1) < 0) {
            return val.replace(",", ".");
        }
        return val;
    }
    static getMaxLength(maxLength, surveyLength) {
        if (maxLength < 0) {
            maxLength = surveyLength;
        }
        return maxLength > 0 ? maxLength : null;
    }
    static getRemainingCharacterCounterText(newValue, maxLength) {
        if (!maxLength || maxLength <= 0 || !settings.showMaxLengthIndicator) {
            return "";
        }
        const value = newValue ? newValue.length : "0";
        return [value, maxLength].join("/");
    }
    static getNumberByIndex(index, startIndexStr, parentIndex) {
        if (index < 0)
            return "";
        var startIndex = 1;
        var prefix = "";
        var postfix = ".";
        var isNumeric = true;
        var strIndex = "A";
        var str = "";
        const hasDigitFunc = (str) => {
            if (!str)
                return false;
            for (var i = 0; i < str.length; i++) {
                if (Helpers.isCharDigit(str[i]))
                    return true;
            }
            return false;
        };
        if (!!startIndexStr) {
            str = startIndexStr;
            var ind = str.length - 1;
            var hasDigit = hasDigitFunc(str);
            var checkLetter = function () {
                return ((hasDigit && !Helpers.isCharDigit(str[ind])) ||
                    Helpers.isCharNotLetterAndDigit(str[ind]));
            };
            while (ind >= 0 && checkLetter())
                ind--;
            var newPostfix = "";
            if (ind < str.length - 1) {
                newPostfix = str.substring(ind + 1);
                str = str.substring(0, ind + 1);
            }
            ind = str.length - 1;
            while (ind >= 0) {
                if (checkLetter())
                    break;
                ind--;
                if (!hasDigit)
                    break;
            }
            strIndex = str.substring(ind + 1);
            prefix = str.substring(0, ind + 1);
            if (parseInt(strIndex))
                startIndex = parseInt(strIndex);
            else if (strIndex.length == 1)
                isNumeric = false;
            if (!!newPostfix || !!prefix) {
                postfix = newPostfix;
            }
        }
        if (parentIndex > -1 && hasDigitFunc(prefix)) {
            prefix = this.getNumberByIndex(parentIndex, prefix);
        }
        if (isNumeric) {
            let val = (index + startIndex).toString();
            while (val.length < strIndex.length)
                val = "0" + val;
            return prefix + val + postfix;
        }
        return (prefix + String.fromCharCode(strIndex.charCodeAt(0) + index) + postfix);
    }
    static isCharNotLetterAndDigit(ch) {
        return ch.toUpperCase() == ch.toLowerCase() && !Helpers.isCharDigit(ch);
    }
    static isCharDigit(ch) {
        return ch >= "0" && ch <= "9";
    }
    static isDigitsOnly(str) {
        if (!str)
            return false;
        for (let i = 0; i < str.length; i++) {
            if (!Helpers.isCharDigit(str[i]))
                return false;
        }
        return true;
    }
    static getNumberFromStr(str, index) {
        if (!this.isCharDigit(str[index]))
            return NaN;
        let nStr = "";
        while (index < str.length && this.isCharDigit(str[index])) {
            nStr += str[index];
            index++;
        }
        if (!nStr)
            return NaN;
        return this.getNumber(nStr);
    }
    static countDecimals(value) {
        if (Helpers.isNumber(value) && Math.floor(value) !== value) {
            const strs = value.toString().split(".");
            return strs.length > 1 && strs[1].length || 0;
        }
        return 0;
    }
    static correctAfterPlusMinis(a, b, res) {
        const digitsA = Helpers.countDecimals(a);
        const digitsB = Helpers.countDecimals(b);
        if (digitsA > 0 || digitsB > 0) {
            const digits = Math.max(digitsA, digitsB);
            res = parseFloat(res.toFixed(digits));
        }
        return res;
    }
    static sumAnyValues(a, b) {
        if (!Helpers.isNumber(a) || !Helpers.isNumber(b)) {
            if (Array.isArray(a) && Array.isArray(b))
                return [].concat(a).concat(b);
            if (Array.isArray(a) || Array.isArray(b)) {
                const arr = Array.isArray(a) ? a : b;
                const val = arr === a ? b : a;
                if (typeof val === "string") {
                    const str = arr.join(", ");
                    return arr === a ? str + val : val + str;
                }
                if (typeof val === "number") {
                    let res = 0;
                    for (var i = 0; i < arr.length; i++) {
                        if (typeof arr[i] === "number") {
                            res = Helpers.correctAfterPlusMinis(res, arr[i], res + arr[i]);
                        }
                    }
                    return Helpers.correctAfterPlusMinis(res, val, res + val);
                }
            }
            return a + b;
        }
        if (typeof a === "string" || typeof b === "string")
            return a + b;
        return Helpers.correctAfterPlusMinis(a, b, a + b);
    }
    static correctAfterMultiple(a, b, res) {
        const digits = Helpers.countDecimals(a) + Helpers.countDecimals(b);
        if (digits > 0) {
            res = parseFloat(res.toFixed(digits));
        }
        return res;
    }
    static convertArrayValueToObject(src, propName, dest = undefined) {
        const res = new Array();
        if (!src || !Array.isArray(src))
            return res;
        for (var i = 0; i < src.length; i++) {
            let item;
            if (Array.isArray(dest)) {
                item = Helpers.findObjByPropValue(dest, propName, src[i]);
            }
            if (!item) {
                item = {};
                item[propName] = src[i];
            }
            res.push(item);
        }
        return res;
    }
    static findObjByPropValue(arr, propName, val) {
        for (var i = 0; i < arr.length; i++) {
            if (Helpers.isTwoValueEquals(arr[i][propName], val))
                return arr[i];
        }
        return undefined;
    }
    static convertArrayObjectToValue(src, propName) {
        const res = new Array();
        if (!src || !Array.isArray(src))
            return res;
        for (var i = 0; i < src.length; i++) {
            const itemVal = !!src[i] ? src[i][propName] : undefined;
            if (!Helpers.isValueEmpty(itemVal))
                res.push(itemVal);
        }
        return res;
    }
    static convertDateToString(date) {
        const toStr = (val) => {
            if (val < 10)
                return "0" + val.toString();
            return val.toString();
        };
        return date.getFullYear() + "-" + toStr(date.getMonth() + 1) + "-" + toStr(date.getDate());
    }
    static convertDateTimeToString(date) {
        const toStr = (val) => {
            if (val < 10)
                return "0" + val.toString();
            return val.toString();
        };
        return this.convertDateToString(date) + " " + toStr(date.getHours()) + ":" + toStr(date.getMinutes());
    }
    static convertValToQuestionVal(val, inputType) {
        if (val instanceof Date) {
            if (inputType === "datetime-local")
                return Helpers.convertDateTimeToString(val);
            return Helpers.convertDateToString(val);
        }
        return this.getUnbindValue(val);
    }
    static compareVerions(ver1, ver2) {
        if (!ver1 && !ver2)
            return 0;
        const ver1Ar = ver1.split(".");
        const ver2Ar = ver2.split(".");
        const len1 = ver1Ar.length;
        const len2 = ver2Ar.length;
        for (let i = 0; i < len1 && i < len2; i++) {
            const str1 = ver1Ar[i];
            const str2 = ver2Ar[i];
            if (str1.length === str2.length) {
                if (str1 !== str2) {
                    return str1 < str2 ? -1 : 1;
                }
            }
            else {
                return str1.length < str2.length ? -1 : 1;
            }
        }
        return len1 === len2 ? 0 : (len1 < len2 ? -1 : 1);
    }
    static isUrlYoutubeVideo(url) {
        if (!url)
            return false;
        const youtubeDomains = ["www.youtube.com", "m.youtube.com", "youtube.com", "youtu.be"];
        url = url.toLowerCase();
        url = url.replace(/^https?:\/\//, "");
        for (let i = 0; i < youtubeDomains.length; i++) {
            if (url.indexOf(youtubeDomains[i] + "/") === 0)
                return true;
        }
        return false;
    }
}
if (!String.prototype["format"]) {
    String.prototype["format"] = function () {
        var args = arguments;
        return this.replace(/{(\d+)}/g, function (match, number) {
            return typeof args[number] != "undefined" ? args[number] : match;
        });
    };
}

// Uncomment the line below if you create a custom dictionary
// import { setupLocale } from "survey-core";
var englishStrings = {
    pagePrevText: "Previous",
    pageNextText: "Next",
    completeText: "Complete",
    previewText: "Preview",
    editText: "Edit",
    startSurveyText: "Start",
    commentText: "Please leave a comment",
    otherItemText: "Other (describe)",
    noneItemText: "None",
    refuseItemText: "Refuse to answer",
    dontKnowItemText: "Don't know",
    selectAllItemText: "Select All",
    deselectAllItemText: "Deselect all",
    progressText: "Page {0} of {1}",
    indexText: "{0} of {1}",
    panelDynamicProgressText: "{0} of {1}",
    panelDynamicTabTextFormat: "Panel {panelIndex}",
    questionsProgressText: "Answered {0}/{1} questions",
    emptySurvey: "The survey doesn't contain any visible elements.",
    completingSurvey: "Thank you for completing the survey",
    completingSurveyBefore: "You have already completed this survey.",
    loadingSurvey: "Loading Survey...",
    placeholder: "Select...",
    ratingOptionsCaption: "Select...",
    buttongroupOptionsCaption: "Select...",
    value: "value",
    requiredError: "Response required.",
    requiredErrorInPanel: "Response required: answer at least one question.",
    requiredInAllRowsError: "Response required: answer questions in all rows.",
    eachRowUniqueError: "Each row must have a unique value.",
    numericError: "The value should be numeric.",
    minError: "The value should not be less than {0}",
    maxError: "The value should not be greater than {0}",
    textNoDigitsAllow: "Numbers are not allowed.",
    textMinLength: "Please enter at least {0} character(s).",
    textMaxLength: "Please enter no more than {0} character(s).",
    textMinMaxLength: "Please enter at least {0} and no more than {1} characters.",
    minRowCountError: "Please fill in at least {0} row(s).",
    minSelectError: "Please select at least {0} option(s).",
    maxSelectError: "Please select no more than {0} option(s).",
    numericMinMax: "The '{0}' should be at least {1} and at most {2}",
    numericMin: "The '{0}' should be at least {1}",
    numericMax: "The '{0}' should be at most {1}",
    invalidEmail: "Please enter a valid e-mail address.",
    invalidExpression: "The expression: {0} should return 'true'.",
    urlRequestError: "The request returned error '{0}'. {1}",
    urlGetChoicesError: "The request returned empty data or the 'path' property is incorrect",
    exceedMaxSize: "The file size should not exceed {0}.",
    noUploadFilesHandler: "Files cannot be uploaded. Please add a handler for the 'onUploadFiles' event.",
    otherRequiredError: "Response required: enter another value.",
    uploadingFile: "Your file is uploading. Please wait several seconds and try again.",
    loadingFile: "Loading...",
    chooseFile: "Choose file(s)...",
    noFileChosen: "No file selected",
    filePlaceholder: "Drag and drop a file here or click the button below to select a file to upload.",
    confirmDelete: "Are you sure you want to delete this record?",
    keyDuplicationError: "This value should be unique.",
    addColumn: "Add Column",
    addRow: "Add Row",
    removeRow: "Remove",
    noRowsText: "There are no rows.",
    rowIndexTemplateTitle: "Row {rowIndex}",
    rowNameTemplateTitle: "{rowTitle}",
    addPanel: "Add new",
    removePanel: "Remove",
    showDetails: "Show Details",
    hideDetails: "Hide Details",
    choices_Item: "item",
    choices_Choice: "Choice option",
    matrix_column: "Column",
    matrix_row: "Row",
    multipletext_itemname: "text",
    savingData: "The results are being saved on the server...",
    savingDataError: "An error occurred and we could not save the results.",
    savingDataSuccess: "The results were saved successfully!",
    savingExceedSize: "Your response exceeds 64KB. Please reduce the size of your file(s) and try again or contact the survey owner.",
    saveAgainButton: "Try again",
    timerMin: "min",
    timerSec: "sec",
    timerSpentAll: "You have spent {0} on this page and {1} in total.",
    timerSpentPage: "You have spent {0} on this page.",
    timerSpentSurvey: "You have spent {0} in total.",
    timerLimitAll: "You have spent {0} of {1} on this page and {2} of {3} in total.",
    timerLimitPage: "You have spent {0} of {1} on this page.",
    timerLimitSurvey: "You have spent {0} of {1} in total.",
    clearCaption: "Clear",
    selectCaption: "Select",
    signaturePlaceHolder: "Sign here",
    signaturePlaceHolderReadOnly: "No signature",
    chooseFileCaption: "Select File",
    takePhotoCaption: "Take Photo",
    photoPlaceholder: "Click the button below to take a photo using the camera.",
    fileOrPhotoPlaceholder: "Drag and drop or select a file to upload or take a photo using the camera.",
    replaceFileCaption: "Replace file",
    removeFileCaption: "Remove this file",
    booleanCheckedLabel: "Yes",
    booleanUncheckedLabel: "No",
    confirmRemoveFile: "Are you sure that you want to remove this file: {0}?",
    confirmRemoveAllFiles: "Are you sure that you want to remove all files?",
    questionTitlePatternText: "Question Title",
    modalCancelButtonText: "Cancel",
    modalApplyButtonText: "Apply",
    filterStringPlaceholder: "Type to search...",
    emptyMessage: "No data to display",
    loadingPage: "Loading...",
    loadingData: "Loading...",
    noEntriesText: "No entries yet.\nClick the button below to add a new entry.",
    noEntriesReadonlyText: "No entries",
    tabTitlePlaceholder: "New Panel",
    more: "More",
    tagboxDoneButtonCaption: "OK",
    selectToRankEmptyRankedAreaText: "All choices are selected for ranking",
    selectToRankEmptyUnrankedAreaText: "Drag choices here to rank them",
    ok: "OK",
    cancel: "Cancel",
    createCustomItem: "Create \"{0}\" item...",
    toc: "Table of contents",
    progressbar: "Progress bar",
};
// Uncomment the lines below if you create a custom dictionary.
// Replace "en" with a custom locale code (for example, "fr" or "de"),
// Replace `englishStrings` with the name of the variable that contains the custom dictionary.
//setupLocale({ localeCode: "en", strings: englishStrings, nativeName: "English", englishName: "English" });

var surveyLocalization = {
    currentLocaleValue: "",
    defaultLocaleValue: "en",
    locales: {},
    localeNames: {},
    localeNamesInEnglish: {},
    localeDirections: {},
    supportedLocales: [],
    useEnglishNames: false,
    //TODO remove on next week
    get showNamesInEnglish() { return this.useEnglishNames; },
    set showNamesInEnglish(val) { this.useEnglishNames = val; },
    setupLocale(localeConfig) {
        const loc = localeConfig.localeCode;
        this.locales[loc] = localeConfig.strings;
        this.localeNames[loc] = localeConfig.nativeName;
        this.localeNamesInEnglish[loc] = localeConfig.englishName;
        if (localeConfig.rtl !== undefined) {
            this.localeDirections[loc] = localeConfig.rtl ? "rtl" : "ltr";
        }
    },
    get currentLocale() {
        return this.currentLocaleValue === this.defaultLocaleValue ? "" : this.currentLocaleValue;
    },
    set currentLocale(val) {
        this.currentLocaleValue = this.getCorrectLocaleName(val);
    },
    get defaultLocale() {
        return this.defaultLocaleValue;
    },
    set defaultLocale(val) {
        this.defaultLocaleValue = this.getCorrectLocaleName(val);
    },
    getCorrectLocaleName(loc) {
        if (loc === "cz")
            loc = "cs";
        if (loc === "ua")
            loc = "uk";
        if (loc === "rs")
            loc = "sr";
        return loc;
    },
    getLocaleStrings(loc) {
        return this.locales[loc];
    },
    getString: function (strName, locale = null) {
        const locs = new Array();
        const addLocaleCore = (locName) => {
            const strs = this.locales[locName];
            if (!!strs)
                locs.push(strs);
        };
        const addLocale = (locName) => {
            if (!locName)
                return;
            addLocaleCore(locName);
            const index = locName.indexOf("-");
            if (index < 1)
                return;
            locName = locName.substring(0, index);
            addLocaleCore(locName);
        };
        addLocale(locale);
        addLocale(this.currentLocale);
        addLocale(this.defaultLocale);
        if (this.defaultLocale !== "en") {
            addLocaleCore("en");
        }
        for (let i = 0; i < locs.length; i++) {
            const res = locs[i][strName];
            if (res !== undefined)
                return res;
        }
        return this.onGetExternalString(strName, locale);
    },
    getLocaleName(loc, inEnglish) {
        if (!loc)
            return "";
        if (inEnglish === undefined)
            inEnglish = this.showNamesInEnglish;
        const firstNames = inEnglish ? this.localeNamesInEnglish : this.localeNames;
        const secondNames = inEnglish ? this.localeNames : this.localeNamesInEnglish;
        return firstNames[loc] || secondNames[loc] || loc;
    },
    getLocales: function (removeDefaultLoc = false) {
        var res = [];
        res.push("");
        var locs = this.locales;
        if (this.supportedLocales && this.supportedLocales.length > 0) {
            locs = {};
            for (var i = 0; i < this.supportedLocales.length; i++) {
                locs[this.supportedLocales[i]] = true;
            }
        }
        for (var key in locs) {
            if (removeDefaultLoc && key == this.defaultLocale)
                continue;
            res.push(key);
        }
        var locName = (loc) => {
            return this.getLocaleName(loc).toLowerCase();
        };
        res.sort((a, b) => {
            var str1 = locName(a);
            var str2 = locName(b);
            if (str1 === str2)
                return 0;
            return str1 < str2 ? -1 : 1;
        });
        return res;
    },
    onGetExternalString: function (name, locale) { return undefined; }
};
function getLocaleString(strName, locale = null) {
    return surveyLocalization.getString(strName, locale);
}
function getLocaleStrings(locale) {
    return surveyLocalization.getLocaleStrings(locale);
}
function setupLocale(localeConfig) {
    surveyLocalization.setupLocale(localeConfig);
}
var surveyStrings = englishStrings;
surveyLocalization.locales["en"] = englishStrings;
surveyLocalization.localeNames["en"] = "english";

function ensureLocString(target, options, key) {
    let locString = target.getLocalizableString(key);
    if (!locString) {
        let defaultStr;
        if (typeof options.localizable === "object" && options.localizable.defaultStr) {
            defaultStr = options.localizable.defaultStr;
        }
        locString = target.createLocalizableString(key, target, true, defaultStr);
        if (typeof options.localizable === "object" &&
            typeof options.localizable.onGetTextCallback === "function") {
            locString.onGetTextCallback = options.localizable.onGetTextCallback;
        }
    }
}
function getLocStringValue(target, options, key) {
    ensureLocString(target, options, key);
    let res = target.getLocalizableStringText(key);
    if (!!res)
        return res;
    if (typeof options.localizable === "object" && options.localizable.defaultStr) {
        const loc = !!target.getLocale ? target.getLocale() : "";
        return getLocaleString(options.localizable.defaultStr, loc);
    }
    return "";
}
function property(options = {}) {
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    return function (target, key) {
        let processComputedUpdater = (obj, val) => {
            if (!!val && typeof val === "object" && val.type === ComputedUpdater.ComputedUpdaterType) {
                Base.startCollectDependencies(() => obj[key] = val.updater(), obj, key);
                const result = val.updater();
                const dependencies = Base.finishCollectDependencies();
                val.setDependencies(dependencies);
                if (obj.dependencies[key]) {
                    obj.dependencies[key].dispose();
                }
                obj.dependencies[key] = val;
                return result;
            }
            return val;
        };
        if (!options || !options.localizable) {
            Object.defineProperty(target, key, {
                get: function () {
                    // const serializationProperty = Serializer.getProperty(target.getType(), key);
                    // if(!!serializationProperty && options.defaultValue !== undefined) {
                    //   ConsoleWarnings.error("remove defaultValue from @property for class " + target.getType() + " property name is " + key);
                    // }
                    let defaultVal = null;
                    if (!!options) {
                        if (typeof options.getDefaultValue === "function") {
                            defaultVal = options.getDefaultValue(this);
                        }
                        if (options.defaultValue !== undefined) {
                            defaultVal = options.defaultValue;
                        }
                    }
                    return this.getPropertyValue(key, defaultVal);
                },
                set: function (val) {
                    const newValue = processComputedUpdater(this, val);
                    const prevValue = this.getPropertyValue(key);
                    if (newValue !== prevValue) {
                        this.setPropertyValue(key, newValue);
                        if (!!options && options.onSet) {
                            options.onSet(newValue, this, prevValue);
                        }
                    }
                },
            });
        }
        else {
            Object.defineProperty(target, key, {
                get: function () {
                    return getLocStringValue(this, options, key);
                },
                set: function (val) {
                    ensureLocString(this, options, key);
                    const newValue = processComputedUpdater(this, val);
                    this.setLocalizableStringText(key, newValue);
                    if (!!options && options.onSet) {
                        options.onSet(newValue, this);
                    }
                },
            });
            Object.defineProperty(target, typeof options.localizable === "object" && !!options.localizable.name ?
                options.localizable.name : "loc" + key.charAt(0).toUpperCase() + key.slice(1), {
                get: function () {
                    ensureLocString(this, options, key);
                    return this.getLocalizableString(key);
                },
            });
        }
    };
}
function ensureArray(target, options, key) {
    target.ensureArray(key, (item, index) => {
        const handler = !!options ? options.onPush : null;
        handler && handler(item, index, target);
    }, (item, index) => {
        const handler = !!options ? options.onRemove : null;
        handler && handler(item, index, target);
    });
}
function propertyArray(options) {
    return function (target, key) {
        Object.defineProperty(target, key, {
            get: function () {
                ensureArray(this, options, key);
                return this.getPropertyValue(key);
            },
            set: function (val) {
                ensureArray(this, options, key);
                const arr = this.getPropertyValue(key);
                if (val === arr) {
                    return;
                }
                if (arr) {
                    arr.splice(0, arr.length, ...(val || []));
                }
                else {
                    this.setPropertyValue(key, val);
                }
                if (!!options && options.onSet) {
                    options.onSet(val, this);
                }
            },
        });
    };
}
/**
 * Contains information about a property of a survey element (page, panel, questions, and etc).
 * @see addProperty
 * @see removeProperty
 * @see [Add Properties](https://surveyjs.io/Documentation/Survey-Creator#addproperties)
 * @see [Remove Properties](https://surveyjs.io/Documentation/Survey-Creator#removeproperties)
 */
class JsonObjectProperty {
    constructor(classInfo, name, isRequired = false) {
        this.name = name;
        this.isRequiredValue = false;
        this.isUniqueValue = false;
        this.isSerializable = true;
        this.isLightSerializable = true;
        this.isCustom = false;
        this.isDynamicChoices = false; //TODO obsolete, use dependsOn attribute
        this.isBindable = false;
        this.category = "";
        this.categoryIndex = -1;
        this.visibleIndex = -1;
        this.maxLength = -1;
        this.isArray = false;
        this.classInfoValue = classInfo;
        this.isRequiredValue = isRequired;
        this.idValue = JsonObjectProperty.Index++;
    }
    get id() {
        return this.idValue;
    }
    get classInfo() {
        return this.classInfoValue;
    }
    get type() {
        return this.typeValue ? this.typeValue : "string";
    }
    set type(value) {
        if (value === "itemvalues")
            value = "itemvalue[]";
        if (value === "textitems")
            value = "textitem[]";
        this.typeValue = value;
        if (this.typeValue.indexOf("[]") === this.typeValue.length - 2) {
            this.isArray = true;
            this.className = this.typeValue.substring(0, this.typeValue.length - 2);
        }
    }
    get locationInTable() {
        const res = this.locationInTableValue;
        return res || "column";
    }
    set locationInTable(val) {
        this.locationInTableValue = val;
    }
    get showMode() {
        const res = this.locationInTableValue;
        return res === "detail" ? "form" : (res === "column" ? "list" : "");
    }
    set showMode(val) {
        this.locationInTable = val === "form" ? "detail" : (val === "list" ? "column" : undefined);
    }
    get isRequired() {
        return this.isRequiredValue;
    }
    set isRequired(val) {
        if (val !== this.isRequired) {
            this.isRequiredValue = val;
            if (!!this.classInfo) {
                this.classInfo.resetAllProperties();
            }
        }
    }
    get isUnique() {
        return this.isUniqueValue;
    }
    set isUnique(val) {
        this.isUniqueValue = val;
    }
    get uniquePropertyName() {
        return this.uniquePropertyValue;
    }
    set uniquePropertyName(val) {
        this.uniquePropertyValue = val;
    }
    isPropertySerializable(obj) {
        if (this.isSerializableFunc)
            return this.isSerializableFunc(obj);
        return this.isSerializable;
    }
    getDefaultValue(obj) {
        let result = !!this.defaultValueFunc ? this.defaultValueFunc(obj) : this.defaultValueValue;
        if (!!JsonObjectProperty.getItemValuesDefaultValue &&
            Serializer.isDescendantOf(this.className, "itemvalue")) {
            result = JsonObjectProperty.getItemValuesDefaultValue(this.defaultValueValue || [], this.className);
        }
        return result;
    }
    get defaultValue() {
        return this.getDefaultValue(undefined);
    }
    set defaultValue(newValue) {
        this.defaultValueValue = newValue;
        if (newValue !== undefined) {
            this.defaultValueFunc = undefined;
        }
    }
    isDefaultValue(value) {
        return this.isDefaultValueByObj(undefined, value);
    }
    isDefaultValueByObj(obj, value) {
        if (this.isLocalizable)
            return value === null || value === undefined;
        const dValue = this.getDefaultValue(obj);
        if (dValue !== undefined) {
            if (typeof dValue !== "object")
                return dValue === value;
            return Helpers.isTwoValueEquals(value, dValue, false, true, false);
        }
        return ((value === false && (this.type == "boolean" || this.type == "switch") && !this.defaultValueFunc) ||
            value === "" || Helpers.isValueEmpty(value));
    }
    getSerializableValue(obj, storeDefaults) {
        if (!!this.onSerializeValue)
            return this.onSerializeValue(obj);
        const value = this.getValue(obj);
        if (value === undefined || value === null)
            return undefined;
        if (!storeDefaults && this.isDefaultValueByObj(obj, value))
            return undefined;
        return value;
    }
    getValue(obj) {
        if (this.onGetValue) {
            obj = this.getOriginalObj(obj);
            return this.onGetValue(obj);
        }
        if (this.serializationProperty && !!obj[this.serializationProperty])
            return obj[this.serializationProperty].getJson();
        return obj[this.name];
    }
    getPropertyValue(obj) {
        if (this.isLocalizable) {
            return !!obj[this.serializationProperty]
                ? obj[this.serializationProperty].text
                : null;
        }
        return this.getValue(obj);
    }
    get hasToUseSetValue() {
        return this.onSetValue || this.serializationProperty;
    }
    settingValue(obj, value) {
        if (!this.onSettingValue || obj.isLoadingFromJson)
            return value;
        return this.onSettingValue(obj, value);
    }
    setValue(obj, value, jsonConv) {
        if (this.onSetValue) {
            obj = this.getOriginalObj(obj);
            this.onSetValue(obj, value, jsonConv);
        }
        else {
            if (this.serializationProperty && !!obj[this.serializationProperty])
                obj[this.serializationProperty].setJson(value, true);
            else {
                if (value && typeof value === "string") {
                    if (this.type == "number") {
                        value = parseInt(value);
                    }
                    if (this.type == "boolean" || this.type == "switch") {
                        value = value.toLowerCase() === "true";
                    }
                }
                obj[this.name] = value;
            }
        }
    }
    validateValue(value) {
        const choices = this.choices;
        if (!Array.isArray(choices) || choices.length === 0)
            return true;
        return choices.indexOf(value) > -1;
    }
    getObjType(objType) {
        if (!this.classNamePart)
            return objType;
        return objType.replace(this.classNamePart, "");
    }
    /**
     * Depricated, please use getChoices
     */
    get choices() {
        return this.getChoices(null);
    }
    get hasChoices() {
        return !!this.choicesValue || !!this.choicesfunc;
    }
    getChoices(obj, choicesCallback = null) {
        if (this.choicesValue != null)
            return this.choicesValue;
        if (this.choicesfunc != null)
            return this.choicesfunc(obj, choicesCallback);
        return null;
    }
    setChoices(value, valueFunc = null) {
        this.choicesValue = value;
        this.choicesfunc = valueFunc;
    }
    getBaseValue() {
        if (!this.baseValue)
            return "";
        if (typeof this.baseValue == "function")
            return this.baseValue();
        return this.baseValue;
    }
    setBaseValue(val) {
        this.baseValue = val;
    }
    get readOnly() {
        return this.readOnlyValue != null ? this.readOnlyValue : false;
    }
    set readOnly(val) {
        this.readOnlyValue = val;
    }
    isEnable(obj) {
        if (this.readOnly)
            return false;
        if (!obj || !this.enableIf)
            return true;
        return this.enableIf(this.getOriginalObj(obj));
    }
    isVisible(layout, obj = null) {
        let isLayout = !this.layout || !layout || this.layout === layout;
        if (!this.visible || !isLayout)
            return false;
        if (!!this.visibleIf && !!obj) {
            return this.visibleIf(this.getOriginalObj(obj));
        }
        return true;
    }
    getOriginalObj(obj) {
        if (obj && obj.getOriginalObj) {
            const orjObj = obj.getOriginalObj();
            if (orjObj && Serializer.findProperty(orjObj.getType(), this.name)) {
                return orjObj;
            }
        }
        return obj;
    }
    get visible() {
        return this.visibleValue != null ? this.visibleValue : true;
    }
    set visible(val) {
        this.visibleValue = val;
    }
    isAvailableInVersion(ver) {
        if (!!this.alternativeName || this.oldName)
            return true;
        return this.isAvailableInVersionCore(ver);
    }
    getSerializedName(ver) {
        if (!this.alternativeName)
            return this.name;
        return this.isAvailableInVersionCore(ver) ? this.name : this.alternativeName || this.oldName;
    }
    getSerializedProperty(obj, ver) {
        if (!this.oldName || this.isAvailableInVersionCore(ver))
            return this;
        if (!obj || !obj.getType)
            return null;
        return Serializer.findProperty(obj.getType(), this.oldName);
    }
    isAvailableInVersionCore(ver) {
        if (!ver || !this.version)
            return true;
        return Helpers.compareVerions(this.version, ver) <= 0;
    }
    get isLocalizable() {
        return this.isLocalizableValue != null ? this.isLocalizableValue : false;
    }
    set isLocalizable(val) {
        this.isLocalizableValue = val;
    }
    get dataList() {
        return Array.isArray(this.dataListValue) ? this.dataListValue : [];
    }
    set dataList(val) {
        this.dataListValue = val;
    }
    mergeWith(prop) {
        var valuesNames = JsonObjectProperty.mergableValues;
        for (var i = 0; i < valuesNames.length; i++) {
            this.mergeValue(prop, valuesNames[i]);
        }
    }
    addDependedProperty(name) {
        if (!this.dependedProperties) {
            this.dependedProperties = [];
        }
        if (this.dependedProperties.indexOf(name) < 0) {
            this.dependedProperties.push(name);
        }
    }
    getDependedProperties() {
        return !!this.dependedProperties ? this.dependedProperties : [];
    }
    schemaType() {
        if (this.className === "choicesByUrl")
            return undefined;
        if (this.className === "string")
            return this.className;
        if (!!this.className)
            return "array";
        if (!!this.baseClassName)
            return "array";
        if (this.type == "switch")
            return "boolean";
        if (this.type == "boolean" || this.type == "number")
            return this.type;
        return "string";
    }
    schemaRef() {
        if (!!this.className)
            return this.className;
        return undefined;
    }
    mergeValue(prop, valueName) {
        if (this[valueName] == null && prop[valueName] != null) {
            this[valueName] = prop[valueName];
        }
    }
}
JsonObjectProperty.Index = 1;
JsonObjectProperty.mergableValues = [
    "typeValue",
    "choicesValue",
    "baseValue",
    "readOnlyValue",
    "visibleValue",
    "isSerializable",
    "isLightSerializable",
    "isCustom",
    "isBindable",
    "isUnique",
    "uniquePropertyName",
    "isDynamicChoices",
    "isLocalizableValue",
    "className",
    "alternativeName",
    "oldName",
    "layout",
    "version",
    "classNamePart",
    "baseClassName",
    "defaultValue",
    "defaultValueFunc",
    "serializationProperty",
    "onGetValue",
    "onSetValue",
    "onSettingValue",
    "displayName",
    "category",
    "categoryIndex",
    "visibleIndex",
    "nextToProperty",
    "overridingProperty",
    "locationInTable",
    "dependedProperties",
    "visibleIf",
    "enableIf",
    "onExecuteExpression",
    "onPropertyEditorUpdate",
    "maxLength",
    "maxValue",
    "minValue",
    "dataListValue",
];
class CustomPropertiesCollection {
    static addProperty(className, property) {
        className = className.toLowerCase();
        var props = CustomPropertiesCollection.properties;
        if (!props[className]) {
            props[className] = [];
        }
        props[className].push(property);
    }
    static removeProperty(className, propertyName) {
        className = className.toLowerCase();
        var props = CustomPropertiesCollection.properties;
        if (!props[className])
            return;
        var properties = props[className];
        for (var i = 0; i < properties.length; i++) {
            if (properties[i].name == propertyName) {
                props[className].splice(i, 1);
                break;
            }
        }
    }
    static removeAllProperties(className) {
        className = className.toLowerCase();
        delete CustomPropertiesCollection.properties[className];
    }
    static addClass(className, parentClassName) {
        className = className.toLowerCase();
        if (parentClassName) {
            parentClassName = parentClassName.toLowerCase();
        }
        CustomPropertiesCollection.parentClasses[className] = parentClassName;
    }
    static getProperties(className) {
        className = className.toLowerCase();
        var res = [];
        var props = CustomPropertiesCollection.properties;
        while (className) {
            var properties = props[className];
            if (properties) {
                for (var i = 0; i < properties.length; i++) {
                    res.push(properties[i]);
                }
            }
            className = CustomPropertiesCollection.parentClasses[className];
        }
        return res;
    }
    static createProperties(obj) {
        if (!obj || !obj.getType)
            return;
        CustomPropertiesCollection.createPropertiesCore(obj, obj.getType());
    }
    static createPropertiesCore(obj, className) {
        var props = CustomPropertiesCollection.properties;
        if (props[className]) {
            CustomPropertiesCollection.createPropertiesInObj(obj, props[className]);
        }
        var parentClass = CustomPropertiesCollection.parentClasses[className];
        if (parentClass) {
            CustomPropertiesCollection.createPropertiesCore(obj, parentClass);
        }
    }
    static createPropertiesInObj(obj, properties) {
        for (var i = 0; i < properties.length; i++) {
            CustomPropertiesCollection.createPropertyInObj(obj, properties[i]);
        }
    }
    static createPropertyInObj(obj, prop) {
        if (CustomPropertiesCollection.checkIsPropertyExists(obj, prop.name))
            return;
        if (!!prop.serializationProperty && CustomPropertiesCollection.checkIsPropertyExists(obj, prop.serializationProperty))
            return;
        if (prop.isLocalizable &&
            prop.serializationProperty &&
            obj.createCustomLocalizableObj) {
            const locStr = obj.createCustomLocalizableObj(prop.name);
            locStr.defaultValue = prop.getDefaultValue(obj);
            var locDesc = {
                get: function () {
                    return obj.getLocalizableString(prop.name);
                },
            };
            Object.defineProperty(obj, prop.serializationProperty, locDesc);
            var desc = {
                get: function () {
                    return obj.getLocalizableStringText(prop.name);
                },
                set: function (v) {
                    obj.setLocalizableStringText(prop.name, v);
                },
            };
            Object.defineProperty(obj, prop.name, desc);
        }
        else {
            var isArrayProp = prop.isArray || prop.type === "multiplevalues";
            if (typeof obj.createNewArray === "function") {
                if (Serializer.isDescendantOf(prop.className, "itemvalue")) {
                    obj.createNewArray(prop.name, function (item) {
                        item.locOwner = obj;
                        item.ownerPropertyName = prop.name;
                    });
                    isArrayProp = true;
                }
                else {
                    //It is a simple array property
                    if (isArrayProp) {
                        obj.createNewArray(prop.name);
                    }
                }
                if (isArrayProp) {
                    const defaultValue = prop.getDefaultValue(obj);
                    if (Array.isArray(defaultValue)) {
                        obj.setPropertyValue(prop.name, defaultValue);
                    }
                }
            }
            if (!!obj.getPropertyValue && !!obj.setPropertyValue) {
                var desc = {
                    get: () => {
                        if (!!prop.onGetValue) {
                            return prop.onGetValue(obj);
                        }
                        return obj.getPropertyValue(prop.name, undefined);
                    },
                    set: function (v) {
                        if (!!prop.onSetValue) {
                            prop.onSetValue(obj, v, null);
                        }
                        else {
                            obj.setPropertyValue(prop.name, v);
                        }
                    },
                };
                Object.defineProperty(obj, prop.name, desc);
            }
        }
        if (prop.type === "condition" || prop.type === "expression") {
            if (!!prop.onExecuteExpression) {
                obj.addExpressionProperty(prop.name, prop.onExecuteExpression);
            }
        }
    }
    static checkIsPropertyExists(obj, name) {
        return obj.hasOwnProperty(name) || obj[name];
    }
}
CustomPropertiesCollection.properties = {};
CustomPropertiesCollection.parentClasses = {};
class JsonMetadataClass {
    constructor(name, properties, creator = null, parentName = null) {
        this.name = name;
        this.creator = creator;
        this.parentName = parentName;
        name = name.toLowerCase();
        this.isCustomValue = !creator && name !== "survey";
        if (this.parentName) {
            this.parentName = this.parentName.toLowerCase();
            CustomPropertiesCollection.addClass(name, this.parentName);
            if (!!creator) {
                this.makeParentRegularClass();
            }
        }
        this.properties = new Array();
        for (var i = 0; i < properties.length; i++) {
            this.createProperty(properties[i], this.isCustom);
        }
    }
    //Obsolete
    find(name) {
        for (var i = 0; i < this.properties.length; i++) {
            if (this.properties[i].name == name)
                return this.properties[i];
        }
        return null;
    }
    findProperty(name) {
        this.fillAllProperties();
        return this.hashProperties[name];
    }
    getAllProperties() {
        this.fillAllProperties();
        return this.allProperties;
    }
    getRequiredProperties() {
        if (!!this.requiredProperties)
            return this.requiredProperties;
        this.requiredProperties = [];
        const props = this.getAllProperties();
        for (let i = 0; i < props.length; i++) {
            if (props[i].isRequired)
                this.requiredProperties.push(props[i]);
        }
        return this.requiredProperties;
    }
    resetAllProperties() {
        this.allProperties = undefined;
        this.requiredProperties = undefined;
        this.hashProperties = undefined;
        var childClasses = Serializer.getChildrenClasses(this.name);
        for (var i = 0; i < childClasses.length; i++) {
            childClasses[i].resetAllProperties();
        }
    }
    get isCustom() { return this.isCustomValue; }
    fillAllProperties() {
        if (!!this.allProperties)
            return;
        this.allProperties = [];
        this.hashProperties = {};
        const localProperties = {};
        this.properties.forEach(prop => localProperties[prop.name] = prop);
        const parentClass = !!this.parentName ? Serializer.findClass(this.parentName) : null;
        if (!!parentClass) {
            const parentProperties = parentClass.getAllProperties();
            parentProperties.forEach(prop => {
                const overridedProp = localProperties[prop.name];
                if (!!overridedProp) {
                    overridedProp.mergeWith(prop);
                    this.addPropCore(overridedProp);
                }
                else {
                    this.addPropCore(prop);
                }
            });
        }
        this.properties.forEach(prop => {
            if (!this.hashProperties[prop.name]) {
                this.addPropCore(prop);
            }
        });
    }
    addPropCore(prop) {
        this.allProperties.push(prop);
        this.hashProperties[prop.name] = prop;
        if (!!prop.alternativeName) {
            this.hashProperties[prop.alternativeName] = prop;
        }
    }
    isOverridedProp(propName) {
        return !!this.parentName && !!Serializer.findProperty(this.parentName, propName);
    }
    hasRegularChildClass() {
        if (!this.isCustom)
            return;
        this.isCustomValue = false;
        for (var i = 0; i < this.properties.length; i++) {
            this.properties[i].isCustom = false;
        }
        CustomPropertiesCollection.removeAllProperties(this.name);
        this.makeParentRegularClass();
    }
    makeParentRegularClass() {
        if (!this.parentName)
            return;
        const parent = Serializer.findClass(this.parentName);
        if (!!parent) {
            parent.hasRegularChildClass();
        }
    }
    createProperty(propInfo, isCustom = false) {
        var propertyName = typeof propInfo === "string" ? propInfo : propInfo.name;
        if (!propertyName)
            return;
        var propertyType = null;
        var typeIndex = propertyName.indexOf(JsonMetadataClass.typeSymbol);
        if (typeIndex > -1) {
            propertyType = propertyName.substring(typeIndex + 1);
            propertyName = propertyName.substring(0, typeIndex);
        }
        var isRequired = this.getIsPropertyNameRequired(propertyName) || !!propInfo.isRequired;
        propertyName = this.getPropertyName(propertyName);
        var prop = new JsonObjectProperty(this, propertyName, isRequired);
        if (propertyType) {
            prop.type = propertyType;
        }
        if (typeof propInfo === "object") {
            if (propInfo.type) {
                prop.type = propInfo.type;
            }
            if (propInfo.default !== undefined) {
                prop.defaultValue = propInfo.default;
            }
            if (propInfo.defaultFunc !== undefined) {
                prop.defaultValueFunc = propInfo.defaultFunc;
            }
            if (!Helpers.isValueEmpty(propInfo.isSerializable)) {
                prop.isSerializable = propInfo.isSerializable;
            }
            if (!Helpers.isValueEmpty(propInfo.isSerializableFunc)) {
                prop.isSerializableFunc = propInfo.isSerializableFunc;
            }
            if (!Helpers.isValueEmpty(propInfo.isLightSerializable)) {
                prop.isLightSerializable = propInfo.isLightSerializable;
            }
            if (!Helpers.isValueEmpty(propInfo.maxLength)) {
                prop.maxLength = propInfo.maxLength;
            }
            if (propInfo.displayName !== undefined) {
                prop.displayName = propInfo.displayName;
            }
            if (!Helpers.isValueEmpty(propInfo.category)) {
                prop.category = propInfo.category;
            }
            if (!Helpers.isValueEmpty(propInfo.categoryIndex)) {
                prop.categoryIndex = propInfo.categoryIndex;
            }
            if (!Helpers.isValueEmpty(propInfo.nextToProperty)) {
                prop.nextToProperty = propInfo.nextToProperty;
            }
            if (!Helpers.isValueEmpty(propInfo.overridingProperty)) {
                prop.overridingProperty = propInfo.overridingProperty;
            }
            if (!Helpers.isValueEmpty(propInfo.visibleIndex)) {
                prop.visibleIndex = propInfo.visibleIndex;
            }
            if (!Helpers.isValueEmpty(propInfo.showMode)) {
                prop.showMode = propInfo.showMode;
            }
            if (!Helpers.isValueEmpty(propInfo.locationInTable)) {
                prop.locationInTable = propInfo.locationInTable;
            }
            if (!Helpers.isValueEmpty(propInfo.maxValue)) {
                prop.maxValue = propInfo.maxValue;
            }
            if (!Helpers.isValueEmpty(propInfo.minValue)) {
                prop.minValue = propInfo.minValue;
            }
            if (!Helpers.isValueEmpty(propInfo.dataList)) {
                prop.dataList = propInfo.dataList;
            }
            if (!Helpers.isValueEmpty(propInfo.isDynamicChoices)) {
                prop.isDynamicChoices = propInfo.isDynamicChoices;
            }
            if (!Helpers.isValueEmpty(propInfo.isBindable)) {
                prop.isBindable = propInfo.isBindable;
            }
            if (!Helpers.isValueEmpty(propInfo.isUnique)) {
                prop.isUnique = propInfo.isUnique;
            }
            if (!Helpers.isValueEmpty(propInfo.uniqueProperty)) {
                prop.uniquePropertyName = propInfo.uniqueProperty;
            }
            if (!Helpers.isValueEmpty(propInfo.isArray)) {
                prop.isArray = propInfo.isArray;
            }
            if (propInfo.visible === true || propInfo.visible === false) {
                prop.visible = propInfo.visible;
            }
            if (!!propInfo.visibleIf) {
                prop.visibleIf = propInfo.visibleIf;
            }
            if (!!propInfo.enableIf) {
                prop.enableIf = propInfo.enableIf;
            }
            if (!!propInfo.onExecuteExpression) {
                prop.onExecuteExpression = propInfo.onExecuteExpression;
            }
            if (!!propInfo.onPropertyEditorUpdate) {
                prop.onPropertyEditorUpdate = propInfo.onPropertyEditorUpdate;
            }
            if (propInfo.readOnly === true) {
                prop.readOnly = true;
            }
            if (propInfo.availableInMatrixColumn === true) {
                prop.availableInMatrixColumn = true;
            }
            if (propInfo.choices) {
                var choicesFunc = typeof propInfo.choices === "function" ? propInfo.choices : null;
                var choicesValue = typeof propInfo.choices !== "function" ? propInfo.choices : null;
                prop.setChoices(choicesValue, choicesFunc);
            }
            if (!!propInfo.baseValue) {
                prop.setBaseValue(propInfo.baseValue);
            }
            if (propInfo.onSerializeValue) {
                prop.onSerializeValue = propInfo.onSerializeValue;
            }
            if (propInfo.onGetValue) {
                prop.onGetValue = propInfo.onGetValue;
            }
            if (propInfo.onSetValue) {
                prop.onSetValue = propInfo.onSetValue;
            }
            if (propInfo.onSettingValue) {
                prop.onSettingValue = propInfo.onSettingValue;
            }
            if (propInfo.isLocalizable) {
                propInfo.serializationProperty = "loc" + prop.name;
            }
            if (propInfo.serializationProperty) {
                prop.serializationProperty = propInfo.serializationProperty;
                if (prop.serializationProperty &&
                    prop.serializationProperty.indexOf("loc") == 0) {
                    prop.isLocalizable = true;
                }
            }
            if (propInfo.isLocalizable) {
                prop.isLocalizable = propInfo.isLocalizable;
            }
            if (propInfo.className) {
                prop.className = propInfo.className;
            }
            if (propInfo.baseClassName) {
                prop.baseClassName = propInfo.baseClassName;
                prop.isArray = true;
            }
            if (prop.isArray === true) {
                prop.isArray = true;
            }
            if (propInfo.classNamePart) {
                prop.classNamePart = propInfo.classNamePart;
            }
            if (propInfo.alternativeName) {
                prop.alternativeName = propInfo.alternativeName;
            }
            if (propInfo.oldName) {
                prop.oldName = propInfo.oldName;
            }
            if (propInfo.layout) {
                prop.layout = propInfo.layout;
            }
            if (propInfo.version) {
                prop.version = propInfo.version;
            }
            if (propInfo.dependsOn) {
                this.addDependsOnProperties(prop, propInfo.dependsOn);
            }
        }
        this.properties.push(prop);
        if (isCustom && !this.isOverridedProp(prop.name)) {
            prop.isCustom = true;
            CustomPropertiesCollection.addProperty(this.name, prop);
        }
        return prop;
    }
    addDependsOnProperties(prop, dependsOn) {
        const dArray = Array.isArray(dependsOn) ? dependsOn : [dependsOn];
        prop.dependsOn = dArray;
        for (var i = 0; i < dArray.length; i++) {
            this.addDependsOnProperty(prop, dArray[i]);
        }
    }
    addDependsOnProperty(prop, dependsOn) {
        var property = this.find(dependsOn);
        if (!property) {
            property = Serializer.findProperty(this.parentName, dependsOn);
        }
        if (!property)
            return;
        property.addDependedProperty(prop.name);
    }
    getIsPropertyNameRequired(propertyName) {
        return (propertyName.length > 0 &&
            propertyName[0] == JsonMetadataClass.requiredSymbol);
    }
    getPropertyName(propertyName) {
        if (!this.getIsPropertyNameRequired(propertyName))
            return propertyName;
        propertyName = propertyName.slice(1);
        return propertyName;
    }
}
JsonMetadataClass.requiredSymbol = "!";
JsonMetadataClass.typeSymbol = ":";
/**
 * The metadata object. It contains object properties' runtime information and allows you to modify it.
 */
class JsonMetadata {
    constructor() {
        this.classes = {};
        this.alternativeNames = {};
        this.childrenClasses = {};
        this.dynamicPropsCache = {};
    }
    getObjPropertyValue(obj, name) {
        if (this.isObjWrapper(obj) && this.isNeedUseObjWrapper(obj, name)) {
            const orignalObj = obj.getOriginalObj();
            const prop = Serializer.findProperty(orignalObj.getType(), name);
            if (!!prop)
                return this.getObjPropertyValueCore(orignalObj, prop);
        }
        const prop = Serializer.findProperty(obj.getType(), name);
        if (!prop)
            return obj[name];
        return this.getObjPropertyValueCore(obj, prop);
    }
    setObjPropertyValue(obj, name, val) {
        if (obj[name] === val)
            return;
        if (!!obj[name] && !!obj[name].setJson) {
            obj[name].setJson(val, true);
        }
        else {
            if (Array.isArray(val)) {
                const newVal = [];
                for (var i = 0; i < val.length; i++)
                    newVal.push(val[i]);
                val = newVal;
            }
            obj[name] = val;
        }
    }
    getObjPropertyValueCore(obj, prop) {
        if (!prop.isPropertySerializable(obj))
            return obj[prop.name];
        if (prop.isLocalizable) {
            if (prop.isArray)
                return obj[prop.name];
            const locStr = obj.getLocalizableString(prop.name);
            if (!!locStr) {
                if (locStr.isDefautlLocale)
                    return locStr.text;
                return locStr.getValue(locStr.locale);
            }
            if (!!prop.serializationProperty)
                return obj[prop.serializationProperty].text;
        }
        return obj.getPropertyValue(prop.name);
    }
    isObjWrapper(obj) {
        return !!obj.getOriginalObj && !!obj.getOriginalObj();
    }
    isNeedUseObjWrapper(obj, name) {
        if (!obj.getDynamicProperties)
            return true;
        const props = obj.getDynamicProperties();
        if (!Array.isArray(props))
            return false;
        for (let i = 0; i < props.length; i++) {
            if (props[i].name === name)
                return true;
        }
        return false;
    }
    addClass(name, properties, creator = null, parentName = null) {
        name = name.toLowerCase();
        var metaDataClass = new JsonMetadataClass(name, properties, creator, parentName);
        this.classes[name] = metaDataClass;
        if (parentName) {
            parentName = parentName.toLowerCase();
            var children = this.childrenClasses[parentName];
            if (!children) {
                this.childrenClasses[parentName] = [];
            }
            this.childrenClasses[parentName].push(metaDataClass);
        }
        return metaDataClass;
    }
    removeClass(name) {
        var metaClass = this.findClass(name);
        if (!metaClass)
            return;
        delete this.classes[metaClass.name];
        if (!!metaClass.parentName) {
            var index = this.childrenClasses[metaClass.parentName].indexOf(metaClass);
            if (index > -1) {
                this.childrenClasses[metaClass.parentName].splice(index, 1);
            }
        }
    }
    overrideClassCreatore(name, creator) {
        this.overrideClassCreator(name, creator);
    }
    overrideClassCreator(name, creator) {
        name = name.toLowerCase();
        var metaDataClass = this.findClass(name);
        if (metaDataClass) {
            metaDataClass.creator = creator;
        }
    }
    getProperties(className) {
        var metaClass = this.findClass(className);
        if (!metaClass)
            return [];
        return metaClass.getAllProperties();
    }
    getPropertiesByObj(obj) {
        const type = !!obj && !!obj.getType ? obj.getType() : undefined;
        if (!type)
            return [];
        const props = this.getProperties(type);
        const dynamicProps = this.getDynamicPropertiesByObj(obj);
        for (let i = dynamicProps.length - 1; i >= 0; i--) {
            if (this.findProperty(type, dynamicProps[i].name)) {
                dynamicProps.splice(i, 1);
            }
        }
        if (dynamicProps.length === 0)
            return props;
        return [].concat(props).concat(dynamicProps);
    }
    addDynamicPropertiesIntoObj(dest, src, props) {
        props.forEach(prop => {
            this.addDynamicPropertyIntoObj(dest, src, prop.name, false);
            if (prop.serializationProperty) {
                this.addDynamicPropertyIntoObj(dest, src, prop.serializationProperty, true);
            }
            if (prop.alternativeName) {
                this.addDynamicPropertyIntoObj(dest, src, prop.alternativeName, false);
            }
        });
    }
    addDynamicPropertyIntoObj(dest, src, propName, isReadOnly) {
        var desc = {
            configurable: true,
            get: function () {
                return src[propName];
            },
        };
        if (!isReadOnly) {
            desc["set"] = function (v) {
                src[propName] = v;
            };
        }
        Object.defineProperty(dest, propName, desc);
    }
    getDynamicPropertiesByObj(obj, dynamicType = null) {
        if (!obj || !obj.getType)
            return [];
        if (!!obj.getDynamicProperties)
            return obj.getDynamicProperties();
        if (!obj.getDynamicType && !dynamicType)
            return [];
        const dType = !!dynamicType ? dynamicType : obj.getDynamicType();
        return this.getDynamicPropertiesByTypes(obj.getType(), dType);
    }
    getDynamicPropertiesByTypes(objType, dynamicType, nonSerialableProps) {
        if (!dynamicType)
            return [];
        const cacheType = dynamicType + "-" + objType;
        if (this.dynamicPropsCache[cacheType])
            return this.dynamicPropsCache[cacheType];
        var dynamicProps = this.getProperties(dynamicType);
        if (!dynamicProps || dynamicProps.length == 0)
            return [];
        const hash = {};
        const props = this.getProperties(objType);
        for (var i = 0; i < props.length; i++) {
            hash[props[i].name] = props[i];
        }
        const res = [];
        if (!nonSerialableProps)
            nonSerialableProps = [];
        for (let i = 0; i < dynamicProps.length; i++) {
            const dProp = dynamicProps[i];
            if (this.canAddDybamicProp(dProp, hash[dProp.name])) {
                if (nonSerialableProps.indexOf(dProp.name) > -1) {
                    dProp.visible = false;
                    dProp.isSerializable = false;
                }
                res.push(dProp);
            }
        }
        this.dynamicPropsCache[cacheType] = res;
        return res;
    }
    canAddDybamicProp(dProp, orgProp) {
        if (!orgProp)
            return true;
        if (dProp === orgProp)
            return false;
        let classInfo = dProp.classInfo;
        while (classInfo && classInfo.parentName) {
            dProp = this.findProperty(classInfo.parentName, dProp.name);
            if (dProp && dProp === orgProp)
                return true;
            classInfo = !!dProp ? dProp.classInfo : undefined;
        }
        return false;
    }
    hasOriginalProperty(obj, propName) {
        return !!this.getOriginalProperty(obj, propName);
    }
    getOriginalProperty(obj, propName) {
        var res = this.findProperty(obj.getType(), propName);
        if (!!res)
            return res;
        if (this.isObjWrapper(obj))
            return this.findProperty(obj.getOriginalObj().getType(), propName);
        return null;
    }
    getProperty(className, propertyName) {
        const prop = this.findProperty(className, propertyName);
        if (!prop)
            return prop;
        const classInfo = this.findClass(className);
        if (prop.classInfo === classInfo)
            return prop;
        const newProp = new JsonObjectProperty(classInfo, prop.name, prop.isRequired);
        newProp.mergeWith(prop);
        newProp.isArray = prop.isArray;
        classInfo.properties.push(newProp);
        classInfo.resetAllProperties();
        return newProp;
    }
    findProperty(className, propertyName) {
        const cl = this.findClass(className);
        return !!cl ? cl.findProperty(propertyName) : null;
    }
    findProperties(className, propertyNames) {
        var result = new Array();
        const cl = this.findClass(className);
        if (!cl)
            return result;
        for (var i = 0; i < propertyNames.length; i++) {
            var prop = cl.findProperty(propertyNames[i]);
            if (prop) {
                result.push(prop);
            }
        }
        return result;
    }
    getAllPropertiesByName(propertyName) {
        var res = new Array();
        var classes = this.getAllClasses();
        for (var i = 0; i < classes.length; i++) {
            var classInfo = this.findClass(classes[i]);
            for (var j = 0; j < classInfo.properties.length; j++) {
                if (classInfo.properties[j].name == propertyName) {
                    res.push(classInfo.properties[j]);
                    break;
                }
            }
        }
        return res;
    }
    getAllClasses() {
        var res = new Array();
        for (var name in this.classes) {
            res.push(name);
        }
        return res;
    }
    createClass(name, json = undefined) {
        name = name.toLowerCase();
        var metaDataClass = this.findClass(name);
        if (!metaDataClass)
            return null;
        if (metaDataClass.creator)
            return metaDataClass.creator(json);
        var parentName = metaDataClass.parentName;
        while (parentName) {
            metaDataClass = this.findClass(parentName);
            if (!metaDataClass)
                return null;
            parentName = metaDataClass.parentName;
            if (metaDataClass.creator)
                return this.createCustomType(name, metaDataClass.creator, json);
        }
        return null;
    }
    createCustomType(name, creator, json = undefined) {
        name = name.toLowerCase();
        var res = creator(json);
        var customTypeName = name;
        var customTemplateName = res.getTemplate
            ? res.getTemplate()
            : res.getType();
        res.getType = function () {
            return customTypeName;
        };
        res.getTemplate = function () {
            return customTemplateName;
        };
        CustomPropertiesCollection.createProperties(res);
        return res;
    }
    getChildrenClasses(name, canBeCreated = false) {
        name = name.toLowerCase();
        var result = [];
        this.fillChildrenClasses(name, canBeCreated, result);
        return result;
    }
    getRequiredProperties(name) {
        const metaClass = this.findClass(name);
        if (!metaClass)
            return [];
        const props = metaClass.getRequiredProperties();
        var res = [];
        for (var i = 0; i < props.length; i++) {
            res.push(props[i].name);
        }
        return res;
    }
    addProperties(className, propertiesInfos) {
        className = className.toLowerCase();
        var metaDataClass = this.findClass(className);
        for (var i = 0; i < propertiesInfos.length; i++) {
            this.addCustomPropertyCore(metaDataClass, propertiesInfos[i]);
        }
    }
    addProperty(className, propertyInfo) {
        return this.addCustomPropertyCore(this.findClass(className), propertyInfo);
    }
    addCustomPropertyCore(metaDataClass, propertyInfo) {
        if (!metaDataClass)
            return null;
        var property = metaDataClass.createProperty(propertyInfo, true);
        if (property) {
            this.clearDynamicPropsCache(metaDataClass);
            metaDataClass.resetAllProperties();
        }
        return property;
    }
    removeProperty(className, propertyName) {
        var metaDataClass = this.findClass(className);
        if (!metaDataClass)
            return false;
        var property = metaDataClass.find(propertyName);
        if (property) {
            this.clearDynamicPropsCache(metaDataClass);
            this.removePropertyFromClass(metaDataClass, property);
            metaDataClass.resetAllProperties();
            CustomPropertiesCollection.removeProperty(metaDataClass.name, propertyName);
        }
    }
    clearDynamicPropsCache(metaDataClass) {
        this.dynamicPropsCache = {};
    }
    removePropertyFromClass(metaDataClass, property) {
        var index = metaDataClass.properties.indexOf(property);
        if (index < 0)
            return;
        metaDataClass.properties.splice(index, 1);
    }
    fillChildrenClasses(name, canBeCreated, result) {
        var children = this.childrenClasses[name];
        if (!children)
            return;
        for (var i = 0; i < children.length; i++) {
            if (!canBeCreated || children[i].creator) {
                result.push(children[i]);
            }
            this.fillChildrenClasses(children[i].name, canBeCreated, result);
        }
    }
    findClass(name) {
        name = name.toLowerCase();
        var res = this.classes[name];
        if (!res) {
            var newName = this.alternativeNames[name];
            if (!!newName && newName != name)
                return this.findClass(newName);
        }
        return res;
    }
    isDescendantOf(className, ancestorClassName) {
        if (!className || !ancestorClassName) {
            return false;
        }
        className = className.toLowerCase();
        ancestorClassName = ancestorClassName.toLowerCase();
        var class_ = this.findClass(className);
        if (!class_) {
            return false;
        }
        var parentClass = class_;
        do {
            if (parentClass.name === ancestorClassName) {
                return true;
            }
            parentClass = this.classes[parentClass.parentName];
        } while (!!parentClass);
        return false;
    }
    addAlterNativeClassName(name, alternativeName) {
        this.alternativeNames[alternativeName.toLowerCase()] = name.toLowerCase();
    }
    generateSchema(className = undefined) {
        if (!className)
            className = "survey";
        var classInfo = this.findClass(className);
        if (!classInfo)
            return null;
        var res = {
            $schema: "http://json-schema.org/draft-07/schema#",
            title: "SurveyJS Library json schema",
            type: "object",
            properties: {},
            definitions: { locstring: this.generateLocStrClass() },
        };
        this.generateSchemaProperties(classInfo, res, res.definitions, true);
        return res;
    }
    generateLocStrClass() {
        const props = {};
        const locProp = Serializer.findProperty("survey", "locale");
        if (!!locProp) {
            const choices = locProp.getChoices(null);
            if (Array.isArray(choices)) {
                if (choices.indexOf("en") < 0) {
                    choices.splice(0, 0, "en");
                }
                choices.splice(0, 0, "default");
                choices.forEach(l => { if (!!l) {
                    props[l] = { type: "string" };
                } });
            }
        }
        return {
            $id: "locstring",
            type: "object",
            properties: props
        };
    }
    generateSchemaProperties(classInfo, classSchema, schemaDef, isRoot) {
        if (!classInfo)
            return;
        const schemaProperties = classSchema.properties;
        const requiredProps = [];
        if (classInfo.name === "question") {
            schemaProperties.type = { type: "string" };
            requiredProps.push("type");
        }
        for (let i = 0; i < classInfo.properties.length; i++) {
            const prop = classInfo.properties[i];
            if (prop.isSerializable === false)
                continue;
            if (!!classInfo.parentName && !!Serializer.findProperty(classInfo.parentName, prop.name))
                continue;
            schemaProperties[prop.name] = this.generateSchemaProperty(prop, schemaDef, isRoot);
            if (prop.isRequired)
                requiredProps.push(prop.name);
        }
        if (requiredProps.length > 0) {
            classSchema.required = requiredProps;
        }
    }
    generateSchemaProperty(prop, schemaDef, isRoot) {
        if (prop.isLocalizable) {
            return {
                oneOf: [
                    { "type": "string" },
                    { "$ref": this.getChemeRefName("locstring", isRoot) }
                ]
            };
        }
        const propType = prop.schemaType();
        const refType = prop.schemaRef();
        var res = {};
        if (!!propType) {
            res.type = propType;
        }
        if (prop.hasChoices) {
            const enumRes = prop.getChoices(null);
            if (Array.isArray(enumRes) && enumRes.length > 0) {
                res.enum = this.getChoicesValues(enumRes);
            }
        }
        if (!!refType) {
            if (propType === "array") {
                if (prop.className === "string") {
                    res.items = { type: prop.className };
                }
                else {
                    res.items = { $ref: this.getChemeRefName(prop.className, isRoot) };
                }
            }
            else {
                res["$ref"] = this.getChemeRefName(refType, isRoot);
            }
            this.generateChemaClass(prop.className, schemaDef, false);
        }
        if (!!prop.baseClassName) {
            var usedClasses = this.getChildrenClasses(prop.baseClassName, true);
            if (prop.baseClassName == "question") {
                usedClasses.push(this.findClass("panel"));
            }
            res.items = { anyOf: [] };
            for (var i = 0; i < usedClasses.length; i++) {
                var className = usedClasses[i].name;
                res.items.anyOf.push({ $ref: this.getChemeRefName(className, isRoot) });
                this.generateChemaClass(className, schemaDef, false);
            }
        }
        return res;
    }
    getChemeRefName(className, isRoot) {
        //Fix for #6486, according to https://niem.github.io/json/reference/json-schema/references/#:~:text=In%20a%20JSON%20schema%2C%20a,%2C%20an%20in%2Dschema%20reference
        //Checked by https://www.jsonschemavalidator.net/
        return isRoot ? "#/definitions/" + className : className;
    }
    generateChemaClass(className, schemaDef, isRoot) {
        if (!!schemaDef[className])
            return;
        var classInfo = this.findClass(className);
        if (!classInfo)
            return;
        var hasParent = !!classInfo.parentName && classInfo.parentName != "base";
        if (hasParent) {
            this.generateChemaClass(classInfo.parentName, schemaDef, isRoot);
        }
        const res = { type: "object", $id: className };
        schemaDef[className] = res;
        const chemaProps = { properties: {} };
        this.generateSchemaProperties(classInfo, chemaProps, schemaDef, isRoot);
        if (hasParent) {
            res.allOf = [
                { $ref: this.getChemeRefName(classInfo.parentName, isRoot) },
                { properties: chemaProps.properties },
            ];
        }
        else {
            res.properties = chemaProps.properties;
        }
        if (Array.isArray(chemaProps.required)) {
            res.required = chemaProps.required;
        }
    }
    getChoicesValues(enumRes) {
        const res = new Array();
        enumRes.forEach(item => {
            if (typeof item === "object" && item.value !== undefined) {
                res.push(item.value);
            }
            else {
                res.push(item);
            }
        });
        return res;
    }
}
class JsonError {
    constructor(type, message) {
        this.type = type;
        this.message = message;
        this.description = "";
        this.at = -1;
        this.end = -1;
    }
    getFullDescription() {
        return this.message + (this.description ? "\n" + this.description : "");
    }
}
class JsonUnknownPropertyError extends JsonError {
    constructor(propertyName, className) {
        super("unknownproperty", "Unknown property in class '" + className + "': '" + propertyName + "'.");
        this.propertyName = propertyName;
        this.className = className;
    }
}
class JsonMissingTypeErrorBase extends JsonError {
    constructor(baseClassName, type, message) {
        super(type, message);
        this.baseClassName = baseClassName;
        this.type = type;
        this.message = message;
    }
}
class JsonMissingTypeError extends JsonMissingTypeErrorBase {
    constructor(propertyName, baseClassName) {
        super(baseClassName, "missingtypeproperty", "The property type is missing in the object. Please take a look at property: '" +
            propertyName +
            "'.");
        this.propertyName = propertyName;
        this.baseClassName = baseClassName;
    }
}
class JsonIncorrectTypeError extends JsonMissingTypeErrorBase {
    constructor(propertyName, baseClassName) {
        super(baseClassName, "incorrecttypeproperty", "The property type is incorrect in the object. Please take a look at property: '" +
            propertyName +
            "'.");
        this.propertyName = propertyName;
        this.baseClassName = baseClassName;
    }
}
class JsonRequiredPropertyError extends JsonError {
    constructor(propertyName, className) {
        super("requiredproperty", "The property '" +
            propertyName +
            "' is required in class '" +
            className +
            "'.");
        this.propertyName = propertyName;
        this.className = className;
    }
}
class JsonRequiredArrayPropertyError extends JsonError {
    constructor(propertyName, className) {
        super("arrayproperty", "The property '" + propertyName + "' should be an array in '" + className + "'.");
        this.propertyName = propertyName;
        this.className = className;
    }
}
class JsonIncorrectPropertyValueError extends JsonError {
    constructor(property, value) {
        super("incorrectvalue", "The property value: '" + value + "' is incorrect for property '" + property.name + "'.");
        this.property = property;
        this.value = value;
    }
}
class JsonObject {
    constructor() {
        this.errors = new Array();
        this.lightSerializing = false;
    }
    static get metaData() {
        return JsonObject.metaDataValue;
    }
    toJsonObject(obj, options) {
        return this.toJsonObjectCore(obj, null, options);
    }
    toObject(jsonObj, obj, options) {
        this.toObjectCore(jsonObj, obj, options);
        var error = this.getRequiredError(obj, jsonObj);
        if (!!error) {
            this.addNewError(error, jsonObj, obj);
        }
    }
    toObjectCore(jsonObj, obj, options) {
        if (!jsonObj)
            return;
        var properties = null;
        var objType = undefined;
        var needAddErrors = true;
        if (obj.getType) {
            objType = obj.getType();
            properties = Serializer.getProperties(objType);
            needAddErrors =
                !!objType && !Serializer.isDescendantOf(objType, "itemvalue");
        }
        if (!properties)
            return;
        if (obj.startLoadingFromJson) {
            obj.startLoadingFromJson(jsonObj);
        }
        properties = this.addDynamicProperties(obj, jsonObj, properties);
        this.options = options;
        const processedProps = {};
        processedProps[JsonObject.typePropertyName] = true;
        const parentProps = {};
        for (var key in jsonObj) {
            this.setPropertyValueToObj(jsonObj, obj, key, properties, processedProps, parentProps, objType, needAddErrors, options);
        }
        this.options = undefined;
        if (obj.endLoadingFromJson) {
            obj.endLoadingFromJson();
        }
    }
    setPropertyValueToObj(jsonObj, obj, key, properties, processedProps, parentProps, objType, needAddErrors, options) {
        if (processedProps[key])
            return;
        if (key === JsonObject.positionPropertyName) {
            obj[key] = jsonObj[key];
            return;
        }
        const property = this.findProperty(properties, key);
        if (!property && needAddErrors) {
            this.addNewError(new JsonUnknownPropertyError(key.toString(), objType), jsonObj, obj);
        }
        if (property) {
            const dProps = property.dependsOn;
            if (Array.isArray(dProps)) {
                parentProps[key] = true;
                dProps.forEach(propKey => {
                    if (!parentProps[propKey]) {
                        this.setPropertyValueToObj(jsonObj, obj, propKey, properties, processedProps, parentProps, objType, false, options);
                    }
                });
            }
            this.valueToObj(jsonObj[key], obj, property, jsonObj, options);
            processedProps[key] = true;
        }
    }
    toJsonObjectCore(obj, property, options) {
        if (!obj || !obj.getType)
            return obj;
        if (!obj.isSurvey && typeof obj.getData === "function")
            return obj.getData();
        var result = {};
        if (property != null && !property.className) {
            result[JsonObject.typePropertyName] = property.getObjType(obj.getType());
        }
        const storeDefaults = options === true;
        if (!options || options === true) {
            options = {};
        }
        if (storeDefaults) {
            options.storeDefaults = storeDefaults;
        }
        this.propertiesToJson(obj, Serializer.getProperties(obj.getType()), result, options);
        this.propertiesToJson(obj, this.getDynamicProperties(obj), result, options);
        return result;
    }
    getDynamicProperties(obj) {
        return Serializer.getDynamicPropertiesByObj(obj);
    }
    addDynamicProperties(obj, jsonObj, props) {
        if (!obj.getDynamicPropertyName && !obj.getDynamicProperties)
            return props;
        if (obj.getDynamicPropertyName) {
            const dynamicPropName = obj.getDynamicPropertyName();
            if (!dynamicPropName)
                return props;
            if (dynamicPropName && jsonObj[dynamicPropName]) {
                obj[dynamicPropName] = jsonObj[dynamicPropName];
            }
        }
        const dynamicProps = this.getDynamicProperties(obj);
        return dynamicProps.length === 0 ? props : [].concat(props).concat(dynamicProps);
    }
    propertiesToJson(obj, properties, json, options) {
        for (var i = 0; i < properties.length; i++) {
            this.valueToJson(obj, json, properties[i], options);
        }
    }
    valueToJson(obj, result, prop, options) {
        if (!options)
            options = {};
        if (!prop.isPropertySerializable(obj) || (prop.isLightSerializable === false && this.lightSerializing))
            return;
        if (options.version && !prop.isAvailableInVersion(options.version))
            return;
        this.valueToJsonCore(obj, result, prop, options);
    }
    valueToJsonCore(obj, result, prop, options) {
        const serProp = prop.getSerializedProperty(obj, options.version);
        if (serProp && serProp !== prop) {
            this.valueToJsonCore(obj, result, serProp, options);
            return;
        }
        var value = prop.getSerializableValue(obj, options.storeDefaults);
        if (value === undefined)
            return;
        if (this.isValueArray(value)) {
            var arrValue = [];
            for (var i = 0; i < value.length; i++) {
                arrValue.push(this.toJsonObjectCore(value[i], prop, options));
            }
            value = arrValue.length > 0 ? arrValue : null;
        }
        else {
            value = this.toJsonObjectCore(value, prop, options);
        }
        if (value === undefined || value === null)
            return;
        const name = prop.getSerializedName(options.version);
        var hasValue = typeof obj["getPropertyValue"] === "function" &&
            obj["getPropertyValue"](name, null) !== null;
        if ((options.storeDefaults && hasValue) || !prop.isDefaultValueByObj(obj, value)) {
            if (!Serializer.onSerializingProperty || !Serializer.onSerializingProperty(obj, prop, value, result)) {
                result[name] = this.removePosOnValueToJson(prop, value);
            }
        }
    }
    valueToObj(value, obj, property, jsonObj, options) {
        if (value === null || value === undefined)
            return;
        this.removePos(property, value);
        if (property != null && property.hasToUseSetValue) {
            property.setValue(obj, value, this);
            return;
        }
        if (property.isArray && !Array.isArray(value) && !!value) {
            value = [value];
            const propName = !!jsonObj && property.alternativeName && !!jsonObj[property.alternativeName] ? property.alternativeName : property.name;
            this.addNewError(new JsonRequiredArrayPropertyError(propName, obj.getType()), !!jsonObj ? jsonObj : value, obj);
        }
        if (this.isValueArray(value)) {
            this.valueToArray(value, obj, property.name, property, options);
            return;
        }
        var newObj = this.createNewObj(value, property);
        if (newObj.newObj) {
            this.toObjectCore(value, newObj.newObj, options);
            value = newObj.newObj;
        }
        if (!newObj.error) {
            if (property != null) {
                property.setValue(obj, value, this);
                if (!!options && options.validatePropertyValues) {
                    if (!property.validateValue(value)) {
                        this.addNewError(new JsonIncorrectPropertyValueError(property, value), jsonObj, obj);
                    }
                }
            }
            else {
                obj[property.name] = value;
            }
        }
    }
    removePosOnValueToJson(property, value) {
        if (!property.isCustom || !value)
            return value;
        this.removePosFromObj(value);
        return value;
    }
    removePos(property, value) {
        if (!property || !property.type || property.type.indexOf("value") < 0)
            return;
        this.removePosFromObj(value);
    }
    removePosFromObj(obj) {
        if (!obj || typeof obj.getType === "function")
            return;
        if (Array.isArray(obj)) {
            for (var i = 0; i < obj.length; i++) {
                this.removePosFromObj(obj[i]);
            }
        }
        if (typeof obj !== "object")
            return;
        if (!!obj[JsonObject.positionPropertyName]) {
            delete obj[JsonObject.positionPropertyName];
        }
        for (let key in obj) {
            this.removePosFromObj(obj[key]);
        }
    }
    isValueArray(value) {
        return value && Array.isArray(value);
    }
    createNewObj(value, property) {
        var result = { newObj: null, error: null };
        const className = this.getClassNameForNewObj(value, property);
        result.newObj = className
            ? Serializer.createClass(className, value)
            : null;
        result.error = this.checkNewObjectOnErrors(result.newObj, value, property, className);
        return result;
    }
    getClassNameForNewObj(value, property) {
        var res = property != null && property.className ? property.className : undefined;
        if (!res) {
            res = value[JsonObject.typePropertyName];
        }
        if (!res)
            return res;
        res = res.toLowerCase();
        const classNamePart = property.classNamePart;
        if (classNamePart && res.indexOf(classNamePart) < 0) {
            res += classNamePart;
        }
        return res;
    }
    checkNewObjectOnErrors(newObj, value, property, className) {
        var error = null;
        if (newObj) {
            error = this.getRequiredError(newObj, value);
        }
        else {
            if (property.baseClassName) {
                if (!className) {
                    error = new JsonMissingTypeError(property.name, property.baseClassName);
                }
                else {
                    error = new JsonIncorrectTypeError(property.name, property.baseClassName);
                }
            }
        }
        if (error) {
            this.addNewError(error, value, newObj);
        }
        return error;
    }
    getRequiredError(obj, jsonValue) {
        if (!obj.getType || typeof obj.getData === "function")
            return null;
        const metaClass = Serializer.findClass(obj.getType());
        if (!metaClass)
            return null;
        const props = metaClass.getRequiredProperties();
        if (!Array.isArray(props))
            return null;
        for (var i = 0; i < props.length; i++) {
            const prop = props[i];
            if (!Helpers.isValueEmpty(prop.defaultValue))
                continue;
            if (!jsonValue[prop.name]) {
                return new JsonRequiredPropertyError(prop.name, obj.getType());
            }
        }
        return null;
    }
    addNewError(error, jsonObj, element) {
        error.jsonObj = jsonObj;
        error.element = element;
        this.errors.push(error);
        if (!jsonObj)
            return;
        const posObj = jsonObj[JsonObject.positionPropertyName];
        if (!posObj)
            return;
        error.at = posObj.start;
        error.end = posObj.end;
    }
    valueToArray(value, obj, key, property, options) {
        if (obj[key] && !this.isValueArray(obj[key]))
            return;
        if (obj[key] && value.length > 0)
            obj[key].splice(0, obj[key].length);
        var valueRes = obj[key] ? obj[key] : [];
        this.addValuesIntoArray(value, valueRes, property, options);
        if (!obj[key])
            obj[key] = valueRes;
    }
    addValuesIntoArray(value, result, property, options) {
        for (var i = 0; i < value.length; i++) {
            var newValue = this.createNewObj(value[i], property);
            if (newValue.newObj) {
                if (!!value[i].name) {
                    newValue.newObj.name = value[i].name;
                }
                if (!!value[i].valueName) {
                    newValue.newObj.valueName = value[i].valueName.toString();
                }
                result.push(newValue.newObj);
                this.toObjectCore(value[i], newValue.newObj, options);
            }
            else {
                if (!newValue.error) {
                    result.push(value[i]);
                }
            }
        }
    }
    findProperty(properties, key) {
        if (!properties)
            return null;
        for (var i = 0; i < properties.length; i++) {
            var prop = properties[i];
            if (prop.name == key || prop.alternativeName == key)
                return prop;
        }
        return null;
    }
}
JsonObject.typePropertyName = "type";
JsonObject.positionPropertyName = "pos";
JsonObject.metaDataValue = new JsonMetadata();
/**
 * An alias for the metadata object. It contains object properties' runtime information and allows you to modify it.
 * @see JsonMetadata
 */
var Serializer = JsonObject.metaData;

const surveyBuiltInVarible = "@survey";
class ProcessValue {
    constructor() {
        this.values = null;
        this.properties = null;
        this.asyncValues = {};
    }
    getFirstName(text, obj = null) {
        if (!text)
            return text;
        var res = "";
        if (!!obj) {
            res = this.getFirstPropertyName(text, obj);
            if (!!res)
                return res;
        }
        for (var i = 0; i < text.length; i++) {
            var ch = text[i];
            if (ch == "." || ch == "[")
                break;
            res += ch;
        }
        return res;
    }
    hasValue(text, values = null) {
        if (!values)
            values = this.values;
        var res = this.getValueCore(text, values);
        return res.hasValue;
    }
    getValue(text, values = null) {
        if (!values)
            values = this.values;
        var res = this.getValueCore(text, values);
        return res.onProcessValue ? res.onProcessValue(res.value) : res.value;
    }
    setValue(obj, text, value) {
        if (!text)
            return;
        var nonNestedObj = this.getNonNestedObject(obj, text, true);
        if (!nonNestedObj)
            return;
        obj = nonNestedObj.value;
        text = nonNestedObj.text;
        if (!!obj && !!text) {
            obj[text] = value;
        }
    }
    getValueInfo(valueInfo) {
        if (!!valueInfo.path) {
            valueInfo.value = this.getValueFromPath(valueInfo.path, this.values);
            valueInfo.hasValue =
                valueInfo.value !== null && !Helpers.isValueEmpty(valueInfo.value);
            if (!valueInfo.hasValue &&
                valueInfo.path.length > 1 &&
                valueInfo.path[valueInfo.path.length - 1] == "length") {
                valueInfo.hasValue = true;
                valueInfo.value = 0;
            }
            return;
        }
        var res = this.getValueCore(valueInfo.name, this.values);
        valueInfo.value = res.value;
        valueInfo.hasValue = res.hasValue;
        valueInfo.path = res.hasValue ? res.path : null;
        valueInfo.onProcessValue = res.onProcessValue;
        valueInfo.sctrictCompare = res.sctrictCompare;
    }
    isAnyKeyChanged(keys, usedNames) {
        for (var i = 0; i < usedNames.length; i++) {
            const name = usedNames[i];
            if (!name)
                continue;
            const lowerName = name.toLowerCase();
            if (keys.hasOwnProperty(name))
                return true;
            if (name !== lowerName && keys.hasOwnProperty(lowerName))
                return true;
            var firstName = this.getFirstName(name);
            if (!keys.hasOwnProperty(firstName))
                continue;
            if (name === firstName)
                return true;
            var keyValue = keys[firstName];
            if (keyValue == undefined)
                continue;
            if (!keyValue.hasOwnProperty("oldValue") ||
                !keyValue.hasOwnProperty("newValue"))
                return true;
            var v = {};
            v[firstName] = keyValue["oldValue"];
            var oldValue = this.getValue(name, v);
            v[firstName] = keyValue["newValue"];
            var newValue = this.getValue(name, v);
            if (!Helpers.isTwoValueEquals(oldValue, newValue, false, false, false))
                return true;
        }
        return false;
    }
    getValueFromPath(path, values) {
        if (path.length === 2 && path[0] === surveyBuiltInVarible) {
            return this.getValueFromSurvey(path[1]);
        }
        var index = 0;
        while (!!values && index < path.length) {
            var ind_name = path[index];
            if (Helpers.isNumber(ind_name) &&
                Array.isArray(values) &&
                ind_name >= values.length)
                return null;
            values = values[ind_name];
            index++;
        }
        return values;
    }
    getValueCore(text, values) {
        const question = this.getQuestionDirectly(text);
        if (question) {
            return { hasValue: true, value: question.value, onProcessValue: (val) => question.getExpressionValue(val), path: [text], sctrictCompare: question.requireStrictCompare };
        }
        const res = this.getValueFromValues(text, values);
        if (!!text && !res.hasValue) {
            const val = this.getValueFromSurvey(text);
            if (val !== undefined) {
                res.hasValue = true;
                res.value = val;
                res.path = [surveyBuiltInVarible, text];
            }
        }
        return res;
    }
    getQuestionDirectly(name) {
        if (!!this.properties && !!this.properties.survey)
            return this.properties.survey.getQuestionByValueName(name);
        return undefined;
    }
    getValueFromSurvey(name) {
        if (!!this.properties && !!this.properties.survey)
            return this.properties.survey.getBuiltInVariableValue(name.toLocaleLowerCase());
        return undefined;
    }
    getValueFromValues(text, values) {
        var res = { hasValue: false, value: null, path: null };
        var curValue = values;
        if (!curValue && curValue !== 0 && curValue !== false)
            return res;
        if (text &&
            text.lastIndexOf(".length") > -1 &&
            text.lastIndexOf(".length") === text.length - ".length".length) {
            res.value = 0;
            res.hasValue = true;
        }
        var obj = this.getNonNestedObject(curValue, text, false);
        if (!obj)
            return res;
        res.path = obj.path;
        res.value = !!obj.text ? this.getObjectValue(obj.value, obj.text) : obj.value;
        res.hasValue = !Helpers.isValueEmpty(res.value);
        return res;
    }
    getNonNestedObject(obj, text, createPath) {
        let curName = this.getFirstPropertyName(text, obj, createPath);
        let curObj = obj;
        const path = !!curName ? [curName] : null;
        let curText = text;
        while (curText != curName && !!curObj) {
            var isArray = curText[0] == "[";
            if (!isArray) {
                if (!curName && curText === this.getFirstName(curText))
                    return { value: obj, text: text, path: path };
                curObj = this.getObjectValue(curObj, curName);
                if (Helpers.isValueEmpty(curObj) && !createPath)
                    return null;
                curText = curText.substring(curName.length);
            }
            else {
                var objInArray = this.getObjInArray(curObj, curText);
                if (!objInArray)
                    return null;
                curObj = objInArray.value;
                curText = objInArray.text;
                path.push(objInArray.index);
            }
            if (!!curText && curText[0] == ".") {
                curText = curText.substring(1);
            }
            curName = this.getFirstPropertyName(curText, curObj, createPath);
            if (!!curName) {
                path.push(curName);
            }
        }
        return { value: curObj, text: curText, path: path };
    }
    getObjInArray(curValue, text) {
        if (!Array.isArray(curValue))
            return null;
        var index = 1;
        var str = "";
        while (index < text.length && text[index] != "]") {
            str += text[index];
            index++;
        }
        text = index < text.length ? text.substring(index + 1) : "";
        index = this.getIntValue(str);
        if (index < 0 || index >= curValue.length)
            return null;
        return { value: curValue[index], text: text, index: index };
    }
    getFirstPropertyName(name, obj, createProp = false) {
        if (!name)
            return "";
        if (!obj)
            obj = {};
        if (obj.hasOwnProperty(name))
            return name;
        let nameInLow = name.toLowerCase();
        const A = nameInLow[0];
        const a = A.toUpperCase();
        let keyWithDot = "";
        for (var key in obj) {
            var first = key[0];
            if (first === a || first === A) {
                var keyName = key.toLowerCase();
                if (keyName == nameInLow)
                    return key;
                if (nameInLow.length <= keyName.length)
                    continue;
                var ch = nameInLow[keyName.length];
                if (ch != "." && ch != "[")
                    continue;
                if (keyName == nameInLow.substring(0, keyName.length)) {
                    if (keyWithDot.length < key.length) {
                        keyWithDot = key;
                    }
                }
            }
        }
        if (keyWithDot)
            return keyWithDot;
        if (createProp && name[0] !== "[") {
            const ind = name.indexOf(".");
            if (ind > -1) {
                name = name.substring(0, ind);
                obj[name] = {};
            }
            return name;
        }
        return "";
    }
    getObjectValue(obj, name) {
        if (!name)
            return null;
        return obj[name];
    }
    getIntValue(str) {
        if (str == "0" || ((str | 0) > 0 && str % 1 == 0))
            return Number(str);
        return -1;
    }
}

class ConsoleWarnings {
    static disposedObjectChangedProperty(propName, objType) {
        ConsoleWarnings.warn("An attempt to set a property \"" + propName + "\" of a disposed object \"" + objType + "\"");
    }
    static inCorrectQuestionValue(questionName, val) {
        const valStr = JSON.stringify(val, null, 3);
        ConsoleWarnings.warn("An attempt to assign an incorrect value" + valStr + " to the following question: \"" + questionName + "\"");
    }
    static warn(text) {
        // eslint-disable-next-line no-console
        console.warn(text);
    }
    static error(text) {
        // eslint-disable-next-line no-console
        console.error(text);
    }
}

class FunctionFactory {
    constructor() {
        this.functionHash = {};
        this.isAsyncHash = {};
    }
    register(name, func, isAsync = false) {
        this.functionHash[name] = func;
        if (isAsync)
            this.isAsyncHash[name] = true;
    }
    unregister(name) {
        delete this.functionHash[name];
        delete this.isAsyncHash[name];
    }
    hasFunction(name) {
        return !!this.functionHash[name];
    }
    isAsyncFunction(name) {
        return !!this.isAsyncHash[name];
    }
    clear() {
        this.functionHash = {};
    }
    getAll() {
        var result = [];
        for (var key in this.functionHash) {
            result.push(key);
        }
        return result.sort();
    }
    run(name, params, properties = null, originalParams) {
        const func = this.functionHash[name];
        if (!func) {
            ConsoleWarnings.warn(this.getUnknownFunctionErrorText(name, properties));
            return null;
        }
        let classRunner = {
            func: func,
        };
        if (properties) {
            for (var key in properties) {
                classRunner[key] = properties[key];
            }
        }
        return classRunner.func(params, originalParams);
    }
    getUnknownFunctionErrorText(name, properties) {
        return "Unknown function name: '" + name + "'." + ExpressionExecutor.getQuestionErrorText(properties);
    }
}
FunctionFactory.Instance = new FunctionFactory();
var registerFunction = FunctionFactory.Instance.register;
function getParamsAsArray(value, arr) {
    if (value === undefined || value === null)
        return;
    if (Array.isArray(value)) {
        for (var i = 0; i < value.length; i++) {
            getParamsAsArray(value[i], arr);
        }
    }
    else {
        if (Helpers.isNumber(value)) {
            value = Helpers.getNumber(value);
        }
        arr.push(value);
    }
}
function sum(params) {
    var arr = [];
    getParamsAsArray(params, arr);
    var res = 0;
    for (var i = 0; i < arr.length; i++) {
        res = Helpers.correctAfterPlusMinis(res, arr[i], res + arr[i]);
    }
    return res;
}
FunctionFactory.Instance.register("sum", sum);
function min_max(params, isMin) {
    var arr = [];
    getParamsAsArray(params, arr);
    var res = undefined;
    for (var i = 0; i < arr.length; i++) {
        if (res === undefined) {
            res = arr[i];
        }
        if (isMin) {
            if (res > arr[i])
                res = arr[i];
        }
        else {
            if (res < arr[i])
                res = arr[i];
        }
    }
    return res;
}
function min(params) {
    return min_max(params, true);
}
FunctionFactory.Instance.register("min", min);
function max(params) {
    return min_max(params, false);
}
FunctionFactory.Instance.register("max", max);
function count(params) {
    var arr = [];
    getParamsAsArray(params, arr);
    return arr.length;
}
FunctionFactory.Instance.register("count", count);
function avg(params) {
    var arr = [];
    getParamsAsArray(params, arr);
    const res = sum(params);
    return arr.length > 0 ? res / arr.length : 0;
}
FunctionFactory.Instance.register("avg", avg);
function round(params) {
    var arr = [];
    getParamsAsArray(params, arr);
    if (arr.length > 0) {
        const num = arr[0];
        const precision = arr[1] || 0;
        if (Helpers.isNumber(num) && Helpers.isNumber(precision)) {
            const p = Math.pow(10, precision);
            const n = (num * p) * (1 + Number.EPSILON);
            return Math.round(n) / p;
        }
    }
    return NaN;
}
FunctionFactory.Instance.register("round", round);
function trunc(params) {
    var arr = [];
    getParamsAsArray(params, arr);
    if (arr.length > 0) {
        const num = arr[0];
        const precision = arr[1] || -1;
        if (Helpers.isNumber(num) && Helpers.isNumber(precision)) {
            const regexp = new RegExp("^-?\\d+(?:.\\d{0," + precision + "})?");
            return Number(num.toString().match(regexp)[0]);
        }
    }
    return NaN;
}
FunctionFactory.Instance.register("trunc", trunc);
function getInArrayParams(params, originalParams) {
    if (params.length < 2 || params.length > 3)
        return null;
    const arr = params[0];
    if (!arr)
        return null;
    if (!Array.isArray(arr) && !Array.isArray(Object.keys(arr)))
        return null;
    const name = params[1];
    if (typeof name !== "string" && !(name instanceof String))
        return null;
    let expression = params.length > 2 ? params[2] : undefined;
    if (typeof expression !== "string" && !(expression instanceof String)) {
        expression = undefined;
    }
    if (!expression) {
        const operand = Array.isArray(originalParams) && originalParams.length > 2 ? originalParams[2] : undefined;
        if (operand && !!operand.toString()) {
            expression = operand.toString();
        }
    }
    return { data: arr, name: name, expression: expression };
}
function convertToNumber(val) {
    if (typeof val === "string")
        return Helpers.isNumber(val) ? Helpers.getNumber(val) : undefined;
    return val;
}
function processItemInArray(item, name, res, func, needToConvert, condition) {
    if (!item || Helpers.isValueEmpty(item[name]))
        return res;
    if (condition && !condition.run(item))
        return res;
    const val = needToConvert ? convertToNumber(item[name]) : 1;
    return func(res, val);
}
function calcInArray(params, originalParams, func, needToConvert = true) {
    var v = getInArrayParams(params, originalParams);
    if (!v)
        return undefined;
    let condition = !!v.expression ? new ConditionRunner(v.expression) : undefined;
    if (condition && condition.isAsync) {
        condition = undefined;
    }
    var res = undefined;
    if (Array.isArray(v.data)) {
        for (var i = 0; i < v.data.length; i++) {
            res = processItemInArray(v.data[i], v.name, res, func, needToConvert, condition);
        }
    }
    else {
        for (var key in v.data) {
            res = processItemInArray(v.data[key], v.name, res, func, needToConvert, condition);
        }
    }
    return res;
}
function sumInArray(params, originalParams) {
    var res = calcInArray(params, originalParams, function (res, val) {
        if (res == undefined)
            res = 0;
        if (val == undefined || val == null)
            return res;
        return Helpers.correctAfterPlusMinis(res, val, res + val);
    });
    return res !== undefined ? res : 0;
}
FunctionFactory.Instance.register("sumInArray", sumInArray);
function minInArray(params, originalParams) {
    return calcInArray(params, originalParams, function (res, val) {
        if (res == undefined)
            return val;
        if (val == undefined || val == null)
            return res;
        return res < val ? res : val;
    });
}
FunctionFactory.Instance.register("minInArray", minInArray);
function maxInArray(params, originalParams) {
    return calcInArray(params, originalParams, function (res, val) {
        if (res == undefined)
            return val;
        if (val == undefined || val == null)
            return res;
        return res > val ? res : val;
    });
}
FunctionFactory.Instance.register("maxInArray", maxInArray);
function countInArray(params, originalParams) {
    var res = calcInArray(params, originalParams, function (res, val) {
        if (res == undefined)
            res = 0;
        if (val == undefined || val == null)
            return res;
        return res + 1;
    }, false);
    return res !== undefined ? res : 0;
}
FunctionFactory.Instance.register("countInArray", countInArray);
function avgInArray(params, originalParams) {
    var count = countInArray(params, originalParams);
    if (count == 0)
        return 0;
    return sumInArray(params, originalParams) / count;
}
FunctionFactory.Instance.register("avgInArray", avgInArray);
function iif(params) {
    if (!Array.isArray(params) || params.length < 2)
        return null;
    const va2 = params.length > 2 ? params[2] : undefined;
    return params[0] ? params[1] : va2;
}
FunctionFactory.Instance.register("iif", iif);
function getDate(params) {
    if (!Array.isArray(params) || params.length < 1 || !params[0])
        return null;
    return createDate("function-getDate", params[0]);
}
FunctionFactory.Instance.register("getDate", getDate);
function dateDiffMonths(date1Param, date2Param, type) {
    if (type === "days")
        return diffDays([date1Param, date2Param]);
    const date1 = createDate("function-dateDiffMonths", date1Param);
    const date2 = createDate("function-dateDiffMonths", date2Param);
    const age = date2.getFullYear() - date1.getFullYear();
    type = type || "years";
    let ageInMonths = age * 12 + date2.getMonth() - date1.getMonth();
    if (date2.getDate() < date1.getDate()) {
        ageInMonths -= 1;
    }
    return type === "months" ? ageInMonths : ~~(ageInMonths / 12);
}
function age(params) {
    if (!Array.isArray(params) || params.length < 1 || !params[0])
        return null;
    return dateDiffMonths(params[0], undefined, (params.length > 1 ? params[1] : "") || "years");
}
FunctionFactory.Instance.register("age", age);
function dateDiff(params) {
    if (!Array.isArray(params) || params.length < 2 || !params[0] || !params[1])
        return null;
    const type = (params.length > 2 ? params[2] : "") || "days";
    const isHours = type === "hours" || type === "minutes";
    const dType = isHours ? "days" : type;
    let days = dateDiffMonths(params[0], params[1], dType);
    if (isHours) {
        const date1 = createDate("function-dateDiffMonths", params[0]);
        const date2 = createDate("function-dateDiffMonths", params[1]);
        if (date2.getHours() > date1.getHours()) {
            days -= 1;
        }
        let hours = days * 24 + date2.getHours() - date1.getHours();
        if (type === "hours")
            return hours;
        if (date2.getMinutes() < date1.getMinutes()) {
            hours -= 1;
        }
        return hours * 60 + date2.getMinutes() - date1.getMinutes();
    }
    return days;
}
FunctionFactory.Instance.register("dateDiff", dateDiff);
function dateAdd(params) {
    if (!Array.isArray(params) || params.length < 2 || !params[0] || !params[1])
        return null;
    const date = createDate("function-dateAdd", params[0]);
    const valToAdd = params[1];
    const interval = params[2] || "days";
    if (interval === "days") {
        date.setDate(date.getDate() + valToAdd);
    }
    if (interval === "months") {
        date.setMonth(date.getMonth() + valToAdd);
    }
    if (interval === "years") {
        date.setFullYear(date.getFullYear() + valToAdd);
    }
    return date;
}
FunctionFactory.Instance.register("dateAdd", dateAdd);
function isContainerReadyCore(container) {
    if (!container)
        return false;
    var questions = container.questions;
    for (var i = 0; i < questions.length; i++) {
        if (!questions[i].validate(false))
            return false;
    }
    return true;
}
function isContainerReady(params) {
    if (!params && params.length < 1)
        return false;
    if (!params[0] || !this.survey)
        return false;
    const name = params[0];
    let container = this.survey.getPageByName(name);
    if (!container)
        container = this.survey.getPanelByName(name);
    if (!container) {
        const question = this.survey.getQuestionByName(name);
        if (!question || !Array.isArray(question.panels))
            return false;
        if (params.length > 1) {
            if (params[1] < question.panels.length) {
                container = question.panels[params[1]];
            }
        }
        else {
            for (let i = 0; i < question.panels.length; i++) {
                if (!isContainerReadyCore(question.panels[i]))
                    return false;
            }
            return true;
        }
    }
    return isContainerReadyCore(container);
}
FunctionFactory.Instance.register("isContainerReady", isContainerReady);
function isDisplayMode() {
    return this.survey && this.survey.isDisplayMode;
}
FunctionFactory.Instance.register("isDisplayMode", isDisplayMode);
function currentDate() {
    return createDate("function-currentDate");
}
FunctionFactory.Instance.register("currentDate", currentDate);
function today(params) {
    var res = createDate("function-today");
    if (settings.localization.useLocalTimeZone) {
        res.setHours(0, 0, 0, 0);
    }
    else {
        res.setUTCHours(0, 0, 0, 0);
    }
    if (Array.isArray(params) && params.length == 1) {
        res.setDate(res.getDate() + params[0]);
    }
    return res;
}
FunctionFactory.Instance.register("today", today);
function getYear(params) {
    if (params.length !== 1 || !params[0])
        return undefined;
    return createDate("function-getYear", params[0]).getFullYear();
}
FunctionFactory.Instance.register("getYear", getYear);
function currentYear() {
    return createDate("function-currentYear").getFullYear();
}
FunctionFactory.Instance.register("currentYear", currentYear);
function diffDays(params) {
    if (!Array.isArray(params) || params.length !== 2)
        return 0;
    if (!params[0] || !params[1])
        return 0;
    const date1 = createDate("function-diffDays", params[0]);
    const date2 = createDate("function-diffDays", params[1]);
    const diffTime = Math.abs(date2 - date1);
    return Math.ceil(diffTime / (1000 * 60 * 60 * 24));
}
FunctionFactory.Instance.register("diffDays", diffDays);
function dateFromFirstParameterOrToday(name, params) {
    let date = today(undefined);
    if (params && params[0]) {
        date = createDate("function-" + name, params[0]);
    }
    return date;
}
function year(params) {
    let date = dateFromFirstParameterOrToday("year", params);
    return date.getFullYear();
}
FunctionFactory.Instance.register("year", year);
function month(params) {
    let date = dateFromFirstParameterOrToday("month", params);
    return date.getMonth() + 1;
}
FunctionFactory.Instance.register("month", month);
function day(params) {
    let date = dateFromFirstParameterOrToday("day", params);
    return date.getDate();
}
FunctionFactory.Instance.register("day", day);
function weekday(params) {
    let date = dateFromFirstParameterOrToday("weekday", params);
    return date.getDay();
}
FunctionFactory.Instance.register("weekday", weekday);
function getQuestionValueByContext(context, name) {
    if (!context || !name)
        return undefined;
    let q = context.question;
    while (q && q.parent) {
        const res = q.parent.getQuestionByName(name);
        if (!!res)
            return res;
        q = q.parentQuestion;
    }
    const keys = ["row", "panel", "survey"];
    for (let i = 0; i < keys.length; i++) {
        const ctx = context[keys[i]];
        if (ctx && ctx.getQuestionByName) {
            const res = ctx.getQuestionByName(name);
            if (res)
                return res;
        }
    }
    return null;
}
function getDisplayValueReturnResult(q, params) {
    if (params.length > 1 && !Helpers.isValueEmpty(params[1]))
        return q.getDisplayValue(true, params[1]);
    return q.displayValue;
}
function displayValue(params) {
    const q = getQuestionValueByContext(this, params[0]);
    if (!q)
        return "";
    if (q.isReady) {
        this.returnResult(getDisplayValueReturnResult(q, params));
    }
    else {
        const displayValueOnReadyChanged = (sender, options) => {
            if (sender.isReady) {
                sender.onReadyChanged.remove(displayValueOnReadyChanged);
                this.returnResult(getDisplayValueReturnResult(sender, params));
            }
        };
        q.onReadyChanged.add(displayValueOnReadyChanged);
    }
    return undefined;
}
FunctionFactory.Instance.register("displayValue", displayValue, true);
function propertyValue(params) {
    if (params.length !== 2 || !params[0] || !params[1])
        return undefined;
    const q = getQuestionValueByContext(this, params[0]);
    return q ? q[params[1]] : undefined;
}
FunctionFactory.Instance.register("propertyValue", propertyValue);
function substring_(params) {
    if (params.length < 2)
        return "";
    const s = params[0];
    if (!s || typeof s !== "string")
        return "";
    const start = params[1];
    if (!Helpers.isNumber(start))
        return "";
    const end = params.length > 2 ? params[2] : undefined;
    if (!Helpers.isNumber(end))
        return s.substring(start);
    return s.substring(start, end);
}
FunctionFactory.Instance.register("substring", substring_);

class Operand {
    constructor() {
        this._id = Operand.counter++;
    }
    get id() { return this._id; }
    toString(func = undefined) {
        return "";
    }
    hasFunction() {
        return false;
    }
    hasAsyncFunction() { return false; }
    addToAsyncList(list) { }
    addOperandsToList(list) {
        list.push(this);
        this.addChildrenToList(list);
    }
    isEqual(op) {
        return !!op && op.getType() === this.getType() && this.isContentEqual(op);
    }
    areOperatorsEquals(op1, op2) {
        return !op1 && !op2 || !!op1 && op1.isEqual(op2);
    }
    addChildrenToList(list) { }
}
Operand.counter = 1;
class BinaryOperand extends Operand {
    constructor(operatorName, left = null, right = null, isArithmeticOp = false) {
        super();
        this.operatorName = operatorName;
        this.left = left;
        this.right = right;
        this.isArithmeticValue = isArithmeticOp;
        if (isArithmeticOp) {
            this.consumer = OperandMaker.binaryFunctions["arithmeticOp"](operatorName);
        }
        else {
            this.consumer = OperandMaker.binaryFunctions[operatorName];
        }
        if (this.consumer == null) {
            OperandMaker.throwInvalidOperatorError(operatorName);
        }
    }
    get requireStrictCompare() {
        return this.getIsOperandRequireStrict(this.left) ||
            this.getIsOperandRequireStrict(this.right);
    }
    getIsOperandRequireStrict(op) {
        return !!op && op.requireStrictCompare;
    }
    getType() {
        return "binary";
    }
    get isArithmetic() {
        return this.isArithmeticValue;
    }
    get isConjunction() {
        return this.operatorName == "or" || this.operatorName == "and";
    }
    get conjunction() {
        return this.isConjunction ? this.operatorName : "";
    }
    get operator() {
        return this.operatorName;
    }
    get leftOperand() {
        return this.left;
    }
    get rightOperand() {
        return this.right;
    }
    isContentEqual(op) {
        const bOp = op;
        return bOp.operator === this.operator &&
            this.areOperatorsEquals(this.left, bOp.left) &&
            this.areOperatorsEquals(this.right, bOp.right);
    }
    evaluateParam(x, processValue) {
        return x == null ? null : x.evaluate(processValue);
    }
    evaluate(processValue) {
        return this.consumer.call(this, this.evaluateParam(this.left, processValue), this.evaluateParam(this.right, processValue), this.requireStrictCompare);
    }
    toString(func = undefined) {
        if (!!func) {
            var res = func(this);
            if (!!res)
                return res;
        }
        return ("(" +
            OperandMaker.safeToString(this.left, func) +
            " " +
            OperandMaker.operatorToString(this.operatorName) +
            " " +
            OperandMaker.safeToString(this.right, func) +
            ")");
    }
    setVariables(variables) {
        if (this.left != null)
            this.left.setVariables(variables);
        if (this.right != null)
            this.right.setVariables(variables);
    }
    hasFunction() {
        return ((!!this.left && this.left.hasFunction()) ||
            (!!this.right && this.right.hasFunction()));
    }
    addChildrenToList(list) {
        if (!!this.left)
            this.left.addOperandsToList(list);
        if (!!this.right)
            this.right.addOperandsToList(list);
    }
    hasAsyncFunction() {
        return ((!!this.left && this.left.hasAsyncFunction()) ||
            (!!this.right && this.right.hasAsyncFunction()));
    }
    addToAsyncList(list) {
        if (!!this.left)
            this.left.addToAsyncList(list);
        if (!!this.right)
            this.right.addToAsyncList(list);
    }
}
class UnaryOperand extends Operand {
    constructor(expressionValue, operatorName) {
        super();
        this.expressionValue = expressionValue;
        this.operatorName = operatorName;
        this.consumer = OperandMaker.unaryFunctions[operatorName];
        if (this.consumer == null) {
            OperandMaker.throwInvalidOperatorError(operatorName);
        }
    }
    get operator() {
        return this.operatorName;
    }
    get expression() {
        return this.expressionValue;
    }
    getType() {
        return "unary";
    }
    toString(func = undefined) {
        if (!!func) {
            var res = func(this);
            if (!!res)
                return res;
        }
        const opName = OperandMaker.operatorToString(this.operator);
        const exp = this.expression.toString(func);
        return this.isRigtOperator ? exp + " " + opName : opName + " " + exp;
    }
    get isRigtOperator() {
        const st = this.operatorName.toLowerCase();
        return st === "notempty" || st === "empty";
    }
    isContentEqual(op) {
        const uOp = op;
        return uOp.operator == this.operator && this.areOperatorsEquals(this.expression, uOp.expression);
    }
    hasFunction() {
        return this.expression.hasFunction();
    }
    addChildrenToList(list) {
        this.expression.addOperandsToList(list);
    }
    hasAsyncFunction() {
        return this.expression.hasAsyncFunction();
    }
    addToAsyncList(list) {
        this.expression.addToAsyncList(list);
    }
    evaluate(processValue) {
        let value = this.expression.evaluate(processValue);
        return this.consumer.call(this, value);
    }
    setVariables(variables) {
        this.expression.setVariables(variables);
    }
}
class ArrayOperand extends Operand {
    constructor(values) {
        super();
        this.values = values;
    }
    getType() {
        return "array";
    }
    toString(func = undefined) {
        if (!!func) {
            var res = func(this);
            if (!!res)
                return res;
        }
        return ("[" +
            this.values
                .map(function (el) {
                return el.toString(func);
            })
                .join(", ") +
            "]");
    }
    evaluate(processValue) {
        return this.values.map(function (el) {
            return el.evaluate(processValue);
        });
    }
    setVariables(variables) {
        this.values.forEach((el) => {
            el.setVariables(variables);
        });
    }
    hasFunction() {
        return this.values.some((operand) => operand.hasFunction());
    }
    addChildrenToList(list) {
        this.values.forEach((el) => {
            el.addOperandsToList(list);
        });
    }
    hasAsyncFunction() {
        return this.values.some((operand) => operand.hasAsyncFunction());
    }
    addToAsyncList(list) {
        this.values.forEach((operand) => operand.addToAsyncList(list));
    }
    isContentEqual(op) {
        const aOp = op;
        if (aOp.values.length !== this.values.length)
            return false;
        for (var i = 0; i < this.values.length; i++) {
            if (!aOp.values[i].isEqual(this.values[i]))
                return false;
        }
        return true;
    }
}
class Const extends Operand {
    constructor(value) {
        super();
        this.value = value;
    }
    getType() {
        return "const";
    }
    toString(func = undefined) {
        if (!!func) {
            var res = func(this);
            if (!!res)
                return res;
        }
        return this.value.toString();
    }
    get correctValue() {
        return this.getCorrectValue(this.value);
    }
    get requireStrictCompare() { return false; }
    evaluate() {
        return this.getCorrectValue(this.value);
    }
    setVariables(variables) { }
    getCorrectValue(value) {
        if (!value || typeof value != "string")
            return value;
        if (OperandMaker.isBooleanValue(value))
            return value.toLowerCase() === "true";
        if (value.length > 1 &&
            this.isQuote(value[0]) &&
            this.isQuote(value[value.length - 1]))
            return value.substring(1, value.length - 1);
        if (Helpers.isNumber(value)) {
            if (value[0] === "0" && value.indexOf("0x") != 0) {
                const len = value.length;
                const hasPoint = len > 1 && (value[1] === "." || value[1] === ",");
                if (!hasPoint && len > 1 || hasPoint && len < 2)
                    return value;
            }
            return Helpers.getNumber(value);
        }
        return value;
    }
    isContentEqual(op) {
        const cOp = op;
        return cOp.value == this.value;
    }
    isQuote(ch) {
        return ch == "'" || ch == '"';
    }
}
class Variable extends Const {
    static get DisableConversionChar() { return settings.expressionDisableConversionChar; }
    static set DisableConversionChar(val) { settings.expressionDisableConversionChar = val; }
    constructor(variableName) {
        super(variableName);
        this.variableName = variableName;
        this.valueInfo = {};
        this.useValueAsItIs = false;
        if (!!this.variableName &&
            this.variableName.length > 1 &&
            this.variableName[0] === Variable.DisableConversionChar) {
            this.variableName = this.variableName.substring(1);
            this.useValueAsItIs = true;
        }
    }
    get requireStrictCompare() {
        return this.valueInfo.sctrictCompare === true;
    }
    getType() {
        return "variable";
    }
    toString(func = undefined) {
        if (!!func) {
            var res = func(this);
            if (!!res)
                return res;
        }
        var prefix = this.useValueAsItIs ? Variable.DisableConversionChar : "";
        return "{" + prefix + this.variableName + "}";
    }
    get variable() {
        return this.variableName;
    }
    evaluate(processValue) {
        this.valueInfo.name = this.variableName;
        processValue.getValueInfo(this.valueInfo);
        if (!this.valueInfo.hasValue)
            return null;
        let val = this.valueInfo.value;
        if (this.valueInfo.onProcessValue) {
            val = this.valueInfo.onProcessValue(val);
        }
        return this.getCorrectValue(val);
    }
    setVariables(variables) {
        variables.push(this.variableName);
    }
    getCorrectValue(value) {
        if (this.useValueAsItIs)
            return value;
        return super.getCorrectValue(value);
    }
    isContentEqual(op) {
        const vOp = op;
        return vOp.variable == this.variable;
    }
}
class FunctionOperand extends Operand {
    constructor(originalValue, parameters) {
        super();
        this.originalValue = originalValue;
        this.parameters = parameters;
        if (Array.isArray(parameters) && parameters.length === 0) {
            this.parameters = new ArrayOperand([]);
        }
    }
    getType() {
        return "function";
    }
    evaluate(processValue) {
        const asyncVal = this.getAsynValue(processValue);
        if (!!asyncVal)
            return asyncVal.value;
        return this.evaluateCore(processValue);
    }
    evaluateCore(processValue) {
        let properties = processValue.properties;
        if (this.isAsyncFunction) {
            properties = Helpers.createCopy(processValue.properties);
            const id = this.id;
            const asyncValues = processValue.asyncValues;
            const onComplete = processValue.onCompleteAsyncFunc;
            const item = this;
            properties.returnResult = (result) => {
                asyncValues[id] = { value: result };
                onComplete(item);
            };
        }
        return FunctionFactory.Instance.run(this.originalValue, this.parameters.evaluate(processValue), properties, this.parameters.values);
    }
    toString(func = undefined) {
        if (!!func) {
            var res = func(this);
            if (!!res)
                return res;
        }
        return this.originalValue + "(" + this.parameters.toString(func) + ")";
    }
    setVariables(variables) {
        this.parameters.setVariables(variables);
    }
    isReady(proccessValue) {
        return !!this.getAsynValue(proccessValue);
    }
    addChildrenToList(list) {
        this.parameters.addOperandsToList(list);
    }
    getAsynValue(proccessValue) {
        return proccessValue.asyncValues[this.id];
    }
    hasFunction() { return true; }
    hasAsyncFunction() {
        return this.isAsyncFunction() || this.parameters.hasAsyncFunction();
    }
    isAsyncFunction() {
        return FunctionFactory.Instance.isAsyncFunction(this.originalValue);
    }
    addToAsyncList(list) {
        let item = undefined;
        if (this.isAsyncFunction()) {
            item = { operand: this };
        }
        if (this.parameters.hasAsyncFunction()) {
            const children = new Array();
            this.parameters.addToAsyncList(children);
            children.forEach(child => child.parent = item);
            if (!item) {
                item = {};
            }
            item.children = children;
        }
        if (item) {
            list.push(item);
        }
    }
    isContentEqual(op) {
        const fOp = op;
        return fOp.originalValue == this.originalValue && this.areOperatorsEquals(fOp.parameters, this.parameters);
    }
}
class OperandMaker {
    static throwInvalidOperatorError(op) {
        throw new Error("Invalid operator: '" + op + "'");
    }
    static safeToString(operand, func) {
        return operand == null ? "" : operand.toString(func);
    }
    static toOperandString(value) {
        if (!!value &&
            !Helpers.isNumber(value) &&
            !OperandMaker.isBooleanValue(value))
            value = "'" + value + "'";
        return value;
    }
    static isBooleanValue(value) {
        return (!!value &&
            (value.toLowerCase() === "true" || value.toLowerCase() === "false"));
    }
    static countDecimals(value) {
        if (Helpers.isNumber(value) && Math.floor(value) !== value) {
            const strs = value.toString().split(".");
            return strs.length > 1 && strs[1].length || 0;
        }
        return 0;
    }
    static plusMinus(a, b, res) {
        const digitsA = OperandMaker.countDecimals(a);
        const digitsB = OperandMaker.countDecimals(b);
        if (digitsA > 0 || digitsB > 0) {
            const digits = Math.max(digitsA, digitsB);
            res = parseFloat(res.toFixed(digits));
        }
        return res;
    }
    static isTwoValueEquals(x, y, ignoreOrder = true) {
        if (x === "undefined")
            x = undefined;
        if (y === "undefined")
            y = undefined;
        return Helpers.isTwoValueEquals(x, y, ignoreOrder);
    }
    static operatorToString(operatorName) {
        let opStr = OperandMaker.signs[operatorName];
        return opStr == null ? operatorName : opStr;
    }
    static convertValForDateCompare(val, second) {
        if (second instanceof Date && typeof val === "string") {
            let res = createDate("expression-operand", val);
            res.setHours(0, 0, 0);
            return res;
        }
        return val;
    }
}
OperandMaker.unaryFunctions = {
    empty: function (value) {
        return Helpers.isValueEmpty(value);
    },
    notempty: function (value) {
        return !OperandMaker.unaryFunctions.empty(value);
    },
    negate: function (value) {
        return !value;
    },
};
OperandMaker.binaryFunctions = {
    arithmeticOp(operatorName) {
        const convertForArithmeticOp = (val, second) => {
            if (!Helpers.isValueEmpty(val))
                return val;
            if (typeof second === "number")
                return 0;
            if (typeof val === "string")
                return val;
            if (typeof second === "string")
                return "";
            if (Array.isArray(second))
                return [];
            return 0;
        };
        return function (a, b) {
            a = convertForArithmeticOp(a, b);
            b = convertForArithmeticOp(b, a);
            let consumer = OperandMaker.binaryFunctions[operatorName];
            return consumer == null ? null : consumer.call(this, a, b);
        };
    },
    and: function (a, b) {
        return a && b;
    },
    or: function (a, b) {
        return a || b;
    },
    plus: function (a, b) {
        return Helpers.sumAnyValues(a, b);
    },
    minus: function (a, b) {
        return Helpers.correctAfterPlusMinis(a, b, a - b);
    },
    mul: function (a, b) {
        return Helpers.correctAfterMultiple(a, b, a * b);
    },
    div: function (a, b) {
        if (!b)
            return null;
        return a / b;
    },
    mod: function (a, b) {
        if (!b)
            return null;
        return a % b;
    },
    power: function (a, b) {
        return Math.pow(a, b);
    },
    greater: function (left, right) {
        if (left == null || right == null)
            return false;
        left = OperandMaker.convertValForDateCompare(left, right);
        right = OperandMaker.convertValForDateCompare(right, left);
        return left > right;
    },
    less: function (left, right) {
        if (left == null || right == null)
            return false;
        left = OperandMaker.convertValForDateCompare(left, right);
        right = OperandMaker.convertValForDateCompare(right, left);
        return left < right;
    },
    greaterorequal: function (left, right) {
        if (OperandMaker.binaryFunctions.equal(left, right))
            return true;
        return OperandMaker.binaryFunctions.greater(left, right);
    },
    lessorequal: function (left, right) {
        if (OperandMaker.binaryFunctions.equal(left, right))
            return true;
        return OperandMaker.binaryFunctions.less(left, right);
    },
    equal: function (left, right, strictCompare) {
        left = OperandMaker.convertValForDateCompare(left, right);
        right = OperandMaker.convertValForDateCompare(right, left);
        return OperandMaker.isTwoValueEquals(left, right, strictCompare !== true);
    },
    notequal: function (left, right, strictCompare) {
        return !OperandMaker.binaryFunctions.equal(left, right, strictCompare);
    },
    contains: function (left, right) {
        return OperandMaker.binaryFunctions.containsCore(left, right, true);
    },
    notcontains: function (left, right) {
        if (!left && !Helpers.isValueEmpty(right))
            return true;
        return OperandMaker.binaryFunctions.containsCore(left, right, false);
    },
    anyof: function (left, right) {
        if (Helpers.isValueEmpty(left) && Helpers.isValueEmpty(right))
            return true;
        if (Helpers.isValueEmpty(left) ||
            (!Array.isArray(left) && left.length === 0))
            return false;
        if (Helpers.isValueEmpty(right))
            return true;
        if (!Array.isArray(left))
            return OperandMaker.binaryFunctions.contains(right, left);
        if (!Array.isArray(right))
            return OperandMaker.binaryFunctions.contains(left, right);
        for (var i = 0; i < right.length; i++) {
            if (OperandMaker.binaryFunctions.contains(left, right[i]))
                return true;
        }
        return false;
    },
    allof: function (left, right) {
        if (!left && !Helpers.isValueEmpty(right))
            return false;
        if (!Array.isArray(right))
            return OperandMaker.binaryFunctions.contains(left, right);
        for (var i = 0; i < right.length; i++) {
            if (!OperandMaker.binaryFunctions.contains(left, right[i]))
                return false;
        }
        return true;
    },
    containsCore: function (left, right, isContains) {
        if (!left && left !== 0 && left !== false)
            return false;
        if (!left.length) {
            left = left.toString();
            if (typeof right === "string" || right instanceof String) {
                left = left.toUpperCase();
                right = right.toUpperCase();
            }
        }
        if (typeof left === "string" || left instanceof String) {
            if (!right)
                return false;
            right = right.toString();
            var found = left.indexOf(right) > -1;
            return isContains ? found : !found;
        }
        var rightArray = Array.isArray(right) ? right : [right];
        for (var rIndex = 0; rIndex < rightArray.length; rIndex++) {
            var i = 0;
            right = rightArray[rIndex];
            for (; i < left.length; i++) {
                if (OperandMaker.isTwoValueEquals(left[i], right))
                    break;
            }
            if (i == left.length)
                return !isContains;
        }
        return isContains;
    },
};
OperandMaker.signs = {
    less: "<",
    lessorequal: "<=",
    greater: ">",
    greaterorequal: ">=",
    equal: "==",
    notequal: "!=",
    plus: "+",
    minus: "-",
    mul: "*",
    div: "/",
    and: "and",
    or: "or",
    power: "^",
    mod: "%",
    negate: "!",
};

/* eslint-disable */
class SyntaxError extends Error {
    static buildMessage(expected, found) {
        function hex(ch) {
            return ch.charCodeAt(0).toString(16).toUpperCase();
        }
        function literalEscape(s) {
            return s
                .replace(/\\/g, "\\\\")
                .replace(/"/g, "\\\"")
                .replace(/\0/g, "\\0")
                .replace(/\t/g, "\\t")
                .replace(/\n/g, "\\n")
                .replace(/\r/g, "\\r")
                .replace(/[\x00-\x0F]/g, (ch) => "\\x0" + hex(ch))
                .replace(/[\x10-\x1F\x7F-\x9F]/g, (ch) => "\\x" + hex(ch));
        }
        function classEscape(s) {
            return s
                .replace(/\\/g, "\\\\")
                .replace(/\]/g, "\\]")
                .replace(/\^/g, "\\^")
                .replace(/-/g, "\\-")
                .replace(/\0/g, "\\0")
                .replace(/\t/g, "\\t")
                .replace(/\n/g, "\\n")
                .replace(/\r/g, "\\r")
                .replace(/[\x00-\x0F]/g, (ch) => "\\x0" + hex(ch))
                .replace(/[\x10-\x1F\x7F-\x9F]/g, (ch) => "\\x" + hex(ch));
        }
        function describeExpectation(expectation) {
            switch (expectation.type) {
                case "literal":
                    return "\"" + literalEscape(expectation.text) + "\"";
                case "class":
                    const escapedParts = expectation.parts.map((part) => {
                        return Array.isArray(part)
                            ? classEscape(part[0]) + "-" + classEscape(part[1])
                            : classEscape(part);
                    });
                    return "[" + (expectation.inverted ? "^" : "") + escapedParts + "]";
                case "any":
                    return "any character";
                case "end":
                    return "end of input";
                case "other":
                    return expectation.description;
            }
        }
        function describeExpected(expected1) {
            const descriptions = expected1.map(describeExpectation);
            let i;
            let j;
            descriptions.sort();
            if (descriptions.length > 0) {
                for (i = 1, j = 1; i < descriptions.length; i++) {
                    if (descriptions[i - 1] !== descriptions[i]) {
                        descriptions[j] = descriptions[i];
                        j++;
                    }
                }
                descriptions.length = j;
            }
            switch (descriptions.length) {
                case 1:
                    return descriptions[0];
                case 2:
                    return descriptions[0] + " or " + descriptions[1];
                default:
                    return descriptions.slice(0, -1).join(", ")
                        + ", or "
                        + descriptions[descriptions.length - 1];
            }
        }
        function describeFound(found1) {
            return found1 ? "\"" + literalEscape(found1) + "\"" : "end of input";
        }
        return "Expected " + describeExpected(expected) + " but " + describeFound(found) + " found.";
    }
    constructor(message, expected, found, location) {
        super();
        this.message = message;
        this.expected = expected;
        this.found = found;
        this.location = location;
        this.name = "SyntaxError";
        if (typeof Error.captureStackTrace === "function") {
            Error.captureStackTrace(this, SyntaxError);
        }
    }
}
function peg$parse(input, options) {
    options = options !== undefined ? options : {};
    const peg$FAILED = {};
    const peg$startRuleFunctions = { Expression: peg$parseExpression };
    let peg$startRuleFunction = peg$parseExpression;
    const peg$c0 = function (head, tail) {
        return buildBinaryOperand(head, tail, true);
    };
    const peg$c1 = "||";
    const peg$c2 = peg$literalExpectation("||", false);
    const peg$c3 = "or";
    const peg$c4 = peg$literalExpectation("or", true);
    const peg$c5 = function () { return "or"; };
    const peg$c6 = "&&";
    const peg$c7 = peg$literalExpectation("&&", false);
    const peg$c8 = "and";
    const peg$c9 = peg$literalExpectation("and", true);
    const peg$c10 = function () { return "and"; };
    const peg$c11 = function (head, tail) {
        return buildBinaryOperand(head, tail);
    };
    const peg$c12 = "<=";
    const peg$c13 = peg$literalExpectation("<=", false);
    const peg$c14 = "lessorequal";
    const peg$c15 = peg$literalExpectation("lessorequal", true);
    const peg$c16 = function () { return "lessorequal"; };
    const peg$c17 = ">=";
    const peg$c18 = peg$literalExpectation(">=", false);
    const peg$c19 = "greaterorequal";
    const peg$c20 = peg$literalExpectation("greaterorequal", true);
    const peg$c21 = function () { return "greaterorequal"; };
    const peg$c22 = "==";
    const peg$c23 = peg$literalExpectation("==", false);
    const peg$c24 = "equal";
    const peg$c25 = peg$literalExpectation("equal", true);
    const peg$c26 = function () { return "equal"; };
    const peg$c27 = "=";
    const peg$c28 = peg$literalExpectation("=", false);
    const peg$c29 = "!=";
    const peg$c30 = peg$literalExpectation("!=", false);
    const peg$c31 = "notequal";
    const peg$c32 = peg$literalExpectation("notequal", true);
    const peg$c33 = function () { return "notequal"; };
    const peg$c34 = "<";
    const peg$c35 = peg$literalExpectation("<", false);
    const peg$c36 = "less";
    const peg$c37 = peg$literalExpectation("less", true);
    const peg$c38 = function () { return "less"; };
    const peg$c39 = ">";
    const peg$c40 = peg$literalExpectation(">", false);
    const peg$c41 = "greater";
    const peg$c42 = peg$literalExpectation("greater", true);
    const peg$c43 = function () { return "greater"; };
    const peg$c44 = "+";
    const peg$c45 = peg$literalExpectation("+", false);
    const peg$c46 = function () { return "plus"; };
    const peg$c47 = "-";
    const peg$c48 = peg$literalExpectation("-", false);
    const peg$c49 = function () { return "minus"; };
    const peg$c50 = "*";
    const peg$c51 = peg$literalExpectation("*", false);
    const peg$c52 = function () { return "mul"; };
    const peg$c53 = "/";
    const peg$c54 = peg$literalExpectation("/", false);
    const peg$c55 = function () { return "div"; };
    const peg$c56 = "%";
    const peg$c57 = peg$literalExpectation("%", false);
    const peg$c58 = function () { return "mod"; };
    const peg$c59 = "^";
    const peg$c60 = peg$literalExpectation("^", false);
    const peg$c61 = "power";
    const peg$c62 = peg$literalExpectation("power", true);
    const peg$c63 = function () { return "power"; };
    const peg$c64 = "*=";
    const peg$c65 = peg$literalExpectation("*=", false);
    const peg$c66 = "contains";
    const peg$c67 = peg$literalExpectation("contains", true);
    const peg$c68 = "contain";
    const peg$c69 = peg$literalExpectation("contain", true);
    const peg$c70 = function () { return "contains"; };
    const peg$c71 = "notcontains";
    const peg$c72 = peg$literalExpectation("notcontains", true);
    const peg$c73 = "notcontain";
    const peg$c74 = peg$literalExpectation("notcontain", true);
    const peg$c75 = function () { return "notcontains"; };
    const peg$c76 = "anyof";
    const peg$c77 = peg$literalExpectation("anyof", true);
    const peg$c78 = function () { return "anyof"; };
    const peg$c79 = "allof";
    const peg$c80 = peg$literalExpectation("allof", true);
    const peg$c81 = function () { return "allof"; };
    const peg$c82 = "(";
    const peg$c83 = peg$literalExpectation("(", false);
    const peg$c84 = ")";
    const peg$c85 = peg$literalExpectation(")", false);
    const peg$c86 = function (expr) { return expr; };
    const peg$c87 = function (name, params) { return new FunctionOperand(name, params); };
    const peg$c88 = "!";
    const peg$c89 = peg$literalExpectation("!", false);
    const peg$c90 = "negate";
    const peg$c91 = peg$literalExpectation("negate", true);
    const peg$c92 = function (expr) { return new UnaryOperand(expr, "negate"); };
    const peg$c93 = function (expr, op) { return new UnaryOperand(expr, op); };
    const peg$c94 = "empty";
    const peg$c95 = peg$literalExpectation("empty", true);
    const peg$c96 = function () { return "empty"; };
    const peg$c97 = "notempty";
    const peg$c98 = peg$literalExpectation("notempty", true);
    const peg$c99 = function () { return "notempty"; };
    const peg$c100 = "undefined";
    const peg$c101 = peg$literalExpectation("undefined", false);
    const peg$c102 = "null";
    const peg$c103 = peg$literalExpectation("null", false);
    const peg$c104 = function () { return null; };
    const peg$c105 = function (value) { return new Const(value); };
    const peg$c106 = "{";
    const peg$c107 = peg$literalExpectation("{", false);
    const peg$c108 = "}";
    const peg$c109 = peg$literalExpectation("}", false);
    const peg$c110 = function (value) { return new Variable(value); };
    const peg$c111 = function (value) { return value; };
    const peg$c112 = "''";
    const peg$c113 = peg$literalExpectation("''", false);
    const peg$c114 = function () { return ""; };
    const peg$c115 = "\"\"";
    const peg$c116 = peg$literalExpectation("\"\"", false);
    const peg$c117 = "'";
    const peg$c118 = peg$literalExpectation("'", false);
    const peg$c119 = function (value) { return "'" + value + "'"; };
    const peg$c120 = "\"";
    const peg$c121 = peg$literalExpectation("\"", false);
    const peg$c122 = "[";
    const peg$c123 = peg$literalExpectation("[", false);
    const peg$c124 = "]";
    const peg$c125 = peg$literalExpectation("]", false);
    const peg$c126 = function (sequence) { return sequence; };
    const peg$c127 = ",";
    const peg$c128 = peg$literalExpectation(",", false);
    const peg$c129 = function (expr, tail) {
        if (expr == null)
            return new ArrayOperand([]);
        var array = [expr];
        if (Array.isArray(tail)) {
            var flatten = flattenArray(tail);
            for (var i = 3; i < flatten.length; i += 4) {
                array.push(flatten[i]);
            }
        }
        return new ArrayOperand(array);
    };
    const peg$c130 = "true";
    const peg$c131 = peg$literalExpectation("true", true);
    const peg$c132 = function () { return true; };
    const peg$c133 = "false";
    const peg$c134 = peg$literalExpectation("false", true);
    const peg$c135 = function () { return false; };
    const peg$c136 = "0x";
    const peg$c137 = peg$literalExpectation("0x", false);
    const peg$c138 = function () { return parseInt(text(), 16); };
    const peg$c139 = /^[\-]/;
    const peg$c140 = peg$classExpectation(["-"], false, false);
    const peg$c141 = function (sign, num) { return sign == null ? num : -num; };
    const peg$c142 = ".";
    const peg$c143 = peg$literalExpectation(".", false);
    const peg$c144 = function () { return parseFloat(text()); };
    const peg$c145 = function () { return parseInt(text(), 10); };
    const peg$c146 = "0";
    const peg$c147 = peg$literalExpectation("0", false);
    const peg$c148 = function () { return 0; };
    const peg$c149 = function (chars) { return chars.join(""); };
    const peg$c150 = "\\'";
    const peg$c151 = peg$literalExpectation("\\'", false);
    const peg$c152 = function () { return "'"; };
    const peg$c153 = "\\\"";
    const peg$c154 = peg$literalExpectation("\\\"", false);
    const peg$c155 = function () { return "\""; };
    const peg$c156 = /^[^"']/;
    const peg$c157 = peg$classExpectation(["\"", "'"], true, false);
    const peg$c158 = function () { return text(); };
    const peg$c159 = /^[^{}]/;
    const peg$c160 = peg$classExpectation(["{", "}"], true, false);
    const peg$c161 = /^[0-9]/;
    const peg$c162 = peg$classExpectation([["0", "9"]], false, false);
    const peg$c163 = /^[1-9]/;
    const peg$c164 = peg$classExpectation([["1", "9"]], false, false);
    const peg$c165 = /^[a-zA-Z_]/;
    const peg$c166 = peg$classExpectation([["a", "z"], ["A", "Z"], "_"], false, false);
    const peg$c167 = peg$otherExpectation("whitespace");
    const peg$c168 = /^[ \t\n\r]/;
    const peg$c169 = peg$classExpectation([" ", "\t", "\n", "\r"], false, false);
    let peg$currPos = 0;
    let peg$savedPos = 0;
    const peg$posDetailsCache = [{ line: 1, column: 1 }];
    let peg$maxFailPos = 0;
    let peg$maxFailExpected = [];
    let peg$silentFails = 0;
    const peg$resultsCache = {};
    let peg$result;
    if (options.startRule !== undefined) {
        if (!(options.startRule in peg$startRuleFunctions)) {
            throw new Error("Can't start parsing from rule \"" + options.startRule + "\".");
        }
        peg$startRuleFunction = peg$startRuleFunctions[options.startRule];
    }
    function text() {
        return input.substring(peg$savedPos, peg$currPos);
    }
    function peg$literalExpectation(text1, ignoreCase) {
        return { type: "literal", text: text1, ignoreCase: ignoreCase };
    }
    function peg$classExpectation(parts, inverted, ignoreCase) {
        return { type: "class", parts: parts, inverted: inverted, ignoreCase: ignoreCase };
    }
    function peg$endExpectation() {
        return { type: "end" };
    }
    function peg$otherExpectation(description) {
        return { type: "other", description: description };
    }
    function peg$computePosDetails(pos) {
        let details = peg$posDetailsCache[pos];
        let p;
        if (details) {
            return details;
        }
        else {
            p = pos - 1;
            while (!peg$posDetailsCache[p]) {
                p--;
            }
            details = peg$posDetailsCache[p];
            details = {
                line: details.line,
                column: details.column
            };
            while (p < pos) {
                if (input.charCodeAt(p) === 10) {
                    details.line++;
                    details.column = 1;
                }
                else {
                    details.column++;
                }
                p++;
            }
            peg$posDetailsCache[pos] = details;
            return details;
        }
    }
    function peg$computeLocation(startPos, endPos) {
        const startPosDetails = peg$computePosDetails(startPos);
        const endPosDetails = peg$computePosDetails(endPos);
        return {
            start: {
                offset: startPos,
                line: startPosDetails.line,
                column: startPosDetails.column
            },
            end: {
                offset: endPos,
                line: endPosDetails.line,
                column: endPosDetails.column
            }
        };
    }
    function peg$fail(expected1) {
        if (peg$currPos < peg$maxFailPos) {
            return;
        }
        if (peg$currPos > peg$maxFailPos) {
            peg$maxFailPos = peg$currPos;
            peg$maxFailExpected = [];
        }
        peg$maxFailExpected.push(expected1);
    }
    function peg$buildStructuredError(expected1, found, location1) {
        return new SyntaxError(SyntaxError.buildMessage(expected1, found), expected1, found, location1);
    }
    function peg$parseExpression() {
        let s0, s1, s2, s3, s4, s5, s6, s7, s8;
        const key = peg$currPos * 34 + 0;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parse_();
        if (s1 !== peg$FAILED) {
            s2 = peg$parseLogicOr();
            if (s2 !== peg$FAILED) {
                s3 = [];
                s4 = peg$currPos;
                s5 = peg$parse_();
                if (s5 !== peg$FAILED) {
                    s6 = peg$parseOrSign();
                    if (s6 !== peg$FAILED) {
                        s7 = peg$parse_();
                        if (s7 !== peg$FAILED) {
                            s8 = peg$parseLogicOr();
                            if (s8 !== peg$FAILED) {
                                s5 = [s5, s6, s7, s8];
                                s4 = s5;
                            }
                            else {
                                peg$currPos = s4;
                                s4 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s4;
                            s4 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s4;
                        s4 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s4;
                    s4 = peg$FAILED;
                }
                while (s4 !== peg$FAILED) {
                    s3.push(s4);
                    s4 = peg$currPos;
                    s5 = peg$parse_();
                    if (s5 !== peg$FAILED) {
                        s6 = peg$parseOrSign();
                        if (s6 !== peg$FAILED) {
                            s7 = peg$parse_();
                            if (s7 !== peg$FAILED) {
                                s8 = peg$parseLogicOr();
                                if (s8 !== peg$FAILED) {
                                    s5 = [s5, s6, s7, s8];
                                    s4 = s5;
                                }
                                else {
                                    peg$currPos = s4;
                                    s4 = peg$FAILED;
                                }
                            }
                            else {
                                peg$currPos = s4;
                                s4 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s4;
                            s4 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s4;
                        s4 = peg$FAILED;
                    }
                }
                if (s3 !== peg$FAILED) {
                    s4 = peg$parse_();
                    if (s4 !== peg$FAILED) {
                        peg$savedPos = s0;
                        s1 = peg$c0(s2, s3);
                        s0 = s1;
                    }
                    else {
                        peg$currPos = s0;
                        s0 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseOrSign() {
        let s0, s1;
        const key = peg$currPos * 34 + 1;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.substr(peg$currPos, 2) === peg$c1) {
            s1 = peg$c1;
            peg$currPos += 2;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c2);
            }
        }
        if (s1 === peg$FAILED) {
            if (input.substr(peg$currPos, 2).toLowerCase() === peg$c3) {
                s1 = input.substr(peg$currPos, 2);
                peg$currPos += 2;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c4);
                }
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c5();
        }
        s0 = s1;
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseLogicOr() {
        let s0, s1, s2, s3, s4, s5, s6, s7;
        const key = peg$currPos * 34 + 2;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseLogicAnd();
        if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse_();
            if (s4 !== peg$FAILED) {
                s5 = peg$parseAndSign();
                if (s5 !== peg$FAILED) {
                    s6 = peg$parse_();
                    if (s6 !== peg$FAILED) {
                        s7 = peg$parseLogicAnd();
                        if (s7 !== peg$FAILED) {
                            s4 = [s4, s5, s6, s7];
                            s3 = s4;
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s3;
                s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
                s2.push(s3);
                s3 = peg$currPos;
                s4 = peg$parse_();
                if (s4 !== peg$FAILED) {
                    s5 = peg$parseAndSign();
                    if (s5 !== peg$FAILED) {
                        s6 = peg$parse_();
                        if (s6 !== peg$FAILED) {
                            s7 = peg$parseLogicAnd();
                            if (s7 !== peg$FAILED) {
                                s4 = [s4, s5, s6, s7];
                                s3 = s4;
                            }
                            else {
                                peg$currPos = s3;
                                s3 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c0(s1, s2);
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseAndSign() {
        let s0, s1;
        const key = peg$currPos * 34 + 3;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.substr(peg$currPos, 2) === peg$c6) {
            s1 = peg$c6;
            peg$currPos += 2;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c7);
            }
        }
        if (s1 === peg$FAILED) {
            if (input.substr(peg$currPos, 3).toLowerCase() === peg$c8) {
                s1 = input.substr(peg$currPos, 3);
                peg$currPos += 3;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c9);
                }
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c10();
        }
        s0 = s1;
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseLogicAnd() {
        let s0, s1, s2, s3, s4, s5, s6, s7;
        const key = peg$currPos * 34 + 4;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseCompOps();
        if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse_();
            if (s4 !== peg$FAILED) {
                s5 = peg$parseComparableOperators();
                if (s5 !== peg$FAILED) {
                    s6 = peg$parse_();
                    if (s6 !== peg$FAILED) {
                        s7 = peg$parseCompOps();
                        if (s7 !== peg$FAILED) {
                            s4 = [s4, s5, s6, s7];
                            s3 = s4;
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s3;
                s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
                s2.push(s3);
                s3 = peg$currPos;
                s4 = peg$parse_();
                if (s4 !== peg$FAILED) {
                    s5 = peg$parseComparableOperators();
                    if (s5 !== peg$FAILED) {
                        s6 = peg$parse_();
                        if (s6 !== peg$FAILED) {
                            s7 = peg$parseCompOps();
                            if (s7 !== peg$FAILED) {
                                s4 = [s4, s5, s6, s7];
                                s3 = s4;
                            }
                            else {
                                peg$currPos = s3;
                                s3 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c11(s1, s2);
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseComparableOperators() {
        let s0, s1;
        const key = peg$currPos * 34 + 5;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.substr(peg$currPos, 2) === peg$c12) {
            s1 = peg$c12;
            peg$currPos += 2;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c13);
            }
        }
        if (s1 === peg$FAILED) {
            if (input.substr(peg$currPos, 11).toLowerCase() === peg$c14) {
                s1 = input.substr(peg$currPos, 11);
                peg$currPos += 11;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c15);
                }
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c16();
        }
        s0 = s1;
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.substr(peg$currPos, 2) === peg$c17) {
                s1 = peg$c17;
                peg$currPos += 2;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c18);
                }
            }
            if (s1 === peg$FAILED) {
                if (input.substr(peg$currPos, 14).toLowerCase() === peg$c19) {
                    s1 = input.substr(peg$currPos, 14);
                    peg$currPos += 14;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c20);
                    }
                }
            }
            if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c21();
            }
            s0 = s1;
            if (s0 === peg$FAILED) {
                s0 = peg$currPos;
                if (input.substr(peg$currPos, 2) === peg$c22) {
                    s1 = peg$c22;
                    peg$currPos += 2;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c23);
                    }
                }
                if (s1 === peg$FAILED) {
                    if (input.substr(peg$currPos, 5).toLowerCase() === peg$c24) {
                        s1 = input.substr(peg$currPos, 5);
                        peg$currPos += 5;
                    }
                    else {
                        s1 = peg$FAILED;
                        if (peg$silentFails === 0) {
                            peg$fail(peg$c25);
                        }
                    }
                }
                if (s1 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c26();
                }
                s0 = s1;
                if (s0 === peg$FAILED) {
                    s0 = peg$currPos;
                    if (input.charCodeAt(peg$currPos) === 61) {
                        s1 = peg$c27;
                        peg$currPos++;
                    }
                    else {
                        s1 = peg$FAILED;
                        if (peg$silentFails === 0) {
                            peg$fail(peg$c28);
                        }
                    }
                    if (s1 === peg$FAILED) {
                        if (input.substr(peg$currPos, 5).toLowerCase() === peg$c24) {
                            s1 = input.substr(peg$currPos, 5);
                            peg$currPos += 5;
                        }
                        else {
                            s1 = peg$FAILED;
                            if (peg$silentFails === 0) {
                                peg$fail(peg$c25);
                            }
                        }
                    }
                    if (s1 !== peg$FAILED) {
                        peg$savedPos = s0;
                        s1 = peg$c26();
                    }
                    s0 = s1;
                    if (s0 === peg$FAILED) {
                        s0 = peg$currPos;
                        if (input.substr(peg$currPos, 2) === peg$c29) {
                            s1 = peg$c29;
                            peg$currPos += 2;
                        }
                        else {
                            s1 = peg$FAILED;
                            if (peg$silentFails === 0) {
                                peg$fail(peg$c30);
                            }
                        }
                        if (s1 === peg$FAILED) {
                            if (input.substr(peg$currPos, 8).toLowerCase() === peg$c31) {
                                s1 = input.substr(peg$currPos, 8);
                                peg$currPos += 8;
                            }
                            else {
                                s1 = peg$FAILED;
                                if (peg$silentFails === 0) {
                                    peg$fail(peg$c32);
                                }
                            }
                        }
                        if (s1 !== peg$FAILED) {
                            peg$savedPos = s0;
                            s1 = peg$c33();
                        }
                        s0 = s1;
                        if (s0 === peg$FAILED) {
                            s0 = peg$currPos;
                            if (input.charCodeAt(peg$currPos) === 60) {
                                s1 = peg$c34;
                                peg$currPos++;
                            }
                            else {
                                s1 = peg$FAILED;
                                if (peg$silentFails === 0) {
                                    peg$fail(peg$c35);
                                }
                            }
                            if (s1 === peg$FAILED) {
                                if (input.substr(peg$currPos, 4).toLowerCase() === peg$c36) {
                                    s1 = input.substr(peg$currPos, 4);
                                    peg$currPos += 4;
                                }
                                else {
                                    s1 = peg$FAILED;
                                    if (peg$silentFails === 0) {
                                        peg$fail(peg$c37);
                                    }
                                }
                            }
                            if (s1 !== peg$FAILED) {
                                peg$savedPos = s0;
                                s1 = peg$c38();
                            }
                            s0 = s1;
                            if (s0 === peg$FAILED) {
                                s0 = peg$currPos;
                                if (input.charCodeAt(peg$currPos) === 62) {
                                    s1 = peg$c39;
                                    peg$currPos++;
                                }
                                else {
                                    s1 = peg$FAILED;
                                    if (peg$silentFails === 0) {
                                        peg$fail(peg$c40);
                                    }
                                }
                                if (s1 === peg$FAILED) {
                                    if (input.substr(peg$currPos, 7).toLowerCase() === peg$c41) {
                                        s1 = input.substr(peg$currPos, 7);
                                        peg$currPos += 7;
                                    }
                                    else {
                                        s1 = peg$FAILED;
                                        if (peg$silentFails === 0) {
                                            peg$fail(peg$c42);
                                        }
                                    }
                                }
                                if (s1 !== peg$FAILED) {
                                    peg$savedPos = s0;
                                    s1 = peg$c43();
                                }
                                s0 = s1;
                            }
                        }
                    }
                }
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseCompOps() {
        let s0, s1, s2, s3, s4, s5, s6, s7;
        const key = peg$currPos * 34 + 6;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parsePlusMinusOps();
        if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse_();
            if (s4 !== peg$FAILED) {
                s5 = peg$parsePlusMinusSigns();
                if (s5 !== peg$FAILED) {
                    s6 = peg$parse_();
                    if (s6 !== peg$FAILED) {
                        s7 = peg$parsePlusMinusOps();
                        if (s7 !== peg$FAILED) {
                            s4 = [s4, s5, s6, s7];
                            s3 = s4;
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s3;
                s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
                s2.push(s3);
                s3 = peg$currPos;
                s4 = peg$parse_();
                if (s4 !== peg$FAILED) {
                    s5 = peg$parsePlusMinusSigns();
                    if (s5 !== peg$FAILED) {
                        s6 = peg$parse_();
                        if (s6 !== peg$FAILED) {
                            s7 = peg$parsePlusMinusOps();
                            if (s7 !== peg$FAILED) {
                                s4 = [s4, s5, s6, s7];
                                s3 = s4;
                            }
                            else {
                                peg$currPos = s3;
                                s3 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c0(s1, s2);
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parsePlusMinusSigns() {
        let s0, s1;
        const key = peg$currPos * 34 + 7;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.charCodeAt(peg$currPos) === 43) {
            s1 = peg$c44;
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c45);
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c46();
        }
        s0 = s1;
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.charCodeAt(peg$currPos) === 45) {
                s1 = peg$c47;
                peg$currPos++;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c48);
                }
            }
            if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c49();
            }
            s0 = s1;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parsePlusMinusOps() {
        let s0, s1, s2, s3, s4, s5, s6, s7;
        const key = peg$currPos * 34 + 8;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseMulDivOps();
        if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse_();
            if (s4 !== peg$FAILED) {
                s5 = peg$parseMulDivSigns();
                if (s5 !== peg$FAILED) {
                    s6 = peg$parse_();
                    if (s6 !== peg$FAILED) {
                        s7 = peg$parseMulDivOps();
                        if (s7 !== peg$FAILED) {
                            s4 = [s4, s5, s6, s7];
                            s3 = s4;
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s3;
                s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
                s2.push(s3);
                s3 = peg$currPos;
                s4 = peg$parse_();
                if (s4 !== peg$FAILED) {
                    s5 = peg$parseMulDivSigns();
                    if (s5 !== peg$FAILED) {
                        s6 = peg$parse_();
                        if (s6 !== peg$FAILED) {
                            s7 = peg$parseMulDivOps();
                            if (s7 !== peg$FAILED) {
                                s4 = [s4, s5, s6, s7];
                                s3 = s4;
                            }
                            else {
                                peg$currPos = s3;
                                s3 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c0(s1, s2);
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseMulDivSigns() {
        let s0, s1;
        const key = peg$currPos * 34 + 9;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.charCodeAt(peg$currPos) === 42) {
            s1 = peg$c50;
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c51);
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c52();
        }
        s0 = s1;
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.charCodeAt(peg$currPos) === 47) {
                s1 = peg$c53;
                peg$currPos++;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c54);
                }
            }
            if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c55();
            }
            s0 = s1;
            if (s0 === peg$FAILED) {
                s0 = peg$currPos;
                if (input.charCodeAt(peg$currPos) === 37) {
                    s1 = peg$c56;
                    peg$currPos++;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c57);
                    }
                }
                if (s1 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c58();
                }
                s0 = s1;
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseMulDivOps() {
        let s0, s1, s2, s3, s4, s5, s6, s7;
        const key = peg$currPos * 34 + 10;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseBinaryFuncOp();
        if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse_();
            if (s4 !== peg$FAILED) {
                s5 = peg$parsePowerSigns();
                if (s5 !== peg$FAILED) {
                    s6 = peg$parse_();
                    if (s6 !== peg$FAILED) {
                        s7 = peg$parseBinaryFuncOp();
                        if (s7 !== peg$FAILED) {
                            s4 = [s4, s5, s6, s7];
                            s3 = s4;
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s3;
                s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
                s2.push(s3);
                s3 = peg$currPos;
                s4 = peg$parse_();
                if (s4 !== peg$FAILED) {
                    s5 = peg$parsePowerSigns();
                    if (s5 !== peg$FAILED) {
                        s6 = peg$parse_();
                        if (s6 !== peg$FAILED) {
                            s7 = peg$parseBinaryFuncOp();
                            if (s7 !== peg$FAILED) {
                                s4 = [s4, s5, s6, s7];
                                s3 = s4;
                            }
                            else {
                                peg$currPos = s3;
                                s3 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c0(s1, s2);
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parsePowerSigns() {
        let s0, s1;
        const key = peg$currPos * 34 + 11;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.charCodeAt(peg$currPos) === 94) {
            s1 = peg$c59;
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c60);
            }
        }
        if (s1 === peg$FAILED) {
            if (input.substr(peg$currPos, 5).toLowerCase() === peg$c61) {
                s1 = input.substr(peg$currPos, 5);
                peg$currPos += 5;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c62);
                }
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c63();
        }
        s0 = s1;
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseBinaryFuncOp() {
        let s0, s1, s2, s3, s4, s5, s6, s7;
        const key = peg$currPos * 34 + 12;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseFactor();
        if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse_();
            if (s4 !== peg$FAILED) {
                s5 = peg$parseBinFunctions();
                if (s5 !== peg$FAILED) {
                    s6 = peg$parse_();
                    if (s6 !== peg$FAILED) {
                        s7 = peg$parseFactor();
                        if (s7 === peg$FAILED) {
                            s7 = null;
                        }
                        if (s7 !== peg$FAILED) {
                            s4 = [s4, s5, s6, s7];
                            s3 = s4;
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s3;
                s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
                s2.push(s3);
                s3 = peg$currPos;
                s4 = peg$parse_();
                if (s4 !== peg$FAILED) {
                    s5 = peg$parseBinFunctions();
                    if (s5 !== peg$FAILED) {
                        s6 = peg$parse_();
                        if (s6 !== peg$FAILED) {
                            s7 = peg$parseFactor();
                            if (s7 === peg$FAILED) {
                                s7 = null;
                            }
                            if (s7 !== peg$FAILED) {
                                s4 = [s4, s5, s6, s7];
                                s3 = s4;
                            }
                            else {
                                peg$currPos = s3;
                                s3 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c11(s1, s2);
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseBinFunctions() {
        let s0, s1;
        const key = peg$currPos * 34 + 13;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.substr(peg$currPos, 2) === peg$c64) {
            s1 = peg$c64;
            peg$currPos += 2;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c65);
            }
        }
        if (s1 === peg$FAILED) {
            if (input.substr(peg$currPos, 8).toLowerCase() === peg$c66) {
                s1 = input.substr(peg$currPos, 8);
                peg$currPos += 8;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c67);
                }
            }
            if (s1 === peg$FAILED) {
                if (input.substr(peg$currPos, 7).toLowerCase() === peg$c68) {
                    s1 = input.substr(peg$currPos, 7);
                    peg$currPos += 7;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c69);
                    }
                }
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c70();
        }
        s0 = s1;
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.substr(peg$currPos, 11).toLowerCase() === peg$c71) {
                s1 = input.substr(peg$currPos, 11);
                peg$currPos += 11;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c72);
                }
            }
            if (s1 === peg$FAILED) {
                if (input.substr(peg$currPos, 10).toLowerCase() === peg$c73) {
                    s1 = input.substr(peg$currPos, 10);
                    peg$currPos += 10;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c74);
                    }
                }
            }
            if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c75();
            }
            s0 = s1;
            if (s0 === peg$FAILED) {
                s0 = peg$currPos;
                if (input.substr(peg$currPos, 5).toLowerCase() === peg$c76) {
                    s1 = input.substr(peg$currPos, 5);
                    peg$currPos += 5;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c77);
                    }
                }
                if (s1 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c78();
                }
                s0 = s1;
                if (s0 === peg$FAILED) {
                    s0 = peg$currPos;
                    if (input.substr(peg$currPos, 5).toLowerCase() === peg$c79) {
                        s1 = input.substr(peg$currPos, 5);
                        peg$currPos += 5;
                    }
                    else {
                        s1 = peg$FAILED;
                        if (peg$silentFails === 0) {
                            peg$fail(peg$c80);
                        }
                    }
                    if (s1 !== peg$FAILED) {
                        peg$savedPos = s0;
                        s1 = peg$c81();
                    }
                    s0 = s1;
                }
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseFactor() {
        let s0, s1, s2, s3, s4, s5;
        const key = peg$currPos * 34 + 14;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.charCodeAt(peg$currPos) === 40) {
            s1 = peg$c82;
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c83);
            }
        }
        if (s1 !== peg$FAILED) {
            s2 = peg$parse_();
            if (s2 !== peg$FAILED) {
                s3 = peg$parseExpression();
                if (s3 !== peg$FAILED) {
                    s4 = peg$parse_();
                    if (s4 !== peg$FAILED) {
                        if (input.charCodeAt(peg$currPos) === 41) {
                            s5 = peg$c84;
                            peg$currPos++;
                        }
                        else {
                            s5 = peg$FAILED;
                            if (peg$silentFails === 0) {
                                peg$fail(peg$c85);
                            }
                        }
                        if (s5 === peg$FAILED) {
                            s5 = null;
                        }
                        if (s5 !== peg$FAILED) {
                            peg$savedPos = s0;
                            s1 = peg$c86(s3);
                            s0 = s1;
                        }
                        else {
                            peg$currPos = s0;
                            s0 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s0;
                        s0 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        if (s0 === peg$FAILED) {
            s0 = peg$parseFunctionOp();
            if (s0 === peg$FAILED) {
                s0 = peg$parseUnaryFunctionOp();
                if (s0 === peg$FAILED) {
                    s0 = peg$parseAtom();
                    if (s0 === peg$FAILED) {
                        s0 = peg$parseArrayOp();
                    }
                }
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseFunctionOp() {
        let s0, s1, s2, s3, s4;
        const key = peg$currPos * 34 + 15;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseLettersAndDigits();
        if (s1 !== peg$FAILED) {
            if (input.charCodeAt(peg$currPos) === 40) {
                s2 = peg$c82;
                peg$currPos++;
            }
            else {
                s2 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c83);
                }
            }
            if (s2 !== peg$FAILED) {
                s3 = peg$parseSequence();
                if (s3 !== peg$FAILED) {
                    if (input.charCodeAt(peg$currPos) === 41) {
                        s4 = peg$c84;
                        peg$currPos++;
                    }
                    else {
                        s4 = peg$FAILED;
                        if (peg$silentFails === 0) {
                            peg$fail(peg$c85);
                        }
                    }
                    if (s4 === peg$FAILED) {
                        s4 = null;
                    }
                    if (s4 !== peg$FAILED) {
                        peg$savedPos = s0;
                        s1 = peg$c87(s1, s3);
                        s0 = s1;
                    }
                    else {
                        peg$currPos = s0;
                        s0 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseUnaryFunctionOp() {
        let s0, s1, s2, s3;
        const key = peg$currPos * 34 + 16;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.charCodeAt(peg$currPos) === 33) {
            s1 = peg$c88;
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c89);
            }
        }
        if (s1 === peg$FAILED) {
            if (input.substr(peg$currPos, 6).toLowerCase() === peg$c90) {
                s1 = input.substr(peg$currPos, 6);
                peg$currPos += 6;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c91);
                }
            }
        }
        if (s1 !== peg$FAILED) {
            s2 = peg$parse_();
            if (s2 !== peg$FAILED) {
                s3 = peg$parseExpression();
                if (s3 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c92(s3);
                    s0 = s1;
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            s1 = peg$parseAtom();
            if (s1 !== peg$FAILED) {
                s2 = peg$parse_();
                if (s2 !== peg$FAILED) {
                    s3 = peg$parseUnFunctions();
                    if (s3 !== peg$FAILED) {
                        peg$savedPos = s0;
                        s1 = peg$c93(s1, s3);
                        s0 = s1;
                    }
                    else {
                        peg$currPos = s0;
                        s0 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseUnFunctions() {
        let s0, s1;
        const key = peg$currPos * 34 + 17;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.substr(peg$currPos, 5).toLowerCase() === peg$c94) {
            s1 = input.substr(peg$currPos, 5);
            peg$currPos += 5;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c95);
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c96();
        }
        s0 = s1;
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.substr(peg$currPos, 8).toLowerCase() === peg$c97) {
                s1 = input.substr(peg$currPos, 8);
                peg$currPos += 8;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c98);
                }
            }
            if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c99();
            }
            s0 = s1;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseAtom() {
        let s0, s1, s2, s3, s4;
        const key = peg$currPos * 34 + 18;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parse_();
        if (s1 !== peg$FAILED) {
            if (input.substr(peg$currPos, 9) === peg$c100) {
                s2 = peg$c100;
                peg$currPos += 9;
            }
            else {
                s2 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c101);
                }
            }
            if (s2 === peg$FAILED) {
                if (input.substr(peg$currPos, 4) === peg$c102) {
                    s2 = peg$c102;
                    peg$currPos += 4;
                }
                else {
                    s2 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c103);
                    }
                }
            }
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c104();
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            s1 = peg$parse_();
            if (s1 !== peg$FAILED) {
                s2 = peg$parseConstValue();
                if (s2 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c105(s2);
                    s0 = s1;
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
            if (s0 === peg$FAILED) {
                s0 = peg$currPos;
                s1 = peg$parse_();
                if (s1 !== peg$FAILED) {
                    if (input.charCodeAt(peg$currPos) === 123) {
                        s2 = peg$c106;
                        peg$currPos++;
                    }
                    else {
                        s2 = peg$FAILED;
                        if (peg$silentFails === 0) {
                            peg$fail(peg$c107);
                        }
                    }
                    if (s2 !== peg$FAILED) {
                        s3 = peg$parseValueInput();
                        if (s3 !== peg$FAILED) {
                            if (input.charCodeAt(peg$currPos) === 125) {
                                s4 = peg$c108;
                                peg$currPos++;
                            }
                            else {
                                s4 = peg$FAILED;
                                if (peg$silentFails === 0) {
                                    peg$fail(peg$c109);
                                }
                            }
                            if (s4 !== peg$FAILED) {
                                peg$savedPos = s0;
                                s1 = peg$c110(s3);
                                s0 = s1;
                            }
                            else {
                                peg$currPos = s0;
                                s0 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s0;
                            s0 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s0;
                        s0 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseConstValue() {
        let s0, s1, s2, s3;
        const key = peg$currPos * 34 + 19;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseLogicValue();
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c111(s1);
        }
        s0 = s1;
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            s1 = peg$parseArithmeticValue();
            if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c111(s1);
            }
            s0 = s1;
            if (s0 === peg$FAILED) {
                s0 = peg$currPos;
                s1 = peg$parseLettersAndDigits();
                if (s1 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c111(s1);
                }
                s0 = s1;
                if (s0 === peg$FAILED) {
                    s0 = peg$currPos;
                    if (input.substr(peg$currPos, 2) === peg$c112) {
                        s1 = peg$c112;
                        peg$currPos += 2;
                    }
                    else {
                        s1 = peg$FAILED;
                        if (peg$silentFails === 0) {
                            peg$fail(peg$c113);
                        }
                    }
                    if (s1 !== peg$FAILED) {
                        peg$savedPos = s0;
                        s1 = peg$c114();
                    }
                    s0 = s1;
                    if (s0 === peg$FAILED) {
                        s0 = peg$currPos;
                        if (input.substr(peg$currPos, 2) === peg$c115) {
                            s1 = peg$c115;
                            peg$currPos += 2;
                        }
                        else {
                            s1 = peg$FAILED;
                            if (peg$silentFails === 0) {
                                peg$fail(peg$c116);
                            }
                        }
                        if (s1 !== peg$FAILED) {
                            peg$savedPos = s0;
                            s1 = peg$c114();
                        }
                        s0 = s1;
                        if (s0 === peg$FAILED) {
                            s0 = peg$currPos;
                            if (input.charCodeAt(peg$currPos) === 39) {
                                s1 = peg$c117;
                                peg$currPos++;
                            }
                            else {
                                s1 = peg$FAILED;
                                if (peg$silentFails === 0) {
                                    peg$fail(peg$c118);
                                }
                            }
                            if (s1 !== peg$FAILED) {
                                s2 = peg$parseAnyInput();
                                if (s2 !== peg$FAILED) {
                                    if (input.charCodeAt(peg$currPos) === 39) {
                                        s3 = peg$c117;
                                        peg$currPos++;
                                    }
                                    else {
                                        s3 = peg$FAILED;
                                        if (peg$silentFails === 0) {
                                            peg$fail(peg$c118);
                                        }
                                    }
                                    if (s3 !== peg$FAILED) {
                                        peg$savedPos = s0;
                                        s1 = peg$c119(s2);
                                        s0 = s1;
                                    }
                                    else {
                                        peg$currPos = s0;
                                        s0 = peg$FAILED;
                                    }
                                }
                                else {
                                    peg$currPos = s0;
                                    s0 = peg$FAILED;
                                }
                            }
                            else {
                                peg$currPos = s0;
                                s0 = peg$FAILED;
                            }
                            if (s0 === peg$FAILED) {
                                s0 = peg$currPos;
                                if (input.charCodeAt(peg$currPos) === 34) {
                                    s1 = peg$c120;
                                    peg$currPos++;
                                }
                                else {
                                    s1 = peg$FAILED;
                                    if (peg$silentFails === 0) {
                                        peg$fail(peg$c121);
                                    }
                                }
                                if (s1 !== peg$FAILED) {
                                    s2 = peg$parseAnyInput();
                                    if (s2 !== peg$FAILED) {
                                        if (input.charCodeAt(peg$currPos) === 34) {
                                            s3 = peg$c120;
                                            peg$currPos++;
                                        }
                                        else {
                                            s3 = peg$FAILED;
                                            if (peg$silentFails === 0) {
                                                peg$fail(peg$c121);
                                            }
                                        }
                                        if (s3 !== peg$FAILED) {
                                            peg$savedPos = s0;
                                            s1 = peg$c119(s2);
                                            s0 = s1;
                                        }
                                        else {
                                            peg$currPos = s0;
                                            s0 = peg$FAILED;
                                        }
                                    }
                                    else {
                                        peg$currPos = s0;
                                        s0 = peg$FAILED;
                                    }
                                }
                                else {
                                    peg$currPos = s0;
                                    s0 = peg$FAILED;
                                }
                            }
                        }
                    }
                }
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseArrayOp() {
        let s0, s1, s2, s3;
        const key = peg$currPos * 34 + 20;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.charCodeAt(peg$currPos) === 91) {
            s1 = peg$c122;
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c123);
            }
        }
        if (s1 !== peg$FAILED) {
            s2 = peg$parseSequence();
            if (s2 !== peg$FAILED) {
                if (input.charCodeAt(peg$currPos) === 93) {
                    s3 = peg$c124;
                    peg$currPos++;
                }
                else {
                    s3 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c125);
                    }
                }
                if (s3 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c126(s2);
                    s0 = s1;
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseSequence() {
        let s0, s1, s2, s3, s4, s5, s6, s7;
        const key = peg$currPos * 34 + 21;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseExpression();
        if (s1 === peg$FAILED) {
            s1 = null;
        }
        if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse_();
            if (s4 !== peg$FAILED) {
                if (input.charCodeAt(peg$currPos) === 44) {
                    s5 = peg$c127;
                    peg$currPos++;
                }
                else {
                    s5 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c128);
                    }
                }
                if (s5 !== peg$FAILED) {
                    s6 = peg$parse_();
                    if (s6 !== peg$FAILED) {
                        s7 = peg$parseExpression();
                        if (s7 !== peg$FAILED) {
                            s4 = [s4, s5, s6, s7];
                            s3 = s4;
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s3;
                s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
                s2.push(s3);
                s3 = peg$currPos;
                s4 = peg$parse_();
                if (s4 !== peg$FAILED) {
                    if (input.charCodeAt(peg$currPos) === 44) {
                        s5 = peg$c127;
                        peg$currPos++;
                    }
                    else {
                        s5 = peg$FAILED;
                        if (peg$silentFails === 0) {
                            peg$fail(peg$c128);
                        }
                    }
                    if (s5 !== peg$FAILED) {
                        s6 = peg$parse_();
                        if (s6 !== peg$FAILED) {
                            s7 = peg$parseExpression();
                            if (s7 !== peg$FAILED) {
                                s4 = [s4, s5, s6, s7];
                                s3 = s4;
                            }
                            else {
                                peg$currPos = s3;
                                s3 = peg$FAILED;
                            }
                        }
                        else {
                            peg$currPos = s3;
                            s3 = peg$FAILED;
                        }
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c129(s1, s2);
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseLogicValue() {
        let s0, s1;
        const key = peg$currPos * 34 + 22;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.substr(peg$currPos, 4).toLowerCase() === peg$c130) {
            s1 = input.substr(peg$currPos, 4);
            peg$currPos += 4;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c131);
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c132();
        }
        s0 = s1;
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.substr(peg$currPos, 5).toLowerCase() === peg$c133) {
                s1 = input.substr(peg$currPos, 5);
                peg$currPos += 5;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c134);
                }
            }
            if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c135();
            }
            s0 = s1;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseArithmeticValue() {
        let s0, s1, s2;
        const key = peg$currPos * 34 + 23;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.substr(peg$currPos, 2) === peg$c136) {
            s1 = peg$c136;
            peg$currPos += 2;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c137);
            }
        }
        if (s1 !== peg$FAILED) {
            s2 = peg$parseDigits();
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c138();
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (peg$c139.test(input.charAt(peg$currPos))) {
                s1 = input.charAt(peg$currPos);
                peg$currPos++;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c140);
                }
            }
            if (s1 === peg$FAILED) {
                s1 = null;
            }
            if (s1 !== peg$FAILED) {
                s2 = peg$parseNumber();
                if (s2 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c141(s1, s2);
                    s0 = s1;
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseNumber() {
        let s0, s1, s2, s3;
        const key = peg$currPos * 34 + 24;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseDigits();
        if (s1 !== peg$FAILED) {
            if (input.charCodeAt(peg$currPos) === 46) {
                s2 = peg$c142;
                peg$currPos++;
            }
            else {
                s2 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c143);
                }
            }
            if (s2 !== peg$FAILED) {
                s3 = peg$parseDigits();
                if (s3 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c144();
                    s0 = s1;
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            s1 = peg$parseNonZeroDigits();
            if (s1 !== peg$FAILED) {
                s2 = peg$parseDigits();
                if (s2 === peg$FAILED) {
                    s2 = null;
                }
                if (s2 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c145();
                    s0 = s1;
                }
                else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
            if (s0 === peg$FAILED) {
                s0 = peg$currPos;
                if (input.charCodeAt(peg$currPos) === 48) {
                    s1 = peg$c146;
                    peg$currPos++;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c147);
                    }
                }
                if (s1 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c148();
                }
                s0 = s1;
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseValueInput() {
        let s0, s1, s2;
        const key = peg$currPos * 34 + 25;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = [];
        s2 = peg$parseValueCharacters();
        if (s2 !== peg$FAILED) {
            while (s2 !== peg$FAILED) {
                s1.push(s2);
                s2 = peg$parseValueCharacters();
            }
        }
        else {
            s1 = peg$FAILED;
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c149(s1);
        }
        s0 = s1;
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseAnyInput() {
        let s0, s1, s2;
        const key = peg$currPos * 34 + 26;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = [];
        s2 = peg$parseAnyCharacters();
        if (s2 !== peg$FAILED) {
            while (s2 !== peg$FAILED) {
                s1.push(s2);
                s2 = peg$parseAnyCharacters();
            }
        }
        else {
            s1 = peg$FAILED;
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c149(s1);
        }
        s0 = s1;
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseAnyCharacters() {
        let s0, s1;
        const key = peg$currPos * 34 + 27;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (input.substr(peg$currPos, 2) === peg$c150) {
            s1 = peg$c150;
            peg$currPos += 2;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c151);
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c152();
        }
        s0 = s1;
        if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.substr(peg$currPos, 2) === peg$c153) {
                s1 = peg$c153;
                peg$currPos += 2;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c154);
                }
            }
            if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c155();
            }
            s0 = s1;
            if (s0 === peg$FAILED) {
                s0 = peg$currPos;
                if (peg$c156.test(input.charAt(peg$currPos))) {
                    s1 = input.charAt(peg$currPos);
                    peg$currPos++;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c157);
                    }
                }
                if (s1 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c158();
                }
                s0 = s1;
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseValueCharacters() {
        let s0, s1;
        const key = peg$currPos * 34 + 28;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        if (peg$c159.test(input.charAt(peg$currPos))) {
            s1 = input.charAt(peg$currPos);
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c160);
            }
        }
        if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c158();
        }
        s0 = s1;
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseLettersAndDigits() {
        let s0, s1, s2, s3, s4, s5, s6;
        const key = peg$currPos * 34 + 29;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = peg$currPos;
        s1 = peg$parseLetters();
        if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parseDigits();
            if (s4 !== peg$FAILED) {
                s5 = [];
                s6 = peg$parseLetters();
                while (s6 !== peg$FAILED) {
                    s5.push(s6);
                    s6 = peg$parseLetters();
                }
                if (s5 !== peg$FAILED) {
                    s4 = [s4, s5];
                    s3 = s4;
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            else {
                peg$currPos = s3;
                s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
                s2.push(s3);
                s3 = peg$currPos;
                s4 = peg$parseDigits();
                if (s4 !== peg$FAILED) {
                    s5 = [];
                    s6 = peg$parseLetters();
                    while (s6 !== peg$FAILED) {
                        s5.push(s6);
                        s6 = peg$parseLetters();
                    }
                    if (s5 !== peg$FAILED) {
                        s4 = [s4, s5];
                        s3 = s4;
                    }
                    else {
                        peg$currPos = s3;
                        s3 = peg$FAILED;
                    }
                }
                else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                }
            }
            if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c158();
                s0 = s1;
            }
            else {
                peg$currPos = s0;
                s0 = peg$FAILED;
            }
        }
        else {
            peg$currPos = s0;
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseDigits() {
        let s0, s1;
        const key = peg$currPos * 34 + 30;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = [];
        if (peg$c161.test(input.charAt(peg$currPos))) {
            s1 = input.charAt(peg$currPos);
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c162);
            }
        }
        if (s1 !== peg$FAILED) {
            while (s1 !== peg$FAILED) {
                s0.push(s1);
                if (peg$c161.test(input.charAt(peg$currPos))) {
                    s1 = input.charAt(peg$currPos);
                    peg$currPos++;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c162);
                    }
                }
            }
        }
        else {
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseNonZeroDigits() {
        let s0, s1;
        const key = peg$currPos * 34 + 31;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = [];
        if (peg$c163.test(input.charAt(peg$currPos))) {
            s1 = input.charAt(peg$currPos);
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c164);
            }
        }
        if (s1 !== peg$FAILED) {
            while (s1 !== peg$FAILED) {
                s0.push(s1);
                if (peg$c163.test(input.charAt(peg$currPos))) {
                    s1 = input.charAt(peg$currPos);
                    peg$currPos++;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c164);
                    }
                }
            }
        }
        else {
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parseLetters() {
        let s0, s1;
        const key = peg$currPos * 34 + 32;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        s0 = [];
        if (peg$c165.test(input.charAt(peg$currPos))) {
            s1 = input.charAt(peg$currPos);
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c166);
            }
        }
        if (s1 !== peg$FAILED) {
            while (s1 !== peg$FAILED) {
                s0.push(s1);
                if (peg$c165.test(input.charAt(peg$currPos))) {
                    s1 = input.charAt(peg$currPos);
                    peg$currPos++;
                }
                else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) {
                        peg$fail(peg$c166);
                    }
                }
            }
        }
        else {
            s0 = peg$FAILED;
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function peg$parse_() {
        let s0, s1;
        const key = peg$currPos * 34 + 33;
        const cached = peg$resultsCache[key];
        if (cached) {
            peg$currPos = cached.nextPos;
            return cached.result;
        }
        peg$silentFails++;
        s0 = [];
        if (peg$c168.test(input.charAt(peg$currPos))) {
            s1 = input.charAt(peg$currPos);
            peg$currPos++;
        }
        else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c169);
            }
        }
        while (s1 !== peg$FAILED) {
            s0.push(s1);
            if (peg$c168.test(input.charAt(peg$currPos))) {
                s1 = input.charAt(peg$currPos);
                peg$currPos++;
            }
            else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) {
                    peg$fail(peg$c169);
                }
            }
        }
        peg$silentFails--;
        if (s0 === peg$FAILED) {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) {
                peg$fail(peg$c167);
            }
        }
        peg$resultsCache[key] = { nextPos: peg$currPos, result: s0 };
        return s0;
    }
    function buildBinaryOperand(head, tail, isArithmeticOp = false) {
        return tail.reduce(function (result, elements) {
            return new BinaryOperand(elements[1], result, elements[3], isArithmeticOp);
        }, head);
    }
    function flattenArray(array) {
        return [].concat.apply([], array);
    }
    peg$result = peg$startRuleFunction();
    if (peg$result !== peg$FAILED && peg$currPos === input.length) {
        return peg$result;
    }
    else {
        if (peg$result !== peg$FAILED && peg$currPos < input.length) {
            peg$fail(peg$endExpectation());
        }
        throw peg$buildStructuredError(peg$maxFailExpected, peg$maxFailPos < input.length ? input.charAt(peg$maxFailPos) : null, peg$maxFailPos < input.length
            ? peg$computeLocation(peg$maxFailPos, peg$maxFailPos + 1)
            : peg$computeLocation(peg$maxFailPos, peg$maxFailPos));
    }
}
const parse = peg$parse;

class ConditionsParserError {
    constructor(at, code) {
        this.at = at;
        this.code = code;
    }
}
class ConditionsParser {
    patchExpression(text) {
        return text
            .replace(/=>/g, ">=")
            .replace(/=</g, "<=")
            .replace(/<>/g, "!=")
            .replace(/equals/g, "equal ")
            .replace(/notequals/g, "notequal ");
    }
    createCondition(text) {
        return this.parseExpression(text);
    }
    parseExpression(text) {
        try {
            return parse(this.patchExpression(text));
        }
        catch (e) {
            if (e instanceof SyntaxError) {
                this.conditionError = new ConditionsParserError(e.location.start.offset, e.message);
            }
        }
    }
    get error() {
        return this.conditionError;
    }
}

class ExpressionExecutorRunner {
    constructor(operand, id, onComplete, values, properties) {
        this.operand = operand;
        this.id = id;
        this.onComplete = onComplete;
        this.processValue = new ProcessValue();
        this.processValue.values = values;
        this.processValue.properties = properties;
    }
    run(isAsync) {
        if (!isAsync)
            return this.runValues();
        this.processValue.values = Helpers.createCopy(this.processValue.values);
        this.processValue.onCompleteAsyncFunc = (op) => {
            const item = this.getAsyncItemByOperand(op, this.asyncFuncList);
            if (item) {
                this.doAsyncFunctionReady(item);
            }
        };
        this.asyncFuncList = new Array();
        this.operand.addToAsyncList(this.asyncFuncList);
        for (var i = 0; i < this.asyncFuncList.length; i++) {
            this.runAsyncItem(this.asyncFuncList[i]);
        }
        return false;
    }
    getAsyncItemByOperand(op, list) {
        if (!Array.isArray(list))
            return null;
        for (let i = 0; i < list.length; i++) {
            if (list[i].operand === op)
                return list[i];
            const res = this.getAsyncItemByOperand(op, list[i].children);
            if (!!res)
                return res;
        }
        return null;
    }
    runAsyncItem(item) {
        if (item.children) {
            item.children.forEach(child => this.runAsyncItem(child));
        }
        else {
            this.runAsyncItemCore(item);
        }
    }
    runAsyncItemCore(item) {
        if (item.operand) {
            item.operand.evaluate(this.processValue);
        }
        else {
            this.doAsyncFunctionReady(item);
        }
    }
    doAsyncFunctionReady(item) {
        if (item.parent && this.isAsyncChildrenReady(item)) {
            this.runAsyncItemCore(item.parent);
            return;
        }
        for (var i = 0; i < this.asyncFuncList.length; i++) {
            if (!this.isAsyncFuncReady(this.asyncFuncList[i]))
                return;
        }
        this.runValues();
    }
    isAsyncFuncReady(item) {
        if (item.operand && !item.operand.isReady(this.processValue))
            return false;
        return this.isAsyncChildrenReady(item);
    }
    isAsyncChildrenReady(item) {
        if (item.children) {
            for (let i = 0; i < item.children.length; i++) {
                if (!this.isAsyncFuncReady(item.children[i]))
                    return false;
            }
        }
        return true;
    }
    runValues() {
        var res = this.operand.evaluate(this.processValue);
        if (!!this.onComplete) {
            this.onComplete(res, this.id);
        }
        return res;
    }
}
class ExpressionExecutor {
    static getQuestionErrorText(properties) {
        if (!!properties) {
            const question = properties["question"];
            if (!!question && !!question.name) {
                return " It is used in the question: '" + question.name + "'.";
            }
        }
        return "";
    }
    constructor(expression) {
        this.parser = new ConditionsParser();
        this.isAsyncValue = false;
        this.hasFunctionValue = false;
        this.setExpression(expression);
    }
    get expression() {
        return this.expressionValue;
    }
    setExpression(value) {
        if (this.expression === value)
            return;
        this.expressionValue = value;
        this.operand = this.parser.parseExpression(value);
        this.hasFunctionValue = this.canRun() ? this.operand.hasFunction() : false;
        this.isAsyncValue = this.hasFunction()
            ? this.operand.hasAsyncFunction()
            : false;
    }
    getVariables() {
        if (!this.operand)
            return [];
        var variables = [];
        this.operand.setVariables(variables);
        return variables;
    }
    hasFunction() {
        return this.hasFunctionValue;
    }
    get isAsync() {
        return this.isAsyncValue;
    }
    canRun() {
        return !!this.operand;
    }
    run(values, properties = null, id) {
        if (!this.operand) {
            if (!!this.expression) {
                ConsoleWarnings.warn("Invalid expression: '" + this.expression + "'." + ExpressionExecutor.getQuestionErrorText(properties));
            }
            return null;
        }
        const runner = new ExpressionExecutorRunner(this.operand, id, this.onComplete, values, properties);
        return runner.run(this.isAsync);
    }
}
ExpressionExecutor.createExpressionExecutor = (expression) => { return new ExpressionExecutor(expression); };
class ExpressionRunnerBase {
    constructor(expression) {
        this.expression = expression;
    }
    get expression() {
        return !!this.expressionExecutor ? this.expressionExecutor.expression : "";
    }
    set expression(value) {
        if (!!this.expressionExecutor && value === this.expression)
            return;
        this.expressionExecutor = ExpressionExecutor.createExpressionExecutor(value);
        this.expressionExecutor.onComplete = (res, id) => { this.doOnComplete(res, id); };
        this.variables = undefined;
        this.containsFunc = undefined;
    }
    getVariables() {
        if (this.variables === undefined) {
            this.variables = this.expressionExecutor.getVariables();
        }
        return this.variables;
    }
    hasFunction() {
        if (this.containsFunc === undefined) {
            this.containsFunc = this.expressionExecutor.hasFunction();
        }
        return this.containsFunc;
    }
    get isAsync() {
        return this.expressionExecutor.isAsync;
    }
    canRun() {
        return this.expressionExecutor.canRun();
    }
    runCore(values, properties = null) {
        const id = ExpressionRunnerBase.IdRunnerCounter++;
        if (this.onBeforeAsyncRun && this.isAsync) {
            this.onBeforeAsyncRun(id);
        }
        return this.expressionExecutor.run(values, properties, id);
    }
    doOnComplete(res, id) {
        if (this.onAfterAsyncRun && this.isAsync) {
            this.onAfterAsyncRun(id);
        }
    }
}
ExpressionRunnerBase.IdRunnerCounter = 1;
class ConditionRunner extends ExpressionRunnerBase {
    run(values, properties = null) {
        return this.runCore(values, properties) == true;
    }
    doOnComplete(res, id) {
        if (!!this.onRunComplete)
            this.onRunComplete(res == true);
        super.doOnComplete(res, id);
    }
}
class ExpressionRunner extends ExpressionRunnerBase {
    run(values, properties = null) {
        return this.runCore(values, properties);
    }
    doOnComplete(res, id) {
        if (!!this.onRunComplete)
            this.onRunComplete(res);
        super.doOnComplete(res, id);
    }
}

class Bindings {
    constructor(obj) {
        this.obj = obj;
        this.properties = null;
        this.values = null;
    }
    getType() {
        return "bindings";
    }
    get isSurveyObj() { return true; }
    getNames() {
        var res = [];
        this.fillProperties();
        for (var i = 0; i < this.properties.length; i++) {
            if (this.properties[i].isVisible("", this.obj)) {
                res.push(this.properties[i].name);
            }
        }
        return res;
    }
    getProperties() {
        var res = [];
        this.fillProperties();
        for (var i = 0; i < this.properties.length; i++) {
            res.push(this.properties[i]);
        }
        return res;
    }
    setBinding(propertyName, valueName) {
        if (!this.values)
            this.values = {};
        const oldValue = this.getJson();
        if (oldValue === valueName)
            return;
        if (!!valueName) {
            this.values[propertyName] = valueName;
        }
        else {
            delete this.values[propertyName];
            if (Object.keys(this.values).length == 0) {
                this.values = null;
            }
        }
        this.onChangedJSON(oldValue);
    }
    clearBinding(propertyName) {
        this.setBinding(propertyName, "");
    }
    isEmpty() {
        if (!this.values)
            return true;
        for (var key in this.values)
            return false;
        return true;
    }
    getValueNameByPropertyName(propertyName) {
        if (!this.values)
            return undefined;
        return this.values[propertyName];
    }
    getPropertiesByValueName(valueName) {
        if (!this.values)
            return [];
        var res = [];
        for (var key in this.values) {
            if (this.values[key] == valueName) {
                res.push(key);
            }
        }
        return res;
    }
    getJson() {
        if (this.isEmpty())
            return undefined;
        const res = {};
        this.getNames().forEach(key => {
            if (this.values[key] !== undefined) {
                res[key] = this.values[key];
            }
        });
        return res;
    }
    setJson(value, isLoading) {
        const oldValue = this.getJson();
        this.values = null;
        if (!!value) {
            this.getNames().forEach(key => {
                if (value[key] !== undefined) {
                    if (!this.values)
                        this.values = {};
                    this.values[key] = value[key];
                }
            });
        }
        if (!isLoading && !Helpers.isTwoValueEquals(oldValue, this.values)) {
            this.onChangedJSON(oldValue);
        }
    }
    fillProperties() {
        if (this.properties !== null)
            return;
        this.properties = [];
        var objProperties = Serializer.getPropertiesByObj(this.obj);
        for (var i = 0; i < objProperties.length; i++) {
            if (objProperties[i].isBindable) {
                this.properties.push(objProperties[i]);
            }
        }
    }
    onChangedJSON(oldValue) {
        if (this.obj) {
            this.obj.onBindingChanged(oldValue, this.getJson());
        }
    }
}
class Dependencies {
    constructor(currentDependency, target, property) {
        this.currentDependency = currentDependency;
        this.target = target;
        this.property = property;
        this.dependencies = [];
        this.id = "" + (++Dependencies.DependenciesCount);
    }
    addDependency(target, property) {
        if (this.target === target && this.property === property)
            return;
        if (this.dependencies.some(dependency => dependency.obj === target && dependency.prop === property))
            return;
        this.dependencies.push({
            obj: target,
            prop: property,
            id: this.id
        });
        target.registerPropertyChangedHandlers([property], this.currentDependency, this.id);
    }
    dispose() {
        this.dependencies.forEach(dependency => {
            dependency.obj.unregisterPropertyChangedHandlers([dependency.prop], dependency.id);
        });
        // this.currentDependency = undefined;
    }
}
Dependencies.DependenciesCount = 0;
class ComputedUpdater {
    constructor(_updater) {
        this._updater = _updater;
        this.dependencies = undefined;
        this.type = ComputedUpdater.ComputedUpdaterType;
    }
    get updater() {
        return this._updater;
    }
    setDependencies(dependencies) {
        this.clearDependencies();
        this.dependencies = dependencies;
    }
    getDependencies() {
        return this.dependencies;
    }
    clearDependencies() {
        if (this.dependencies) {
            this.dependencies.dispose();
            this.dependencies = undefined;
        }
    }
    dispose() {
        this.clearDependencies();
        this._updater = undefined;
    }
}
ComputedUpdater.ComputedUpdaterType = "__dependency_computed";
/**
 * A base class for all SurveyJS objects.
 */
class Base {
    static finishCollectDependencies() {
        const deps = Base.currentDependencis;
        Base.currentDependencis = undefined;
        return deps;
    }
    static startCollectDependencies(updater, target, property) {
        if (Base.currentDependencis !== undefined) {
            throw new Error("Attempt to collect nested dependencies. Nested dependencies are not supported.");
        }
        Base.currentDependencis = new Dependencies(updater, target, property);
    }
    static collectDependency(target, property) {
        if (Base.currentDependencis === undefined)
            return;
        Base.currentDependencis.addDependency(target, property);
    }
    static get commentSuffix() {
        return settings.commentSuffix;
    }
    static set commentSuffix(val) {
        settings.commentSuffix = val;
    }
    static get commentPrefix() {
        return Base.commentSuffix;
    }
    static set commentPrefix(val) {
        Base.commentSuffix = val;
    }
    /**
     * Returns `true` if a passed `value` is an empty string, array, or object or if it equals to `undefined` or `null`.
     *
     * @param value A value to be checked.
     * @param trimString *(Optional)* When this parameter is `true`, the method ignores whitespace characters at the beginning and end of a string value. Pass `false` to disable this functionality.
     */
    isValueEmpty(value, trimString = true) {
        if (trimString) {
            value = this.trimValue(value);
        }
        return Helpers.isValueEmpty(value);
    }
    equals(obj) {
        if (!obj)
            return false;
        if (this.isDisposed || obj.isDisposed)
            return false;
        if (this.getType() != obj.getType())
            return false;
        return this.equalsCore(obj);
    }
    equalsCore(obj) {
        if (this.name !== obj.name)
            return false;
        return Helpers.isTwoValueEquals(this.toJSON(), obj.toJSON(), false, true, false);
    }
    trimValue(value) {
        if (!!value && (typeof value === "string" || value instanceof String))
            return value.trim();
        return value;
    }
    static createPropertiesHash() {
        return {};
    }
    constructor() {
        this.dependencies = {};
        this.propertyHash = Base.createPropertiesHash();
        this.eventList = [];
        this.isLoadingFromJsonValue = false;
        this.loadingOwner = null;
        /**
         * An event that is raised when a property of this SurveyJS object has changed.
         *
         * Parameters:
         *
         * - `sender`: `this`\
         * A SurveyJS object whose property has changed.
         * - `options.name`: `string`\
         * The name of the changed property.
         * - `options.newValue`: `any`\
         * A new value for the property.
         * - `options.oldValue`: `any`\
         * An old value of the property. If the property is an array, `oldValue` contains the same array as `newValue` does.
         *
         * If you need to add and remove property change event handlers dynamically, use the [`registerPropertyChangedHandlers`](#registerPropertyChangedHandlers) and [`unregisterPropertyChangedHandlers`](#unregisterPropertyChangedHandlers) methods instead.
         */
        this.onPropertyChanged = this.addEvent();
        this.onNestedPropertyChanged = this.addEvent();
        /**
         * An event that is raised when an [`ItemValue`](https://surveyjs.io/form-library/documentation/itemvalue) property is changed.
         *
         * Parameters:
         *
         * - `sender`: `this`\
         * A SurveyJS object whose property contains an array of `ItemValue` objects.
         * - `options.obj`: [`ItemValue`](https://surveyjs.io/form-library/documentation/itemvalue)\
         * An `ItemValue` object.
         * - `options.propertyName`: `string`\
         * The name of the property to which an array of `ItemValue` objects is assigned (for example, `"choices"` or `"rows"`).
         * - `options.name`: `"text"` | `"value"`\
         * The name of the changed property.
         * - `options.newValue`: `any`\
         * A new value for the property.
         */
        this.onItemValuePropertyChanged = this.addEvent();
        this.isCreating = true;
        this.animationAllowedLock = 0;
        //remove when knockout obsolete
        this.supportOnElementRerenderedEvent = true;
        this.onElementRerenderedEventEnabled = false;
        this._onElementRerendered = new EventBase();
        CustomPropertiesCollection.createProperties(this);
        this.onBaseCreating();
        this.isCreating = false;
    }
    dispose() {
        for (var i = 0; i < this.eventList.length; i++) {
            this.eventList[i].clear();
        }
        this.onPropertyValueChangedCallback = undefined;
        this.isDisposedValue = true;
        Object.keys(this.dependencies).forEach(key => this.dependencies[key].dispose());
        // this.dependencies = {};
        Object.keys(this.propertyHash).forEach(key => {
            const propVal = this.getPropertyValueCore(this.propertyHash, key);
            if (!!propVal && propVal.type == ComputedUpdater.ComputedUpdaterType) {
                propVal.dispose();
            }
        });
    }
    get isDisposed() {
        return this.isDisposedValue === true;
    }
    get isSurveyObj() { return true; }
    addEvent() {
        const res = new EventBase();
        this.eventList.push(res);
        return res;
    }
    onBaseCreating() { }
    /**
     * Returns the object type as it is used in the JSON schema.
     */
    getType() {
        return "base";
    }
    /**
     * Use this method to find out if the current object is of a given `typeName` or inherited from it.
     *
     * @param typeName One of the values listed in the [getType()](https://surveyjs.io/form-library/documentation/question#getType) description.
     * @returns `true` if the current object is of a given `typeName` or inherited from it.
     * @see getType
     */
    isDescendantOf(typeName) {
        return Serializer.isDescendantOf(this.getType(), typeName);
    }
    getSurvey(isLive = false) {
        return null;
    }
    /**
     * Returns `true` if the survey is being designed in Survey Creator.
     */
    get isDesignMode() {
        const survey = this.getSurvey();
        return !!survey && survey.isDesignMode;
    }
    /**
     * Returns `true` if the object is included in a survey.
     *
     * This property may return `false`, for example, when you [create a survey model dynamically](https://surveyjs.io/form-library/documentation/design-survey-create-a-simple-survey#create-or-change-a-survey-model-dynamically).
     */
    get inSurvey() {
        return !!this.getSurvey(true);
    }
    get bindings() {
        if (!this.bindingsValue) {
            this.bindingsValue = new Bindings(this);
        }
        return this.bindingsValue;
    }
    isBindingEmpty() {
        return !this.bindingsValue || this.bindingsValue.isEmpty();
    }
    checkBindings(valueName, value) { }
    updateBindings(propertyName, value) {
        if (!this.bindingsValue)
            return;
        var valueName = this.bindings.getValueNameByPropertyName(propertyName);
        if (!!valueName) {
            this.updateBindingValue(valueName, value);
        }
    }
    updateBindingValue(valueName, value) { }
    getTemplate() {
        return this.getType();
    }
    /**
     * Returns `true` if the object configuration is being loaded from JSON.
     */
    get isLoadingFromJson() {
        return this.isLoadingFromJsonValue || this.getIsLoadingFromJson();
    }
    getIsLoadingFromJson() {
        if (!!this.loadingOwner && this.loadingOwner.isLoadingFromJson)
            return true;
        return this.isLoadingFromJsonValue;
    }
    startLoadingFromJson(json) {
        this.isLoadingFromJsonValue = true;
        this.jsonObj = json;
    }
    endLoadingFromJson() {
        this.isLoadingFromJsonValue = false;
    }
    /**
     * Returns a JSON schema that corresponds to the current survey element.
     * @param options An object with configuration options.
     * @param {boolean} options.storeDefaults Pass `true` the JSON schema should include properties with default values.
     * @returns A JSON schema of the survey element.
     * @see fromJSON
     */
    toJSON(options) {
        return new JsonObject().toJsonObject(this, options);
    }
    /**
     * Assigns a new JSON schema to the current survey element.
     *
     * The JSON schema should contain only serializable properties of this survey element. Event handlers and properties that do not belong to the survey element are ignored.
     *
     * @param json A JSON schema that you want to apply to the current survey element.
     * @param options An object with configuration options.
     * @param {boolean} options.validatePropertyValues Pass `true` if you want to validate property values. Use the [`jsonErrors`](#jsonErrors) array to access validation errors.
     * @see toJSON
     */
    fromJSON(json, options) {
        new JsonObject().toObject(json, this, options);
        this.onSurveyLoad();
    }
    onSurveyLoad() { }
    /**
     * Creates a new object that has the same type and properties as the current SurveyJS object.
     */
    clone() {
        var clonedObj = Serializer.createClass(this.getType());
        clonedObj.fromJSON(this.toJSON());
        return clonedObj;
    }
    /**
     * Returns a `JsonObjectProperty` object with metadata about a serializable property that belongs to the current SurveyJS object.
     *
     * If the property is not found, this method returns `null`.
     * @param propName A property name.
     */
    getPropertyByName(propName) {
        const type = this.getType();
        if (!this.classMetaData || this.classMetaData.name !== type) {
            this.classMetaData = Serializer.findClass(type);
        }
        return !!this.classMetaData ? this.classMetaData.findProperty(propName) : null;
    }
    isPropertyVisible(propName) {
        const prop = this.getPropertyByName(propName);
        return !!prop ? prop.isVisible("", this) : false;
    }
    static createProgressInfo() {
        return {
            questionCount: 0,
            answeredQuestionCount: 0,
            requiredQuestionCount: 0,
            requiredAnsweredQuestionCount: 0,
        };
    }
    getProgressInfo() {
        return Base.createProgressInfo();
    }
    localeChanged() { }
    locStrsChanged() {
        if (!!this.arraysInfo) {
            for (let key in this.arraysInfo) {
                let item = this.arraysInfo[key];
                if (item && item.isItemValues) {
                    var arr = this.getPropertyValue(key);
                    if (arr && !!Base.itemValueLocStrChanged)
                        Base.itemValueLocStrChanged(arr);
                }
            }
        }
        if (!!this.localizableStrings) {
            for (let key in this.localizableStrings) {
                let item = this.getLocalizableString(key);
                if (item)
                    item.strChanged();
            }
        }
    }
    /**
     * Returns the value of a property with a specified name.
     *
     * If the property is not found or does not have a value, this method returns either `undefined`, `defaultValue` specified in the property configuration, or a value passed as the `defaultValue` parameter.
     *
     * @param name A property name.
     * @param defaultValue *(Optional)* A value to return if the property is not found or does not have a value.
     */
    getPropertyValue(name, defaultValue, calcFunc) {
        const res = this.getPropertyValueWithoutDefault(name);
        if (!!calcFunc && Array.isArray(res) && res.length === 0 && res.isReset === true) {
            delete res.isReset;
            this.setArrayPropertyDirectly(name, calcFunc(), false);
            return res;
        }
        if (this.isValueUndefined(res)) {
            const locStr = this.localizableStrings ? this.localizableStrings[name] : undefined;
            if (locStr)
                return locStr.text;
            if (!this.isValueUndefined(defaultValue))
                return defaultValue;
            if (!!calcFunc) {
                const newVal = calcFunc();
                if (newVal !== undefined) {
                    if (Array.isArray(newVal)) {
                        const array = this.createNewArray(name);
                        array.splice(0, 0, ...newVal);
                        return array;
                    }
                    else {
                        this.setPropertyValueDirectly(name, newVal);
                        return newVal;
                    }
                }
            }
            const propDefaultValue = this.getDefaultPropertyValue(name);
            if (propDefaultValue !== undefined)
                return propDefaultValue;
        }
        return res;
    }
    isValueUndefined(value) {
        return Helpers.isValueUndefined(value);
    }
    getDefaultPropertyValue(name) {
        const prop = this.getPropertyByName(name);
        if (!prop || prop.isCustom && this.isCreating)
            return undefined;
        if (!!prop.defaultValueFunc)
            return prop.defaultValueFunc(this);
        const dValue = prop.getDefaultValue(this);
        if (!this.isValueUndefined(dValue) && !Array.isArray(dValue))
            return dValue;
        const locStr = this.localizableStrings ? this.localizableStrings[name] : undefined;
        if (locStr && locStr.localizationName)
            return this.getLocalizationString(locStr.localizationName);
        if (prop.type == "boolean" || prop.type == "switch")
            return false;
        if (prop.isCustom && !!prop.onGetValue)
            return prop.onGetValue(this);
        return undefined;
    }
    hasDefaultPropertyValue(name) {
        return this.getDefaultPropertyValue(name) !== undefined;
    }
    resetPropertyValue(name) {
        const locStr = this.localizableStrings ? this.localizableStrings[name] : undefined;
        if (locStr) {
            this.setLocalizableStringText(name, undefined);
            locStr.clear();
        }
        else {
            this.setPropertyValue(name, undefined);
        }
    }
    getPropertyValueWithoutDefault(name) {
        return this.getPropertyValueCore(this.propertyHash, name);
    }
    getPropertyValueCore(propertiesHash, name) {
        if (!this.isLoadingFromJson) {
            Base.collectDependency(this, name);
        }
        if (this.getPropertyValueCoreHandler)
            return this.getPropertyValueCoreHandler(propertiesHash, name);
        else
            return propertiesHash[name];
    }
    geValueFromHash() {
        return this.propertyHash["value"];
    }
    setPropertyValueCore(propertiesHash, name, val) {
        if (this.setPropertyValueCoreHandler) {
            if (!this.isDisposedValue) {
                this.setPropertyValueCoreHandler(propertiesHash, name, val);
            }
            else {
                ConsoleWarnings.disposedObjectChangedProperty(name, this.getType());
            }
        }
        else
            propertiesHash[name] = val;
    }
    get isEditingSurveyElement() {
        var survey = this.getSurvey();
        return !!survey && survey.isEditingSurveyElement;
    }
    iteratePropertiesHash(func) {
        var keys = [];
        for (var key in this.propertyHash) {
            if (key === "value" &&
                this.isEditingSurveyElement &&
                Array.isArray(this.value))
                continue;
            keys.push(key);
        }
        keys.forEach((key) => func(this.propertyHash, key));
    }
    /**
     * Assigns a new value to a specified property.
     * @param name A property name.
     * @param val A new value for the property.
     */
    setPropertyValue(name, val) {
        if (this.isDisposedValue)
            return;
        if (!this.isLoadingFromJson) {
            const prop = this.getPropertyByName(name);
            if (!!prop) {
                val = prop.settingValue(this, val);
            }
        }
        var oldValue = this.getPropertyValue(name);
        if (oldValue &&
            Array.isArray(oldValue) &&
            !!this.arraysInfo &&
            (!val || Array.isArray(val))) {
            if (!this.isTwoValueEquals(oldValue, val)) {
                this.setArrayPropertyDirectly(name, val);
            }
        }
        else {
            if (val !== oldValue) {
                this.setPropertyValueDirectly(name, val);
                if (!this.isTwoValueEquals(oldValue, val)) {
                    this.propertyValueChanged(name, oldValue, val);
                }
            }
        }
    }
    setArrayPropertyDirectly(name, val, sendNotification = true) {
        var arrayInfo = this.arraysInfo[name];
        this.setArray(name, this.getPropertyValue(name), val, arrayInfo ? arrayInfo.isItemValues : false, arrayInfo ? sendNotification && arrayInfo.onPush : null);
    }
    setPropertyValueDirectly(name, val) {
        this.setPropertyValueCore(this.propertyHash, name, val);
    }
    clearPropertyValue(name) {
        this.setPropertyValueCore(this.propertyHash, name, null);
        delete this.propertyHash[name];
    }
    onPropertyValueChangedCallback(name, oldValue, newValue, sender, arrayChanges) { }
    itemValuePropertyChanged(item, name, oldValue, newValue) {
        this.onItemValuePropertyChanged.fire(this, {
            obj: item,
            name: name,
            oldValue: oldValue,
            newValue: newValue,
            propertyName: item.ownerPropertyName,
        });
    }
    onPropertyValueChanged(name, oldValue, newValue) { }
    propertyValueChanged(name, oldValue, newValue, arrayChanges, target) {
        if (this.isLoadingFromJson)
            return;
        this.updateBindings(name, newValue);
        this.onPropertyValueChanged(name, oldValue, newValue);
        this.onPropertyChanged.fire(this, {
            name: name,
            oldValue: oldValue,
            newValue: newValue,
            arrayChanges: arrayChanges,
            target: target
        });
        this.doPropertyValueChangedCallback(name, oldValue, newValue, arrayChanges, this);
        this.checkConditionPropertyChanged(name);
        if (!this.onPropChangeFunctions)
            return;
        for (var i = 0; i < this.onPropChangeFunctions.length; i++) {
            if (this.onPropChangeFunctions[i].name == name)
                this.onPropChangeFunctions[i].func(newValue, arrayChanges);
        }
    }
    onBindingChanged(oldValue, newValue) {
        if (this.isLoadingFromJson)
            return;
        this.doPropertyValueChangedCallback("bindings", oldValue, newValue);
    }
    get isInternal() {
        return false;
    }
    doPropertyValueChangedCallback(name, oldValue, newValue, arrayChanges, target) {
        const fireCallback = (obj) => {
            if (!!obj && !!obj.onPropertyValueChangedCallback) {
                obj.onPropertyValueChangedCallback(name, oldValue, newValue, target, arrayChanges);
            }
        };
        if (this.isInternal) {
            fireCallback(this);
            return;
        }
        if (!target)
            target = this;
        var notifier = this.getSurvey();
        if (!notifier)
            notifier = this;
        fireCallback(notifier);
        if (notifier !== this) {
            fireCallback(this);
        }
    }
    addExpressionProperty(name, onExecute, canRun) {
        if (!this.expressionInfo) {
            this.expressionInfo = {};
        }
        this.expressionInfo[name] = { onExecute: onExecute, canRun: canRun };
    }
    getDataFilteredValues() {
        return {};
    }
    getDataFilteredProperties() {
        return {};
    }
    runConditionCore(values, properties) {
        if (!this.expressionInfo)
            return;
        for (var key in this.expressionInfo) {
            this.runConditionItemCore(key, values, properties);
        }
    }
    canRunConditions() {
        return !this.isDesignMode;
    }
    checkConditionPropertyChanged(propName) {
        if (!this.expressionInfo || !this.expressionInfo[propName])
            return;
        if (!this.canRunConditions())
            return;
        this.runConditionItemCore(propName, this.getDataFilteredValues(), this.getDataFilteredProperties());
    }
    runConditionItemCore(propName, values, properties) {
        const info = this.expressionInfo[propName];
        const expression = this.getPropertyValue(propName);
        if (!expression)
            return;
        if (!!info.canRun && !info.canRun(this))
            return;
        if (!info.runner) {
            info.runner = this.createExpressionRunner(expression);
            info.runner.onRunComplete = (res) => {
                info.onExecute(this, res);
            };
        }
        info.runner.expression = expression;
        info.runner.run(values, properties);
    }
    doBeforeAsynRun(id) {
        if (!this.asynExpressionHash)
            this.asynExpressionHash = {};
        const isChanged = !this.isAsyncExpressionRunning;
        this.asynExpressionHash[id] = true;
        if (isChanged) {
            this.onAsyncRunningChanged();
        }
    }
    doAfterAsynRun(id) {
        if (!!this.asynExpressionHash) {
            delete this.asynExpressionHash[id];
            if (!this.isAsyncExpressionRunning) {
                this.onAsyncRunningChanged();
            }
        }
    }
    onAsyncRunningChanged() { }
    get isAsyncExpressionRunning() {
        return !!this.asynExpressionHash && Object.keys(this.asynExpressionHash).length > 0;
    }
    createExpressionRunner(expression) {
        const res = new ExpressionRunner(expression);
        res.onBeforeAsyncRun = (id) => { this.doBeforeAsynRun(id); };
        res.onAfterAsyncRun = (id) => { this.doAfterAsynRun(id); };
        return res;
    }
    /**
     * Registers a single value change handler for one or multiple properties.
     *
     * The `registerPropertyChangedHandlers` and [`unregisterPropertyChangedHandlers`](#unregisterPropertyChangedHandlers) methods allow you to manage property change event handlers dynamically. If you only need to attach an event handler without removing it afterwards, you can use the [`onPropertyChanged`](#onPropertyChanged) event instead.
     * @param propertyNames An array of one or multiple property names.
     * @param handler A function to call when one of the listed properties change. Accepts a new property value as an argument.
     * @param key *(Optional)* A key that identifies the current registration. If a function for one of the properties is already registered with the same key, the function will be overwritten. You can also use the key to subsequently unregister handlers.
     * @see unregisterPropertyChangedHandlers
     */
    registerPropertyChangedHandlers(propertyNames, handler, key = null) {
        for (var i = 0; i < propertyNames.length; i++) {
            this.registerFunctionOnPropertyValueChanged(propertyNames[i], handler, key);
        }
    }
    /**
     * Unregisters value change event handlers for the specified properties.
     * @param propertyNames An array of one or multiple property names.
     * @param key *(Optional)* A key of the registration that you want to cancel.
     * @see registerPropertyChangedHandlers
     */
    unregisterPropertyChangedHandlers(propertyNames, key = null) {
        for (var i = 0; i < propertyNames.length; i++) {
            this.unRegisterFunctionOnPropertyValueChanged(propertyNames[i], key);
        }
    }
    registerFunctionOnPropertyValueChanged(name, func, key = null) {
        if (!this.onPropChangeFunctions) {
            this.onPropChangeFunctions = [];
        }
        if (key) {
            for (var i = 0; i < this.onPropChangeFunctions.length; i++) {
                var item = this.onPropChangeFunctions[i];
                if (item.name == name && item.key == key) {
                    item.func = func;
                    return;
                }
            }
        }
        this.onPropChangeFunctions.push({ name: name, func: func, key: key });
    }
    registerFunctionOnPropertiesValueChanged(names, func, key = null) {
        this.registerPropertyChangedHandlers(names, func, key);
    }
    unRegisterFunctionOnPropertyValueChanged(name, key = null) {
        if (!this.onPropChangeFunctions)
            return;
        for (var i = 0; i < this.onPropChangeFunctions.length; i++) {
            var item = this.onPropChangeFunctions[i];
            if (item.name == name && item.key == key) {
                return this.onPropChangeFunctions.splice(i, 1);
            }
        }
    }
    unRegisterFunctionOnPropertiesValueChanged(names, key = null) {
        this.unregisterPropertyChangedHandlers(names, key);
    }
    createCustomLocalizableObj(name) {
        const locStr = this.getLocalizableString(name);
        if (locStr)
            return locStr;
        return this.createLocalizableString(name, this, false, true);
    }
    getLocale() {
        const locOwner = this.getSurvey();
        return !!locOwner ? locOwner.getLocale() : "";
    }
    getLocalizationString(strName) {
        return getLocaleString(strName, this.getLocale());
    }
    getLocalizationFormatString(strName, ...args) {
        const str = this.getLocalizationString(strName);
        if (!str || !str.format)
            return "";
        return str.format(...args);
    }
    createLocalizableString(name, owner, useMarkDown = false, defaultStr = false) {
        let locName = undefined;
        if (defaultStr) {
            locName = defaultStr === true ? name : defaultStr;
        }
        const locStr = new LocalizableString(owner, useMarkDown, name, locName);
        locStr.onStrChanged = (oldValue, newValue) => {
            this.propertyValueChanged(name, oldValue, newValue);
        };
        if (!this.localizableStrings) {
            this.localizableStrings = {};
        }
        this.localizableStrings[name] = locStr;
        const prop = this.getPropertyByName(name);
        locStr.disableLocalization = prop && prop.isLocalizable === false;
        return locStr;
    }
    removeLocalizableString(name) {
        if (this.localizableStrings) {
            delete this.localizableStrings[name];
        }
    }
    getLocalizableString(name) {
        return !!this.localizableStrings ? this.localizableStrings[name] : null;
    }
    getLocalizableStringText(name, defaultStr = "") {
        Base.collectDependency(this, name);
        var locStr = this.getLocalizableString(name);
        if (!locStr)
            return "";
        var res = locStr.text;
        return res ? res : defaultStr;
    }
    setLocalizableStringText(name, value) {
        let locStr = this.getLocalizableString(name);
        if (!locStr)
            return;
        let oldValue = locStr.text;
        if (oldValue != value) {
            locStr.text = value;
            // this.propertyValueChanged(name, oldValue, value);
        }
    }
    addUsedLocales(locales) {
        if (!!this.localizableStrings) {
            for (let key in this.localizableStrings) {
                let item = this.getLocalizableString(key);
                if (item)
                    this.AddLocStringToUsedLocales(item, locales);
            }
        }
        if (!!this.arraysInfo) {
            for (let key in this.arraysInfo) {
                const prop = this.getPropertyByName(key);
                if (!prop || !prop.isPropertySerializable(this))
                    continue;
                let items = this.getPropertyValue(key);
                if (!items || !items.length)
                    continue;
                for (let i = 0; i < items.length; i++) {
                    let item = items[i];
                    if (item && item.addUsedLocales) {
                        item.addUsedLocales(locales);
                    }
                }
            }
        }
    }
    searchText(text, founded) {
        var strs = [];
        this.getSearchableLocalizedStrings(strs);
        for (var i = 0; i < strs.length; i++) {
            if (strs[i].setFindText(text)) {
                founded.push({ element: this, str: strs[i] });
            }
        }
    }
    getSearchableLocalizedStrings(arr) {
        if (!!this.localizableStrings) {
            let keys = [];
            this.getSearchableLocKeys(keys);
            for (var i = 0; i < keys.length; i++) {
                let item = this.getLocalizableString(keys[i]);
                if (item)
                    arr.push(item);
            }
        }
        if (!this.arraysInfo)
            return;
        let keys = [];
        this.getSearchableItemValueKeys(keys);
        for (var i = 0; i < keys.length; i++) {
            var items = this.getPropertyValue(keys[i]);
            if (!items)
                continue;
            for (var j = 0; j < items.length; j++) {
                arr.push(items[j].locText);
            }
        }
    }
    getSearchableLocKeys(keys) { }
    getSearchableItemValueKeys(keys) { }
    AddLocStringToUsedLocales(locStr, locales) {
        var locs = locStr.getLocales();
        for (var i = 0; i < locs.length; i++) {
            if (locales.indexOf(locs[i]) < 0) {
                locales.push(locs[i]);
            }
        }
    }
    createItemValues(name) {
        var self = this;
        var result = this.createNewArray(name, function (item) {
            item.locOwner = self;
            item.ownerPropertyName = name;
            if (typeof item.getSurvey == "function") {
                const survey = item.getSurvey();
                if (!!survey && typeof survey.makeReactive == "function") {
                    survey.makeReactive(item);
                }
            }
        });
        this.arraysInfo[name].isItemValues = true;
        return result;
    }
    notifyArrayChanged(ar, arrayChanges) {
        !!ar.onArrayChanged && ar.onArrayChanged(arrayChanges);
    }
    createNewArrayCore(name) {
        var res = null;
        if (!!this.createArrayCoreHandler) {
            res = this.createArrayCoreHandler(this.propertyHash, name);
        }
        if (!res) {
            res = new Array();
            this.setPropertyValueCore(this.propertyHash, name, res);
        }
        return res;
    }
    ensureArray(name, onPush = null, onRemove = null) {
        if (this.arraysInfo && this.arraysInfo[name]) {
            return;
        }
        return this.createNewArray(name, onPush, onRemove);
    }
    createNewArray(name, onPush = null, onRemove = null) {
        var newArray = this.createNewArrayCore(name);
        if (!this.arraysInfo) {
            this.arraysInfo = {};
        }
        this.arraysInfo[name] = { onPush: onPush, isItemValues: false };
        var self = this;
        newArray.push = function (value) {
            var result = Object.getPrototypeOf(newArray).push.call(newArray, value);
            if (!self.isDisposedValue) {
                if (onPush)
                    onPush(value, newArray.length - 1);
                const arrayChanges = new ArrayChanges(newArray.length - 1, 0, [value], []);
                self.propertyValueChanged(name, newArray, newArray, arrayChanges);
                self.notifyArrayChanged(newArray, arrayChanges);
            }
            return result;
        };
        newArray.shift = function () {
            var result = Object.getPrototypeOf(newArray).shift.call(newArray);
            if (!self.isDisposedValue && result) {
                if (onRemove)
                    onRemove(result);
                const arrayChanges = new ArrayChanges(newArray.length - 1, 1, [], []);
                self.propertyValueChanged(name, newArray, newArray, arrayChanges);
                self.notifyArrayChanged(newArray, arrayChanges);
            }
            return result;
        };
        newArray.unshift = function (value) {
            var result = Object.getPrototypeOf(newArray).unshift.call(newArray, value);
            if (!self.isDisposedValue) {
                if (onPush)
                    onPush(value, newArray.length - 1);
                const arrayChanges = new ArrayChanges(0, 0, [value], []);
                self.propertyValueChanged(name, newArray, newArray, arrayChanges);
                self.notifyArrayChanged(newArray, arrayChanges);
            }
            return result;
        };
        newArray.pop = function () {
            var result = Object.getPrototypeOf(newArray).pop.call(newArray);
            if (!self.isDisposedValue) {
                if (onRemove)
                    onRemove(result);
                const arrayChanges = new ArrayChanges(newArray.length - 1, 1, [], []);
                self.propertyValueChanged(name, newArray, newArray, arrayChanges);
                self.notifyArrayChanged(newArray, arrayChanges);
            }
            return result;
        };
        newArray.splice = function (start, deleteCount, ...items) {
            if (!start)
                start = 0;
            if (!deleteCount)
                deleteCount = 0;
            var result = Object.getPrototypeOf(newArray).splice.call(newArray, start, deleteCount, ...items);
            if (!items)
                items = [];
            if (!self.isDisposedValue) {
                if (onRemove && result) {
                    for (var i = 0; i < result.length; i++) {
                        onRemove(result[i]);
                    }
                }
                if (onPush) {
                    for (var i = 0; i < items.length; i++) {
                        onPush(items[i], start + i);
                    }
                }
                const arrayChanges = new ArrayChanges(start, deleteCount, items, result);
                self.propertyValueChanged(name, newArray, newArray, arrayChanges);
                self.notifyArrayChanged(newArray, arrayChanges);
            }
            return result;
        };
        return newArray;
    }
    getItemValueType() {
        return undefined;
    }
    setArray(name, src, dest, isItemValues, onPush) {
        var deletedItems = [].concat(src);
        Object.getPrototypeOf(src).splice.call(src, 0, src.length);
        if (!!dest) {
            for (var i = 0; i < dest.length; i++) {
                var item = dest[i];
                if (isItemValues) {
                    if (!!Base.createItemValue) {
                        item = Base.createItemValue(item, this.getItemValueType());
                    }
                }
                Object.getPrototypeOf(src).push.call(src, item);
                if (onPush)
                    onPush(src[i]);
            }
            delete src.isReset;
        }
        else {
            src.isReset = true;
        }
        const arrayChanges = new ArrayChanges(0, deletedItems.length, src, deletedItems);
        this.propertyValueChanged(name, deletedItems, src, arrayChanges);
        this.notifyArrayChanged(src, arrayChanges);
    }
    isTwoValueEquals(x, y, caseInSensitive = false, trimString = false) {
        return Helpers.checkIfValuesEqual(x, y, { ignoreOrder: false, caseSensitive: !caseInSensitive, trimStrings: trimString, doNotConvertNumbers: true });
    }
    static copyObject(dst, src) {
        for (var key in src) {
            var source = src[key];
            if (typeof source === "object") {
                source = {};
                this.copyObject(source, src[key]);
            }
            dst[key] = source;
        }
    }
    copyCssClasses(dest, source) {
        if (!source)
            return;
        if (typeof source === "string" || source instanceof String) {
            dest["root"] = source;
        }
        else {
            Base.copyObject(dest, source);
        }
    }
    getValueInLowCase(val) {
        if (!!val && typeof val == "string")
            return val.toLowerCase();
        return val;
    }
    getElementsInDesign(includeHidden = false) {
        return [];
    }
    get animationAllowed() {
        return this.getIsAnimationAllowed();
    }
    getIsAnimationAllowed() {
        return settings.animationEnabled && this.animationAllowedLock >= 0 && !this.isLoadingFromJson && !this.isDisposed && (!!this.onElementRerendered || !this.supportOnElementRerenderedEvent);
    }
    blockAnimations() {
        this.animationAllowedLock--;
    }
    releaseAnimations() {
        this.animationAllowedLock++;
    }
    enableOnElementRerenderedEvent() {
        this.onElementRerenderedEventEnabled = true;
    }
    disableOnElementRerenderedEvent() {
        var _a;
        (_a = this.onElementRerendered) === null || _a === void 0 ? void 0 : _a.fire(this, { isCancel: true });
        this.onElementRerenderedEventEnabled = false;
    }
    get onElementRerendered() {
        return this.supportOnElementRerenderedEvent && this.onElementRerenderedEventEnabled ? this._onElementRerendered : undefined;
    }
    afterRerender() {
        var _a;
        (_a = this.onElementRerendered) === null || _a === void 0 ? void 0 : _a.fire(this, { isCancel: false });
    }
}
Base.currentDependencis = undefined;
class ArrayChanges {
    constructor(index, deleteCount, itemsToAdd, deletedItems) {
        this.index = index;
        this.deleteCount = deleteCount;
        this.itemsToAdd = itemsToAdd;
        this.deletedItems = deletedItems;
    }
}
class Event {
    get isEmpty() {
        return this.length === 0;
    }
    get length() {
        return !!this.callbacks ? this.callbacks.length : 0;
    }
    fireByCreatingOptions(sender, createOptions) {
        if (!this.callbacks)
            return;
        for (var i = 0; i < this.callbacks.length; i++) {
            this.callbacks[i](sender, createOptions());
            if (!this.callbacks)
                return;
        }
    }
    fire(sender, options) {
        if (!this.callbacks)
            return;
        const callbacks = [].concat(this.callbacks);
        for (var i = 0; i < callbacks.length; i++) {
            callbacks[i](sender, options);
            if (!this.callbacks)
                return;
        }
    }
    clear() {
        this.callbacks = undefined;
    }
    add(func) {
        if (this.hasFunc(func))
            return;
        if (!this.callbacks) {
            this.callbacks = new Array();
        }
        this.callbacks.push(func);
        this.fireCallbackChanged();
    }
    remove(func) {
        if (this.hasFunc(func)) {
            var index = this.callbacks.indexOf(func, 0);
            this.callbacks.splice(index, 1);
            this.fireCallbackChanged();
        }
    }
    hasFunc(func) {
        if (this.callbacks == null)
            return false;
        return this.callbacks.indexOf(func, 0) > -1;
    }
    fireCallbackChanged() {
        if (!!this.onCallbacksChanged) {
            this.onCallbacksChanged();
        }
    }
}
class EventBase extends Event {
}

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */


function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function debounce(func) {
    let isSheduled = false;
    let isCanceled = false;
    let funcArgs;
    return { run: ((...args) => {
            isCanceled = false;
            funcArgs = args;
            if (!isSheduled) {
                isSheduled = true;
                queueMicrotask(() => {
                    if (!isCanceled) {
                        func.apply(this, funcArgs);
                    }
                    isCanceled = false;
                    isSheduled = false;
                });
            }
        }), cancel: () => {
            isCanceled = true;
        } };
}

class ResponsivityManager {
    constructor(container, model, afterInitializeCallback) {
        this.container = container;
        this.model = model;
        this.afterInitializeCallback = afterInitializeCallback;
        this.resizeObserver = undefined;
        this.isInitialized = false;
        this.getComputedStyle = (elt) => {
            return DomDocumentHelper.getComputedStyle(elt);
        };
        this.debouncedProcess = debounce(() => {
            this.process();
        });
        this.isDisposed = false;
        this.model.updateCallback =
            (isResetInitialized) => {
                if (!this.model.isResponsivenessDisabled) {
                    if (isResetInitialized) {
                        this.isInitialized = false;
                    }
                    this.debouncedProcess.run();
                }
            };
        if (typeof ResizeObserver !== "undefined") {
            this.resizeObserver = new ResizeObserver((entries) => {
                DomWindowHelper.requestAnimationFrame(() => {
                    this.process();
                });
            });
            this.resizeObserver.observe(this.container.parentElement);
        }
    }
    getDimensions(element) {
        return {
            scroll: element.scrollWidth,
            offset: element.offsetWidth,
        };
    }
    getAvailableSpace() {
        const style = this.getComputedStyle(this.container);
        let space = this.container.offsetWidth;
        if (style.boxSizing === "border-box") {
            space -= parseFloat(style.paddingLeft) + parseFloat(style.paddingRight);
        }
        return space;
    }
    getGap() {
        const computedStyle = this.getComputedStyle(this.container);
        if (computedStyle.display == "flex") {
            const gap = parseFloat(computedStyle.rowGap);
            return !isNaN(gap) ? gap : 0;
        }
        return 0;
    }
    calcItemSize(item) {
        return item.offsetWidth || item.getBoundingClientRect().width;
    }
    updateItemsDimensions(callback) {
        if (!this.container)
            return;
        const actionsToUpdateDimension = this.isInitialized
            ? this.model.renderedActions.filter(action => action.needUpdateMaxDimension || action.needUpdateMinDimension)
            : this.model.renderedActions;
        let actionsCounter = actionsToUpdateDimension.length;
        if (actionsCounter == 0) {
            callback();
        }
        const onItemDimensionsUpdated = () => {
            if (--actionsCounter <= 0) {
                callback();
            }
        };
        actionsToUpdateDimension.forEach(action => {
            const needUpdateMaxDimension = !this.isInitialized || action.needUpdateMaxDimension;
            const needUpdateMinDimension = !this.isInitialized || action.needUpdateMinDimension;
            const modeToCalculate = needUpdateMinDimension ? (needUpdateMaxDimension ? undefined : "small") : "large";
            action.updateDimensions((el) => this.calcItemSize(el), () => {
                action.needUpdateMaxDimension = false;
                action.needUpdateMinDimension = false;
                onItemDimensionsUpdated();
            }, modeToCalculate);
        });
    }
    get isContainerVisible() {
        return !!this.container && isContainerVisible(this.container);
    }
    shouldProcessResponsiveness() {
        return this.isContainerVisible && !this.model.isResponsivenessDisabled && !this.isDisposed;
    }
    process() {
        if (this.shouldProcessResponsiveness()) {
            this.updateItemsDimensions(() => {
                if (this.shouldProcessResponsiveness()) {
                    this.model.fit({ availableSpace: this.getAvailableSpace(), gap: this.getGap() });
                }
                if (!this.isInitialized) {
                    this.isInitialized = true;
                    this.afterInitializeCallback && this.afterInitializeCallback();
                }
            });
        }
    }
    dispose() {
        this.isDisposed = true;
        this.model.updateCallback = undefined;
        if (!!this.resizeObserver) {
            this.resizeObserver.disconnect();
        }
        this.resizeObserver = undefined;
        this.container = undefined;
    }
}
class VerticalResponsivityManager extends ResponsivityManager {
    constructor(container, model) {
        super(container, model);
    }
    getDimensions() {
        return {
            scroll: this.container.scrollHeight,
            offset: this.container.offsetHeight,
        };
    }
    getAvailableSpace() {
        const style = this.getComputedStyle(this.container);
        let space = this.container.offsetHeight;
        if (style.boxSizing === "border-box") {
            space -= parseFloat(style.paddingTop) + parseFloat(style.paddingBottom);
        }
        return space;
    }
    calcItemSize(item) {
        return item.offsetHeight;
    }
}

class CssClassBuilder {
    constructor() {
        this.classes = [];
    }
    isEmpty() {
        return this.toString() === "";
    }
    append(value, condition = true) {
        if (!!value && condition) {
            if (typeof value === "string") {
                value = value.trim();
            }
            this.classes.push(value);
        }
        return this;
    }
    toString() {
        return this.classes.join(" ");
    }
}

let defaultActionBarCss = {
    root: "sv-action-bar",
    defaultSizeMode: "sv-action-bar--default-size-mode",
    smallSizeMode: "sv-action-bar--small-size-mode",
    item: "sv-action-bar-item",
    itemWithTitle: "",
    itemAsIcon: "sv-action-bar-item--icon",
    itemActive: "sv-action-bar-item--active",
    itemPressed: "sv-action-bar-item--pressed",
    itemIcon: "sv-action-bar-item__icon",
    itemTitle: "sv-action-bar-item__title",
    itemTitleWithIcon: "sv-action-bar-item__title--with-icon",
};
class ActionContainer extends Base {
    constructor() {
        super(...arguments);
        this.visibleActions = [];
        this.sizeMode = "default";
        this.onActionVisibilityChangedCallback = (action) => {
            this.onActionVisibilityChanged(action);
        };
        this.blockUpdates = 0;
    }
    getMarkdownHtml(text, name, item) {
        return !!this.locOwner ? this.locOwner.getMarkdownHtml(text, name, item) : undefined;
    }
    getRenderer(name) {
        return !!this.locOwner ? this.locOwner.getRenderer(name) : null;
    }
    getRendererContext(locStr) {
        return !!this.locOwner ? this.locOwner.getRendererContext(locStr) : locStr;
    }
    getProcessedText(text) {
        return this.locOwner ? this.locOwner.getProcessedText(text) : text;
    }
    getLocale() {
        return !!this.locOwner ? this.locOwner.getLocale() : "";
    }
    getRenderedActions() {
        return this.visibleActions;
    }
    locStrsChanged() {
        super.locStrsChanged();
        this.actions.forEach(item => {
            if (item.locTitle)
                item.locTitle.strChanged();
            item.locStrsChanged();
        });
    }
    raiseUpdate(isResetInitialized) {
        if (this.isUpdating)
            return;
        this.updateVisibleActions();
        this.updateCallback && this.updateCallback(isResetInitialized);
    }
    updateVisibleActions() {
        if (this.isUpdating)
            return;
        this.visibleActions = this.actions.filter((action) => action.visible !== false);
        this.isEmpty = this.visibleActions.length <= 0;
    }
    onActionVisibilityChanged(action) {
        this.updateVisibleActions();
    }
    onSet() {
        this.beginUpdates();
        this.actions.forEach((item) => {
            this.setActionCssClasses(item);
            item.addVisibilityChangedCallback(this.onActionVisibilityChangedCallback);
        });
        this.endUpdates();
    }
    onPush(item) {
        this.setActionCssClasses(item);
        item.addVisibilityChangedCallback(this.onActionVisibilityChangedCallback);
        item.owner = this;
        this.raiseUpdate(true);
    }
    onRemove(item) {
        item.owner = null;
        item.removeVisibilityChangedCallback(this.onActionVisibilityChangedCallback);
        this.raiseUpdate(true);
    }
    setActionCssClasses(item) {
        item.cssClasses = this.cssClasses;
    }
    get hasActions() {
        return (this.actions || []).length > 0;
    }
    get hasVisibleActions() {
        return !this.isEmpty;
    }
    get renderedActions() {
        return this.getRenderedActions();
    }
    getRootStyle() {
        return undefined;
    }
    getRootCss() {
        const sizeModeClass = this.sizeMode === "small" ? this.cssClasses.smallSizeMode : this.cssClasses.defaultSizeMode;
        return new CssClassBuilder().append(this.cssClasses.root + (!!sizeModeClass ? " " + sizeModeClass : "") + (!!this.containerCss ? " " + this.containerCss : ""))
            .append(this.cssClasses.root + "--empty", this.isEmpty)
            .toString();
    }
    getDefaultCssClasses() {
        return defaultActionBarCss;
    }
    getAllActions() {
        return this.actions;
    }
    set cssClasses(val) {
        this.cssClassesValue = {};
        this.copyCssClasses(this.cssClassesValue, this.getDefaultCssClasses());
        mergeValues(val, this.cssClasses);
        this.getAllActions().forEach((action) => {
            this.setActionCssClasses(action);
        });
    }
    get cssClasses() {
        if (!this.cssClassesValue) {
            this.cssClassesValue = this.getDefaultCssClasses();
        }
        return this.cssClassesValue;
    }
    createAction(item) {
        return (item instanceof BaseAction ? item : new Action(item));
    }
    addAction(val, sortByVisibleIndex = true) {
        const res = this.createAction(val);
        if (sortByVisibleIndex && !this.isActionVisible(res))
            return res;
        const items = [].concat(this.actions, res);
        this.sortItems(items);
        this.actions = items;
        return res;
    }
    beginUpdates() {
        this.blockUpdates++;
    }
    endUpdates() {
        this.blockUpdates--;
        if (this.blockUpdates < 0) {
            this.blockUpdates = 0;
        }
        if (this.blockUpdates === 0) {
            this.raiseUpdate(true);
        }
    }
    get isUpdating() { return this.blockUpdates > 0; }
    setItems(items, sortByVisibleIndex = true) {
        this.beginUpdates();
        const newActions = [];
        items.forEach(item => {
            if (!sortByVisibleIndex || this.isActionVisible(item)) {
                newActions.push(this.createAction(item));
            }
        });
        if (sortByVisibleIndex) {
            this.sortItems(newActions);
        }
        this.actions = newActions;
        this.endUpdates();
    }
    sortItems(items) {
        if (this.hasSetVisibleIndex(items)) {
            items.sort(this.compareByVisibleIndex);
        }
    }
    hasSetVisibleIndex(items) {
        for (let i = 0; i < items.length; i++) {
            const index = items[i].visibleIndex;
            if (index !== undefined && index >= 0)
                return true;
        }
        return false;
    }
    compareByVisibleIndex(first, second) {
        return first.visibleIndex - second.visibleIndex;
    }
    isActionVisible(item) {
        return item.visibleIndex >= 0 || item.visibleIndex === undefined;
    }
    popupAfterShowCallback(itemValue) {
    }
    mouseOverHandler(itemValue) {
        itemValue.isHovered = true;
        let needToShowPopup = false;
        let otherPopupVisible = false;
        this.actions.forEach(action => {
            if (action === itemValue && !!itemValue.popupModel) {
                needToShowPopup = true;
            }
            if (action.popupModel && action.popupModel.isVisible) {
                otherPopupVisible = true;
            }
        });
        if (needToShowPopup) {
            const delay = otherPopupVisible ? Math.max(this.subItemsShowDelay, this.subItemsHideDelay) : this.subItemsShowDelay;
            itemValue.showPopupDelayed(delay);
            this.popupAfterShowCallback(itemValue);
        }
    }
    initResponsivityManager(container, delayedUpdateFunction) {
        return;
    }
    resetResponsivityManager() { }
    getActionById(id) {
        for (var i = 0; i < this.actions.length; i++) {
            if (this.actions[i].id === id)
                return this.actions[i];
        }
        return null;
    }
    dispose() {
        super.dispose();
        this.resetResponsivityManager();
        this.actions.forEach(action => action.dispose());
        this.actions.length = 0;
    }
}
__decorate([
    propertyArray({})
], ActionContainer.prototype, "visibleActions", void 0);
__decorate([
    propertyArray({
        onSet: (_, target) => {
            target.onSet();
        },
        onPush: (item, i, target) => {
            target.onPush(item);
        },
        onRemove: (item, i, target) => {
            target.onRemove(item);
        }
    })
], ActionContainer.prototype, "actions", void 0);
__decorate([
    property({})
], ActionContainer.prototype, "containerCss", void 0);
__decorate([
    property({ defaultValue: true })
], ActionContainer.prototype, "isEmpty", void 0);
__decorate([
    property({ defaultValue: 300 })
], ActionContainer.prototype, "subItemsShowDelay", void 0);
__decorate([
    property({ defaultValue: 300 })
], ActionContainer.prototype, "subItemsHideDelay", void 0);

class ElementHelper {
    static focusElement(element) {
        element && element.focus();
    }
    static visibility(node) {
        var style = DomDocumentHelper.getComputedStyle(node);
        if (style.display === "none" || style.visibility === "hidden")
            return false;
        return node.parentElement ? this.visibility(node.parentElement) : true;
    }
    static getNextElementPreorder(element) {
        const result = !!element.nextElementSibling ? element.nextElementSibling : element.parentElement.firstElementChild;
        if (this.visibility(result)) {
            return result;
        }
        else {
            return this.getNextElementPreorder(result);
        }
    }
    static getNextElementPostorder(element) {
        const result = !!element.previousElementSibling ? element.previousElementSibling : element.parentElement.lastElementChild;
        if (this.visibility(result)) {
            return result;
        }
        else {
            return this.getNextElementPostorder(result);
        }
    }
    static hasHorizontalScroller(element) {
        if (!!element) {
            return element.scrollWidth > element.offsetWidth;
        }
        return false;
    }
    static hasVerticalScroller(element) {
        if (!!element) {
            return element.scrollHeight > element.offsetHeight;
        }
        return false;
    }
}

// isMobile
let _isMobile = false;
let vendor = null;
if (typeof navigator !== "undefined" && !!navigator && DomWindowHelper.isAvailable()) {
    vendor = navigator.userAgent || navigator.vendor || DomWindowHelper.hasOwn("opera");
}
(function (a) {
    if (!a)
        return;
    if ((navigator.platform === "MacIntel" && navigator.maxTouchPoints > 0) || navigator.platform === "iPad") {
        _isMobile = true;
    }
    else if (/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino/i.test(a) ||
        /1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(a.substring(0, 4)))
        _isMobile = true;
})(vendor);
let _IPad = false;
const IsMobile = _isMobile || _IPad;
var mouseInfo = {
    get isTouch() {
        return !this.hasMouse && this.hasTouchEvent;
    },
    get hasTouchEvent() {
        return DomWindowHelper.isAvailable() && (DomWindowHelper.hasOwn("ontouchstart") || navigator.maxTouchPoints > 0);
    },
    hasMouse: true
};
const matchMediaMethod = DomWindowHelper.matchMedia;
mouseInfo.hasMouse = detectMouseSupport(matchMediaMethod);
let IsTouch = mouseInfo.isTouch;
//for tests
function _setIsTouch(val) {
    IsTouch = val;
}
//for tests
let _isTablet = undefined;
function _setIsTablet(val) {
    _isTablet = val;
}
function calculateIsTablet(windowWidth, windowHeight, tabletSizeBreakpoint = 600) {
    if (_isTablet !== undefined)
        return _isTablet;
    const _windowWidth = windowWidth || DomWindowHelper.getInnerWidth();
    const _windowHeight = windowHeight || DomWindowHelper.getInnerHeight();
    const width = Math.min(_windowWidth, _windowHeight);
    const isTablet = width >= tabletSizeBreakpoint;
    return isTablet;
}
function detectMouseSupport(matchMedia) {
    if (!matchMedia)
        return false;
    if (IsMobile)
        return false;
    const pointerQuery = matchMedia("(pointer:fine)");
    const hoverQuery = matchMedia("(any-hover:hover)");
    return !!pointerQuery && pointerQuery.matches || !!hoverQuery && hoverQuery.matches;
}

let defaultListCss = {
    root: "sv-list__container",
    item: "sv-list__item",
    searchClearButtonIcon: "sv-list__filter-clear-button",
    loadingIndicator: "sv-list__loading-indicator",
    itemSelected: "sv-list__item--selected",
    itemGroup: "sv-list__item--group",
    itemGroupSelected: "sv-list__item--group-selected",
    itemWithIcon: "sv-list__item--with-icon",
    itemDisabled: "sv-list__item--disabled",
    itemFocused: "sv-list__item--focused",
    itemHovered: "sv-list__item--hovered",
    itemTextWrap: "sv-list__item-text--wrap",
    itemIcon: "sv-list__item-icon",
    itemMarkerIcon: "sv-list-item__marker-icon",
    itemSeparator: "sv-list__item-separator",
    itemBody: "sv-list__item-body",
    itemsContainer: "sv-list",
    itemsContainerFiltering: "sv-list--filtering",
    filter: "sv-list__filter",
    filterIcon: "sv-list__filter-icon",
    filterInput: "sv-list__input",
    emptyContainer: "sv-list__empty-container",
    emptyText: "sv-list__empty-text"
};
class ListModel extends ActionContainer {
    hasText(item, filterStringInLow) {
        if (!filterStringInLow)
            return true;
        const text = item.title || "";
        if (this.onTextSearchCallback)
            return this.onTextSearchCallback(item, filterStringInLow);
        let textInLow = text.toLocaleLowerCase();
        textInLow = settings.comparator.normalizeTextCallback(textInLow, "filter");
        return textInLow.indexOf(filterStringInLow.toLocaleLowerCase()) > -1;
    }
    isItemVisible(item) {
        if (item.id === this.loadingIndicator.id)
            return item.visible;
        return item.visible && this.hasText(item, this.filterString);
    }
    getRenderedActions() {
        let actions = super.getRenderedActions();
        if (this.filterString) {
            let newActions = [];
            actions.forEach(action => {
                newActions.push(action);
                if (action.items) {
                    action.items.forEach(item => {
                        const a = new Action(item);
                        if (!a.iconName) {
                            a.iconName = action.iconName;
                        }
                        newActions.push(a);
                    });
                }
            });
            return newActions;
        }
        return actions;
    }
    get visibleItems() {
        return this.visibleActions.filter(item => this.isItemVisible(item));
    }
    onFilterStringChanged(text) {
        if (!!this.onFilterStringChangedCallback) {
            this.onFilterStringChangedCallback(text);
        }
        this.updateIsEmpty();
    }
    updateIsEmpty() {
        this.isEmpty = !this.renderedActions.some(action => this.isItemVisible(action));
    }
    scrollToItem(classes, ms = 0) {
        setTimeout(() => {
            if (!this.listContainerHtmlElement)
                return;
            const item = this.listContainerHtmlElement.querySelector(classesToSelector(classes));
            if (item) {
                setTimeout(() => {
                    item.scrollIntoView({ behavior: "smooth", block: "nearest", inline: "start" });
                }, ms);
            }
        }, ms);
    }
    constructor(items, onSelectionChanged, allowSelection, selectedItem, elementId) {
        super();
        this.onSelectionChanged = onSelectionChanged;
        this.allowSelection = allowSelection;
        this.elementId = elementId;
        this.onItemClick = (itemValue) => {
            if (this.isItemDisabled(itemValue)) {
                return;
            }
            this.isExpanded = false;
            if (this.allowSelection) {
                this.selectedItem = itemValue;
            }
            if (!!this.onSelectionChanged) {
                this.onSelectionChanged(itemValue);
            }
            const action = itemValue.action;
            if (!!action) {
                action(itemValue);
            }
        };
        this.onItemHover = (itemValue) => {
            this.mouseOverHandler(itemValue);
        };
        this.isItemDisabled = (itemValue) => {
            return itemValue.enabled !== undefined && !itemValue.enabled;
        };
        this.getA11yItemAriaSelected = (itemValue) => {
            if (this.listItemRole == "option")
                return this.isItemSelected(itemValue) ? "true" : "false";
            return undefined;
        };
        this.getA11yItemAriaChecked = (itemValue) => {
            if (this.listItemRole == "menuitemradio")
                return this.isItemSelected(itemValue) ? "true" : "false";
            return undefined;
        };
        this.isItemSelected = (itemValue) => {
            return this.areSameItems(this.selectedItem, itemValue);
        };
        this.isItemFocused = (itemValue) => {
            return this.areSameItems(this.focusedItem, itemValue);
        };
        this.getListClass = () => {
            return new CssClassBuilder()
                .append(this.cssClasses.itemsContainer)
                .append(this.cssClasses.itemsContainerFiltering, !!this.filterString && this.visibleActions.length !== this.visibleItems.length)
                .toString();
        };
        this.getItemClass = (itemValue) => {
            const isSelected = this.isItemSelected(itemValue);
            return new CssClassBuilder()
                .append(this.cssClasses.item)
                .append(this.cssClasses.itemWithIcon, !!itemValue.iconName)
                .append(this.cssClasses.itemDisabled, this.isItemDisabled(itemValue))
                .append(this.cssClasses.itemFocused, this.isItemFocused(itemValue))
                .append(this.cssClasses.itemSelected, !itemValue.hasSubItems && isSelected)
                .append(this.cssClasses.itemGroup, itemValue.hasSubItems)
                .append(this.cssClasses.itemGroupSelected, itemValue.hasSubItems && isSelected)
                .append(this.cssClasses.itemHovered, itemValue.isHovered)
                .append(this.cssClasses.itemTextWrap, this.textWrapEnabled)
                .append(itemValue.css)
                .toString();
        };
        // public getItemIndent = (itemValue: any) => {
        //   const level: number = itemValue.level || 0;
        //   return (level + 1) * ListModel.INDENT + "px";
        // };
        this.getItemStyle = (itemValue) => {
            const level = itemValue.level || 0;
            return {
                "--sjs-list-item-level": level + 1
            };
        };
        if (Object.keys(items).indexOf("items") !== -1) {
            const options = items;
            Object.keys(options).forEach((key) => {
                switch (key) {
                    case "items":
                        this.setItems(options.items);
                        break;
                    case "onFilterStringChangedCallback":
                        this.setOnFilterStringChangedCallback(options.onFilterStringChangedCallback);
                        break;
                    case "onTextSearchCallback":
                        this.setOnTextSearchCallback(options.onTextSearchCallback);
                        break;
                    default:
                        this[key] = options[key];
                }
            });
            this.updateActionsIds();
        }
        else {
            this.setItems(items);
            this.selectedItem = selectedItem;
        }
    }
    setOnFilterStringChangedCallback(callback) {
        this.onFilterStringChangedCallback = callback;
    }
    setOnTextSearchCallback(callback) {
        this.onTextSearchCallback = callback;
    }
    setItems(items, sortByVisibleIndex = true) {
        super.setItems(items, sortByVisibleIndex);
        this.updateActionsIds();
        if (!this.isAllDataLoaded && !!this.actions.length) {
            this.actions.push(this.loadingIndicator);
        }
    }
    updateActionsIds() {
        if (this.elementId) {
            this.renderedActions.forEach((action) => { action.elementId = this.elementId + action.id; });
        }
    }
    setSearchEnabled(newValue) {
        this.searchEnabled = newValue;
        this.showSearchClearButton = newValue;
    }
    onSet() {
        this.showFilter = this.searchEnabled && (this.forceShowFilter || (this.actions || []).length > ListModel.MINELEMENTCOUNT);
        super.onSet();
    }
    getDefaultCssClasses() {
        return defaultListCss;
    }
    popupAfterShowCallback(itemValue) {
        this.addScrollEventListener(() => {
            itemValue.hidePopup();
        });
    }
    onItemLeave(itemValue) {
        itemValue.hidePopupDelayed(this.subItemsHideDelay);
    }
    areSameItems(item1, item2) {
        if (!!this.areSameItemsCallback)
            return this.areSameItemsCallback(item1, item2);
        return !!item1 && !!item2 && item1.id == item2.id;
    }
    get a11ya11y_input_ariaLabel() {
        return this.listAriaLabel;
    }
    get filterStringPlaceholder() {
        return this.getLocalizationString("filterStringPlaceholder");
    }
    get emptyMessage() {
        return this.isAllDataLoaded ? this.getLocalizationString("emptyMessage") : this.getLocalizationString("loadingData");
    }
    get scrollableContainer() {
        return this.listContainerHtmlElement.querySelector(classesToSelector(this.cssClasses.itemsContainer));
    }
    get loadingIndicator() {
        if (!this.loadingIndicatorValue) {
            this.loadingIndicatorValue = (new Action({
                id: "loadingIndicator",
                title: this.getLocalizationString("loadingPage"),
                action: () => { },
                css: this.cssClasses.loadingIndicator
            }));
        }
        return this.loadingIndicatorValue;
    }
    goToItems(event) {
        if (event.key === "ArrowDown" || event.keyCode === 40) {
            const currentElement = event.target.parentElement;
            const listElement = currentElement.parentElement.querySelector("ul");
            const firstChild = getFirstVisibleChild(listElement);
            if (!!listElement && !!firstChild) {
                ElementHelper.focusElement(firstChild);
                event.preventDefault();
            }
        }
    }
    onMouseMove(event) {
        this.resetFocusedItem();
    }
    onKeyDown(event) {
        const currentElement = event.target;
        if (event.key === "ArrowDown" || event.keyCode === 40) {
            ElementHelper.focusElement(ElementHelper.getNextElementPreorder(currentElement));
            event.preventDefault();
        }
        else if (event.key === "ArrowUp" || event.keyCode === 38) {
            ElementHelper.focusElement(ElementHelper.getNextElementPostorder(currentElement));
            event.preventDefault();
        }
    }
    onPointerDown(event, item) { }
    refresh() {
        if (this.filterString !== "") {
            this.filterString = "";
        }
        else {
            this.updateIsEmpty();
        }
        this.resetFocusedItem();
    }
    onClickSearchClearButton(event) {
        event.currentTarget.parentElement.querySelector("input").focus();
        this.refresh();
    }
    resetFocusedItem() {
        this.focusedItem = undefined;
    }
    focusFirstVisibleItem() {
        if (!IsTouch) {
            this.focusedItem = this.visibleItems[0];
        }
    }
    focusLastVisibleItem() {
        this.focusedItem = this.visibleItems[this.visibleItems.length - 1];
    }
    initFocusedItem() {
        this.focusedItem = this.visibleItems.filter(item => item.visible && this.isItemSelected(item))[0];
        if (!this.focusedItem) {
            this.focusFirstVisibleItem();
        }
    }
    focusNextVisibleItem() {
        if (!this.focusedItem) {
            this.initFocusedItem();
        }
        else {
            const items = this.visibleItems;
            const currentFocusedItemIndex = items.indexOf(this.focusedItem);
            const nextItem = items[currentFocusedItemIndex + 1];
            if (nextItem) {
                this.focusedItem = nextItem;
            }
            else {
                this.focusFirstVisibleItem();
            }
        }
    }
    focusPrevVisibleItem() {
        if (!this.focusedItem) {
            this.initFocusedItem();
        }
        else {
            const items = this.visibleItems;
            const currentFocusedItemIndex = items.indexOf(this.focusedItem);
            const prevItem = items[currentFocusedItemIndex - 1];
            if (prevItem) {
                this.focusedItem = prevItem;
            }
            else {
                this.focusLastVisibleItem();
            }
        }
    }
    selectFocusedItem() {
        !!this.focusedItem && this.onItemClick(this.focusedItem);
    }
    initListContainerHtmlElement(htmlElement) {
        this.listContainerHtmlElement = htmlElement;
    }
    onLastItemRended(item) {
        if (this.isAllDataLoaded)
            return;
        if (item === this.actions[this.actions.length - 1] && !!this.listContainerHtmlElement) {
            this.hasVerticalScroller = ElementHelper.hasVerticalScroller(this.scrollableContainer);
        }
    }
    scrollToFocusedItem() {
        this.scrollToItem(this.cssClasses.itemFocused);
    }
    scrollToSelectedItem() {
        if (!!this.selectedItem && this.selectedItem.items && this.selectedItem.items.length > 0) {
            this.scrollToItem(this.cssClasses.itemGroupSelected, 110);
        }
        else {
            this.scrollToItem(this.cssClasses.itemSelected, 110);
        }
    }
    addScrollEventListener(handler) {
        if (!!handler) {
            this.removeScrollEventListener();
            this.scrollHandler = handler;
        }
        if (!!this.scrollHandler) {
            this.scrollableContainer.addEventListener("scroll", this.scrollHandler);
        }
    }
    removeScrollEventListener() {
        if (!!this.scrollHandler) {
            this.scrollableContainer.removeEventListener("scroll", this.scrollHandler);
        }
    }
    dispose() {
        super.dispose();
        if (!!this.loadingIndicatorValue) {
            this.loadingIndicatorValue.dispose();
        }
        this.listContainerHtmlElement = undefined;
    }
}
ListModel.INDENT = 16;
ListModel.MINELEMENTCOUNT = 10;
__decorate([
    property({
        defaultValue: true,
        onSet: (newValue, target) => {
            target.onSet();
        }
    })
], ListModel.prototype, "searchEnabled", void 0);
__decorate([
    property({ defaultValue: false })
], ListModel.prototype, "showFilter", void 0);
__decorate([
    property({ defaultValue: false })
], ListModel.prototype, "forceShowFilter", void 0);
__decorate([
    property({ defaultValue: false })
], ListModel.prototype, "isExpanded", void 0);
__decorate([
    property({})
], ListModel.prototype, "selectedItem", void 0);
__decorate([
    property()
], ListModel.prototype, "focusedItem", void 0);
__decorate([
    property({
        onSet: (_, target) => {
            target.onFilterStringChanged(target.filterString);
        }
    })
], ListModel.prototype, "filterString", void 0);
__decorate([
    property({ defaultValue: false })
], ListModel.prototype, "hasVerticalScroller", void 0);
__decorate([
    property({ defaultValue: true })
], ListModel.prototype, "isAllDataLoaded", void 0);
__decorate([
    property({ defaultValue: false })
], ListModel.prototype, "showSearchClearButton", void 0);
__decorate([
    property({ defaultValue: true })
], ListModel.prototype, "renderElements", void 0);
__decorate([
    property({ defaultValue: false })
], ListModel.prototype, "textWrapEnabled", void 0);
__decorate([
    property({ defaultValue: "sv-list-item-content" })
], ListModel.prototype, "itemComponent", void 0);
__decorate([
    property({ defaultValue: "listbox" })
], ListModel.prototype, "listRole", void 0);
__decorate([
    property({ defaultValue: "option" })
], ListModel.prototype, "listItemRole", void 0);
__decorate([
    property()
], ListModel.prototype, "listAriaLabel", void 0);

class PopupModel extends Base {
    refreshInnerModel() {
        const innerModel = this.contentComponentData["model"];
        innerModel && innerModel.refresh && innerModel.refresh();
    }
    constructor(contentComponentName, contentComponentData, options) {
        super();
        this.focusFirstInputSelector = "";
        this.onCancel = () => { };
        this.onApply = () => { return true; };
        this.onHide = () => { };
        this.onShow = () => { };
        this.onDispose = () => { };
        this.onVisibilityChanged = this.addEvent();
        this.onFooterActionsCreated = this.addEvent();
        this.onRecalculatePosition = this.addEvent();
        this.contentComponentName = contentComponentName;
        this.contentComponentData = contentComponentData;
        if (!!options) {
            for (var key in options) {
                this[key] = options[key];
            }
        }
    }
    get isVisible() {
        return this.getPropertyValue("isVisible", false);
    }
    set isVisible(value) {
        if (this.isVisible === value) {
            return;
        }
        this.setPropertyValue("isVisible", value);
        this.onVisibilityChanged.fire(this, { model: this, isVisible: value });
    }
    toggleVisibility() {
        this.isVisible = !this.isVisible;
    }
    show() {
        if (!this.isVisible)
            this.isVisible = true;
    }
    hide() {
        if (this.isVisible)
            this.isVisible = false;
    }
    recalculatePosition(isResetHeight) {
        this.onRecalculatePosition.fire(this, { isResetHeight: isResetHeight });
    }
    updateFooterActions(footerActions) {
        const options = { actions: footerActions };
        this.onFooterActionsCreated.fire(this, options);
        return options.actions;
    }
    getDisplayMode() {
        if (this.isModal) {
            return this.displayMode === "popup" ? "modal-popup" : "modal-overlay";
        }
        else {
            if (this.displayMode === "popup") {
                return "menu-popup";
            }
            else {
                let result;
                switch (this.overlayDisplayMode) {
                    case "plain": {
                        result = "menu-popup";
                        break;
                    }
                    case "dropdown-overlay": {
                        result = "menu-overlay";
                        break;
                    }
                    case "tablet-dropdown-overlay": {
                        result = "menu-popup-overlay";
                        break;
                    }
                    case "auto": {
                        if (!IsTouch) {
                            result = "menu-popup"; // desktop
                        }
                        else {
                            result = "menu-popup-overlay"; //tablet
                        }
                        break;
                    }
                }
                return result;
            }
        }
    }
    updateDisplayMode(menuType) {
        let newDisplayMode;
        let newOverlayDisplayMode;
        switch (menuType) {
            case "dropdown": {
                newDisplayMode = "popup";
                newOverlayDisplayMode = "auto";
                break;
            }
            case "popup": {
                newDisplayMode = "overlay";
                newOverlayDisplayMode = "tablet-dropdown-overlay";
                break;
            }
            case "overlay": {
                newDisplayMode = "overlay";
                newOverlayDisplayMode = "dropdown-overlay";
                break;
            }
        }
        if (this.displayMode !== newDisplayMode) {
            const isDropdown = menuType === "dropdown";
            this.setWidthByTarget = isDropdown;
            this.isFocusedContent = !isDropdown;
        }
        if (this.displayMode !== newDisplayMode || this.overlayDisplayMode !== newOverlayDisplayMode) {
            this.displayMode = newDisplayMode;
            this.overlayDisplayMode = newOverlayDisplayMode;
            return true;
        }
        else {
            return false;
        }
    }
    onHiding() {
        this.refreshInnerModel();
        this.onHide();
    }
    dispose() {
        super.dispose();
        this.onDispose();
    }
}
__decorate([
    property()
], PopupModel.prototype, "contentComponentName", void 0);
__decorate([
    property()
], PopupModel.prototype, "contentComponentData", void 0);
__decorate([
    property({ defaultValue: "bottom" })
], PopupModel.prototype, "verticalPosition", void 0);
__decorate([
    property({ defaultValue: "left" })
], PopupModel.prototype, "horizontalPosition", void 0);
__decorate([
    property({ defaultValue: true })
], PopupModel.prototype, "showPointer", void 0);
__decorate([
    property({ defaultValue: false })
], PopupModel.prototype, "isModal", void 0);
__decorate([
    property({ defaultValue: true })
], PopupModel.prototype, "canShrink", void 0);
__decorate([
    property({ defaultValue: true })
], PopupModel.prototype, "isFocusedContent", void 0);
__decorate([
    property({ defaultValue: true })
], PopupModel.prototype, "isFocusedContainer", void 0);
__decorate([
    property({ defaultValue: "" })
], PopupModel.prototype, "cssClass", void 0);
__decorate([
    property({ defaultValue: "" })
], PopupModel.prototype, "title", void 0);
__decorate([
    property({ defaultValue: "auto" })
], PopupModel.prototype, "overlayDisplayMode", void 0);
__decorate([
    property({ defaultValue: "popup" })
], PopupModel.prototype, "displayMode", void 0);
__decorate([
    property({ defaultValue: "flex" })
], PopupModel.prototype, "positionMode", void 0);

function createDropdownActionModel(actionOptions, dropdownOptions, locOwner) {
    dropdownOptions.locOwner = locOwner;
    return createDropdownActionModelAdvanced(actionOptions, dropdownOptions, dropdownOptions);
}
function createDropdownActionModelAdvanced(actionOptions, listOptions, popupOptions) {
    var _a;
    const originalSelectionChanged = listOptions.onSelectionChanged;
    listOptions.onSelectionChanged = (item, ...params) => {
        if (newAction.hasTitle) {
            newAction.title = item.title;
        }
        if (originalSelectionChanged) {
            originalSelectionChanged(item, params);
        }
    };
    const popupModel = createPopupModelWithListModel(listOptions, popupOptions);
    popupModel.getTargetCallback = getActionDropdownButtonTarget;
    const newActionOptions = Object.assign({}, actionOptions, {
        component: "sv-action-bar-item-dropdown",
        popupModel: popupModel,
        action: (action, isUserAction) => {
            !!(actionOptions.action) && actionOptions.action();
            popupModel.isFocusedContent = popupModel.isFocusedContent || !isUserAction;
            popupModel.show();
        },
    });
    const newAction = new Action(newActionOptions);
    newAction.data = (_a = popupModel.contentComponentData) === null || _a === void 0 ? void 0 : _a.model;
    return newAction;
}
function createPopupModelWithListModel(listOptions, popupOptions) {
    if (!listOptions.listRole)
        listOptions.listRole = "menu";
    if (!listOptions.listItemRole)
        listOptions.listItemRole = !!listOptions.allowSelection ? "menuitemradio" : "menuitem";
    const listModel = new ListModel(listOptions);
    listModel.onSelectionChanged = (item) => {
        if (listOptions.onSelectionChanged) {
            listOptions.onSelectionChanged(item);
        }
        popupModel.hide();
    };
    const _popupOptions = popupOptions || {};
    _popupOptions.onDispose = () => { listModel.dispose(); };
    const popupModel = new PopupModel("sv-list", { model: listModel }, _popupOptions);
    popupModel.isFocusedContent = listModel.showFilter;
    popupModel.onShow = () => {
        if (!!_popupOptions.onShow)
            _popupOptions.onShow();
        listModel.scrollToSelectedItem();
    };
    return popupModel;
}
function getActionDropdownButtonTarget(container) {
    return container === null || container === void 0 ? void 0 : container.previousElementSibling;
}
class BaseAction extends Base {
    constructor() {
        super(...arguments);
        this.rendredIdValue = BaseAction.getNextRendredId();
    }
    static getNextRendredId() { return BaseAction.renderedId++; }
    get data() {
        return this._data;
    }
    set data(val) {
        this._data = val;
    }
    addVisibilityChangedCallback(callback) { }
    removeVisibilityChangedCallback(callback) { }
    get renderedId() { return this.rendredIdValue; }
    get owner() { return this.ownerValue; }
    set owner(val) {
        if (val !== this.owner) {
            this.ownerValue = val;
            this.locStrsChanged();
        }
    }
    get visible() {
        return this.getVisible();
    }
    set visible(val) {
        this.setVisible(val);
    }
    get enabled() {
        return this.getEnabled();
    }
    set enabled(val) {
        this.setEnabled(val);
    }
    get component() {
        return this.getComponent();
    }
    set component(val) {
        this.setComponent(val);
    }
    get locTitle() {
        return this.getLocTitle();
    }
    set locTitle(val) {
        this.setLocTitle(val);
    }
    get title() {
        return this.getTitle();
    }
    set title(val) {
        this.setTitle(val);
    }
    set cssClasses(val) {
        this.cssClassesValue = val;
    }
    get cssClasses() {
        return this.cssClassesValue || defaultActionBarCss;
    }
    get isVisible() {
        return this.visible && this.mode !== "popup" && this.mode !== "removed";
    }
    get disabled() {
        return this.enabled !== undefined && !this.enabled;
    }
    get canShrink() {
        return !this.disableShrink && !!this.iconName;
    }
    get hasTitle() {
        return (((this.mode != "small" &&
            (this.showTitle || this.showTitle === undefined)) ||
            !this.iconName) &&
            !!this.title);
    }
    get hasSubItems() {
        return !!this.items && this.items.length > 0;
    }
    getActionBarItemTitleCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.itemTitle)
            .append(this.cssClasses.itemTitleWithIcon, !!this.iconName)
            .toString();
    }
    getActionBarItemCss() {
        const hasTitle = this.hasTitle;
        return new CssClassBuilder()
            .append(this.cssClasses.item)
            .append(this.cssClasses.itemWithTitle, hasTitle)
            .append(this.cssClasses.itemAsIcon, !hasTitle)
            .append(this.cssClasses.itemActive, !!this.active)
            .append(this.cssClasses.itemPressed, !!this.pressed)
            .append(this.innerCss)
            .toString();
    }
    getActionRootCss() {
        return new CssClassBuilder()
            .append("sv-action")
            .append(this.css)
            .append("sv-action--space", this.needSpace)
            .append("sv-action--hidden", !this.isVisible)
            .toString();
    }
    getTooltip() {
        return this.tooltip || this.title;
    }
    getIsTrusted(args) {
        if (!!args.originalEvent) {
            return args.originalEvent.isTrusted;
        }
        return args.isTrusted;
    }
    showPopup() {
        if (!!this.popupModel) {
            this.popupModel.show();
        }
    }
    hidePopup() {
        if (!!this.popupModel) {
            this.popupModel.hide();
        }
    }
    clearPopupTimeouts() {
        if (this.showPopupTimeout)
            clearTimeout(this.showPopupTimeout);
        if (this.hidePopupTimeout)
            clearTimeout(this.hidePopupTimeout);
    }
    showPopupDelayed(delay) {
        this.clearPopupTimeouts();
        this.showPopupTimeout = setTimeout(() => {
            this.clearPopupTimeouts();
            this.showPopup();
        }, delay);
    }
    hidePopupDelayed(delay) {
        var _a;
        if ((_a = this.popupModel) === null || _a === void 0 ? void 0 : _a.isVisible) {
            this.clearPopupTimeouts();
            this.hidePopupTimeout = setTimeout(() => {
                this.clearPopupTimeouts();
                this.hidePopup();
                this.isHovered = false;
            }, delay);
        }
        else {
            this.clearPopupTimeouts();
            this.isHovered = false;
        }
    }
}
BaseAction.renderedId = 1;
__decorate([
    property()
], BaseAction.prototype, "tooltip", void 0);
__decorate([
    property()
], BaseAction.prototype, "showTitle", void 0);
__decorate([
    property()
], BaseAction.prototype, "innerCss", void 0);
__decorate([
    property()
], BaseAction.prototype, "active", void 0);
__decorate([
    property()
], BaseAction.prototype, "pressed", void 0);
__decorate([
    property()
], BaseAction.prototype, "popupModel", void 0);
__decorate([
    property()
], BaseAction.prototype, "needSeparator", void 0);
__decorate([
    property()
], BaseAction.prototype, "template", void 0);
__decorate([
    property({ defaultValue: "large" })
], BaseAction.prototype, "mode", void 0);
__decorate([
    property()
], BaseAction.prototype, "visibleIndex", void 0);
__decorate([
    property()
], BaseAction.prototype, "disableTabStop", void 0);
__decorate([
    property()
], BaseAction.prototype, "disableShrink", void 0);
__decorate([
    property()
], BaseAction.prototype, "disableHide", void 0);
__decorate([
    property({ defaultValue: false })
], BaseAction.prototype, "needSpace", void 0);
__decorate([
    property()
], BaseAction.prototype, "ariaChecked", void 0);
__decorate([
    property()
], BaseAction.prototype, "ariaExpanded", void 0);
__decorate([
    property({ defaultValue: "button" })
], BaseAction.prototype, "ariaRole", void 0);
__decorate([
    property()
], BaseAction.prototype, "iconName", void 0);
__decorate([
    property({ defaultValue: 24 })
], BaseAction.prototype, "iconSize", void 0);
__decorate([
    property()
], BaseAction.prototype, "markerIconName", void 0);
__decorate([
    property()
], BaseAction.prototype, "css", void 0);
__decorate([
    property({ defaultValue: false })
], BaseAction.prototype, "isPressed", void 0);
__decorate([
    property({ defaultValue: false })
], BaseAction.prototype, "isHovered", void 0);
class Action extends BaseAction {
    raiseUpdate(isResetInitialized = false) {
        this.updateCallback && this.updateCallback(isResetInitialized);
    }
    addVisibilityChangedCallback(callback) {
        this.visibityChangedEvent.add(callback);
    }
    removeVisibilityChangedCallback(callback) {
        this.visibityChangedEvent.remove(callback);
    }
    raiseOnVisibilityChanged() {
        this.visibityChangedEvent.fire(this, {});
    }
    constructor(innerItemData) {
        super();
        this.visibityChangedEvent = new EventBase();
        this.locTitleChanged = () => {
            const val = this.locTitle.renderedHtml;
            this.setPropertyValue("_title", !!val ? val : undefined);
        };
        this.needUpdateMaxDimension = false;
        this.needUpdateMinDimension = false;
        const innerItem = (innerItemData instanceof Action) ? innerItemData.innerItem : innerItemData;
        this.innerItem = innerItem;
        this.locTitle = !!innerItem ? innerItem["locTitle"] : null;
        //Object.assign(this, item) to support IE11
        if (!!innerItem) {
            for (var key in innerItem) {
                if (key === "locTitle" || key === "title" && !!this.locTitle && !!this.title)
                    continue;
                this[key] = innerItem[key];
            }
        }
        if (!!this.locTitleName) {
            this.locTitleChanged();
        }
        this.registerFunctionOnPropertyValueChanged("_title", () => {
            this.needUpdateMaxDimension = true;
            this.raiseUpdate();
        });
        this.locStrChangedInPopupModel();
    }
    createLocTitle() {
        return this.createLocalizableString("title", this, true);
    }
    setSubItems(options) {
        this.markerIconName = "icon-next_16x16";
        this.component = this.getGroupComponentName();
        this.items = [...options.items];
        if (!this.popupModel) {
            this.createPopupForSubitems(options);
        }
        else {
            const list = this.popupModel.contentComponentData.model;
            list.setItems(this.items);
        }
    }
    createPopupForSubitems(options) {
        const listOptions = Object.assign({}, options);
        listOptions.searchEnabled = false;
        const popupModel = createPopupModelWithListModel(listOptions, { horizontalPosition: "right", showPointer: false, canShrink: false });
        popupModel.cssClass = "sv-popup-inner";
        this.popupModel = popupModel;
    }
    getLocTitle() {
        return this.locTitleValue;
    }
    setLocTitle(val) {
        if (!val && !this.locTitleValue) {
            val = this.createLocTitle();
        }
        if (!!this.locTitleValue) {
            this.locTitleValue.onStringChanged.remove(this.locTitleChanged);
        }
        this.locTitleValue = val;
        this.locTitleValue.onStringChanged.add(this.locTitleChanged);
        this.locTitleChanged();
    }
    getTitle() {
        return this._title;
    }
    setTitle(val) {
        this._title = val;
    }
    get locTitleName() {
        return this.locTitle.localizationName;
    }
    set locTitleName(val) {
        this.locTitle.localizationName = val;
    }
    locStrsChanged() {
        super.locStrsChanged();
        this.locTooltipChanged();
        this.locStrChangedInPopupModel();
    }
    doAction(args) {
        const evt = !!args.originalEvent ? args.originalEvent : args;
        this.action(this, evt.isTrusted);
        evt.preventDefault();
        evt.stopPropagation();
        return true;
    }
    doMouseDown(args) {
        this.isMouseDown = true;
    }
    doFocus(args) {
        if (!!this.onFocus) {
            const evt = !!args.originalEvent ? args.originalEvent : args;
            this.onFocus(this.isMouseDown, evt);
        }
        this.isMouseDown = false;
    }
    locStrChangedInPopupModel() {
        if (!this.popupModel || !this.popupModel.contentComponentData || !this.popupModel.contentComponentData.model)
            return;
        const model = this.popupModel.contentComponentData.model;
        if (Array.isArray(model.actions)) {
            const actions = model.actions;
            actions.forEach(item => {
                if (!!item.locStrsChanged) {
                    item.locStrsChanged();
                }
            });
        }
    }
    locTooltipChanged() {
        if (!this.locTooltipName)
            return;
        this.tooltip = getLocaleString(this.locTooltipName, this.locTitle.locale);
    }
    //ILocalizableOwner
    getLocale() { return this.owner ? this.owner.getLocale() : ""; }
    getMarkdownHtml(text, name, item) { return this.owner ? this.owner.getMarkdownHtml(text, name, item) : undefined; }
    getProcessedText(text) { return this.owner ? this.owner.getProcessedText(text) : text; }
    getRenderer(name) { return this.owner ? this.owner.getRenderer(name) : null; }
    getRendererContext(locStr) { return this.owner ? this.owner.getRendererContext(locStr) : locStr; }
    setVisible(val) {
        if (this.visible !== val) {
            this._visible = val;
        }
    }
    getVisible() {
        return this._visible;
    }
    setEnabled(val) {
        this._enabled = val;
    }
    getEnabled() {
        if (this.enabledIf)
            return this.enabledIf();
        return this._enabled;
    }
    setComponent(val) {
        this._component = val;
    }
    getComponent() {
        return this._component;
    }
    getGroupComponentName() {
        return "sv-list-item-group";
    }
    dispose() {
        this.updateCallback = undefined;
        if (!!this.locTitleValue) {
            this.locTitleValue.onStringChanged.remove(this.locTitleChanged);
        }
        this.locTitleChanged = undefined;
        this.action = undefined;
        super.dispose();
        if (this.popupModel) {
            this.popupModel.dispose();
        }
    }
    updateDimension(mode, htmlElement, calcDimension) {
        const property = mode == "small" ? "minDimension" : "maxDimension";
        if (htmlElement) {
            const actionContainer = htmlElement;
            if (actionContainer.classList.contains("sv-action--hidden")) {
                actionContainer.classList.remove("sv-action--hidden");
                this[property] = calcDimension(htmlElement);
                actionContainer.classList.add("sv-action--hidden");
            }
            else {
                this[property] = calcDimension(htmlElement);
            }
        }
    }
    afterRender() {
        this.afterRenderCallback && this.afterRenderCallback();
    }
    updateMode(mode, callback) {
        if (this.updateModeCallback) {
            this.updateModeCallback(mode, callback);
        }
        else {
            this.afterRenderCallback = () => {
                this.updateModeCallback(mode, callback);
                this.afterRenderCallback = undefined;
            };
        }
    }
    updateDimensions(calcDimension, callback, modeToCalculate) {
        const mode = !modeToCalculate || (modeToCalculate == "large" && this.mode !== "small") ? this.mode : modeToCalculate;
        this.updateMode(mode, (mode, htmlElement) => {
            this.updateDimension(mode, htmlElement, calcDimension);
            if (!modeToCalculate) {
                this.updateMode(mode !== "small" ? "small" : "large", (mode, htmlElement) => {
                    this.updateDimension(mode, htmlElement, calcDimension);
                    callback();
                });
            }
            else {
                callback();
            }
        });
    }
}
__decorate([
    property()
], Action.prototype, "id", void 0);
__decorate([
    property({
        defaultValue: true, onSet: (_, target) => {
            target.raiseOnVisibilityChanged();
            target.raiseUpdate();
        }
    })
], Action.prototype, "_visible", void 0);
__decorate([
    property({
        onSet: (_, target) => {
            target.locTooltipChanged();
        }
    })
], Action.prototype, "locTooltipName", void 0);
__decorate([
    property()
], Action.prototype, "_enabled", void 0);
__decorate([
    property()
], Action.prototype, "action", void 0);
__decorate([
    property()
], Action.prototype, "onFocus", void 0);
__decorate([
    property()
], Action.prototype, "_component", void 0);
__decorate([
    property()
], Action.prototype, "items", void 0);
__decorate([
    property({
        onSet: (val, target) => {
            if (target.locTitleValue.text === val)
                return;
            target.locTitleValue.text = val;
        }
    })
], Action.prototype, "_title", void 0);
class ActionDropdownViewModel {
    constructor(item) {
        this.item = item;
        this.funcKey = "sv-dropdown-action";
        this.setupPopupCallbacks();
    }
    setupPopupCallbacks() {
        const popupModel = this.popupModel = this.item.popupModel;
        if (!popupModel)
            return;
        popupModel.registerPropertyChangedHandlers(["isVisible"], () => {
            if (!popupModel.isVisible) {
                this.item.pressed = false;
            }
            else {
                this.item.pressed = true;
            }
        }, this.funcKey);
    }
    removePopupCallbacks() {
        if (!!this.popupModel) {
            this.popupModel.unregisterPropertyChangedHandlers(["isVisible"], this.funcKey);
        }
    }
    dispose() {
        this.removePopupCallbacks();
    }
}

class AdaptiveActionContainer extends ActionContainer {
    hideItemsGreaterN(visibleItemsCount) {
        const actionsToHide = this.getActionsToHide();
        visibleItemsCount = Math.max(visibleItemsCount, this.minVisibleItemsCount - (this.visibleActions.length - actionsToHide.length));
        const hiddenItems = [];
        actionsToHide.forEach((item) => {
            if (visibleItemsCount <= 0) {
                item.mode = "popup";
                hiddenItems.push(item.innerItem);
            }
            visibleItemsCount--;
        });
        this.hiddenItemsListModel.setItems(hiddenItems);
    }
    getActionsToHide() {
        return this.visibleActions.filter(action => !action.disableHide);
    }
    updateItemMode(availableSpace, maxItemsSize) {
        const items = this.visibleActions;
        for (let index = items.length - 1; index >= 0; index--) {
            if (maxItemsSize > availableSpace && !items[index].disableShrink) {
                maxItemsSize -= items[index].maxDimension - items[index].minDimension;
                items[index].mode = "small";
            }
            else {
                items[index].mode = "large";
            }
        }
    }
    constructor() {
        super();
        this.minVisibleItemsCount = 0;
        this.isResponsivenessDisabled = false;
        this.isInitialized = false;
        this.dotsItem = createDropdownActionModelAdvanced({
            id: "dotsItem-id" + AdaptiveActionContainer.ContainerID++,
            css: "sv-dots",
            innerCss: "sv-dots__item",
            iconName: "icon-more",
            visible: false,
            tooltip: getLocaleString("more"),
        }, {
            items: [],
            allowSelection: false
        });
    }
    get hiddenItemsListModel() {
        return this.dotsItem.data;
    }
    onSet() {
        this.actions.forEach(action => action.updateCallback = (isResetInitialized) => this.raiseUpdate(isResetInitialized));
        super.onSet();
    }
    onPush(item) {
        item.updateCallback = (isResetInitialized) => this.raiseUpdate(isResetInitialized);
        super.onPush(item);
    }
    getRenderedActions() {
        const actions = super.getRenderedActions();
        if (actions.length == 0 || (actions.length === 1 && !!actions[0].iconName))
            return actions;
        return actions.concat([this.dotsItem]);
    }
    getAllActions() {
        return this.actions.concat(this.dotsItem);
    }
    getActionMinDimension(action) {
        return action.disableShrink ? action.maxDimension : action.minDimension;
    }
    onActionVisibilityChanged(action) {
        action.needUpdateMaxDimension = true;
        action.needUpdateMinDimension = true;
        super.onActionVisibilityChanged(action);
    }
    getVisibleItemsCount(options) {
        let { availableSpace, gap } = options;
        availableSpace -= this.dotsItem.minDimension + gap;
        let currentItemsSize = 0;
        if (this.visibleActions[0].disableHide) {
            availableSpace += gap;
        }
        else {
            currentItemsSize -= gap;
        }
        this.visibleActions
            .filter((action) => action.disableHide)
            .forEach(action => {
            return availableSpace -= (this.getActionMinDimension(action) + gap);
        });
        const actionsToHide = this.getActionsToHide();
        if (actionsToHide.length === 1 && !!actionsToHide[0].iconName) {
            return 1;
        }
        for (let i = 0; i < actionsToHide.length; i++) {
            currentItemsSize += this.getActionMinDimension(actionsToHide[i]) + gap;
            if (currentItemsSize > availableSpace) {
                return i;
            }
        }
    }
    fit(options) {
        var _a;
        if (options.availableSpace <= 0)
            return;
        options.gap = (_a = options.gap) !== null && _a !== void 0 ? _a : 0;
        const { availableSpace, gap } = options;
        this.dotsItem.visible = false;
        const actions = this.visibleActions;
        let minSize = -1 * options.gap;
        let maxSize = -1 * options.gap;
        actions.forEach((action) => {
            minSize += this.getActionMinDimension(action) + gap;
            maxSize += action.maxDimension + gap;
        });
        if (availableSpace >= maxSize) {
            this.setActionsMode("large");
        }
        else if (availableSpace < minSize) {
            this.setActionsMode("small");
            this.hideItemsGreaterN(this.getVisibleItemsCount(options));
            this.dotsItem.visible = !!this.hiddenItemsListModel.actions.length;
        }
        else {
            this.updateItemMode(options.availableSpace, maxSize);
        }
    }
    createResponsivityManager(container) {
        return new ResponsivityManager(container, this);
    }
    initResponsivityManager(container) {
        if (!!this.responsivityManager) {
            if (this.responsivityManager.container == container) {
                return;
            }
            this.responsivityManager.dispose();
        }
        this.isInitialized = false;
        this.responsivityManager = this.createResponsivityManager(container);
        this.responsivityManager.afterInitializeCallback = () => {
            this.isInitialized = true;
        };
    }
    resetResponsivityManager() {
        if (!!this.responsivityManager) {
            this.responsivityManager.dispose();
            this.responsivityManager = undefined;
        }
    }
    getRootStyle() {
        if (!this.isInitialized && !this.isResponsivenessDisabled) {
            return { opacity: 0 };
        }
        else {
            return undefined;
        }
    }
    setActionsMode(mode) {
        this.actions.forEach((action) => {
            if (mode == "small" && action.disableShrink) {
                action.mode = "large";
            }
            else {
                action.mode = mode;
            }
        });
    }
    dispose() {
        super.dispose();
        this.dotsItem.data.dispose();
        this.dotsItem.dispose();
        this.resetResponsivityManager();
    }
}
AdaptiveActionContainer.ContainerID = 1;
__decorate([
    property()
], AdaptiveActionContainer.prototype, "isInitialized", void 0);

class AnimationUtils {
    constructor() {
        this.cancelQueue = [];
    }
    getMsFromRule(value) {
        if (value === "auto")
            return 0;
        return Number(value.slice(0, -1).replace(",", ".")) * 1000;
    }
    reflow(element) {
        return element.offsetHeight;
    }
    getAnimationsCount(element) {
        let animationName = "";
        if (getComputedStyle) {
            animationName = getComputedStyle(element).animationName;
        }
        return (animationName && animationName != "none" ? animationName.split(", ").length : 0);
    }
    getAnimationDuration(element) {
        const style = getComputedStyle(element);
        const delays = style["animationDelay"].split(", ");
        const durations = style["animationDuration"].split(", ");
        let duration = 0;
        for (let i = 0; i < Math.max(durations.length, delays.length); i++) {
            duration = Math.max(duration, this.getMsFromRule(durations[i % durations.length]) + this.getMsFromRule(delays[i % delays.length]));
        }
        return duration;
    }
    addCancelCallback(callback) {
        this.cancelQueue.push(callback);
    }
    removeCancelCallback(callback) {
        if (this.cancelQueue.indexOf(callback) >= 0) {
            this.cancelQueue.splice(this.cancelQueue.indexOf(callback), 1);
        }
    }
    onAnimationEnd(element, callback, options) {
        let cancelTimeout;
        let animationsCount = this.getAnimationsCount(element);
        const onEndCallback = (isCancel = true) => {
            callback(isCancel);
            clearTimeout(cancelTimeout);
            this.removeCancelCallback(onEndCallback);
            element.removeEventListener("animationend", onAnimationEndCallback);
        };
        const onAnimationEndCallback = (event) => {
            if (event.target == event.currentTarget && --animationsCount <= 0) {
                onEndCallback(false);
            }
        };
        if (animationsCount > 0) {
            element.addEventListener("animationend", onAnimationEndCallback);
            this.addCancelCallback(onEndCallback);
            cancelTimeout = setTimeout(() => {
                onEndCallback(false);
            }, this.getAnimationDuration(element) + 10);
        }
        else {
            callback(true);
        }
    }
    afterAnimationRun(element, options) {
        if (element && options) {
            options.onAfterRunAnimation && options.onAfterRunAnimation(element);
        }
    }
    beforeAnimationRun(element, options) {
        if (element && options) {
            options.onBeforeRunAnimation && options.onBeforeRunAnimation(element);
        }
    }
    getCssClasses(options) {
        return options.cssClass.replace(/\s+$/, "").split(/\s+/);
    }
    runAnimation(element, options, callback) {
        if (element && (options === null || options === void 0 ? void 0 : options.cssClass)) {
            this.reflow(element);
            this.getCssClasses(options).forEach((cssClass) => {
                element.classList.add(cssClass);
            });
            this.onAnimationEnd(element, callback, options);
        }
        else {
            callback(true);
        }
    }
    clearHtmlElement(element, options) {
        if (element && options.cssClass) {
            this.getCssClasses(options).forEach((cssClass) => {
                element.classList.remove(cssClass);
            });
        }
        this.afterAnimationRun(element, options);
    }
    onNextRender(callback, isCancel = false) {
        if (!isCancel && DomWindowHelper.isAvailable()) {
            let latestRAF;
            const cancelCallback = () => {
                callback(true);
                cancelAnimationFrame(latestRAF);
            };
            latestRAF = DomWindowHelper.requestAnimationFrame(() => {
                latestRAF = DomWindowHelper.requestAnimationFrame(() => {
                    callback(false);
                    this.removeCancelCallback(cancelCallback);
                });
            });
            this.addCancelCallback(cancelCallback);
        }
        else {
            callback(true);
        }
    }
    cancel() {
        const cancelQueue = [].concat(this.cancelQueue);
        cancelQueue.forEach(callback => callback());
        this.cancelQueue = [];
    }
}
class AnimationPropertyUtils extends AnimationUtils {
    onEnter(options) {
        const htmlElement = options.getAnimatedElement();
        const enterOptions = options.getEnterOptions ? options.getEnterOptions() : {};
        this.beforeAnimationRun(htmlElement, enterOptions);
        this.runAnimation(htmlElement, enterOptions, () => {
            this.clearHtmlElement(htmlElement, enterOptions);
        });
    }
    onLeave(options, callback) {
        const htmlElement = options.getAnimatedElement();
        const leaveOptions = options.getLeaveOptions ? options.getLeaveOptions() : {};
        this.beforeAnimationRun(htmlElement, leaveOptions);
        this.runAnimation(htmlElement, leaveOptions, (isCancel) => {
            callback();
            this.onNextRender(() => {
                this.clearHtmlElement(htmlElement, leaveOptions);
            }, isCancel);
        });
    }
}
class AnimationGroupUtils extends AnimationUtils {
    runGroupAnimation(options, addedItems, removedItems, reorderedItems, callback) {
        const info = {
            isAddingRunning: addedItems.length > 0,
            isDeletingRunning: removedItems.length > 0,
            isReorderingRunning: reorderedItems.length > 0
        };
        const addedHtmlElements = addedItems.map((el) => options.getAnimatedElement(el));
        const enterOptions = addedItems.map((el) => options.getEnterOptions ? options.getEnterOptions(el, info) : {});
        const removedHtmlElements = removedItems.map((el) => options.getAnimatedElement(el));
        const leaveOptions = removedItems.map((el) => options.getLeaveOptions ? options.getLeaveOptions(el, info) : {});
        const reorderedHtmlElements = reorderedItems.map(el => options.getAnimatedElement(el.item));
        const reorderedOptions = reorderedItems.map(el => options.getReorderOptions ? options.getReorderOptions(el.item, el.movedForward, info) : {});
        addedItems.forEach((_, i) => {
            this.beforeAnimationRun(addedHtmlElements[i], enterOptions[i]);
        });
        removedItems.forEach((_, i) => {
            this.beforeAnimationRun(removedHtmlElements[i], leaveOptions[i]);
        });
        reorderedItems.forEach((_, i) => {
            this.beforeAnimationRun(reorderedHtmlElements[i], reorderedOptions[i]);
        });
        let counter = addedItems.length + removedItems.length + reorderedHtmlElements.length;
        const onAnimationEndCallback = (isCancel) => {
            if (--counter <= 0) {
                callback && callback();
                this.onNextRender(() => {
                    addedItems.forEach((_, i) => {
                        this.clearHtmlElement(addedHtmlElements[i], enterOptions[i]);
                    });
                    removedItems.forEach((_, i) => {
                        this.clearHtmlElement(removedHtmlElements[i], leaveOptions[i]);
                    });
                    reorderedItems.forEach((_, i) => {
                        this.clearHtmlElement(reorderedHtmlElements[i], reorderedOptions[i]);
                    });
                }, isCancel);
            }
        };
        addedItems.forEach((_, i) => {
            this.runAnimation(addedHtmlElements[i], enterOptions[i], onAnimationEndCallback);
        });
        removedItems.forEach((_, i) => {
            this.runAnimation(removedHtmlElements[i], leaveOptions[i], onAnimationEndCallback);
        });
        reorderedItems.forEach((_, i) => {
            this.runAnimation(reorderedHtmlElements[i], reorderedOptions[i], onAnimationEndCallback);
        });
    }
}
class AnimationProperty {
    constructor(animationOptions, update, getCurrentValue) {
        this.animationOptions = animationOptions;
        this.update = update;
        this.getCurrentValue = getCurrentValue;
        this._debouncedSync = debounce((newValue) => {
            this.cancelAnimations();
            try {
                this._sync(newValue);
            }
            catch (_a) {
                this.update(newValue);
            }
        });
    }
    onNextRender(callback, onCancel) {
        const rerenderEvent = this.animationOptions.getRerenderEvent();
        if (!rerenderEvent) {
            if (DomWindowHelper.isAvailable()) {
                const raf = DomWindowHelper.requestAnimationFrame(() => {
                    callback();
                    this.cancelCallback = undefined;
                });
                this.cancelCallback = () => {
                    onCancel && onCancel();
                    cancelAnimationFrame(raf);
                    this.cancelCallback = undefined;
                };
            }
            else {
                throw new Error("Can't get next render");
            }
        }
        else {
            const clear = () => {
                rerenderEvent.remove(nextRenderCallback);
                this.cancelCallback = undefined;
            };
            const nextRenderCallback = (_, options) => {
                if (options.isCancel) {
                    onCancel && onCancel();
                }
                else {
                    callback();
                }
                clear();
            };
            this.cancelCallback = () => {
                onCancel && onCancel();
                clear();
            };
            rerenderEvent.add(nextRenderCallback);
        }
    }
    sync(newValue) {
        if (this.animationOptions.isAnimationEnabled()) {
            this._debouncedSync.run(newValue);
        }
        else {
            this.cancel();
            this.update(newValue);
        }
    }
    cancel() {
        this._debouncedSync.cancel();
        this.cancelAnimations();
    }
    cancelAnimations() {
        this.cancelCallback && this.cancelCallback();
        this.animation.cancel();
    }
}
class AnimationBoolean extends AnimationProperty {
    constructor() {
        super(...arguments);
        this.animation = new AnimationPropertyUtils();
    }
    _sync(newValue) {
        if (newValue !== this.getCurrentValue()) {
            if (newValue) {
                this.onNextRender(() => {
                    this.animation.onEnter(this.animationOptions);
                });
                this.update(newValue);
            }
            else {
                this.animation.onLeave(this.animationOptions, () => {
                    this.update(newValue);
                });
            }
        }
        else {
            this.update(newValue);
        }
    }
}
class AnimationGroup extends AnimationProperty {
    constructor() {
        super(...arguments);
        this.animation = new AnimationGroupUtils();
    }
    _sync(newValue) {
        var _a, _b;
        newValue = [].concat(newValue);
        const oldValue = [].concat(this.getCurrentValue());
        const allowSyncRemovalAddition = (_a = this.animationOptions.allowSyncRemovalAddition) !== null && _a !== void 0 ? _a : true;
        let compareResult = compareArrays(oldValue, newValue, (_b = this.animationOptions.getKey) !== null && _b !== void 0 ? _b : ((item) => item));
        if (!allowSyncRemovalAddition && (compareResult.reorderedItems.length > 0 || compareResult.addedItems.length > 0)) {
            compareResult.deletedItems = [];
            compareResult.mergedItems = newValue;
        }
        if (!!this.animationOptions.onCompareArrays) {
            this.animationOptions.onCompareArrays(compareResult);
        }
        let { addedItems, reorderedItems, deletedItems, mergedItems } = compareResult;
        const runAnimationCallback = () => {
            this.animation.runGroupAnimation(this.animationOptions, addedItems, deletedItems, reorderedItems, () => {
                if (deletedItems.length > 0) {
                    this.update(newValue);
                }
            });
        };
        if ([addedItems, deletedItems, reorderedItems].some((arr) => arr.length > 0)) {
            if (deletedItems.length <= 0 || reorderedItems.length > 0 || addedItems.length > 0) {
                this.onNextRender(runAnimationCallback, () => {
                    this.update(newValue);
                });
                this.update(mergedItems);
            }
            else {
                runAnimationCallback();
            }
        }
        else {
            this.update(newValue);
        }
    }
}
class AnimationTab extends AnimationProperty {
    constructor(animationOptions, update, getCurrentValue, mergeValues) {
        super(animationOptions, update, getCurrentValue);
        this.mergeValues = mergeValues;
        this.animation = new AnimationGroupUtils();
    }
    _sync(newValue) {
        const oldValue = [].concat(this.getCurrentValue());
        if (oldValue[0] !== newValue[0]) {
            const tempValue = !!this.mergeValues ? this.mergeValues(newValue, oldValue) : [].concat(oldValue, newValue);
            this.onNextRender(() => {
                this.animation.runGroupAnimation(this.animationOptions, newValue, oldValue, [], () => {
                    this.update(newValue);
                });
            }, () => this.update(newValue));
            this.update(tempValue, true);
        }
        else {
            this.update(newValue);
        }
    }
}

/**
 * A base class for the [`SurveyElement`](https://surveyjs.io/form-library/documentation/surveyelement) and [`SurveyModel`](https://surveyjs.io/form-library/documentation/surveymodel) classes.
 */
class SurveyElementCore extends Base {
    constructor() {
        super();
        this.createLocTitleProperty();
    }
    createLocTitleProperty() {
        return this.createLocalizableString("title", this, true);
    }
    /**
     * Returns `true` if the survey element is a page.
     *
     * This property returns `false` for [`PageModel`](https://surveyjs.io/form-library/documentation/api-reference/page-model) objects in the following cases:
     *
     * - `SurveyModel`'s [`questionsOnPageMode`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionsOnPageMode) is set to `"singlePage"`.
     * - The page is included in a [preview of given answers](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#preview-page).
     *
     * In those cases, the survey creates an internal `PageModel` object to show all questions on one page, and all regular pages become panels.
     */
    get isPage() { return false; }
    /**
     * Returns `true` if the survey element is a panel or acts as one.
     *
     * This property returns `true` for `PageModel` objects in the following cases:
     *
     * - `SurveyModel`'s [`questionsOnPageMode`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionsOnPageMode) is set to `"singlePage"`.
     * - The page is included in a [preview of given answers](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#preview-page).
     *
     * In those cases, the survey creates an internal `PageModel` object to show all questions on one page, and all regular pages become panels.
     */
    get isPanel() { return false; }
    /**
     * Returns `true` if the survey element is a question.
     */
    get isQuestion() { return false; }
    /**
     * Returns `true` if the element is a survey.
     */
    get isSurvey() { return false; }
    /**
     * A title for the survey element. If `title` is undefined, the `name` property value is displayed instead.
     *
     * Empty pages and panels do not display their titles or names.
     *
     * @see [Configure Question Titles](https://surveyjs.io/form-library/documentation/design-survey-question-titles)
    */
    get title() {
        return this.getLocalizableStringText("title", this.getDefaultTitleValue());
    }
    set title(val) {
        this.setTitleValue(val);
    }
    get locTitle() {
        return this.getLocalizableString("title");
    }
    get locRenderedTitle() {
        return this.locTitle;
    }
    getDefaultTitleValue() { return undefined; }
    setTitleValue(val) {
        this.setLocalizableStringText("title", val);
    }
    /**
     * Returns `true` if the survey element has a description.
     * @see description
    */
    get hasDescription() {
        return this.getPropertyValue("hasDescription", undefined, () => this.calcDescriptionVisibility());
    }
    set hasDescription(val) {
        this.setPropertyValue("hasDescription", val);
    }
    calcDescriptionVisibility() {
        const newDescription = this.description;
        let showPlaceholder = false;
        if (this.isDesignMode) {
            const property = Serializer.findProperty(this.getType(), "description");
            showPlaceholder = !!(property === null || property === void 0 ? void 0 : property.placeholder);
        }
        return !!newDescription || (showPlaceholder && this.isDesignMode);
    }
    resetDescriptionVisibility() {
        this.resetPropertyValue("hasDescription");
    }
    get locDescription() {
        return this.getLocalizableString("description");
    }
    get titleTagName() {
        let titleTagName = this.getDefaultTitleTagName();
        const survey = this.getSurvey();
        return !!survey ? survey.getElementTitleTagName(this, titleTagName) : titleTagName;
    }
    getDefaultTitleTagName() {
        return settings.titleTags[this.getType()];
    }
    get hasTitle() { return this.title.length > 0; }
    get hasTitleActions() { return false; }
    get hasTitleEvents() {
        return this.hasTitleActions;
    }
    getTitleToolbar() { return null; }
    getTitleOwner() { return undefined; }
    get isTitleOwner() { return !!this.getTitleOwner(); }
    get isTitleRenderedAsString() { return this.getIsTitleRenderedAsString(); }
    toggleState() { return undefined; }
    get cssClasses() { return {}; }
    get cssTitle() { return ""; }
    get ariaTitleId() { return undefined; }
    get ariaDescriptionId() { return undefined; }
    get titleTabIndex() { return undefined; }
    get titleAriaExpanded() { return undefined; }
    get titleAriaRole() { return undefined; }
    get ariaLabel() {
        return this.locTitle.renderedHtml;
    }
    get titleAriaLabel() {
        return this.ariaLabel;
    }
    getIsTitleRenderedAsString() { return !this.isTitleOwner; }
}
__decorate([
    property({
        localizable: true, onSet: (newDescription, self) => {
            self.resetDescriptionVisibility();
        }
    })
], SurveyElementCore.prototype, "description", void 0);
/**
 * A base class for all survey elements.
 */
class SurveyElement extends SurveyElementCore {
    static getProgressInfoByElements(children, isRequired) {
        const info = Base.createProgressInfo();
        for (let i = 0; i < children.length; i++) {
            if (!children[i].isVisible)
                continue;
            const childInfo = children[i].getProgressInfo();
            info.questionCount += childInfo.questionCount;
            info.answeredQuestionCount += childInfo.answeredQuestionCount;
            info.requiredQuestionCount += childInfo.requiredQuestionCount;
            info.requiredAnsweredQuestionCount +=
                childInfo.requiredAnsweredQuestionCount;
        }
        if (isRequired && info.questionCount > 0) {
            if (info.requiredQuestionCount == 0)
                info.requiredQuestionCount = 1;
            if (info.answeredQuestionCount > 0)
                info.requiredAnsweredQuestionCount = 1;
        }
        return info;
    }
    static IsNeedScrollIntoView(el, checkLeft, scrollIfVisible) {
        const elTop = scrollIfVisible ? -1 : el.getBoundingClientRect().top;
        let needScroll = elTop < 0;
        let elLeft = -1;
        if (!needScroll && checkLeft) {
            elLeft = el.getBoundingClientRect().left;
            needScroll = elLeft < 0;
        }
        if (!needScroll && DomWindowHelper.isAvailable()) {
            const height = DomWindowHelper.getInnerHeight();
            needScroll = height > 0 && height < elTop;
            if (!needScroll && checkLeft) {
                const width = DomWindowHelper.getInnerWidth();
                needScroll = width > 0 && width < elLeft;
            }
        }
        return needScroll;
    }
    static ScrollIntoView(el, scrollIntoViewOptions, doneCallback) {
        el.scrollIntoView(scrollIntoViewOptions);
        if (typeof doneCallback === "function") {
            let lastPos = null;
            let same = 0;
            const checkPos = () => {
                const newPos = el.getBoundingClientRect().top;
                if (newPos === lastPos) {
                    if (same++ > 2) {
                        doneCallback();
                        return;
                    }
                }
                else {
                    lastPos = newPos;
                    same = 0;
                }
                requestAnimationFrame(checkPos);
            };
            DomWindowHelper.requestAnimationFrame(checkPos);
        }
    }
    static ScrollElementToTop(element, scrollIfVisible, scrollIntoViewOptions, doneCallback) {
        return SurveyElement.ScrollElementToViewCore(element, false, scrollIfVisible, scrollIntoViewOptions, doneCallback);
    }
    static ScrollElementToViewCore(el, checkLeft, scrollIfVisible, scrollIntoViewOptions, doneCallback) {
        if (!el || !el.scrollIntoView) {
            doneCallback && doneCallback();
            return false;
        }
        const needScroll = SurveyElement.IsNeedScrollIntoView(el, checkLeft, scrollIfVisible);
        if (needScroll) {
            SurveyElement.ScrollIntoView(el, scrollIntoViewOptions, doneCallback);
        }
        else {
            doneCallback && doneCallback();
        }
        return needScroll;
    }
    static GetFirstNonTextElement(elements, removeSpaces = false) {
        if (!elements || !elements.length || elements.length == 0)
            return null;
        if (removeSpaces) {
            let tEl = elements[0];
            if (tEl.nodeName === "#text")
                tEl.data = "";
            tEl = elements[elements.length - 1];
            if (tEl.nodeName === "#text")
                tEl.data = "";
        }
        for (let i = 0; i < elements.length; i++) {
            if (elements[i].nodeName != "#text" && elements[i].nodeName != "#comment")
                return elements[i];
        }
        return null;
    }
    static FocusElement(elementId, isTimeOut, containerEl) {
        if (!elementId || !DomDocumentHelper.isAvailable())
            return false;
        const res = !isTimeOut ? SurveyElement.focusElementCore(elementId, containerEl) : false;
        if (!res) {
            setTimeout(() => {
                SurveyElement.focusElementCore(elementId, containerEl);
            }, isTimeOut ? 100 : 10);
        }
        return res;
    }
    static focusElementCore(elementId, containerEl) {
        const { root } = settings.environment;
        if (!root && !containerEl)
            return false;
        const el = containerEl ? containerEl.querySelector(`#${CSS.escape(elementId)}`) : root.getElementById(elementId);
        // https://stackoverflow.com/questions/19669786/check-if-element-is-visible-in-dom
        if (el && !el["disabled"] && el.style.display !== "none" && el.offsetParent !== null) {
            SurveyElement.ScrollElementToViewCore(el, true, false);
            el.focus();
            return true;
        }
        return false;
    }
    get effectiveColSpan() {
        const res = this.getPropertyValueWithoutDefault("effectiveColSpan");
        if (res !== undefined)
            return res;
        this.setRootStyle();
        return this.getPropertyValue("effectiveColSpan");
    }
    /**
     * Specifies how many columns this survey element spans in the grid layout. Applies only if you set the `SurveyModel`'s [`gridLayoutEnabled`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#gridLayoutEnabled) property to `true` and define the [`gridLayoutColumns`](https://surveyjs.io/form-library/documentation/api-reference/page-model#gridLayoutColumns) array for the parent page or panel.
     *
     * Default value: 1
     */
    get colSpan() {
        return this.getPropertyValue("colSpan", 1);
    }
    set colSpan(val) {
        this.setPropertyValue("colSpan", val);
    }
    constructor(name) {
        super();
        this.selectedElementInDesignValue = this;
        this.disableDesignActions = SurveyElement.CreateDisabledDesignElements;
        this.parentQuestionValue = null;
        this.isContentElement = false;
        this.isEditableTemplateElement = false;
        this.isInteractiveDesignElement = true;
        this.isSingleInRow = true;
        this._renderedIsExpanded = true;
        this._isAnimatingCollapseExpand = false;
        this.animationCollapsed = new AnimationBoolean(this.getExpandCollapseAnimationOptions(), (val) => {
            this._renderedIsExpanded = val;
            if (this.animationAllowed) {
                if (val) {
                    this.isAnimatingCollapseExpand = true;
                }
                else {
                    this.updateElementCss(false);
                }
            }
        }, () => this.renderedIsExpanded);
        this.onAfterRenderElement = this.addEvent();
        this.setPropertyValueDirectly("name", this.getValidName(name));
        this.createNewArray("errors");
        this.createNewArray("titleActions");
        this.registerPropertyChangedHandlers(["isReadOnly"], () => { this.onReadOnlyChanged(); });
        this.registerPropertyChangedHandlers(["errors"], () => { this.updateVisibleErrors(); });
        this.registerPropertyChangedHandlers(["isSingleInRow"], () => { this.updateElementCss(false); });
        this.registerPropertyChangedHandlers(["minWidth", "maxWidth", "renderWidth", "allowRootStyle", "parent"], () => { this.updateRootStyle(); });
        this.registerPropertyChangedHandlers(["effectiveColSpan"], (val) => { this.colSpan = val; });
    }
    onPropertyValueChanged(name, oldValue, newValue) {
        super.onPropertyValueChanged(name, oldValue, newValue);
        if (name === "state") {
            this.updateElementCss(false);
            this.notifyStateChanged(oldValue);
            if (this.stateChangedCallback)
                this.stateChangedCallback();
        }
    }
    getSkeletonComponentNameCore() {
        if (this.survey) {
            return this.survey.getSkeletonComponentName(this);
        }
        return "sv-skeleton";
    }
    /**
     * A Dynamic Panel, Dynamic Matrix, or Dropdown Matrix that includes the current question.
     *
     * This property is `null` for standalone questions.
     */
    get parentQuestion() {
        return this.parentQuestionValue;
    }
    setParentQuestion(val) {
        this.parentQuestionValue = val;
        this.onParentQuestionChanged();
    }
    onParentQuestionChanged() { }
    updateElementVisibility() {
        this.setPropertyValue("isVisible", this.isVisible);
    }
    get skeletonComponentName() {
        return this.getSkeletonComponentNameCore();
    }
    /**
     * Gets and sets the survey element's expand state.
     *
     * Possible values:
     *
     * - `"default"` (default) - The survey element is displayed in full and cannot be collapsed in the UI.
     * - `"expanded"` - The survey element is displayed in full and can be collapsed in the UI.
     * - `"collapsed"` - The survey element displays only `title` and `description` and can be expanded in the UI.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/set-properties-on-multiple-questions-using-panel/ (linkStyle))
     * @hidefor PageModel
     * @see toggleState
     * @see collapse
     * @see expand
     * @see isCollapsed
     * @see isExpanded
     */
    get state() {
        return this.getPropertyValue("state");
    }
    set state(val) {
        this.setPropertyValue("state", val);
        this.renderedIsExpanded = !this.isCollapsed;
    }
    notifyStateChanged(prevState) {
        if (this.survey) {
            this.survey.elementContentVisibilityChanged(this);
        }
    }
    /**
     * Returns `true` if the survey element is collapsed.
     * @hidefor PageModel
     * @see state
     * @see toggleState
     * @see collapse
     * @see expand
     * @see isExpanded
     */
    get isCollapsed() {
        return this.state === "collapsed" && !this.isDesignMode;
    }
    /**
     * Returns `true` if the survey element is expanded.
     * @hidefor PageModel
     * @see state
     * @see toggleState
     * @see collapse
     * @see expand
     * @see isCollapsed
     */
    get isExpanded() {
        return this.state === "expanded";
    }
    /**
     * Collapses the survey element.
     *
     * In collapsed state, the element displays only `title` and `description`.
     * @hidefor PageModel
     * @see title
     * @see description
     * @see state
     * @see toggleState
     * @see expand
     * @see isCollapsed
     * @see isExpanded
     */
    collapse() {
        if (this.isDesignMode)
            return;
        this.state = "collapsed";
    }
    /**
     * Expands the survey element.
     * @see state
     * @see toggleState
     * @see collapse
     * @see isCollapsed
     * @see isExpanded
     */
    expand() {
        this.state = "expanded";
    }
    /**
     * Toggles the survey element's `state` between collapsed and expanded.
     * @hidefor PageModel
     * @see state
     * @see collapse
     * @see expand
     * @see isCollapsed
     * @see isExpanded
     */
    toggleState() {
        if (this.isCollapsed) {
            this.expand();
            return true;
        }
        if (this.isExpanded) {
            this.collapse();
            return false;
        }
        return true;
    }
    get hasStateButton() {
        return this.isExpanded || this.isCollapsed;
    }
    get shortcutText() {
        return this.title || this.name;
    }
    getTitleToolbar() {
        if (!this.titleToolbarValue) {
            this.titleToolbarValue = this.createActionContainer(true);
            this.titleToolbarValue.locOwner = this;
            this.titleToolbarValue.containerCss = (this.isPanel ? this.cssClasses.panel.titleBar : this.cssClasses.titleBar) || "sv-action-title-bar";
            this.titleToolbarValue.setItems(this.getTitleActions());
        }
        return this.titleToolbarValue;
    }
    createActionContainer(allowAdaptiveActions) {
        const actionContainer = allowAdaptiveActions ? new AdaptiveActionContainer() : new ActionContainer();
        if (this.survey && !!this.survey.getCss().actionBar) {
            actionContainer.cssClasses = this.survey.getCss().actionBar;
        }
        return actionContainer;
    }
    get titleActions() {
        return this.getPropertyValue("titleActions");
    }
    getTitleActions() {
        if (!this.isTitleActionRequested) {
            this.updateTitleActions();
            this.isTitleActionRequested = true;
        }
        return this.titleActions;
    }
    getDefaultTitleActions() {
        return [];
    }
    updateTitleActions() {
        let actions = this.getDefaultTitleActions();
        if (!!this.survey) {
            actions = this.survey.getUpdatedElementTitleActions(this, actions);
        }
        this.setPropertyValue("titleActions", actions);
    }
    locStrsChanged() {
        super.locStrsChanged();
        if (!!this.titleToolbarValue) {
            this.titleToolbarValue.locStrsChanged();
        }
    }
    get hasTitleActions() {
        return this.getTitleActions().length > 0;
    }
    get hasTitleEvents() {
        return this.state !== undefined && this.state !== "default";
    }
    get titleTabIndex() {
        return !this.isPage && this.state !== "default" ? 0 : undefined;
    }
    get titleAriaExpanded() {
        if (this.isPage || this.state === "default")
            return undefined;
        return this.state === "expanded" ? "true" : "false";
    }
    get titleAriaRole() {
        if (this.isPage || this.state === "default")
            return undefined;
        return "button";
    }
    setSurveyImpl(value, isLight) {
        this.surveyImplValue = value;
        if (!this.surveyImplValue) {
            this.setSurveyCore(null);
            this.surveyDataValue = null;
        }
        else {
            this.surveyDataValue = this.surveyImplValue.getSurveyData();
            this.setSurveyCore(this.surveyImplValue.getSurvey());
            this.textProcessorValue = this.surveyImplValue.getTextProcessor();
            this.onSetData();
        }
        if (!!this.survey) {
            this.resetDescriptionVisibility();
            this.clearCssClasses();
        }
        this.blockAnimations();
        this.renderedIsExpanded = !this.isCollapsed;
        this.releaseAnimations();
    }
    canRunConditions() {
        return super.canRunConditions() && !!this.data;
    }
    getDataFilteredValues() {
        return !!this.data ? this.data.getFilteredValues() : {};
    }
    getDataFilteredProperties() {
        var props = !!this.data ? this.data.getFilteredProperties() : {};
        props.question = this;
        return props;
    }
    get surveyImpl() {
        return this.surveyImplValue;
    }
    /* You shouldn't use this method ever */
    __setData(data) {
        this.surveyDataValue = data;
    }
    get data() {
        return this.surveyDataValue;
    }
    /**
     * Returns the survey object.
     */
    get survey() {
        return this.getSurvey();
    }
    getSurvey(live = false) {
        if (!!this.surveyValue)
            return this.surveyValue;
        if (!!this.surveyImplValue) {
            this.setSurveyCore(this.surveyImplValue.getSurvey());
        }
        return this.surveyValue;
    }
    setSurveyCore(value) {
        this.surveyValue = value;
        if (!!this.surveyChangedCallback) {
            this.surveyChangedCallback();
        }
    }
    get skeletonHeight() {
        let skeletonHeight = undefined;
        if (!!this.survey && this.survey.skeletonHeight) {
            skeletonHeight = this.survey.skeletonHeight + "px";
        }
        return skeletonHeight;
    }
    get isInternal() {
        return this.isContentElement;
    }
    get areInvisibleElementsShowing() {
        return (!!this.survey &&
            this.survey.areInvisibleElementsShowing &&
            !this.isContentElement);
    }
    get isVisible() {
        return true;
    }
    /**
     * Returns `true` if the survey element or its parent element is read-only.
     *
     * If you want to switch a survey element to the read-only state based on a condition, specify the [`enableIf`](https://surveyjs.io/form-library/documentation/question#enableIf) property. Refer to the following help topic for information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see readOnly
     */
    get isReadOnly() {
        return this.readOnly;
    }
    /**
     * Makes the survey element read-only.
     *
     * If you want to switch a survey element to the read-only state based on a condition, specify the [`enableIf`](https://surveyjs.io/form-library/documentation/question#enableIf) property. Refer to the following help topic for information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see isReadOnly
     */
    get readOnly() {
        return this.getPropertyValue("readOnly");
    }
    set readOnly(val) {
        if (this.readOnly == val)
            return;
        this.setPropertyValue("readOnly", val);
        if (!this.isLoadingFromJson) {
            this.setPropertyValue("isReadOnly", this.isReadOnly);
        }
    }
    onReadOnlyChanged() {
        if (!!this.readOnlyChangedCallback) {
            this.readOnlyChangedCallback();
        }
    }
    get css() {
        return !!this.survey ? this.survey.getCss() : {};
    }
    get cssClassesValue() {
        let res = this.getPropertyValueWithoutDefault("cssClassesValue");
        if (!res && !this.isCssValueCalculating) {
            this.isCssValueCalculating = true;
            res = this.createCssClassesValue();
            this.isCssValueCalculating = false;
        }
        return res;
    }
    createCssClassesValue() {
        const res = this.calcCssClasses(this.css);
        this.setPropertyValue("cssClassesValue", res);
        this.onCalcCssClasses(res);
        this.updateElementCssCore(this.cssClassesValue);
        return res;
    }
    onCalcCssClasses(classes) { }
    /**
     * Returns an object in which keys are UI elements and values are CSS classes applied to them.
     *
     * Use the following events of the [`SurveyModel`](https://surveyjs.io/form-library/documentation/surveymodel) object to override CSS classes:
     *
     * - [`onUpdateQuestionCssClasses`](https://surveyjs.io/form-library/documentation/surveymodel#onUpdateQuestionCssClasses)
     * - [`onUpdatePanelCssClasses`](https://surveyjs.io/form-library/documentation/surveymodel#onUpdatePanelCssClasses)
     * - [`onUpdatePageCssClasses`](https://surveyjs.io/form-library/documentation/surveymodel#onUpdatePageCssClasses)
     * - [`onUpdateChoiceItemCss`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onUpdateChoiceItemCss)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/customize-survey-with-css/ (linkStyle))
     */
    get cssClasses() {
        this.cssClassesValue;
        if (!this.survey)
            return this.calcCssClasses(this.css);
        if (!this.cssClassesValue) {
            this.createCssClassesValue();
        }
        return this.cssClassesValue;
    }
    get cssTitleNumber() {
        const css = this.cssClasses;
        if (css.number)
            return css.number;
        return css.panel ? css.panel.number : undefined;
    }
    get cssRequiredMark() {
        const css = this.cssClasses;
        return css.requiredMark || (css.panel && css.panel.requiredMark);
    }
    getCssTitleExpandableSvg() {
        if (this.state === "default")
            return null;
        return this.cssClasses.titleExpandableSvg;
    }
    calcCssClasses(css) { return undefined; }
    updateElementCssCore(cssClasses) { }
    get cssError() { return ""; }
    updateElementCss(reNew) {
        this.clearCssClasses();
    }
    clearCssClasses() {
        this.resetPropertyValue("cssClassesValue");
    }
    getIsLoadingFromJson() {
        if (super.getIsLoadingFromJson())
            return true;
        return this.surveyValue ? this.surveyValue.isLoadingFromJson : false;
    }
    /**
     * A survey element identifier.
     *
     * > Question names must be unique.
     */
    get name() {
        return this.getPropertyValue("name", "");
    }
    set name(val) {
        var oldValue = this.name;
        this.setPropertyValue("name", this.getValidName(val));
        if (!this.isLoadingFromJson && !!oldValue) {
            this.onNameChanged(oldValue);
        }
    }
    getValidName(name) {
        return name;
    }
    onNameChanged(oldValue) { }
    updateBindingValue(valueName, value) {
        if (!!this.data &&
            !this.isTwoValueEquals(value, this.data.getValue(valueName))) {
            this.data.setValue(valueName, value, false);
        }
    }
    /**
     * Validation errors. Call the `validate()` method to validate survey element data.
     * @see validate
     */
    get errors() {
        return this.getPropertyValue("errors");
    }
    set errors(val) {
        this.setPropertyValue("errors", val);
    }
    updateVisibleErrors() {
        var counter = 0;
        for (var i = 0; i < this.errors.length; i++) {
            if (this.errors[i].visible)
                counter++;
        }
        this.hasVisibleErrors = counter > 0;
    }
    /**
     * Returns `true` if the survey element or its child elements have validation errors.
     *
     * This property contains the result of the most recent validation. This result may be outdated. Call the `validate` method to get an up-to-date value.
     * @see errors
     */
    get containsErrors() {
        return this.getPropertyValue("containsErrors", false);
    }
    updateContainsErrors() {
        this.setPropertyValue("containsErrors", this.getContainsErrors());
    }
    getContainsErrors() {
        return this.errors.length > 0;
    }
    get selectedElementInDesign() {
        return this.selectedElementInDesignValue;
    }
    set selectedElementInDesign(val) {
        this.selectedElementInDesignValue = val;
    }
    updateCustomWidgets() { }
    onSurveyLoad() { }
    get wasRendered() { return !!this.wasRenderedValue; }
    resetWasRendered() {
        this.wasRenderedValue = false;
    }
    onFirstRendering() {
        if (!this.wasRendered) {
            this.wasRenderedValue = true;
            this.onFirstRenderingCore();
        }
    }
    onFirstRenderingCore() { }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        if (!this.survey) {
            this.onSurveyLoad();
        }
    }
    setVisibleIndex(index) {
        return 0;
    }
    delete(doDispose) { }
    /**
     * Returns the survey's [locale](https://surveyjs.io/form-library/documentation/surveymodel#locale).
     *
     * If a default locale is used, this method returns an empty string. To get the applied locale in this case, use the following code:
     *
     * ```js
     * import { surveyLocalization } from 'survey-core';
     * const defaultLocale = surveyLocalization.defaultLocale;
     * ```
     *
     * @see [Localization & Globalization](https://surveyjs.io/form-library/documentation/localization)
     */
    getLocale() {
        return this.survey
            ? this.survey.getLocale()
            : this.locOwner
                ? this.locOwner.getLocale()
                : "";
    }
    getMarkdownHtml(text, name, item) {
        return this.survey
            ? this.survey.getSurveyMarkdownHtml(this, text, name, item)
            : this.locOwner
                ? this.locOwner.getMarkdownHtml(text, name, item)
                : undefined;
    }
    getRenderer(name) {
        return this.survey && typeof this.survey.getRendererForString === "function"
            ? this.survey.getRendererForString(this, name)
            : this.locOwner && typeof this.locOwner.getRenderer === "function"
                ? this.locOwner.getRenderer(name)
                : null;
    }
    getRendererContext(locStr) {
        return this.survey && typeof this.survey.getRendererContextForString === "function"
            ? this.survey.getRendererContextForString(this, locStr)
            : this.locOwner && typeof this.locOwner.getRendererContext === "function"
                ? this.locOwner.getRendererContext(locStr)
                : locStr;
    }
    getProcessedText(text) {
        if (this.isLoadingFromJson)
            return text;
        if (this.textProcessor)
            return this.textProcessor.processText(text, this.getUseDisplayValuesInDynamicTexts());
        if (this.locOwner)
            return this.locOwner.getProcessedText(text);
        return text;
    }
    getUseDisplayValuesInDynamicTexts() { return true; }
    removeSelfFromList(list) {
        if (!list || !Array.isArray(list))
            return;
        const index = list.indexOf(this);
        if (index > -1) {
            list.splice(index, 1);
        }
    }
    get textProcessor() {
        return this.textProcessorValue;
    }
    getProcessedHtml(html) {
        if (!html || !this.textProcessor)
            return html;
        return this.textProcessor.processText(html, true);
    }
    onSetData() { }
    get parent() {
        return this.getPropertyValue("parent", null);
    }
    set parent(val) {
        this.setPropertyValue("parent", val);
    }
    getPage(parent) {
        while (parent && parent.parent)
            parent = parent.parent;
        if (parent && parent.isPage)
            return parent;
        return null;
    }
    moveToBase(parent, container, insertBefore = null) {
        if (!container)
            return false;
        parent.removeElement(this);
        let index = -1;
        if (Helpers.isNumber(insertBefore)) {
            index = parseInt(insertBefore);
        }
        if (index == -1 && !!insertBefore && !!insertBefore.getType) {
            index = container.indexOf(insertBefore);
        }
        container.addElement(this, index);
        return true;
    }
    setPage(parent, newPage) {
        const oldPage = this.getPage(parent);
        this.prevSurvey = this.survey;
        //fix for the creator v1: https://github.com/surveyjs/survey-creator/issues/1744
        if (typeof newPage === "string") {
            const survey = this.getSurvey();
            survey.pages.forEach((page) => {
                if (newPage === page.name)
                    newPage = page;
            });
        }
        if (oldPage === newPage)
            return;
        if (parent)
            parent.removeElement(this);
        if (newPage) {
            newPage.addElement(this, -1);
        }
        this.prevSurvey = undefined;
    }
    getSearchableLocKeys(keys) {
        keys.push("title");
        keys.push("description");
    }
    get hasParent() {
        return (this.parent && !this.parent.isPage) || (this.parent === undefined);
    }
    shouldAddRunnerStyles() {
        return !this.isDesignMode;
    }
    get isCompact() {
        return this.survey && this.survey["isCompact"];
    }
    canHaveFrameStyles() {
        var _a;
        if (((_a = this.survey) === null || _a === void 0 ? void 0 : _a.currentSingleElement) === this)
            return true;
        return (this.parent !== undefined && (!this.hasParent || this.parent && this.parent.showPanelAsPage));
    }
    getHasFrameV2() {
        return this.shouldAddRunnerStyles() && this.canHaveFrameStyles();
    }
    getIsNested() {
        return this.shouldAddRunnerStyles() && !this.canHaveFrameStyles();
    }
    getCssRoot(cssClasses) {
        const isExpanadable = !!this.isCollapsed || !!this.isExpanded;
        return new CssClassBuilder()
            .append(cssClasses.withFrame, this.getHasFrameV2() && !this.isCompact)
            .append(cssClasses.compact, this.isCompact && this.getHasFrameV2())
            .append(cssClasses.collapsed, !!this.isCollapsed)
            .append(cssClasses.expandableAnimating, isExpanadable && this.isAnimatingCollapseExpand)
            .append(cssClasses.expanded, !!this.isExpanded && this.renderedIsExpanded)
            .append(cssClasses.expandable, isExpanadable)
            .append(cssClasses.nested, this.getIsNested())
            .toString();
    }
    /**
     * Sets survey element width in CSS values.
     *
     * Default value: ""
     * @see minWidth
     * @see maxWidth
    */
    get width() {
        return this.getPropertyValue("width", "");
    }
    set width(val) {
        this.setPropertyValue("width", val);
    }
    /**
     * Gets or sets minimum survey element width in CSS values.
     *
     * Default value: "300px" (taken from [`settings.minWidth`](https://surveyjs.io/form-library/documentation/settings#minWidth))
     * @see maxWidth
     * @see renderWidth
     * @see width
     */
    get minWidth() {
        return this.getPropertyValue("minWidth");
    }
    set minWidth(val) {
        this.setPropertyValue("minWidth", val);
    }
    /**
     * Gets or sets maximum survey element width in CSS values.
     *
     * Default value: "100%" (taken from [`settings.maxWidth`](https://surveyjs.io/form-library/documentation/settings#maxWidth))
     * @see minWidth
     * @see renderWidth
     * @see width
     */
    get maxWidth() {
        return this.getPropertyValue("maxWidth");
    }
    set maxWidth(val) {
        this.setPropertyValue("maxWidth", val);
    }
    /**
     * Returns a calculated width of the rendered survey element in CSS values.
     * @see width
     * @see minWidth
     * @see maxWidth
     */
    get renderWidth() {
        return this.getPropertyValue("renderWidth", "");
    }
    set renderWidth(val) {
        this.setPropertyValue("renderWidth", val);
    }
    /**
     * Increases or decreases an indent of survey element content from the left edge. Accepts positive integer values and 0.
     */
    get indent() {
        return this.getPropertyValue("indent");
    }
    set indent(val) {
        this.setPropertyValue("indent", val);
    }
    get rightIndent() {
        return this.getPropertyValue("rightIndent", 0);
    }
    set rightIndent(val) {
        this.setPropertyValue("rightIndent", val);
    }
    getRootStyle() {
        const style = {};
        if (!!this.paddingLeft) {
            style["--sv-element-add-padding-left"] = this.paddingLeft;
        }
        if (!!this.paddingRight) {
            style["--sv-element-add-padding-right"] = this.paddingRight;
        }
        return style;
    }
    get paddingLeft() {
        return this.getPropertyValue("paddingLeft", undefined, () => this.calcPaddingLeft());
    }
    calcPaddingLeft() {
        return "";
    }
    get paddingRight() {
        return this.getPropertyValue("paddingRight", undefined, () => this.calcPaddingRight());
    }
    set paddingRight(val) {
        this.setPropertyValue("paddingRight", val);
    }
    calcPaddingRight() {
        return "";
    }
    resetIndents() {
        this.resetPropertyValue("paddingLeft");
        this.resetPropertyValue("paddingRight");
    }
    get rootStyle() {
        return this.getPropertyValue("rootStyle", undefined, () => this.calcRootStyle());
    }
    set rootStyle(val) { this.setPropertyValue("rootStyle", val); }
    updateRootStyle() {
        if (!this.getPropertyValueWithoutDefault("rootStyle")) {
            this.resetPropertyValue("effectiveColSpan");
        }
        else {
            this.setRootStyle();
        }
    }
    setRootStyle() {
        this.rootStyle = this.calcRootStyle();
    }
    calcRootStyle() {
        const style = {};
        let _width;
        if (!!this.parent) {
            const columns = this.parent.getColumsForElement(this);
            _width = columns.reduce((sum, col) => col.effectiveWidth + sum, 0);
            if (!!_width && _width !== 100) {
                style["flexGrow"] = 1;
                style["flexShrink"] = 0;
                style["flexBasis"] = _width + "%";
                style["minWidth"] = undefined;
                style["maxWidth"] = this.maxWidth;
            }
        }
        if (Object.keys(style).length == 0) {
            let minWidth = "" + this.minWidth;
            if (!!minWidth && minWidth != "auto") {
                if (minWidth.indexOf("px") != -1 && this.survey) {
                    minWidth = minWidth.replace("px", "");
                    let minWidthNum = parseFloat(minWidth);
                    if (!isNaN(minWidthNum)) {
                        minWidth = minWidthNum * this.survey.widthScale / 100;
                        minWidth = "" + minWidth + "px";
                    }
                }
                minWidth = "min(100%, " + minWidth + ")";
            }
            if (this.allowRootStyle && this.renderWidth) {
                style["flexGrow"] = 1;
                style["flexShrink"] = 1;
                style["flexBasis"] = this.renderWidth;
                style["minWidth"] = minWidth;
                style["maxWidth"] = this.maxWidth;
            }
        }
        return style;
    }
    isContainsSelection(el) {
        let elementWithSelection = undefined;
        const _document = DomDocumentHelper.getDocument();
        if (DomDocumentHelper.isAvailable() && !!_document && _document["selection"]) {
            elementWithSelection = _document["selection"].createRange().parentElement();
        }
        else {
            var selection = DomWindowHelper.getSelection();
            if (!!selection && selection.rangeCount > 0) {
                const range = selection.getRangeAt(0);
                if (range.startOffset !== range.endOffset) {
                    elementWithSelection = range.startContainer.parentNode;
                }
            }
        }
        return elementWithSelection == el;
    }
    get clickTitleFunction() {
        if (this.needClickTitleFunction()) {
            return (event) => {
                if (!!event && this.isContainsSelection(event.target)) {
                    return;
                }
                return this.processTitleClick();
            };
        }
        return undefined;
    }
    needClickTitleFunction() {
        return this.state !== "default";
    }
    processTitleClick() {
        if (this.state !== "default") {
            this.toggleState();
        }
    }
    get hasAdditionalTitleToolbar() {
        return false;
    }
    get additionalTitleToolbar() {
        return this.getAdditionalTitleToolbar();
    }
    getAdditionalTitleToolbar() {
        return null;
    }
    getCssTitle(cssClasses) {
        if (!cssClasses)
            return "";
        const isExpandable = this.state !== "default";
        const numInlineLimit = 4;
        return new CssClassBuilder()
            .append(cssClasses.title)
            .append(cssClasses.titleNumInline, (this.no || "").length > numInlineLimit || isExpandable)
            .append(cssClasses.titleExpandable, isExpandable)
            .append(cssClasses.titleExpanded, this.isExpanded)
            .append(cssClasses.titleCollapsed, this.isCollapsed)
            .append(cssClasses.titleDisabled, this.isDisabledStyle)
            .append(cssClasses.titleReadOnly, this.isReadOnly)
            .append(cssClasses.titleOnError, this.containsErrors).toString();
    }
    get isDisabledStyle() {
        return this.getIsDisableAndReadOnlyStyles(false)[1];
    }
    get isReadOnlyStyle() {
        return this.getIsDisableAndReadOnlyStyles(false)[0];
    }
    getIsDisableAndReadOnlyStyles(itemReadOnly) {
        const isPreview = this.isPreviewStyle;
        const isReadOnly = itemReadOnly || this.isReadOnly;
        const isReadOnlyStyle = isReadOnly && !isPreview;
        // const isDisableStyle = this.isDefaultV2Theme && (isReadOnly || isPreview); this was useful for the old theme
        return [isReadOnlyStyle, false];
    }
    get isPreviewStyle() {
        return !!this.survey && this.survey.state === "preview";
    }
    localeChanged() {
        super.localeChanged();
        this.resetDescriptionVisibility();
        if (this.errors.length > 0) {
            this.errors.forEach(err => {
                err.updateText();
            });
        }
    }
    setWrapperElement(element) {
        this.wrapperElement = element;
    }
    getWrapperElement() {
        return this.wrapperElement;
    }
    set isAnimatingCollapseExpand(val) {
        if (val !== this._isAnimatingCollapseExpand) {
            this._isAnimatingCollapseExpand = val;
            this.updateElementCss(false);
        }
    }
    get isAnimatingCollapseExpand() {
        return this._isAnimatingCollapseExpand || this._renderedIsExpanded != this.isExpanded;
    }
    onElementExpanded(elementIsRendered) {
    }
    getExpandCollapseAnimationOptions() {
        const beforeRunAnimation = (el) => {
            this.isAnimatingCollapseExpand = true;
            prepareElementForVerticalAnimation(el);
        };
        const afterRunAnimation = (el) => {
            this.isAnimatingCollapseExpand = false;
            cleanHtmlElementAfterAnimation(el);
        };
        return {
            getRerenderEvent: () => this.onElementRerendered,
            getEnterOptions: () => {
                const cssClasses = this.isPanel ? this.cssClasses.panel : this.cssClasses;
                return {
                    cssClass: cssClasses.contentEnter,
                    onBeforeRunAnimation: beforeRunAnimation,
                    onAfterRunAnimation: (el) => {
                        afterRunAnimation(el);
                        this.onElementExpanded(true);
                    },
                };
            },
            getLeaveOptions: () => {
                const cssClasses = this.isPanel ? this.cssClasses.panel : this.cssClasses;
                return {
                    cssClass: cssClasses.contentLeave,
                    onBeforeRunAnimation: beforeRunAnimation,
                    onAfterRunAnimation: afterRunAnimation
                };
            },
            getAnimatedElement: () => {
                var _a;
                const cssClasses = this.isPanel ? this.cssClasses.panel : this.cssClasses;
                if (cssClasses.content) {
                    const selector = classesToSelector(cssClasses.content);
                    if (selector) {
                        return (_a = this.getWrapperElement()) === null || _a === void 0 ? void 0 : _a.querySelector(`:scope ${selector}`);
                    }
                }
                return undefined;
            },
            isAnimationEnabled: () => this.isExpandCollapseAnimationEnabled
        };
    }
    get isExpandCollapseAnimationEnabled() {
        return this.animationAllowed && !this.isDesignMode;
    }
    set renderedIsExpanded(val) {
        const oldValue = this._renderedIsExpanded;
        this.animationCollapsed.sync(val);
        if (!this.isExpandCollapseAnimationEnabled && !oldValue && this.renderedIsExpanded) {
            this.onElementExpanded(false);
        }
    }
    get renderedIsExpanded() {
        return !!this._renderedIsExpanded;
    }
    getIsAnimationAllowed() {
        return super.getIsAnimationAllowed() && !!this.survey && !this.survey["isEndLoadingFromJson"];
    }
    afterRenderCore(element) {
        this.onAfterRenderElement.fire(this, { htmlElement: element });
    }
    dispose() {
        super.dispose();
        if (this.titleToolbarValue) {
            this.titleToolbarValue.dispose();
        }
    }
}
// TODO V2: get rid of this flag
SurveyElement.CreateDisabledDesignElements = false;
__decorate([
    property({ defaultValue: false })
], SurveyElement.prototype, "hasVisibleErrors", void 0);
__decorate([
    property({ defaultValue: true })
], SurveyElement.prototype, "isSingleInRow", void 0);
__decorate([
    property({ defaultValue: true })
], SurveyElement.prototype, "allowRootStyle", void 0);
__decorate([
    property()
], SurveyElement.prototype, "_renderedIsExpanded", void 0);
class RenderingCompletedAwaiter {
    constructor(_elements, _renderedHandler, waitingTimeout = 100) {
        this._elements = _elements;
        this._renderedHandler = _renderedHandler;
        this._elementsToRenderCount = 0;
        this._elementsToRenderTimer = undefined;
        this._elementRenderedHandler = (s, o) => {
            var _a;
            (_a = s.onAfterRenderElement) === null || _a === void 0 ? void 0 : _a.remove(this._elementRenderedHandler);
            this._elementsToRenderCount--;
            if (this._elementsToRenderCount <= 0) {
                this.visibleElementsRendered();
            }
        };
        this._elements.forEach(element => {
            if (element.onAfterRenderElement) {
                element.onAfterRenderElement.add(this._elementRenderedHandler);
                this._elementsToRenderCount++;
            }
        });
        if (this._elementsToRenderCount > 0) {
            this._elementsToRenderTimer = setTimeout(() => {
                if (this._elementsToRenderCount > 0) {
                    this.visibleElementsRendered();
                }
            }, waitingTimeout);
        }
        else {
            this.visibleElementsRendered();
        }
    }
    stopWaitingForElementsRendering() {
        if (this._elementsToRenderTimer) {
            clearTimeout(this._elementsToRenderTimer);
            this._elementsToRenderTimer = undefined;
        }
        this._elements.forEach(element => {
            var _a;
            (_a = element.onAfterRenderElement) === null || _a === void 0 ? void 0 : _a.remove(this._elementRenderedHandler);
        });
        this._elementsToRenderCount = 0;
    }
    visibleElementsRendered() {
        const renderedHandler = this._renderedHandler;
        this.dispose();
        if (typeof renderedHandler == "function") {
            renderedHandler();
        }
    }
    dispose() {
        this.stopWaitingForElementsRendering();
        this._elements = undefined;
        this._renderedHandler = undefined;
    }
}

/**
 * The class represents the string that supports multi-languages and markdown.
 * It uses in all objects where support for multi-languages and markdown is required.
 */
class LocalizableString {
    static get defaultLocale() {
        return settings.localization.defaultLocaleName;
    }
    static set defaultLocale(val) {
        settings.localization.defaultLocaleName = val;
    }
    get localizationName() {
        return this._localizationName;
    }
    set localizationName(val) {
        if (this._localizationName != val) {
            this._localizationName = val;
            this.strChanged();
        }
    }
    get allowLineBreaks() {
        var _a;
        if (this._allowLineBreaks === undefined) {
            this._allowLineBreaks = false;
            if (!!this.name && this.owner instanceof SurveyElementCore) {
                this._allowLineBreaks = ((_a = Serializer.findProperty(this.owner.getType(), this.name)) === null || _a === void 0 ? void 0 : _a.type) == "text";
            }
        }
        return this._allowLineBreaks;
    }
    constructor(owner, useMarkdown = false, name, locName) {
        this.owner = owner;
        this.useMarkdown = useMarkdown;
        this.name = name;
        this.values = {};
        this.htmlValues = {};
        this.onStringChanged = new EventBase();
        this._localizationName = locName;
        this.onCreating();
    }
    getIsMultiple() { return false; }
    get locale() {
        if (this.owner && this.owner.getLocale) {
            const res = this.owner.getLocale();
            if (!!res || !this.sharedData)
                return res;
        }
        if (!!this.sharedData)
            return this.sharedData.locale;
        return "";
    }
    get isDefautlLocale() {
        const loc = this.locale;
        return !loc || loc === settings.defaultLocaleName;
    }
    strChanged() {
        if (!this.isTextRequested)
            return;
        this.searchableText = undefined;
        if (this.renderedText === undefined && this.isEmpty && !this.onGetTextCallback && !this.localizationName)
            return;
        this.calculatedTextValue = this.calcText();
        if (this.renderedText !== this.calculatedTextValue) {
            this.renderedText = undefined;
            this.calculatedTextValue = undefined;
        }
        this.htmlValues = {};
        this.onChanged();
        this.onStringChanged.fire(this, {});
    }
    get text() {
        return this.pureText;
    }
    set text(value) {
        this.setLocaleText(this.locale, value);
    }
    get calculatedText() {
        this.renderedText =
            this.calculatedTextValue !== undefined
                ? this.calculatedTextValue
                : this.calcText();
        this.calculatedTextValue = undefined;
        return this.renderedText;
    }
    getPlaceholder() {
        let res = "";
        if (!this.isDefautlLocale) {
            const dialectLocale = this.getRootDialect(this.locale);
            res = this.getLocaleText(dialectLocale || settings.defaultLocaleName);
        }
        if (!res && this.onGetTextCallback) {
            res = this.onGetTextCallback("", "");
        }
        return res;
    }
    calcText() {
        const pureText = this.pureText;
        let res = pureText;
        if (res && this.owner && this.owner.getProcessedText && res.indexOf("{") > -1) {
            res = this.owner.getProcessedText(res);
        }
        if (this.onGetTextCallback)
            res = this.onGetTextCallback(res, pureText);
        return res;
    }
    get pureText() {
        this.isTextRequested = true;
        var loc = this.locale;
        if (!loc)
            loc = this.defaultLoc;
        var res = this.getValue(loc);
        if (this.isValueEmpty(res) && loc === this.defaultLoc) {
            res = this.getValue(surveyLocalization.defaultLocale);
        }
        if (this.isValueEmpty(res)) {
            const dialect = this.getRootDialect(loc);
            if (!!dialect) {
                res = this.getValue(dialect);
            }
        }
        if (this.isValueEmpty(res) && loc !== this.defaultLoc) {
            res = this.getValue(this.defaultLoc);
        }
        if (this.isValueEmpty(res) && !!this.getLocalizationName()) {
            res = this.getLocalizationStr();
        }
        if (!res)
            res = this.defaultValue || "";
        return res;
    }
    getRootDialect(loc) {
        if (!loc)
            return loc;
        const index = loc.indexOf("-");
        return index > -1 ? loc.substring(0, index) : "";
    }
    getLocalizationName() {
        return !!this.sharedData ? this.sharedData.localizationName : this.localizationName;
    }
    getLocalizationStr() {
        const name = this.getLocalizationName();
        return !!name ? getLocaleString(name, this.locale) : "";
    }
    get hasHtml() {
        return this.hasHtmlValue();
    }
    get html() {
        if (!this.hasHtml)
            return "";
        return this.getHtmlValue();
    }
    get isEmpty() {
        return this.getValuesKeys().length == 0;
    }
    get textOrHtml() {
        return this.hasHtml ? this.getHtmlValue() : this.calculatedText;
    }
    get renderedHtml() {
        return this.textOrHtml;
    }
    getLocaleText(loc) {
        const res = this.getLocaleTextCore(loc);
        return res ? res : "";
    }
    getLocaleTextCore(loc) {
        if (!loc)
            loc = this.defaultLoc;
        return this.getValue(loc);
    }
    isLocaleTextEqualsWithDefault(loc, val) {
        let res = this.getLocaleTextCore(loc);
        if (res === val)
            return true;
        return this.isValueEmpty(res) && this.isValueEmpty(val);
    }
    clear() {
        this.setJson(undefined);
    }
    clearLocale(loc) {
        this.setLocaleText(loc, undefined);
    }
    setLocaleText(loc, value) {
        loc = this.getValueLoc(loc);
        this.lastChangedLoc = loc;
        if (!!loc && value === undefined) {
            const oldValue = this.getValue(loc);
            if (oldValue !== undefined) {
                this.deleteValue(loc);
                this.fireStrChanged(loc, oldValue);
            }
            return;
        }
        if (!this.storeDefaultText && this.isLocaleTextEqualsWithDefault(loc, value)) {
            if (!this.isValueEmpty(value) || !!loc && loc !== this.defaultLoc)
                return;
            let dl = surveyLocalization.defaultLocale;
            let oldValue = this.getValue(dl);
            if (!!dl && !this.isValueEmpty(oldValue)) {
                this.setValue(dl, value);
                this.fireStrChanged(dl, oldValue);
            }
            return;
        }
        if (!settings.localization.storeDuplicatedTranslations &&
            !this.isValueEmpty(value) && loc && loc != this.defaultLoc &&
            !this.getValue(loc) &&
            value == this.getLocaleText(this.defaultLoc))
            return;
        var curLoc = this.curLocale;
        if (!loc)
            loc = this.defaultLoc;
        var oldValue = this.onStrChanged && loc === curLoc ? this.pureText : undefined;
        delete this.htmlValues[loc];
        if (this.isValueEmpty(value)) {
            this.deleteValue(loc);
        }
        else {
            if (typeof value === "string") {
                if (this.canRemoveLocValue(loc, value)) {
                    this.setLocaleText(loc, null);
                }
                else {
                    this.setValue(loc, value);
                    if (loc == this.defaultLoc) {
                        this.deleteValuesEqualsToDefault(value);
                    }
                }
            }
        }
        this.fireStrChanged(loc, oldValue);
    }
    isValueEmpty(val) {
        if (val === undefined || val === null)
            return true;
        if (this.localizationName)
            return false;
        return val === "";
    }
    get curLocale() {
        return !!this.locale ? this.locale : this.defaultLoc;
    }
    canRemoveLocValue(loc, val) {
        if (settings.localization.storeDuplicatedTranslations)
            return false;
        if (loc === this.defaultLoc)
            return false;
        const dialect = this.getRootDialect(loc);
        if (!!dialect) {
            const dialectVal = this.getLocaleText(dialect);
            if (!!dialectVal)
                return dialectVal == val;
            return this.canRemoveLocValue(dialect, val);
        }
        else {
            return val == this.getLocaleText(this.defaultLoc);
        }
    }
    fireStrChanged(loc, oldValue) {
        this.strChanged();
        if (!this.onStrChanged)
            return;
        const value = this.pureText;
        if (loc !== this.curLocale || oldValue !== value) {
            this.onStrChanged(oldValue, value);
        }
    }
    hasNonDefaultText() {
        var keys = this.getValuesKeys();
        if (keys.length == 0)
            return false;
        return keys.length > 1 || keys[0] != this.defaultLoc;
    }
    getLocales() {
        var keys = this.getValuesKeys();
        if (keys.length == 0)
            return [];
        return keys;
    }
    getJson() {
        if (!!this.sharedData)
            return this.sharedData.getJson();
        const keys = this.getValuesKeys();
        if (keys.length == 0) {
            if (this.serializeCallBackText) {
                const text = this.calcText();
                if (!!text)
                    return text;
            }
            return null;
        }
        if (keys.length == 1 &&
            keys[0] == settings.localization.defaultLocaleName &&
            !settings.serialization.localizableStringSerializeAsObject)
            return this.values[keys[0]];
        const res = {};
        for (let key in this.values) {
            res[key] = this.values[key];
        }
        return res;
    }
    setJson(value, isLoading) {
        if (!!this.sharedData) {
            this.sharedData.setJson(value, isLoading);
            return;
        }
        this.lastChangedLoc = undefined;
        this.values = {};
        this.htmlValues = {};
        if (value === null || value === undefined)
            return;
        if (isLoading) {
            if (typeof value === "string") {
                this.values[settings.defaultLocaleName] = value;
            }
            else {
                this.values = value;
                delete this.values["pos"];
            }
        }
        else {
            if (typeof value === "string") {
                this.setLocaleText(null, value);
            }
            else {
                for (var key in value) {
                    this.setLocaleText(key, value[key]);
                }
            }
            this.strChanged();
        }
    }
    get renderAs() {
        if (!this.owner || typeof this.owner.getRenderer !== "function") {
            return LocalizableString.defaultRenderer;
        }
        return this.owner.getRenderer(this.name) || LocalizableString.defaultRenderer;
    }
    get renderAsData() {
        if (!this.owner || typeof this.owner.getRendererContext !== "function") {
            return this;
        }
        return this.owner.getRendererContext(this) || this;
    }
    equals(obj) {
        if (!!this.sharedData)
            return this.sharedData.equals(obj);
        if (!obj || !obj.values)
            return false;
        return Helpers.isTwoValueEquals(this.values, obj.values, false, true, false);
    }
    setFindText(text) {
        if (this.searchText == text)
            return;
        this.searchText = text;
        if (!this.searchableText) {
            let textOrHtml = this.textOrHtml;
            this.searchableText = !!textOrHtml ? textOrHtml.toLowerCase() : "";
        }
        var str = this.searchableText;
        var index = !!str && !!text ? str.indexOf(text) : undefined;
        if (index < 0)
            index = undefined;
        if (index != undefined || this.searchIndex != index) {
            this.searchIndex = index;
            if (!!this.onSearchChanged) {
                this.onSearchChanged();
            }
        }
        return this.searchIndex != undefined;
    }
    onChanged() { }
    onCreating() { }
    hasHtmlValue() {
        if (!this.owner || !this.useMarkdown)
            return false;
        let loc = this.locale;
        if (!loc)
            loc = this.defaultLoc;
        if (this.htmlValues[loc] !== undefined)
            return !!this.htmlValues[loc];
        let renderedText = this.calculatedText;
        if (!renderedText) {
            this.setHtmlValue(loc, "");
            return false;
        }
        if (!!this.getLocalizationName() && renderedText === this.getLocalizationStr()) {
            this.setHtmlValue(loc, "");
            return false;
        }
        const res = this.owner.getMarkdownHtml(renderedText, this.name);
        this.setHtmlValue(loc, res);
        return !!res;
    }
    setHtmlValue(loc, val) {
        this.htmlValues[loc] = val;
    }
    getHtmlValue() {
        var loc = this.locale;
        if (!loc)
            loc = this.defaultLoc;
        return this.htmlValues[loc];
    }
    deleteValuesEqualsToDefault(defaultValue) {
        if (settings.localization.storeDuplicatedTranslations)
            return;
        var keys = this.getValuesKeys();
        for (var i = 0; i < keys.length; i++) {
            if (keys[i] == this.defaultLoc)
                continue;
            if (this.getValue(keys[i]) == defaultValue) {
                this.deleteValue(keys[i]);
            }
        }
    }
    getValue(loc) {
        if (!!this.sharedData)
            return this.sharedData.getValue(loc);
        return this.values[this.getValueLoc(loc)];
    }
    setValue(loc, value) {
        if (!!this.sharedData)
            this.sharedData.setValue(loc, value);
        else
            this.values[this.getValueLoc(loc)] = value;
    }
    deleteValue(loc) {
        if (!!this.sharedData)
            this.sharedData.deleteValue(loc);
        else
            delete this.values[this.getValueLoc(loc)];
    }
    getValueLoc(loc) {
        if (this.disableLocalization)
            return settings.localization.defaultLocaleName;
        return loc;
    }
    getValuesKeys() {
        if (!!this.sharedData)
            return this.sharedData.getValuesKeys();
        return Object.keys(this.values);
    }
    get defaultLoc() {
        return settings.localization.defaultLocaleName;
    }
}
LocalizableString.SerializeAsObject = false;
LocalizableString.defaultRenderer = "sv-string-viewer";
LocalizableString.editableRenderer = "sv-string-editor";
/**
 * The class represents the list of strings that supports multi-languages.
 */
class LocalizableStrings {
    constructor(owner) {
        this.owner = owner;
        this.values = {};
    }
    getIsMultiple() { return true; }
    get locale() {
        return this.owner && this.owner.getLocale ? this.owner.getLocale() : "";
    }
    get value() {
        return this.getValue("");
    }
    set value(val) {
        this.setValue("", val);
    }
    get text() {
        return Array.isArray(this.value) ? this.value.join("\n") : "";
    }
    set text(val) {
        this.value = !!val ? val.split("\n") : [];
    }
    getLocaleText(loc) {
        var res = this.getValueCore(loc, !loc || loc === this.locale);
        if (!res || !Array.isArray(res) || res.length == 0)
            return "";
        return res.join("\n");
    }
    setLocaleText(loc, newValue) {
        var val = !!newValue ? newValue.split("\n") : null;
        this.setValue(loc, val);
    }
    getValue(loc) {
        return this.getValueCore(loc);
    }
    getValueCore(loc, useDefault = true) {
        loc = this.getLocale(loc);
        if (this.values[loc])
            return this.values[loc];
        if (useDefault) {
            var defLoc = settings.localization.defaultLocaleName;
            if (loc !== defLoc && this.values[defLoc])
                return this.values[defLoc];
        }
        return [];
    }
    setValue(loc, val) {
        loc = this.getLocale(loc);
        const oldValue = Helpers.createCopy(this.values);
        if (!val || val.length == 0) {
            delete this.values[loc];
        }
        else {
            this.values[loc] = val;
        }
        if (!!this.onValueChanged) {
            this.onValueChanged(oldValue, this.values);
        }
    }
    hasValue(loc = "") {
        return !this.isEmpty && this.getValue(loc).length > 0;
    }
    get isEmpty() {
        return this.getValuesKeys().length == 0;
    }
    getLocale(loc) {
        if (!!loc)
            return loc;
        loc = this.locale;
        return !!loc ? loc : settings.localization.defaultLocaleName;
    }
    getLocales() {
        var keys = this.getValuesKeys();
        if (keys.length == 0)
            return [];
        return keys;
    }
    getJson() {
        var keys = this.getValuesKeys();
        if (keys.length == 0)
            return null;
        if (keys.length == 1 &&
            keys[0] == settings.localization.defaultLocaleName &&
            !settings.serialization.localizableStringSerializeAsObject)
            return this.values[keys[0]];
        return Helpers.createCopy(this.values);
    }
    setJson(value) {
        this.values = {};
        if (!value)
            return;
        if (Array.isArray(value)) {
            this.setValue(null, value);
        }
        else {
            for (var key in value) {
                this.setValue(key, value[key]);
            }
        }
    }
    getValuesKeys() {
        return Object.keys(this.values);
    }
}

function confirmAction(message) {
    if (!!settings && !!settings.confirmActionFunc)
        return settings.confirmActionFunc(message);
    return confirm(message);
}
function confirmActionAsync(options) {
    const callbackFunc = (res) => {
        if (res)
            options.funcOnYes();
        else if (!!options.funcOnNo)
            options.funcOnNo();
    };
    if (!!settings && !!settings.confirmActionAsync) {
        if (settings.confirmActionAsync(options.message, callbackFunc, options))
            return;
    }
    callbackFunc(confirmAction(options.message));
}
function detectIEOrEdge() {
    if (typeof detectIEOrEdge.isIEOrEdge === "undefined") {
        const ua = navigator.userAgent;
        const msie = ua.indexOf("MSIE ");
        const trident = ua.indexOf("Trident/");
        const edge = ua.indexOf("Edge/");
        detectIEOrEdge.isIEOrEdge = edge > 0 || trident > 0 || msie > 0;
    }
    return detectIEOrEdge.isIEOrEdge;
}
function loadFileFromBase64(b64Data, fileName) {
    try {
        const byteString = atob(b64Data.split(",")[1]);
        // separate out the mime component
        const mimeString = b64Data
            .split(",")[0]
            .split(":")[1]
            .split(";")[0];
        // write the bytes of the string to an ArrayBuffer
        const ab = new ArrayBuffer(byteString.length);
        const ia = new Uint8Array(ab);
        for (let i = 0; i < byteString.length; i++) {
            ia[i] = byteString.charCodeAt(i);
        }
        // write the ArrayBuffer to a blob, and you're done
        const bb = new Blob([ab], { type: mimeString });
        if (!!navigator && navigator["msSaveBlob"]) {
            navigator["msSaveOrOpenBlob"](bb, fileName);
        }
    }
    catch (err) { }
}
const isShadowDOM = (rootElement) => {
    return !!rootElement && !!("host" in rootElement && rootElement.host);
};
const getElement = (element) => {
    const { root } = settings.environment;
    return typeof element === "string" ? root.getElementById(element) : element;
};
function isElementVisible(element, threshold = 0) {
    if (typeof settings.environment === "undefined" || !element.offsetHeight) {
        return false;
    }
    const { root } = settings.environment;
    const clientHeight = isShadowDOM(root)
        ? root.host.clientHeight
        : root.documentElement.clientHeight;
    const elementRect = element.getBoundingClientRect();
    const viewHeight = Math.max(clientHeight, DomWindowHelper.getInnerHeight());
    const topWin = -threshold;
    const bottomWin = viewHeight + threshold;
    const topEl = elementRect.top;
    const bottomEl = elementRect.bottom;
    const maxTop = Math.max(topWin, topEl);
    const minBottom = Math.min(bottomWin, bottomEl);
    return maxTop <= minBottom;
}
function findScrollableParent(element) {
    if (!element) {
        return DomDocumentHelper.isAvailable() ? DomDocumentHelper.getDocument().documentElement : undefined;
    }
    if (element.scrollHeight > element.clientHeight &&
        (getComputedStyle(element).overflowY === "scroll" ||
            getComputedStyle(element).overflowY === "auto")) {
        return element;
    }
    if (element.scrollWidth > element.clientWidth &&
        (getComputedStyle(element).overflowX === "scroll" ||
            getComputedStyle(element).overflowX === "auto")) {
        return element;
    }
    if (!element.parentElement) {
        const rootNode = element.getRootNode();
        if (rootNode instanceof Document || rootNode instanceof ShadowRoot) {
            return isShadowDOM(rootNode) ? rootNode.host : rootNode.documentElement;
        }
    }
    return findScrollableParent(element.parentElement);
}
function activateLazyRenderingChecks(element) {
    if (!element)
        return;
    const scrollableEl = findScrollableParent(element);
    if (!!scrollableEl) {
        setTimeout(() => scrollableEl.dispatchEvent(new CustomEvent("scroll")), 10);
    }
}
function navigateToUrl(url) {
    const location = DomWindowHelper.getLocation();
    if (!url || !location)
        return;
    location.href = getSafeUrl(url);
}
function wrapUrlForBackgroundImage(url) {
    return !!url ? ["url(", url, ")"].join("") : "";
}
function isBase64URL(url) {
    if (typeof url == "string") {
        return /^data:((?:\w+\/(?:(?!;).)+)?)((?:;[^;]+?)*),(.+)$/.test(url);
    }
    return null;
}
// old-name: new-name
const renamedIcons = {
    "changecamera": "flip-24x24",
    "clear": "clear-24x24",
    "cancel": "cancel-24x24",
    "closecamera": "close-24x24",
    "defaultfile": "file-72x72",
    "choosefile": "folder-24x24",
    "file": "toolbox-file-24x24",
    "left": "chevronleft-16x16",
    "modernbooleancheckchecked": "plus-32x32",
    "modernbooleancheckunchecked": "minus-32x32",
    "more": "more-24x24",
    "navmenu_24x24": "navmenu-24x24",
    "removefile": "error-24x24",
    "takepicture": "camera-32x32",
    "takepicture_24x24": "camera-24x24",
    "v2check": "check-16x16",
    "checked": "check-16x16",
    "v2check_24x24": "check-24x24",
    "back-to-panel_16x16": "restoredown-16x16",
    "clear_16x16": "clear-16x16",
    "close_16x16": "close-16x16",
    "collapsedetail": "collapsedetails-16x16",
    "expanddetail": "expanddetails-16x16",
    "full-screen_16x16": "maximize-16x16",
    "loading": "loading-48x48",
    "minimize_16x16": "minimize-16x16",
    "next_16x16": "chevronright-16x16",
    "previous_16x16": "chevronleft-16x16",
    "no-image": "noimage-48x48",
    "ranking-dash": "rankingundefined-16x16",
    "drag-n-drop": "drag-24x24",
    "ranking-arrows": "reorder-24x24",
    "restore_16x16": "fullsize-16x16",
    "reset": "restore-24x24",
    "search": "search-24x24",
    "average": "smiley-rate5-24x24",
    "excellent": "smiley-rate9-24x24",
    "good": "smiley-rate7-24x24",
    "normal": "smiley-rate6-24x24",
    "not-good": "smiley-rate4-24x24",
    "perfect": "smiley-rate10-24x24",
    "poor": "smiley-rate3-24x24",
    "terrible": "smiley-rate1-24x24",
    "very-good": "smiley-rate8-24x24",
    "very-poor": "smiley-rate2-24x24",
    "add_16x16": "add-16x16",
    "add_24x24": "add-24x24",
    "alert_24x24": "warning-24x24",
    "apply": "apply-24x24",
    "arrow-down": "arrowdown-24x24",
    "arrow-left": "arrowleft-24x24",
    "arrow-left_16x16": "arrowleft-16x16",
    "arrowleft": "arrowleft-16x16",
    "arrow-right": "arrowright-24x24",
    "arrow-right_16x16": "arrowright-16x16",
    "arrowright": "arrowright-16x16",
    "arrow-up": "arrowup-24x24",
    "boolean": "toolbox-boolean-24x24",
    "change-question-type_16x16": "speechbubble-16x16",
    "checkbox": "toolbox-checkbox-24x24",
    "collapse-detail_16x16": "minusbox-16x16",
    "collapse-panel": "collapse-pg-24x24",
    "collapse_16x16": "collapse-16x16",
    "color-picker": "dropper-16x16",
    "comment": "toolbox-longtext-24x24",
    "config": "wrench-24x24",
    "copy": "copy-24x24",
    "default": "toolbox-customquestion-24x24",
    "delete_16x16": "delete-16x16",
    "delete_24x24": "delete-24x24",
    "delete": "delete-24x24",
    "description-hide": "hidehint-16x16",
    "description": "hint-16x16",
    "device-desktop": "desktop-24x24",
    "device-phone": "phone-24x24",
    "device-rotate": "rotate-24x24",
    "device-tablet": "tablet-24x24",
    "download": "download-24x24",
    "drag-area-indicator": "drag-24x24",
    "drag-area-indicator_24x16": "draghorizontal-24x16",
    "v2dragelement_16x16": "draghorizontal-24x16",
    "drop-down-arrow": "chevrondown-24x24",
    "drop-down-arrow_16x16": "chevrondown-16x16",
    "chevron_16x16": "chevrondown-16x16",
    "dropdown": "toolbox-dropdown-24x24",
    "duplicate_16x16": "copy-16x16",
    "edit": "edit-24x24",
    "edit_16x16": "edit-16x16",
    "editing-finish": "finishedit-24x24",
    "error": "error-16x16",
    "expand-detail_16x16": "plusbox-16x16",
    "expand-panel": "expand-pg-24x24",
    "expand_16x16": "expand-16x16",
    "expression": "toolbox-expression-24x24",
    "fast-entry": "textedit-24x24",
    "fix": "fix-24x24",
    "html": "toolbox-html-24x24",
    "image": "toolbox-image-24x24",
    "imagepicker": "toolbox-imagepicker-24x24",
    "import": "import-24x24",
    "invisible-items": "invisible-24x24",
    "language": "language-24x24",
    "load": "import-24x24",
    "logic-collapse": "collapse-24x24",
    "logic-expand": "expand-24x24",
    "logo": "image-48x48",
    "matrix": "toolbox-matrix-24x24",
    "matrixdropdown": "toolbox-multimatrix-24x24",
    "matrixdynamic": "toolbox-dynamicmatrix-24x24",
    "multipletext": "toolbox-multipletext-24x24",
    "panel": "toolbox-panel-24x24",
    "paneldynamic": "toolbox-dynamicpanel-24x24",
    "preview": "preview-24x24",
    "radiogroup": "toolbox-radiogroup-24x24",
    "ranking": "toolbox-ranking-24x24",
    "rating": "toolbox-rating-24x24",
    "slider": "toolbox-slider-24x24",
    "redo": "redo-24x24",
    "remove_16x16": "remove-16x16",
    "required": "required-16x16",
    "save": "save-24x24",
    "select-page": "selectpage-24x24",
    "settings": "settings-24x24",
    "settings_16x16": "settings-16x16",
    "signaturepad": "toolbox-signature-24x24",
    "switch-active_16x16": "switchon-16x16",
    "switch-inactive_16x16": "switchoff-16x16",
    "tagbox": "toolbox-tagbox-24x24",
    "text": "toolbox-singleline-24x24",
    "theme": "theme-24x24",
    "toolbox": "toolbox-24x24",
    "undo": "undo-24x24",
    "visible": "visible-24x24",
    "wizard": "wand-24x24",
    "searchclear": "clear-16x16",
    "chevron-16x16": "chevrondown-16x16",
    "chevron": "chevrondown-24x24",
    "progressbuttonv2": "arrowleft-16x16",
    "right": "chevronright-16x16",
    "add-lg": "add-24x24",
    "add": "add-24x24",
};
function getIconNameFromProxy(iconName) {
    const customIconName = getCustomNewIconNameIfExists(iconName);
    return customIconName || getNewIconName(iconName);
}
function getNewIconName(iconName) {
    const prefix = "icon-";
    const nameWithoutPrefix = iconName.replace(prefix, "");
    const result = renamedIcons[nameWithoutPrefix] || nameWithoutPrefix;
    return prefix + result;
}
function getCustomNewIconNameIfExists(iconName) {
    // only for settings.customIcons["icon-import"] = "icon-export"; feature
    let result = settings.customIcons[iconName];
    if (result)
        return getNewIconName(result);
    iconName = getNewIconName(iconName);
    result = settings.customIcons[iconName];
    if (result)
        return result;
    return null;
}
function createSvg(size, width, height, iconName, svgElem, title) {
    if (!svgElem)
        return;
    if (size !== "auto") {
        svgElem.style.width = (size || width || 16) + "px";
        svgElem.style.height = (size || height || 16) + "px";
    }
    const node = svgElem.childNodes[0];
    const realIconName = getIconNameFromProxy(iconName);
    node.setAttributeNS("http://www.w3.org/1999/xlink", "xlink:href", "#" + realIconName);
    let titleElement = svgElem.getElementsByTagName("title")[0];
    if (!title) {
        if (!!titleElement) {
            svgElem.removeChild(titleElement);
        }
        return;
    }
    else {
        if (!titleElement) {
            titleElement = DomDocumentHelper.getDocument().createElementNS("http://www.w3.org/2000/svg", "title");
            svgElem.appendChild(titleElement);
        }
    }
    titleElement.textContent = title;
}
function getSafeUrl(url) {
    if (!url)
        return url;
    if (url.toLocaleLowerCase().indexOf("javascript:") > -1)
        return encodeURIComponent(url);
    return url;
}
function unwrap(value) {
    if (typeof value !== "function") {
        return value;
    }
    else {
        return value();
    }
}
// export function getSize(value: any): number {
//   if (typeof value === "number") {
//     return value;
//   }
//   if (typeof value === "string" && value.includes("px")) {
//     return parseInt(value);
//   }
//   if (!!value && typeof value === "string" && value.length > 0) {
//     const lastSymbol: string = value[value.length - 1];
//     if ((lastSymbol >= "0" && lastSymbol <= "9") || lastSymbol == ".") {
//       try {
//         const num: number = parseInt(value);
//         return num;
//       } catch { }
//     }
//   }
//   return value;
// }
function getRenderedSize(val) {
    if (typeof val == "string") {
        if (!isNaN(Number(val))) {
            return Number(val);
        }
        else if (val.includes("px")) {
            return parseFloat(val);
        }
    }
    if (typeof val == "number") {
        return val;
    }
    return undefined;
}
function getRenderedStyleSize(val) {
    if (getRenderedSize(val) !== undefined) {
        return undefined;
    }
    return val;
}
const keyFocusedClassName = "sv-focused--by-key";
function doKey2ClickBlur(evt) {
    const element = evt.target;
    if (!element || !element.classList)
        return;
    element.classList.remove(keyFocusedClassName);
}
function doKey2ClickUp(evt, options) {
    if (!!evt.target && evt.target["contentEditable"] === "true") {
        return;
    }
    const element = evt.target;
    if (!element)
        return;
    const char = evt.which || evt.keyCode;
    if (char === 9) {
        if (!!element.classList && !element.classList.contains(keyFocusedClassName)) {
            element.classList.add(keyFocusedClassName);
        }
        return;
    }
    if (options) {
        if (!options.__keyDownReceived)
            return;
        options.__keyDownReceived = false;
    }
    if (char === 13 || char === 32) {
        if (element.click)
            element.click();
    }
    else if ((!options || options.processEsc) && char === 27) {
        if (element.blur)
            element.blur();
    }
}
function doKey2ClickDown(evt, options = { processEsc: true }) {
    if (options)
        options.__keyDownReceived = true;
    if (!!evt.target && evt.target["contentEditable"] === "true") {
        return;
    }
    var char = evt.which || evt.keyCode;
    const supportedCodes = [13, 32];
    if (options.processEsc) {
        supportedCodes.push(27);
    }
    if (supportedCodes.indexOf(char) !== -1) {
        evt.preventDefault();
    }
}
function increaseHeightByContent(element, getComputedStyle) {
    if (!element)
        return;
    if (!getComputedStyle)
        getComputedStyle = (elt) => { return DomDocumentHelper.getComputedStyle(elt); };
    const style = getComputedStyle(element);
    element.style.height = "auto";
    if (!!element.scrollHeight) {
        element.style.height = (element.scrollHeight + parseFloat(style.borderTopWidth) + parseFloat(style.borderBottomWidth)) + "px";
    }
}
function getOriginalEvent(event) {
    return event.originalEvent || event;
}
function preventDefaults(event) {
    event.preventDefault();
    event.stopPropagation();
}
function classesToSelector(str) {
    if (!str)
        return str;
    const re = /\s*?([\w-]+)\s*?/g;
    return str.replace(re, ".$1");
}
function getElementWidth(el) {
    return !!getComputedStyle ? Number.parseFloat(getComputedStyle(el).width) : el.offsetWidth;
}
function isContainerVisible(el) {
    return !!(el.offsetWidth ||
        el.offsetHeight ||
        el.getClientRects().length);
}
function getFirstVisibleChild(el) {
    let result;
    for (let index = 0; index < el.children.length; index++) {
        if (!result && getComputedStyle(el.children[index]).display !== "none") {
            result = el.children[index];
        }
    }
    return result;
}
function sanitizeEditableContent(element, cleanLineBreaks = true) {
    if (DomWindowHelper.isAvailable() && DomDocumentHelper.isAvailable() && element.childNodes.length > 0) {
        const selection = DomWindowHelper.getSelection();
        if (selection.rangeCount == 0) {
            return;
        }
        let range = selection.getRangeAt(0);
        range.setStart(range.endContainer, range.endOffset);
        range.setEndAfter(element.lastChild);
        selection.removeAllRanges();
        selection.addRange(range);
        let tail = selection.toString();
        let innerText = element.innerText;
        tail = tail.replace(/\r/g, "");
        if (cleanLineBreaks) {
            tail = tail.replace(/\n/g, "");
            innerText = innerText.replace(/\n/g, "");
        }
        const tail_len = tail.length;
        element.innerText = innerText;
        range = DomDocumentHelper.getDocument().createRange();
        range.setStart(element.firstChild, 0);
        range.setEnd(element.firstChild, 0);
        selection.removeAllRanges();
        selection.addRange(range);
        while (selection.toString().length < innerText.length - tail_len) {
            const selLen = selection.toString().length;
            selection.modify("extend", "forward", "character");
            if (selection.toString().length == selLen)
                break;
        }
        range = selection.getRangeAt(0);
        range.setStart(range.endContainer, range.endOffset);
    }
}
function mergeValues(src, dest) {
    if (!dest || !src)
        return;
    if (typeof dest !== "object")
        return;
    for (var key in src) {
        var value = src[key];
        if (!Array.isArray(value) && value && typeof value === "object") {
            if (!dest[key] || typeof dest[key] !== "object")
                dest[key] = {};
            mergeValues(value, dest[key]);
        }
        else {
            dest[key] = value;
        }
    }
}
function updateListCssValues(res, css) {
    const listCssClasses = {};
    mergeValues(css.list, listCssClasses);
    mergeValues(res.list, listCssClasses);
    res["list"] = listCssClasses;
}
function showConfirmDialog(message, callback, options = {}) {
    const locStr = new LocalizableString(undefined, false);
    locStr.defaultValue = message || options.message;
    const popupViewModel = settings.showDialog({
        componentName: "sv-string-viewer",
        data: { locStr: locStr, locString: locStr, model: locStr }, //TODO fix in library
        onApply: () => {
            callback(true);
            return true;
        },
        onCancel: () => {
            callback(false);
            return false;
        },
        displayMode: "popup",
        isFocusedContent: false,
        cssClass: options.cssClass || "sv-popup--confirm"
    }, options.rootElement);
    const toolbar = popupViewModel.footerToolbar;
    const applyBtn = toolbar.getActionById("apply");
    const cancelBtn = toolbar.getActionById("cancel");
    cancelBtn.title = getLocaleString("cancel", options.locale);
    applyBtn.title = options.applyTitle || getLocaleString("ok", options.locale);
    applyBtn.innerCss = "sd-btn--danger";
    configConfirmDialog(popupViewModel);
    return true;
}
function configConfirmDialog(popupViewModel) {
    popupViewModel.width = "min-content";
}
function chooseFiles(input, callback) {
    if (!DomWindowHelper.isFileReaderAvailable())
        return;
    input.value = "";
    input.onchange = (event) => {
        if (!DomWindowHelper.isFileReaderAvailable())
            return;
        if (!input || !input.files || input.files.length < 1)
            return;
        let files = [];
        for (let i = 0; i < input.files.length; i++) {
            files.push(input.files[i]);
        }
        callback(files);
    };
    input.click();
}
function compareArrays(oldValue, newValue, getKey) {
    const oldItemsMap = new Map();
    const newItemsMap = new Map();
    const commonItemsInNewMap = new Map();
    const commonItemsInOldMap = new Map();
    oldValue.forEach((item) => {
        const itemKey = getKey(item);
        if (!oldItemsMap.has(itemKey)) {
            oldItemsMap.set(getKey(item), item);
        }
        else {
            //if keys are set incorrectly do not process comparing
            throw new Error("keys must be unique");
        }
    });
    newValue.forEach((item) => {
        const itemKey = getKey(item);
        if (!newItemsMap.has(itemKey)) {
            newItemsMap.set(itemKey, item);
        }
        else {
            //if keys are set incorrectly do not process comparing
            throw new Error("keys must be unique");
        }
    });
    const addedItems = [];
    const deletedItems = [];
    //calculating addedItems and items that exist in both arrays
    newItemsMap.forEach((item, key) => {
        if (!oldItemsMap.has(key)) {
            addedItems.push(item);
        }
        else {
            commonItemsInNewMap.set(key, commonItemsInNewMap.size);
        }
    });
    //calculating deletedItems and items that exist in both arrays
    oldItemsMap.forEach((item, key) => {
        if (!newItemsMap.has(key)) {
            deletedItems.push(item);
        }
        else {
            commonItemsInOldMap.set(key, commonItemsInOldMap.size);
        }
    });
    //calculating reordered items
    const reorderedItems = [];
    commonItemsInNewMap.forEach((index, key) => {
        const oldIndex = commonItemsInOldMap.get(key);
        const item = newItemsMap.get(key);
        if (oldIndex !== index)
            reorderedItems.push({ item: item, movedForward: oldIndex < index });
    });
    //calculating merged array if multiple operations are applied at once
    const oldItemsWithCorrectOrder = new Array(oldValue.length);
    let commonItemsIndex = 0;
    const commonItemsKeysOrder = Array.from(commonItemsInNewMap.keys());
    oldValue.forEach((item, index) => {
        if (commonItemsInNewMap.has(getKey(item))) {
            oldItemsWithCorrectOrder[index] = newItemsMap.get(commonItemsKeysOrder[commonItemsIndex]);
            commonItemsIndex++;
        }
        else {
            oldItemsWithCorrectOrder[index] = item;
        }
    });
    const valuesToInsertBeforeKey = new Map();
    let tempValuesArray = [];
    oldItemsWithCorrectOrder.forEach((item) => {
        const itemKey = getKey(item);
        if (newItemsMap.has(itemKey)) {
            if (tempValuesArray.length > 0) {
                valuesToInsertBeforeKey.set(itemKey, tempValuesArray);
                tempValuesArray = [];
            }
        }
        else {
            tempValuesArray.push(item);
        }
    });
    const mergedItems = new Array();
    newItemsMap.forEach((item, key) => {
        if (valuesToInsertBeforeKey.has(key)) {
            valuesToInsertBeforeKey.get(key).forEach((item) => {
                mergedItems.push(item);
            });
        }
        mergedItems.push(item);
    });
    tempValuesArray.forEach((item) => {
        mergedItems.push(item);
    });
    return { reorderedItems, deletedItems, addedItems, mergedItems };
}
function getVerticalDimensions(el) {
    if (DomDocumentHelper.isAvailable()) {
        const { paddingTop, paddingBottom, borderTopWidth, borderBottomWidth, marginTop, marginBottom, boxSizing } = DomDocumentHelper.getComputedStyle(el);
        let heightTo = el.offsetHeight + "px";
        if (boxSizing == "content-box") {
            let heightPx = el.offsetHeight;
            [borderBottomWidth, borderTopWidth, paddingBottom, paddingTop].forEach((style) => {
                heightPx -= parseFloat(style);
            });
            heightTo = heightPx + "px";
        }
        return {
            paddingTop,
            paddingBottom,
            borderTopWidth,
            borderBottomWidth,
            marginTop,
            marginBottom,
            heightFrom: "0px",
            heightTo: heightTo
        };
    }
    else {
        return undefined;
    }
}
function setPropertiesOnElementForAnimation(el, styles, prefix = "--animation-") {
    var _a;
    el["__sv_created_properties"] = (_a = el["__sv_created_properties"]) !== null && _a !== void 0 ? _a : [];
    Object.keys(styles).forEach((key) => {
        const propertyName = `${prefix}${key.split(/\.?(?=[A-Z])/).join("-").toLowerCase()}`;
        el.style.setProperty(propertyName, styles[key]);
        el["__sv_created_properties"].push(propertyName);
    });
}
function prepareElementForVerticalAnimation(el) {
    setPropertiesOnElementForAnimation(el, getVerticalDimensions(el));
}
function cleanHtmlElementAfterAnimation(el) {
    if (Array.isArray(el["__sv_created_properties"])) {
        el["__sv_created_properties"].forEach((propertyName) => {
            el.style.removeProperty(propertyName);
        });
        delete el["__sv_created_properties"];
    }
}
function floorTo2Decimals(number) {
    return Math.floor(number * 100) / 100;
}

const document$1 = typeof globalThis !== "undefined" ? globalThis.document : this.document;
const defaultEnvironment = (!!document$1 ? {
    root: document$1,
    _rootElement: DomDocumentHelper.getBody(),
    get rootElement() {
        var _a;
        return (_a = this._rootElement) !== null && _a !== void 0 ? _a : DomDocumentHelper.getBody();
    },
    set rootElement(rootElement) {
        this._rootElement = rootElement;
    },
    _popupMountContainer: DomDocumentHelper.getBody(),
    get popupMountContainer() {
        var _a;
        return (_a = this._popupMountContainer) !== null && _a !== void 0 ? _a : DomDocumentHelper.getBody();
    },
    set popupMountContainer(popupMountContainer) {
        this._popupMountContainer = popupMountContainer;
    },
    svgMountContainer: document$1.head,
    stylesSheetsMountContainer: document$1.head,
} : undefined);
const columnWidthsByType = {
    "file": { minWidth: "240px" },
    "comment": { minWidth: "200px" }
};
/**
 * Global settings that apply to all surveys on the page. To specify one of the settings, use the code below:
 *
 * ```js
 * import { settings } from "survey-core";
 *
 * settings.settingName = "value";
 * ```
 */
var settings = {
    version: "",
    /**
     * An object that configures survey appearance when the survey is being designed in Survey Creator.
     *
     * Nested properties:
     *
     * - `showEmptyDescriptions`: `boolean`\
     * Specifies whether to display an empty description for pages and panels. Default value: `true`.
     *
     * - `showEmptyTitles`: `boolean`\
     * Specifies whether to display an empty title for pages and panels. Default value: `true`.
     */
    designMode: {
        showEmptyDescriptions: true,
        showEmptyTitles: true
    },
    //#region designMode section, Obsolete properties
    get allowShowEmptyDescriptionInDesignMode() { return this.designMode.showEmptyDescriptions; },
    set allowShowEmptyDescriptionInDesignMode(val) { this.designMode.showEmptyDescriptions = val; },
    get allowShowEmptyTitleInDesignMode() { return this.designMode.showEmptyTitles; },
    set allowShowEmptyTitleInDesignMode(val) { this.designMode.showEmptyTitles = val; },
    //#endregion
    /**
     * An object that contains properties related to localization.
     *
     * Nested properties:
     *
     * - `defaultLocaleName`: `string`\
     * A property key that stores a translation for the default locale. Default value: `"default"`.
     *
     * - `storeDuplicatedTranslations`: `boolean`\
     * Specifies whether surveys should store translation strings that equal the translation strings in the default locale. Default value: `false`.
     *
     * - `useLocalTimeZone`: `boolean`\
     * Obsolete. Use the [`storeUtcDates`](https://surveyjs.io/form-library/documentation/api-reference/settings#storeUtcDates) setting instead.
     */
    localization: {
        /**
         * @deprecated Use the [`storeUtcDates`](https://surveyjs.io/form-library/documentation/api-reference/settings#storeUtcDates) property instead.
         */
        useLocalTimeZone: true,
        storeDuplicatedTranslations: false,
        defaultLocaleName: "default"
    },
    //#region localization section, obsolete properties
    get useLocalTimeZone() { return this.localization.useLocalTimeZone; },
    set useLocalTimeZone(val) { this.localization.useLocalTimeZone = val; },
    get storeDuplicatedTranslations() { return this.localization.storeDuplicatedTranslations; },
    set storeDuplicatedTranslations(val) { this.localization.storeDuplicatedTranslations = val; },
    get defaultLocaleName() { return this.localization.defaultLocaleName; },
    set defaultLocaleName(val) { this.localization.defaultLocaleName = val; },
    //#endregion
    /**
     * An object with properties that configure surveys when they work with a web service.
     *
     * Nested properties:
     *
     * - `encodeUrlParams`: `boolean`\
     * Specifies whether to encode URL parameters when you access a web service. Default value: `true`.
     *
     * - `cacheLoadedChoices`: `boolean`\
     * Specifies whether to cache [choices loaded from a web service](https://surveyjs.io/form-library/documentation/api-reference/questionselectbase#choicesByUrl). Default value: `true`.
     *
     * - `disableQuestionWhileLoadingChoices`: `boolean`\
     * Disables a question while its choices are being loaded from a web service. Default value: `false`.
     *
     * - `surveyServiceUrl`: `string`\
     * Obsolete. Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
     *
     * - `onBeforeRequestChoices`: `(sender: ChoicesRestful, options: { url: string, request?: XMLHttpRequest, fetchOptions?: RequestInit })`\
     * An event that is raised before a request for choices is sent. Applies to questions with a specified [`choiceByUrl`](https://surveyjs.io/form-library/documentation/api-reference/questionselectbase#choicesByUrl) property. Use the `options` parameter to access and modify the request to be sent. The `options.fetchOptions` object is defined only when the Form Library is run on a Node.js server; `options.request` is defined in the rest of cases. The following example shows how you can add authentication headers to a request for choices:
     *
     *     ```js
     *     import { settings } from "survey-core";
     *
     *     settings.web.onBeforeRequestChoices = (_, options) => {
     *       if (options.request) {
     *         options.request.setRequestHeader("RequestVerificationToken", requestVerificationToken);
     *       }
     *       if (options.fetchOptions) {
     *         options.fetchOptions.headers.append("RequestVerificationToken", requestVerificationToken);
     *       }
     *     };
     *     ```
     */
    web: {
        onBeforeRequestChoices: (sender, options) => { },
        encodeUrlParams: true,
        cacheLoadedChoices: true,
        disableQuestionWhileLoadingChoices: false
    },
    //#region web section, obsolete properties
    get webserviceEncodeParameters() { return this.web.encodeUrlParams; },
    set webserviceEncodeParameters(val) { this.web.encodeUrlParams = val; },
    get useCachingForChoicesRestful() { return this.web.cacheLoadedChoices; },
    set useCachingForChoicesRestful(val) { this.web.cacheLoadedChoices = val; },
    get useCachingForChoicesRestfull() { return this.web.cacheLoadedChoices; },
    set useCachingForChoicesRestfull(val) { this.web.cacheLoadedChoices = val; },
    get disableOnGettingChoicesFromWeb() { return this.web.disableQuestionWhileLoadingChoices; },
    set disableOnGettingChoicesFromWeb(val) { this.web.disableQuestionWhileLoadingChoices = val; },
    //#endregion
    /**
     * An object that contains properties related to [triggers](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-survey-logic-triggers).
     *
     * Nested properties:
     *
     * - `changeNavigationButtonsOnComplete`: `boolean`\
     * Specifies whether to re-evaluate an expression associated with the [Complete trigger](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#complete) immediately when a question value changes. If the expression evaluates to `true`, the trigger is executed. Default value: `false`.\
     * Keep this property set to `false` if you want to re-evaluate the Complete trigger's expression only when the respondents navigate to another page.
     *
     * - `executeCompleteOnValueChanged`: `boolean`\
     * Specifies whether to replace the Next button with the Complete button when the [Complete trigger](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#complete) is going to be executed. Default value: `true`.
     *
     * - `executeSkipOnValueChanged`: `boolean`\
     * Specifies whether to re-evaluate an expression associated with the [Skip trigger](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#skip) immediately when a question value changes. If the expression evaluates to `true`, the trigger is executed. Default value: `true`.\
     * Disable this property if you want to re-evaluate the Skip trigger's expression only when respondents navigate to another page.
     */
    triggers: {
        changeNavigationButtonsOnComplete: true,
        executeCompleteOnValueChanged: false,
        executeSkipOnValueChanged: true
    },
    //#region triggers section, Obsolete properties
    get executeCompleteTriggerOnValueChanged() { return this.triggers.executeCompleteOnValueChanged; },
    set executeCompleteTriggerOnValueChanged(val) { this.triggers.executeCompleteOnValueChanged = val; },
    get changeNavigationButtonsOnCompleteTrigger() { return this.triggers.changeNavigationButtonsOnComplete; },
    set changeNavigationButtonsOnCompleteTrigger(val) { this.triggers.changeNavigationButtonsOnComplete = val; },
    get executeSkipTriggerOnValueChanged() { return this.triggers.executeSkipOnValueChanged; },
    set executeSkipTriggerOnValueChanged(val) { this.triggers.executeSkipOnValueChanged = val; },
    //#endregion
    /**
     * An object that contains properties related to JSON serialization.
     *
     * Nested properties:
     *
     * - `itemValueSerializeAsObject`: `boolean`\
     * Enable this property if you want to serialize [`ItemValue`](https://surveyjs.io/form-library/documentation/api-reference/itemvalue) instances (choice options, matrix rows, columns in a [Single-Select Matrix](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-question-model)) as objects even when they include only the `value` property. Default value: `false`.
     *
     * - `itemValueSerializeDisplayText`: `boolean`\
     * Enable this property if you want to serialize the `text` property of [`ItemValue`](https://surveyjs.io/form-library/documentation/api-reference/itemvalue) objects even when it is empty or equal to the `value` property. Default value: `false`.
     *
     * - `localizableStringSerializeAsObject`: `boolean`\
     * Enable this property if you want to serialize [`LocalizableString`](https://surveyjs.io/form-library/documentation/api-reference/localizablestring) instances as objects even when they include only a translation string for the default locale. For example, `"Custom String"` will be serialized as `{ default: "Custom String" }`. Default value: `false`.
     *
     * - `matrixDropdownColumnSerializeTitle`: `boolean`\
     * Enable this property if you want to serialize the `title` property of [`MatrixDropdownColumn`](https://surveyjs.io/form-library/documentation/api-reference/multi-select-matrix-column-values) objects even when it is empty or equal to the `name` property. Default value: `false`.
     * @see [settings.parseNumber](https://surveyjs.io/form-library/documentation/api-reference/settings#parseNumber)
     */
    serialization: {
        itemValueSerializeAsObject: false,
        itemValueSerializeDisplayText: false,
        localizableStringSerializeAsObject: false,
        matrixDropdownColumnSerializeTitle: false
    },
    //#region serialization section, Obsolete properties
    get itemValueAlwaysSerializeAsObject() { return this.serialization.itemValueSerializeAsObject; },
    set itemValueAlwaysSerializeAsObject(val) { this.serialization.itemValueSerializeAsObject = val; },
    get itemValueAlwaysSerializeText() { return this.serialization.itemValueSerializeDisplayText; },
    set itemValueAlwaysSerializeText(val) { this.serialization.itemValueSerializeDisplayText = val; },
    get serializeLocalizableStringAsObject() { return this.serialization.localizableStringSerializeAsObject; },
    set serializeLocalizableStringAsObject(val) { this.serialization.localizableStringSerializeAsObject = val; },
    //#endregion
    /**
     * An object that configures lazy rendering.
     *
     * Nested properties:
     *
     * - `enabled`: `boolean`\
     * Specifies whether to add questions to the DOM only when they get into the viewport. Default value: `false`.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-lazy/ (linkStyle))
     * @see [SurveyModel.lazyRenderEnabled](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#lazyRenderEnabled)
     */
    lazyRender: {
        enabled: false,
        firstBatchSize: 3
    },
    //#region lazyRender section, Obsolete properties
    get lazyRowsRendering() { return this.lazyRender.enabled; },
    set lazyRowsRendering(val) { this.lazyRender.enabled = val; },
    get lazyRowsRenderingStartRow() { return this.lazyRender.firstBatchSize; },
    set lazyRowsRenderingStartRow(val) { this.lazyRender.firstBatchSize = val; },
    //#endregion
    /**
     * An object with properties that apply to [Single-Choice](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-question-model), [Multiple-Choice](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list), and [Dynamic Matrix](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model) questions.
     *
     * Nested properties:
     *
     * - `defaultRowName`: `string`\
     * A property key that stores an object with default cell values. Default value: "default".
     *
     * - `defaultCellType`: `string`\
     * The default type of matrix cells. Default value: `"dropdown"`.\
     * You can specify this setting for individual questions or matrix columns: [`cellType`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model#cellType). Refer to the `cellType` property description for information on possible values.
     *
     * - `totalsSuffix`: `string`\
     * A suffix added to the name of the property that stores total values. The resulting property name consists of the matrix name and the suffix. Default value: `"-total"`.
     *
     * - `maxRowCount`: `number`\
     * A maximum number of rows in a Dynamic Matrix. Default value: 1000.\
     * You can specify this setting for an individual Dynamic Matrix: [`maxRowCount`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model#maxRowCount).
     *
     * - `maxRowCountInCondition`: `number`\
     * A maximum number of matrix rows included in the Condition drop-down menu in Survey Creator. This menu is used to configure conditional survey logic. Default value: 1.\
     * If you set this property to 0, the Condition menu does not include any matrix rows. Users still can specify conditions that use matrix rows but only with Manual Entry.
     *
     * - `renderRemoveAsIcon`: `boolean`\
     * Disable this property if you want to render the Remove action in Dynamic Matrix as a button. Otherwise, the action is rendered as an icon. Default value: `true`.
     *
     * - `columnWidthsByType`: `object`\
     * An object that specifies fixed and minimum column width based on the column type.\
     * Example: `settings.matrix.columnWidthsByType = { "tagbox": { minWidth: "240px", width: "300px" } }`
     *
     * - `rateSize`: `"small"` (default) | `"normal"`\
     * Specifies the size of rate values. Applies to [Rating Scale](https://surveyjs.io/form-library/examples/rating-scale/) questions within matrixes.
     */
    matrix: {
        defaultCellType: "dropdown",
        defaultRowName: "default",
        totalsSuffix: "-total",
        maxRowCount: 1000,
        maxRowCountInCondition: 1,
        renderRemoveAsIcon: true,
        columnWidthsByType: columnWidthsByType,
        rateSize: "small",
    },
    //#region matrix section, Obsolete properties
    get matrixDefaultRowName() { return this.matrix.defaultRowName; },
    set matrixDefaultRowName(val) { this.matrix.defaultRowName = val; },
    get matrixDefaultCellType() { return this.matrix.defaultCellType; },
    set matrixDefaultCellType(val) { this.matrix.defaultCellType = val; },
    get matrixTotalValuePostFix() { return this.matrix.totalsSuffix; },
    set matrixTotalValuePostFix(val) { this.matrix.totalsSuffix = val; },
    get matrixMaximumRowCount() { return this.matrix.maxRowCount; },
    set matrixMaximumRowCount(val) { this.matrix.maxRowCount = val; },
    get matrixMaxRowCountInCondition() { return this.matrix.maxRowCountInCondition; },
    set matrixMaxRowCountInCondition(val) { this.matrix.maxRowCountInCondition = val; },
    get matrixRenderRemoveAsIcon() { return this.matrix.renderRemoveAsIcon; },
    set matrixRenderRemoveAsIcon(val) { this.matrix.renderRemoveAsIcon = val; },
    //#endregion
    /**
     * An object with properties that apply to [Dynamic Panel](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model) questions.
     *
     * Nested properties:
     *
     * - `maxPanelCount`: `number`\
     * A maximum number of panels in Dynamic Panel. Default value: 100.\
     * You can specify this setting for an individual Dynamic Panel: [`maxPanelCount`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#maxPanelCount).
     *
     * - `maxPanelCountInCondition`: `number`\
     * A maximum number of Dynamic Panel panels included in the Condition drop-down menu in Survey Creator. This menu is used to configure conditional survey logic. Default value: 1.\
     * If you set this property to 0, the Condition menu does not include any panel questions. Users still can specify conditions that use panel questions but only with Manual Entry.
     */
    panel: {
        maxPanelCount: 100,
        maxPanelCountInCondition: 1
    },
    //#region panel section, Obsolete properties
    get panelDynamicMaxPanelCountInCondition() { return this.panel.maxPanelCountInCondition; },
    set panelDynamicMaxPanelCountInCondition(val) { this.panel.maxPanelCountInCondition = val; },
    get panelMaximumPanelCount() { return this.panel.maxPanelCount; },
    set panelMaximumPanelCount(val) { this.panel.maxPanelCount = val; },
    //#endregion
    /**
     * An object with properties that configure questions in read-only mode.
     *
     * Nested properties:
     *
     * - `commentRenderMode`: `"textarea"` (default) | `"div"`\
     * Specifies how to render the input field of [Comment](https://surveyjs.io/form-library/documentation/api-reference/comment-field-model) questions in [read-only](https://surveyjs.io/form-library/documentation/api-reference/comment-field-model#readOnly) mode: as a disabled `<textarea>` element or as a `<div>` element with a non-editable question value within it.
     *
     * - `textRenderMode`: `"input"` (default) | `"div"`\
     * Specifies how to render the input field of [Text](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model) questions in [read-only](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#readOnly) mode: as a disabled `<input>` element or as a `<div>` element with a non-editable question value within it.
     */
    readOnly: {
        enableValidation: false,
        commentRenderMode: "textarea",
        textRenderMode: "input"
    },
    //#region readOnly section, Obsolete properties
    get readOnlyCommentRenderMode() { return this.readOnly.commentRenderMode; },
    set readOnlyCommentRenderMode(val) { this.readOnly.commentRenderMode = val; },
    get readOnlyTextRenderMode() { return this.readOnly.textRenderMode; },
    set readOnlyTextRenderMode(val) { this.readOnly.textRenderMode = val; },
    //#endregion
    /**
     * An object with properties that configure question numbering.
     *
     * Nested properties:
     *
     * - `includeQuestionsWithHiddenNumber`: `boolean`\
     * Specifies whether to number questions whose [`showNumber`](https://surveyjs.io/form-library/documentation/api-reference/question#showNumber) property is disabled. Default value: `false`.
     *
     * - `includeQuestionsWithHiddenTitle`: `boolean`\
     * Specifies whether to number questions whose [`titleLocation`](https://surveyjs.io/form-library/documentation/api-reference/question#titleLocation) property is set to `"hidden"`. Default value: `false`.
     */
    numbering: {
        includeQuestionsWithHiddenNumber: false,
        includeQuestionsWithHiddenTitle: false
    },
    //#region numbering section, Obsolete properties
    get setQuestionVisibleIndexForHiddenTitle() { return this.numbering.includeQuestionsWithHiddenTitle; },
    set setQuestionVisibleIndexForHiddenTitle(val) { this.numbering.includeQuestionsWithHiddenTitle = val; },
    get setQuestionVisibleIndexForHiddenNumber() { return this.numbering.includeQuestionsWithHiddenNumber; },
    set setQuestionVisibleIndexForHiddenNumber(val) { this.numbering.includeQuestionsWithHiddenNumber = val; },
    //#endregion
    /**
     * Specifies an action to perform when users press the Enter key within a survey.
     *
     * Possible values:
     *
     * - `"moveToNextEditor"` - Moves focus to the next editor.
     * - `"loseFocus"` - Removes focus from the current editor.
     * - `"default"` - Behaves as a standard `<input>` element.
     */
    enterKeyAction: "default",
    /**
     * An object that configures string comparison.
     *
     * Nested properties:
     *
     * - `trimStrings`: `boolean`\
     * Specifies whether to remove whitespace from both ends of a string before the comparison. Default value: `true`.
     *
     * - `caseSensitive`: `boolean`\
     * Specifies whether to differentiate between capital and lower-case letters. Default value: `false`.
     */
    comparator: {
        trimStrings: true,
        caseSensitive: false,
        normalizeTextCallback: (str, reason) => { return str; }
    },
    expressionDisableConversionChar: "#",
    get commentPrefix() { return settings.commentSuffix; },
    set commentPrefix(val) { settings.commentSuffix = val; },
    /**
     * A suffix added to the name of the property that stores comments.
     *
     * Default value: "-Comment"
     *
     * You can specify this setting for an individual survey: [`commentSuffix`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#commentSuffix).
     */
    commentSuffix: "-Comment",
    /**
     * A separator used in a shorthand notation that specifies a value and display text for an [`ItemValue`](https://surveyjs.io/form-library/documentation/api-reference/itemvalue) object: `"value|text"`.
     *
     * Default value: `"|"`
     * @see [settings.choicesSeparator](https://surveyjs.io/form-library/documentation/api-reference/settings#choicesSeparator)
     */
    itemValueSeparator: "|",
    /**
     * A maximum number of rate values in a [Rating](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model) question.
     *
     * Default value: 20
     */
    ratingMaximumRateValueCount: 20,
    /**
     * Specifies whether to close the drop-down menu of a [Multi-Select Dropdown (Tag Box)](https://surveyjs.io/form-library/examples/how-to-create-multiselect-tag-box/) question after a user selects a value.
     *
     * This setting applies to all Multi-Select Dropdown questions on a web page. You can use the [`closeOnSelect`](https://surveyjs.io/form-library/documentation/api-reference/dropdown-tag-box-model#closeOnSelect) property to specify the same setting for an individual Multi-Select Dropdown question.
     */
    tagboxCloseOnSelect: false,
    /**
     * A time interval in milliseconds between the last entered character and the beginning of search in [Single-](https://surveyjs.io/form-library/examples/create-dropdown-menu-in-javascript/) and [Multi-Select Dropdown](https://surveyjs.io/form-library/examples/how-to-create-multiselect-tag-box/) questions. Applies only to questions with the [`choicesLazyLoadEnabled`](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model#choicesLazyLoadEnabled) property set to `true`.
     *
     * Default value: 500
     *
     * [View Demo](https://surveyjs.io/form-library/examples/lazy-loading-dropdown/ (linkStyle))
     */
    dropdownSearchDelay: 500,
    /**
     * A function that activates a browser confirm dialog.
     *
     * Use the following code to execute this function:
     *
     * ```js
     * import { settings } from "survey-core";
     *
     * // `result` contains `true` if the action was confirmed or `false` otherwise
     * const result = settings.confirmActionFunc("Are you sure?");
     * ```
     *
     * You can redefine the `confirmActionFunc` function if you want to display a custom dialog window. Your function should return `true` if a user confirms an action or `false` otherwise.
     * @param message A message to be displayed in the confirm dialog window.
     */
    confirmActionFunc: function (message) {
        return confirm(message);
    },
    /**
     * A function that activates a proprietary SurveyJS confirm dialog.
     *
     * Use the following code to execute this function:
     *
     * ```js
     * import { settings } from "survey-core";
     *
     * settings.confirmActionAsync("Are you sure?", (confirmed) => {
     *   if (confirmed) {
     *     // ...
     *     // Proceed with the action
     *     // ...
     *   } else {
     *     // ...
     *     // Cancel the action
     *     // ...
     *   }
     * });
     * ```
     *
     * You can redefine the `confirmActionAsync` function if you want to display a custom dialog window. Your function should return `true` to be enabled; otherwise, a survey executes the [`confirmActionFunc`](#confirmActionFunc) function. Pass the dialog result as the `callback` parameter: `true` if a user confirms an action, `false` otherwise.
     * @param message A message to be displayed in the confirm dialog window.
     * @param callback A callback function that should be called with `true` if a user confirms an action or `false` otherwise.
     */
    confirmActionAsync: function (message, callback, options) {
        return showConfirmDialog(message, callback, options);
    },
    /**
     * A minimum width value for all survey elements.
     *
     * Default value: `"300px"`
     *
     * You can override this setting for individual elements: [`minWidth`](https://surveyjs.io/form-library/documentation/api-reference/surveyelement#minWidth).
     */
    minWidth: "300px",
    /**
     * A maximum width value for all survey elements.
     *
     * Default value: `"100%"`
     *
     * You can override this setting for individual elements: [`maxWidth`](https://surveyjs.io/form-library/documentation/api-reference/surveyelement#maxWidth).
     */
    maxWidth: "100%",
    /**
     * Specifies how many times surveys can re-evaluate expressions when a question value changes. This limit helps avoid recursions in expressions.
     *
     * Default value: 10
     */
    maxConditionRunCountOnValueChanged: 10,
    /**
     * An object that configures notifications.
     *
     * Nested properties:
     *
     * - `lifetime`: `number`\
     * Specifies a time period during which a notification is displayed; measured in milliseconds. Default value: 2000.
     */
    notifications: {
        lifetime: 2000
    },
    /**
     * Specifies how many milliseconds a survey should wait before it automatically switches to the next page. Applies only when [auto-advance](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#autoAdvanceEnabled) is enabled.
     *
     * Default value: 300
     */
    autoAdvanceDelay: 300,
    /**
     * Specifies the direction in which to lay out Checkbox and Radio Button Group items. This setting affects the resulting UI when items are arranged in [more than one column](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model#colCount).
     *
     * Possible values:
     *
     * - `"column"` (default) - Items fill the current column, then move on to the next column.
     * - `"row"` - Items fill the current row, then move on to the next row.
     */
    itemFlowDirection: "column",
    /**
     * @deprecated Use the [`itemFlowDirection`](https://surveyjs.io/form-library/documentation/api-reference/settings#itemFlowDirection) property instead.
     */
    get showItemsInOrder() { return settings.itemFlowDirection; },
    set showItemsInOrder(val) { settings.itemFlowDirection = val; },
    /**
     * A value to save in survey results when respondents select the "None" choice item.
     *
     * Default value: `"none"`
     */
    noneItemValue: "none",
    /**
     * A value to save in survey results when respondents select the "Refuse to answer" choice item.
     *
     * Default value: `"refused"`
     */
    refuseItemValue: "refused",
    /**
     * A value to save in survey results when respondents select the "Don't know" choice item.
     *
     * Default value: `"dontknow"`
     */
    dontKnowItemValue: "dontknow",
    /**
     * An object whose properties specify the order of the special choice items ("None", "Other", "Select All", "Refuse to answer", "Don't know") in select-based questions.
     *
     * Default value: `{ selectAllItem: [-1], noneItem: [1], otherItem: [2], dontKnowItem: [3], otherItem: [4] }`
     *
     * Use this object to reorder special choices. Each property accepts an array of integer numbers. Negative numbers place a special choice item above regular choice items, positive numbers place it below them. For instance, the code below specifies the following order of choices: None, Select All, regular choices, Other.
     *
     * ```js
     * import { settings } from "survey-core";
     *
     * settings.specialChoicesOrder.noneItem = [-2];
     * settings.specialChoicesOrder.selectAllItem = [-1];
     * settings.specialChoicesOrder.otherItem = [1];
     * ```
     *
     * If you want to duplicate a special choice item above and below other choices, add two numbers to the corresponding array:
     *
     * ```js
     * settings.specialChoicesOrder.selectAllItem = [-1, 3] // Displays Select All above and below other choices
     * ```
     */
    specialChoicesOrder: {
        selectAllItem: [-1],
        noneItem: [1],
        refuseItem: [2],
        dontKnowItem: [3],
        otherItem: [4]
    },
    /**
     * One or several characters used to separate choice options in a list.
     *
     * Default value: `", "`
     * @see [settings.itemValueSeparator](https://surveyjs.io/form-library/documentation/api-reference/settings#itemValueSeparator)
     */
    choicesSeparator: ", ",
    /**
     * A list of supported validators by question type.
     */
    supportedValidators: {
        question: ["expression"],
        comment: ["text", "regex"],
        text: ["numeric", "text", "regex", "email"],
        checkbox: ["answercount"],
        imagepicker: ["answercount"],
    },
    /**
     * Specifies a minimum date that users can enter into a [Text](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model) question with [`inputType`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#inputType) set to `"date"` or `"datetime-local"`. Set this property to a string with the folllowing format: `"yyyy-mm-dd"`.
     */
    minDate: "",
    /**
     * Specifies a maximum date that users can enter into a [Text](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model) question with [`inputType`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#inputType) set to `"date"` or `"datetime-local"`. Set this property to a string with the folllowing format: `"yyyy-mm-dd"`.
     */
    maxDate: "",
    showDialog: undefined,
    showDefaultItemsInCreator: true,
    /**
     * An object that specifies icon replacements. Object keys are built-in icon names. To use a custom icon, assign its name to the key of the icon you want to replace:
     *
     * ```js
     * import { settings } from "survey-core";
     *
     * settings.customIcons["icon-redo"] = "custom-redo-icon";
     * ```
     *
     * For more information about icons in SurveyJS, refer to the following help topic: [UI Icons](https://surveyjs.io/form-library/documentation/icons).
     */
    customIcons: {},
    /**
     * Specifies which part of a choice item responds to a drag gesture in Ranking questions.
     *
     * Possible values:
     *
     * - `"entireItem"` (default) - Users can use the entire choice item as a drag handle.
     * - `"icon"` - Users can only use the choice item icon as a drag handle.
     */
    rankingDragHandleArea: "entireItem",
    environment: defaultEnvironment,
    /**
     * Allows you to hide the maximum length indicator in text input questions.
     *
     * If you specify a question's [`maxLength`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#maxLength) property or a survey's [`maxTextLength`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#maxTextLength) property, text input questions indicate the number of entered characters and the character limit. Assign `false` to the `settings.showMaxLengthIndicator` property if you want to hide this indicator.
     *
     * Default value: `true`
     */
    showMaxLengthIndicator: true,
    /**
     * Specifies whether to animate survey elements.
     *
     * Default value: `true`
    */
    animationEnabled: true,
    /**
     * An object that specifies HTML tags to use when rendering survey, page, panel, and question titles.
     *
     * Default value: `{ survey: "div", page: "div", panel: "div", question: "div" }`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/change-heading-levels/ (linkStyle))
     *
     * If you want to modify HTML tags for individual titles, handle `SurveyModel`'s [`onGetTitleTagName`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onGetTitleTagName) event.
     */
    titleTags: {
        survey: "div",
        page: "div",
        panel: "div",
        question: "div",
    },
    questions: {
        inputTypes: [
            "color",
            "date",
            "datetime-local",
            "email",
            "month",
            "number",
            "password",
            "range",
            "tel",
            "text",
            "time",
            "url",
            "week",
        ],
        dataList: [
            "",
            "name",
            "honorific-prefix",
            "given-name",
            "additional-name",
            "family-name",
            "honorific-suffix",
            "nickname",
            "organization-title",
            "username",
            "new-password",
            "current-password",
            "organization",
            "street-address",
            "address-line1",
            "address-line2",
            "address-line3",
            "address-level4",
            "address-level3",
            "address-level2",
            "address-level1",
            "country",
            "country-name",
            "postal-code",
            "cc-name",
            "cc-given-name",
            "cc-additional-name",
            "cc-family-name",
            "cc-number",
            "cc-exp",
            "cc-exp-month",
            "cc-exp-year",
            "cc-csc",
            "cc-type",
            "transaction-currency",
            "transaction-amount",
            "language",
            "bday",
            "bday-day",
            "bday-month",
            "bday-year",
            "sex",
            "url",
            "photo",
            "tel",
            "tel-country-code",
            "tel-national",
            "tel-area-code",
            "tel-local",
            "tel-local-prefix",
            "tel-local-suffix",
            "tel-extension",
            "email",
            "impp",
        ]
    },
    legacyProgressBarView: false,
    /**
     * An object with properties that configure input masks.
     *
     * Nested properties:
     *
     * - `patternPlaceholderChar`: `string`\
     * A symbol used as a placeholder for characters to be entered in [pattern masks](https://surveyjs.io/form-library/documentation/api-reference/inputmaskpattern). Default value: `"_"`.
     *
     * - `patternEscapeChar`: `string`\
     * A symbol used to insert literal representations of special characters in [pattern masks](https://surveyjs.io/form-library/documentation/api-reference/inputmaskpattern). Default value: `"\\"`.
     *
     * - `patternDefinitions`: `<{ [key: string]: RegExp }>`\
     * An object that maps placeholder symbols to regular expressions in [pattern masks](https://surveyjs.io/form-library/documentation/api-reference/inputmaskpattern). Default value: `{ "9": /[0-9]/, "a": /[a-zA-Z]/, "#": /[a-zA-Z0-9]/ }`.
     */
    maskSettings: {
        patternPlaceholderChar: "_",
        patternEscapeChar: "\\",
        patternDefinitions: {
            "9": /[0-9]/,
            "a": /[a-zA-Z]/,
            "#": /[a-zA-Z0-9]/
        }
    },
    /**
     * Specifies whether to store date-time values in the following format: `"YYYY-MM-DDThh:mm:ss.sssZ"`. Applies only to form fields with [`inputType`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#inputType) set to `"datetime-local"`.
     *
     * Default value: `false`
     *
     * If you enable this setting, date-time values are converted from local time to UTC when they are saved to the survey's [`data`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#data) object, while the question values remain in local time. Therefore, when you specify default values using a question's [`defaultValue`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#defaultValue) property, you need to use local time, but if you specify them using the `data` object, use a UTC date-time value in the following format: `"YYYY-MM-DDThh:mm:ss.sssZ"`.
     *
     * ```js
     * const surveyJson = {
     *   "elements": [{
     *     "name": "datetime",
     *     "type": "text",
     *     "title": "Select a date and time",
     *     "inputType": "datetime-local",
     *     "defaultValue": "2024-07-16T12:15:00" // Local date-time value
     *   }]
     * }
     * ```
     *
     * ```js
     * import { Model } from "survey-core";
     * const surveyJson = { ... }
     * const survey = new Model(surveyJson);
     *
     * survey.data = {
     *   datetime: "2024-07-16T12:15:00.000Z" // UTC date-time value
     * }
     * ```
     */
    storeUtcDates: false,
    // @param reason "function-[functionname]", "question-[questionname]", "expression-operand"
    onDateCreated: (newDate, reason, val) => {
        return newDate;
    },
    /**
     * A function that allows you to define custom parsing rules for numbers represented as string values.
     *
     * The following code shows a template that you can use to implement the `parseNumber` function:
     *
     * ```js
     * import { settings } from "survey-core";
     *
     * settings.parseNumber = (stringValue, numericValue) => {
     *   if (typeof stringValue !== "string" || !stringValue)
     *     return numericValue;
     *   let parsedNumber = numericValue;
     *   // ...
     *   // Parsing the number according to custom parsing rules
     *   // ...
     *   return parsedNumber;
     * };
     * ```
     * @param stringValue A number represented as a string value.
     * @param numericValue A number parsed using a default parsing function. `NaN` if the original string is not a number.
     * @returns A number that results from parsing the string value.
     * @see [settings.serialization](https://surveyjs.io/form-library/documentation/api-reference/settings#serialization)
     */
    parseNumber: (stringValue, numericValue) => { return numericValue; },
};

class SurveyError {
    constructor(text = null, errorOwner = null) {
        this.text = text;
        this.errorOwner = errorOwner;
        this.visible = true;
        this.onUpdateErrorTextCallback = undefined;
    }
    equals(error) {
        if (!error || !error.getErrorType)
            return false;
        if (this.getErrorType() !== error.getErrorType())
            return false;
        return this.text === error.text && this.visible === error.visible;
    }
    get locText() {
        if (!this.locTextValue) {
            this.locTextValue = new LocalizableString(this.errorOwner, true);
            this.locTextValue.storeDefaultText = true;
            this.locTextValue.text = this.getText();
        }
        return this.locTextValue;
    }
    getText() {
        var res = this.text;
        if (!res)
            res = this.getDefaultText();
        if (!!this.errorOwner) {
            res = this.errorOwner.getErrorCustomText(res, this);
        }
        return res;
    }
    getErrorType() {
        return "base";
    }
    getDefaultText() {
        return "";
    }
    getLocale() {
        return !!this.errorOwner ? this.errorOwner.getLocale() : "";
    }
    getLocalizationString(locStrName) {
        return getLocaleString(locStrName, this.getLocale());
    }
    updateText() {
        if (this.onUpdateErrorTextCallback) {
            this.onUpdateErrorTextCallback(this);
        }
        this.locText.text = this.getText();
    }
}

class AnswerRequiredError extends SurveyError {
    constructor(text = null, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "required";
    }
    getDefaultText() {
        return this.getLocalizationString("requiredError");
    }
}
class OneAnswerRequiredError extends SurveyError {
    constructor(text = null, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "requireoneanswer";
    }
    getDefaultText() {
        return this.getLocalizationString("requiredErrorInPanel");
    }
}
class RequreNumericError extends SurveyError {
    constructor(text = null, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "requirenumeric";
    }
    getDefaultText() {
        return this.getLocalizationString("numericError");
    }
}
class ExceedSizeError extends SurveyError {
    constructor(maxSize, errorOwner = null) {
        super(null, errorOwner);
        this.maxSize = maxSize;
        this.locText.text = this.getText();
    }
    getErrorType() {
        return "exceedsize";
    }
    getDefaultText() {
        return this.getLocalizationString("exceedMaxSize")["format"](this.getTextSize());
    }
    getTextSize() {
        var sizes = ["Bytes", "KB", "MB", "GB", "TB"];
        var fixed = [0, 0, 2, 3, 3];
        if (this.maxSize === 0) {
            return "0 Byte";
        }
        var i = Math.floor(Math.log(this.maxSize) / Math.log(1024));
        var value = this.maxSize / Math.pow(1024, i);
        return value.toFixed(fixed[i]) + " " + sizes[i];
    }
}
class WebRequestError extends SurveyError {
    constructor(status, response, errorOwner = null) {
        super(null, errorOwner);
        this.status = status;
        this.response = response;
    }
    getErrorType() {
        return "webrequest";
    }
    getDefaultText() {
        const str = this.getLocalizationString("urlRequestError");
        return !!str ? str["format"](this.status, this.response) : "";
    }
}
class WebRequestEmptyError extends SurveyError {
    constructor(text, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "webrequestempty";
    }
    getDefaultText() {
        return this.getLocalizationString("urlGetChoicesError");
    }
}
class OtherEmptyError extends SurveyError {
    constructor(text, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "otherempty";
    }
    getDefaultText() {
        return this.getLocalizationString("otherRequiredError");
    }
}
class UploadingFileError extends SurveyError {
    constructor(text, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "uploadingfile";
    }
    getDefaultText() {
        return this.getLocalizationString("uploadingFile");
    }
}
class RequiredInAllRowsError extends SurveyError {
    constructor(text, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "requiredinallrowserror";
    }
    getDefaultText() {
        return this.getLocalizationString("requiredInAllRowsError");
    }
}
class EachRowUniqueError extends SurveyError {
    constructor(text, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "eachrowuniqueeerror";
    }
    getDefaultText() {
        return this.getLocalizationString("eachRowUniqueError");
    }
}
class MinRowCountError extends SurveyError {
    constructor(minRowCount, errorOwner = null) {
        super(null, errorOwner);
        this.minRowCount = minRowCount;
    }
    getErrorType() {
        return "minrowcounterror";
    }
    getDefaultText() {
        return this.getLocalizationString("minRowCountError")["format"](this.minRowCount);
    }
}
class KeyDuplicationError extends SurveyError {
    constructor(text, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "keyduplicationerror";
    }
    getDefaultText() {
        return this.getLocalizationString("keyDuplicationError");
    }
}
class CustomError extends SurveyError {
    constructor(text, errorOwner = null) {
        super(text, errorOwner);
        this.text = text;
    }
    getErrorType() {
        return "custom";
    }
}

class ValidatorResult {
    constructor(value, error = null) {
        this.value = value;
        this.error = error;
    }
}
/**
 * A base class for all classes that implement validators.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
 */
class SurveyValidator extends Base {
    constructor() {
        super();
        this.createLocalizableString("text", this, true);
    }
    get isValidator() { return true; }
    getSurvey(live = false) {
        return !!this.errorOwner && !!this.errorOwner["getSurvey"]
            ? this.errorOwner.getSurvey()
            : null;
    }
    /**
     * An error message to display when a value fails validation.
     */
    get text() {
        return this.getLocalizableStringText("text");
    }
    set text(value) {
        this.setLocalizableStringText("text", value);
    }
    get isValidateAllValues() {
        return false;
    }
    get locText() {
        return this.getLocalizableString("text");
    }
    getErrorText(name) {
        if (this.text)
            return this.text;
        return this.getDefaultErrorText(name);
    }
    getDefaultErrorText(name) {
        return "";
    }
    validate(value, name = null, values = null, properties = null) {
        return null;
    }
    get isRunning() {
        return false;
    }
    get isAsync() {
        return false;
    }
    getLocale() {
        return !!this.errorOwner ? this.errorOwner.getLocale() : "";
    }
    getMarkdownHtml(text, name, item) {
        return !!this.errorOwner
            ? this.errorOwner.getMarkdownHtml(text, name, item)
            : undefined;
    }
    getRenderer(name) {
        return !!this.errorOwner ? this.errorOwner.getRenderer(name) : null;
    }
    getRendererContext(locStr) {
        return !!this.errorOwner ? this.errorOwner.getRendererContext(locStr) : locStr;
    }
    getProcessedText(text) {
        return !!this.errorOwner ? this.errorOwner.getProcessedText(text) : text;
    }
    createCustomError(name) {
        const err = new CustomError(this.getErrorText(name), this.errorOwner);
        err.onUpdateErrorTextCallback = (err => err.text = this.getErrorText(name));
        return err;
    }
    toString() {
        var res = this.getType().replace("validator", "");
        if (!!this.text) {
            res += ", " + this.text;
        }
        return res;
    }
}
class ValidatorRunner {
    run(owner) {
        var res = [];
        var values = null;
        var properties = null;
        this.prepareAsyncValidators();
        var asyncResults = [];
        var validators = owner.getValidators();
        for (var i = 0; i < validators.length; i++) {
            var validator = validators[i];
            if (!values && validator.isValidateAllValues) {
                values = owner.getDataFilteredValues();
                properties = owner.getDataFilteredProperties();
            }
            if (validator.isAsync) {
                this.asyncValidators.push(validator);
                validator.onAsyncCompleted = (result) => {
                    if (!!result && !!result.error)
                        asyncResults.push(result.error);
                    if (!this.onAsyncCompleted)
                        return;
                    for (var i = 0; i < this.asyncValidators.length; i++) {
                        if (this.asyncValidators[i].isRunning)
                            return;
                    }
                    this.onAsyncCompleted(asyncResults);
                };
            }
        }
        validators = owner.getValidators();
        for (var i = 0; i < validators.length; i++) {
            var validator = validators[i];
            var validatorResult = validator.validate(owner.validatedValue, owner.getValidatorTitle(), values, properties);
            if (!!validatorResult && !!validatorResult.error) {
                res.push(validatorResult.error);
            }
        }
        if (this.asyncValidators.length == 0 && !!this.onAsyncCompleted)
            this.onAsyncCompleted([]);
        return res;
    }
    prepareAsyncValidators() {
        if (!!this.asyncValidators) {
            for (var i = 0; i < this.asyncValidators.length; i++) {
                this.asyncValidators[i].onAsyncCompleted = null;
            }
        }
        this.asyncValidators = [];
    }
}
/**
 * A class that implements a validator for numeric values.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
 */
class NumericValidator extends SurveyValidator {
    constructor(minValue = null, maxValue = null) {
        super();
        this.minValue = minValue;
        this.maxValue = maxValue;
    }
    getType() {
        return "numericvalidator";
    }
    validate(value, name = null, values = null, properties = null) {
        if (this.isValueEmpty(value))
            return null;
        if (!Helpers.isNumber(value)) {
            return new ValidatorResult(null, new RequreNumericError(this.text, this.errorOwner));
        }
        var result = new ValidatorResult(Helpers.getNumber(value));
        if (this.minValue !== null && this.minValue > result.value) {
            result.error = this.createCustomError(name);
            return result;
        }
        if (this.maxValue !== null && this.maxValue < result.value) {
            result.error = this.createCustomError(name);
            return result;
        }
        return typeof value === "number" ? null : result;
    }
    getDefaultErrorText(name) {
        var vName = name ? name : this.getLocalizationString("value");
        if (this.minValue !== null && this.maxValue !== null) {
            return this.getLocalizationFormatString("numericMinMax", vName, this.minValue, this.maxValue);
        }
        else {
            if (this.minValue !== null) {
                return this.getLocalizationFormatString("numericMin", vName, this.minValue);
            }
            return this.getLocalizationFormatString("numericMax", vName, this.maxValue);
        }
    }
    /**
     * A minimum allowed numeric value.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
     */
    get minValue() {
        return this.getPropertyValue("minValue");
    }
    set minValue(val) {
        this.setPropertyValue("minValue", val);
    }
    /**
     * A maximum allowed numeric value.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
     */
    get maxValue() {
        return this.getPropertyValue("maxValue");
    }
    set maxValue(val) {
        this.setPropertyValue("maxValue", val);
    }
}
/**
 * A class that implements a validator for text values.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
 */
class TextValidator extends SurveyValidator {
    constructor() {
        super();
    }
    getType() {
        return "textvalidator";
    }
    validate(value, name = null, values = null, properties = null) {
        if (this.isValueEmpty(value))
            return null;
        if (!this.allowDigits) {
            var reg = /\d+$/;
            if (reg.test(value)) {
                return new ValidatorResult(null, this.createCustomError("textNoDigitsAllow"));
            }
        }
        if (this.minLength > 0 && value.length < this.minLength) {
            return new ValidatorResult(null, this.createCustomError(name));
        }
        if (this.maxLength > 0 && value.length > this.maxLength) {
            return new ValidatorResult(null, this.createCustomError(name));
        }
        return null;
    }
    getDefaultErrorText(name) {
        if (name === "textNoDigitsAllow")
            return this.getLocalizationString(name);
        if (this.minLength > 0 && this.maxLength > 0)
            return this.getLocalizationFormatString("textMinMaxLength", this.minLength, this.maxLength);
        if (this.minLength > 0)
            return this.getLocalizationFormatString("textMinLength", this.minLength);
        return this.getLocalizationFormatString("textMaxLength", this.maxLength);
    }
    /**
     * The minimum length of a text value measured in characters.
     *
     * Default value: 0
     *
     * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
     */
    get minLength() {
        return this.getPropertyValue("minLength");
    }
    set minLength(val) {
        this.setPropertyValue("minLength", val);
    }
    /**
     * The maximum length of a text value measured in characters.
     *
     * Default value: 0 (unlimited)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
     */
    get maxLength() {
        return this.getPropertyValue("maxLength");
    }
    set maxLength(val) {
        this.setPropertyValue("maxLength", val);
    }
    /**
     * Specifies whether a text value can include numerical digits.
     *
     * Default value: `true`
     */
    get allowDigits() {
        return this.getPropertyValue("allowDigits");
    }
    set allowDigits(val) {
        this.setPropertyValue("allowDigits", val);
    }
}
/**
 * A class that implements answer count validation in the question types that can have multiple values (for instance, [Checkboxes](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model)).
 *
 * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
 */
class AnswerCountValidator extends SurveyValidator {
    constructor(minCount = null, maxCount = null) {
        super();
        this.minCount = minCount;
        this.maxCount = maxCount;
    }
    getType() {
        return "answercountvalidator";
    }
    validate(value, name = null, values = null, properties = null) {
        if (value == null || value.constructor != Array)
            return null;
        var count = value.length;
        if (count == 0)
            return null;
        if (this.minCount && count < this.minCount) {
            return new ValidatorResult(null, this.createCustomError(this.getLocalizationFormatString("minSelectError", this.minCount)));
        }
        if (this.maxCount && count > this.maxCount) {
            return new ValidatorResult(null, this.createCustomError(this.getLocalizationFormatString("maxSelectError", this.maxCount)));
        }
        return null;
    }
    getDefaultErrorText(name) {
        return name;
    }
    /**
     * A minimum number of selected answers.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
     */
    get minCount() {
        return this.getPropertyValue("minCount");
    }
    set minCount(val) {
        this.setPropertyValue("minCount", val);
    }
    /**
     * A maximum number of selected answers.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
     */
    get maxCount() {
        return this.getPropertyValue("maxCount");
    }
    set maxCount(val) {
        this.setPropertyValue("maxCount", val);
    }
}
/**
 * A class that implements validation using regular expressions.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
 */
class RegexValidator extends SurveyValidator {
    constructor(regex = null) {
        super();
        this.regex = regex;
    }
    getType() {
        return "regexvalidator";
    }
    validate(value, name = null, values = null, properties = null) {
        if (!this.regex || this.isValueEmpty(value))
            return null;
        var re = this.createRegExp();
        if (Array.isArray(value)) {
            for (var i = 0; i < value.length; i++) {
                var res = this.hasError(re, value[i], name);
                if (res)
                    return res;
            }
        }
        return this.hasError(re, value, name);
    }
    hasError(re, value, name) {
        if (re.test(value))
            return null;
        return new ValidatorResult(value, this.createCustomError(name));
    }
    /**
     * A regular expression used to validate values.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
     */
    get regex() {
        return this.getPropertyValue("regex");
    }
    set regex(val) {
        this.setPropertyValue("regex", val);
    }
    /**
     * Specifies whether uppercase and lowercase letters must be treated as distinct or equivalent when validating values.
     *
     * Default value: `false` (uppercase and lowercase letters are treated as distinct)
     */
    get caseInsensitive() {
        return this.getPropertyValue("caseInsensitive");
    }
    set caseInsensitive(val) {
        this.setPropertyValue("caseInsensitive", val);
    }
    get insensitive() { return this.caseInsensitive; }
    set insensitive(val) {
        this.caseInsensitive = val;
    }
    createRegExp() {
        return new RegExp(this.regex, this.caseInsensitive ? "i" : "");
    }
}
/**
 * A class that implements a validator for e-mail addresses.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
 */
class EmailValidator extends SurveyValidator {
    constructor() {
        super();
        this.re = /^(([^<>()\[\]\.,;:\s@\"]+(\.[^<>()\[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()=[\]\.,;:\s@\"]+\.)+[^<>()=[\]\.,;:\s@\"]{2,})$/i;
    }
    getType() {
        return "emailvalidator";
    }
    validate(value, name = null, values = null, properties = null) {
        if (!value)
            return null;
        if (this.re.test(value))
            return null;
        return new ValidatorResult(value, this.createCustomError(name));
    }
    getDefaultErrorText(name) {
        return this.getLocalizationString("invalidEmail");
    }
}
/**
 * A class that implements validation using [expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions).
 *
 * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
 */
class ExpressionValidator extends SurveyValidator {
    constructor(expression = null) {
        super();
        this.conditionRunner = null;
        this.isRunningValue = false;
        this.expression = expression;
    }
    getType() {
        return "expressionvalidator";
    }
    get isValidateAllValues() {
        return true;
    }
    get isAsync() {
        if (!this.ensureConditionRunner(false))
            return false;
        return this.conditionRunner.isAsync;
    }
    get isRunning() {
        return this.isRunningValue;
    }
    validate(value, name = null, values = null, properties = null) {
        if (!this.expression)
            return null;
        if (!!this.conditionRunner) {
            this.conditionRunner.onRunComplete = null;
        }
        this.ensureConditionRunner(true);
        this.conditionRunner.onRunComplete = (res) => {
            this.isRunningValue = false;
            if (!!this.onAsyncCompleted) {
                this.onAsyncCompleted(this.generateError(res, value, name));
            }
        };
        this.isRunningValue = true;
        var res = this.conditionRunner.run(values, properties);
        if (this.conditionRunner.isAsync)
            return null;
        this.isRunningValue = false;
        return this.generateError(res, value, name);
    }
    generateError(res, value, name) {
        if (!res) {
            return new ValidatorResult(value, this.createCustomError(name));
        }
        return null;
    }
    getDefaultErrorText(name) {
        return this.getLocalizationFormatString("invalidExpression", this.expression);
    }
    ensureConditionRunner(reNew) {
        if (!this.expression)
            return false;
        if (reNew || !this.conditionRunner) {
            this.conditionRunner = new ConditionRunner(this.expression);
        }
        else {
            this.conditionRunner.expression = this.expression;
        }
        return true;
    }
    /**
     * A Boolean [expression](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions). If it evaluates to `false`, validation fails.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/ (linkStyle))
     */
    get expression() {
        return this.getPropertyValue("expression");
    }
    set expression(val) {
        this.setPropertyValue("expression", val);
    }
}
Serializer.addClass("surveyvalidator", [
    { name: "text", serializationProperty: "locText" },
]);
Serializer.addClass("numericvalidator", ["minValue:number", "maxValue:number"], function () {
    return new NumericValidator();
}, "surveyvalidator");
Serializer.addClass("textvalidator", [{ name: "minLength:number", default: 0 },
    { name: "maxLength:number", default: 0 },
    { name: "allowDigits:boolean", default: true }], function () {
    return new TextValidator();
}, "surveyvalidator");
Serializer.addClass("answercountvalidator", ["minCount:number", "maxCount:number"], function () {
    return new AnswerCountValidator();
}, "surveyvalidator");
Serializer.addClass("regexvalidator", ["regex", { name: "caseInsensitive:boolean", alternativeName: "insensitive" }], function () {
    return new RegexValidator();
}, "surveyvalidator");
Serializer.addClass("emailvalidator", [], function () {
    return new EmailValidator();
}, "surveyvalidator");
Serializer.addClass("expressionvalidator", ["expression:condition"], function () {
    return new ExpressionValidator();
}, "surveyvalidator");

class QuestionCustomWidget {
    constructor(name, widgetJson) {
        this.name = name;
        this.widgetJson = widgetJson;
        this.htmlTemplate = widgetJson.htmlTemplate ? widgetJson.htmlTemplate : "";
    }
    afterRender(question, el) {
        if (!this.widgetJson.afterRender)
            return;
        question.localeChangedCallback = () => {
            if (this.widgetJson.willUnmount) {
                this.widgetJson.willUnmount(question, el);
            }
            this.widgetJson.afterRender(question, el);
        };
        this.widgetJson.afterRender(question, el);
    }
    willUnmount(question, el) {
        if (this.widgetJson.willUnmount)
            this.widgetJson.willUnmount(question, el);
    }
    getDisplayValue(question, value = undefined) {
        if (this.widgetJson.getDisplayValue)
            return this.widgetJson.getDisplayValue(question, value);
        return null;
    }
    validate(question) {
        if (this.widgetJson.validate)
            return this.widgetJson.validate(question);
        return undefined;
    }
    isFit(question) {
        if (this.isLibraryLoaded() && this.widgetJson.isFit)
            return this.widgetJson.isFit(question);
        return false;
    }
    get canShowInToolbox() {
        if (this.widgetJson.showInToolbox === false)
            return false;
        if (CustomWidgetCollection.Instance.getActivatedBy(this.name) != "customtype")
            return false;
        return !this.widgetJson.widgetIsLoaded || this.widgetJson.widgetIsLoaded();
    }
    get showInToolbox() {
        return this.widgetJson.showInToolbox !== false;
    }
    set showInToolbox(val) {
        this.widgetJson.showInToolbox = val;
    }
    init() {
        if (this.widgetJson.init) {
            this.widgetJson.init();
        }
    }
    activatedByChanged(activatedBy) {
        if (this.isLibraryLoaded() && this.widgetJson.activatedByChanged) {
            this.widgetJson.activatedByChanged(activatedBy);
        }
    }
    isLibraryLoaded() {
        if (this.widgetJson.widgetIsLoaded)
            return this.widgetJson.widgetIsLoaded() == true;
        return true;
    }
    get isDefaultRender() {
        return this.widgetJson.isDefaultRender;
    }
    get pdfQuestionType() {
        return this.widgetJson.pdfQuestionType;
    }
    get pdfRender() {
        return this.widgetJson.pdfRender;
    }
}
class CustomWidgetCollection {
    constructor() {
        this.widgetsValues = [];
        this.widgetsActivatedBy = {};
        this.onCustomWidgetAdded = new Event();
    }
    get widgets() {
        return this.widgetsValues;
    }
    add(widgetJson, activatedBy = "property") {
        this.addCustomWidget(widgetJson, activatedBy);
    }
    addCustomWidget(widgetJson, activatedBy = "property") {
        var name = widgetJson.name;
        if (!name) {
            name = "widget_" + this.widgets.length + 1;
        }
        var customWidget = new QuestionCustomWidget(name, widgetJson);
        this.widgetsValues.push(customWidget);
        customWidget.init();
        this.widgetsActivatedBy[name] = activatedBy;
        customWidget.activatedByChanged(activatedBy);
        this.onCustomWidgetAdded.fire(customWidget, null);
        return customWidget;
    }
    /**
     * Returns the way the custom wiget is activated. It can be activated by a property ("property"), question type ("type") or by new/custom question type ("customtype").
     * @param widgetName the custom widget name
     * @see setActivatedBy
     */
    getActivatedBy(widgetName) {
        var res = this.widgetsActivatedBy[widgetName];
        return res ? res : "property";
    }
    /**
     * Sets the way the custom wiget is activated. The activation types are: property ("property"), question type ("type") or new/custom question type ("customtype"). A custom wiget may support all or only some of this activation types.
     * @param widgetName
     * @param activatedBy there are three possible variants: "property", "type" and "customtype"
     */
    setActivatedBy(widgetName, activatedBy) {
        if (!widgetName || !activatedBy)
            return;
        var widget = this.getCustomWidgetByName(widgetName);
        if (!widget)
            return;
        this.widgetsActivatedBy[widgetName] = activatedBy;
        widget.activatedByChanged(activatedBy);
    }
    clear() {
        this.widgetsValues = [];
    }
    getCustomWidgetByName(name) {
        for (var i = 0; i < this.widgets.length; i++) {
            if (this.widgets[i].name == name)
                return this.widgets[i];
        }
        return null;
    }
    getCustomWidget(question) {
        for (var i = 0; i < this.widgetsValues.length; i++) {
            if (this.widgetsValues[i].isFit(question))
                return this.widgetsValues[i];
        }
        return null;
    }
}
CustomWidgetCollection.Instance = new CustomWidgetCollection();

class RendererFactory {
    constructor() {
        this.renderersHash = {};
        this.defaultHash = {};
    }
    unregisterRenderer(questionType, rendererAs) {
        delete this.renderersHash[questionType][rendererAs];
        if (this.defaultHash[questionType] === rendererAs) {
            delete this.defaultHash[questionType];
        }
    }
    registerRenderer(questionType, renderAs, renderer, useAsDefault = false) {
        if (!this.renderersHash[questionType]) {
            this.renderersHash[questionType] = {};
        }
        this.renderersHash[questionType][renderAs] = renderer;
        if (useAsDefault) {
            this.defaultHash[questionType] = renderAs;
        }
    }
    getRenderer(questionType, renderAs) {
        const qHash = this.renderersHash[questionType];
        if (!!qHash) {
            if (!!renderAs && qHash[renderAs])
                return qHash[renderAs];
            const dVal = this.defaultHash[questionType];
            if (!!dVal && qHash[dVal])
                return qHash[dVal];
        }
        return "default";
    }
    getRendererByQuestion(question) {
        return this.getRenderer(question.getType(), question.renderAs);
    }
    clear() {
        this.renderersHash = {};
    }
}
RendererFactory.Instance = new RendererFactory();

class TextAreaModel {
    updateElement() {
        if (this.element && this.autoGrow) {
            setTimeout(() => increaseHeightByContent(this.element), 1);
        }
    }
    constructor(options) {
        this.options = options;
        this.onPropertyChangedCallback = () => {
            if (this.element) {
                this.element.value = this.getTextValue();
                this.updateElement();
            }
        };
        this.question.registerFunctionOnPropertiesValueChanged(this.options.propertyNames, this.onPropertyChangedCallback, "__textarea");
    }
    setElement(element) {
        if (!!element) {
            this.element = element;
            this.updateElement();
        }
    }
    resetElement() {
        this.element = undefined;
    }
    getTextValue() {
        if (!!this.options.getTextValue)
            return this.options.getTextValue() || "";
        return "";
    }
    onTextAreaChange(event) {
        if (!!this.options.onTextAreaChange)
            this.options.onTextAreaChange(event);
    }
    onTextAreaInput(event) {
        if (!!this.options.onTextAreaInput)
            this.options.onTextAreaInput(event);
        if (this.element && this.autoGrow) {
            increaseHeightByContent(this.element);
        }
    }
    onTextAreaKeyDown(event) {
        if (!!this.options.onTextAreaKeyDown)
            this.options.onTextAreaKeyDown(event);
    }
    onTextAreaBlur(event) {
        this.onTextAreaChange(event);
        if (!!this.options.onTextAreaBlur)
            this.options.onTextAreaBlur(event);
    }
    onTextAreaFocus(event) {
        var _a;
        if (!!this.options.onTextAreaFocus)
            this.options.onTextAreaFocus(event);
        if (this.isReadOnlyAttr) {
            (_a = event === null || event === void 0 ? void 0 : event.target) === null || _a === void 0 ? void 0 : _a.select();
        }
    }
    get question() {
        return this.options.question;
    }
    get id() {
        return this.options.id();
    }
    get placeholder() {
        return this.options.placeholder();
    }
    get className() {
        return this.options.className();
    }
    get maxLength() {
        if (this.options.maxLength)
            return this.options.maxLength();
    }
    get autoGrow() {
        if (this.options.autoGrow)
            return this.options.autoGrow();
    }
    get rows() {
        if (this.options.rows)
            return this.options.rows();
    }
    get cols() {
        if (this.options.cols)
            return this.options.cols();
    }
    get isDisabledAttr() {
        return this.options.isDisabledAttr();
    }
    get isReadOnlyAttr() {
        if (this.options.isReadOnlyAttr)
            return this.options.isReadOnlyAttr();
    }
    get ariaRequired() {
        if (this.options.ariaRequired)
            return this.options.ariaRequired();
    }
    get ariaLabel() {
        if (this.options.ariaLabel)
            return this.options.ariaLabel();
    }
    get ariaInvalid() {
        if (this.options.ariaInvalid)
            return this.options.ariaInvalid();
    }
    get ariaLabelledBy() {
        if (this.options.ariaLabelledBy)
            return this.options.ariaLabelledBy();
    }
    get ariaDescribedBy() {
        if (this.options.ariaDescribedBy)
            return this.options.ariaDescribedBy();
    }
    get ariaErrormessage() {
        if (this.options.ariaErrormessage)
            return this.options.ariaErrormessage();
    }
    dispose() {
        if (this.question) {
            this.question.unRegisterFunctionOnPropertiesValueChanged(this.options.propertyNames, "__textarea");
        }
        this.resetElement();
    }
}

class TriggerExpressionInfo {
    constructor(name, canRun, doComplete) {
        this.name = name;
        this.canRun = canRun;
        this.doComplete = doComplete;
        this.getSecondRunner = () => undefined;
    }
}
/**
 * A base class for all questions.
 */
class Question extends SurveyElement {
    static getQuestionId() {
        return "sq_" + Question.questionCounter++;
    }
    isReadOnlyRenderDiv() {
        return this.isReadOnly && settings.readOnly.commentRenderMode === "div";
    }
    allowMobileInDesignMode() {
        return false;
    }
    updateIsMobileFromSurvey() {
        this.setIsMobile(this.survey._isMobile);
    }
    setIsMobile(val) {
        const newVal = val && (this.allowMobileInDesignMode() || !this.isDesignMode);
        this.isMobile = newVal;
    }
    getIsMobile() {
        return this._isMobile;
    }
    get isMobile() {
        return this.getIsMobile();
    }
    set isMobile(val) {
        this._isMobile = val;
    }
    themeChanged(theme) { }
    get _isMobile() { return this.getPropertyValue("_isMobile", false); }
    set _isMobile(val) { this.setPropertyValue("_isMobile", val); }
    get forceIsInputReadOnly() { return this.getPropertyValue("forceIsInputReadOnly"); }
    set forceIsInputReadOnly(val) { this.setPropertyValue("forceIsInputReadOnly", val); }
    get ariaExpanded() {
        if (this.isNewA11yStructure) {
            return null;
        }
        return this.getPropertyValue("ariaExpanded");
    }
    set ariaExpanded(val) { this.setPropertyValue("ariaExpanded", val); }
    constructor(name) {
        super(name);
        this.customWidgetData = { isNeedRender: true };
        this.hasCssErrorCallback = () => false;
        this.isReadyValue = true;
        this.dependedQuestions = [];
        /**
         * An event that is raised when the question's ready state has changed (expressions are evaluated, choices are loaded from a web resource specified by the `choicesByUrl` property, etc.).
         *
         * Parameters:
         *
         * - `sender`: `SurveyModel`\
         * A survey instance that contains the question whose ready state has changed.
         * - `options.isReady`: `boolean`\
         * Indicates whether the question is ready.
         * - `options.oldIsReady`: `boolean`\
         * Indicates the previous ready state.
         */
        this.onReadyChanged = this.addEvent();
        this.triggersInfo = [];
        this.isRunningValidatorsValue = false;
        this.isValueChangedInSurvey = false;
        this.allowNotifyValueChanged = true;
        //EO new a11y
        this._syncPropertiesChanging = false;
        this.setPropertyValueDirectly("id", Question.getQuestionId());
        this.onCreating();
        this.createNewArray("validators", (validator) => {
            validator.errorOwner = this;
        });
        this.addExpressionProperty("visibleIf", (obj, res) => { this.visible = res === true; });
        this.addExpressionProperty("enableIf", (obj, res) => { this.readOnly = res === false; });
        this.addExpressionProperty("requiredIf", (obj, res) => { this.isRequired = res === true; });
        this.createLocalizableString("commentText", this, true, true);
        this.createLocalizableString("requiredErrorText", this);
        this.createLocalizableString("commentPlaceholder", this);
        this.createLocalizableString("defaultDisplayValue", this);
        this.addTriggerInfo("resetValueIf", () => !this.isEmpty(), () => {
            this.startSetValueOnExpression();
            this.updateValueWithDefaultsOrClear();
            this.finishSetValueOnExpression();
        });
        const setValueIfInfo = this.addTriggerInfo("setValueIf", () => true, () => this.runSetValueExpression());
        setValueIfInfo.getSecondRunner = () => this.getSetValueExpressionRunner();
        this.registerPropertyChangedHandlers(["width"], () => {
            this.updateQuestionCss();
            if (!!this.parent) {
                this.parent.elementWidthChanged(this);
            }
        });
        this.registerPropertyChangedHandlers(["isRequired"], () => {
            if (!this.isRequired && this.errors.length > 0) {
                this.validate();
            }
            this.locTitle.strChanged();
            this.clearCssClasses();
        });
        this.registerPropertyChangedHandlers(["indent", "rightIndent"], () => {
            this.resetIndents();
        });
        this.registerPropertyChangedHandlers(["showCommentArea", "showOtherItem"], () => {
            this.initCommentFromSurvey();
        });
        this.registerPropertyChangedHandlers(["commentPlaceholder"], () => {
            this.resetRenderedCommentPlaceholder();
        });
        this.registerFunctionOnPropertiesValueChanged(["no", "readOnly", "hasVisibleErrors", "containsErrors"], () => {
            this.updateQuestionCss();
        });
        this.registerPropertyChangedHandlers(["_isMobile"], () => { this.onMobileChanged(); });
        this.registerPropertyChangedHandlers(["colSpan"], () => { var _a; (_a = this.parent) === null || _a === void 0 ? void 0 : _a.updateColumns(); });
    }
    getDefaultTitle() { return this.name; }
    createLocTitleProperty() {
        const locTitleValue = super.createLocTitleProperty();
        locTitleValue.storeDefaultText = true;
        locTitleValue.onGetTextCallback = (text, nonProcessedText) => {
            if (!text && !nonProcessedText) {
                text = this.getDefaultTitle();
            }
            if (!this.survey)
                return text;
            return this.survey.getUpdatedQuestionTitle(this, text);
        };
        this.locProcessedTitle = new LocalizableString(this, true);
        this.locProcessedTitle.sharedData = locTitleValue;
        return locTitleValue;
    }
    get locRenderedTitle() {
        if (this.isSingleInputActive && !!this.singleInputLocTitle)
            return this.singleInputLocTitle;
        return this.locTitle;
    }
    get commentTextAreaModel() {
        if (!this.commentTextAreaModelValue) {
            this.commentTextAreaModelValue = new TextAreaModel(this.getCommentTextAreaOptions());
        }
        return this.commentTextAreaModelValue;
    }
    getCommentTextAreaOptions() {
        const options = {
            question: this,
            id: () => this.commentId,
            propertyNames: ["comment"],
            className: () => this.cssClasses.comment,
            placeholder: () => this.renderedCommentPlaceholder,
            isDisabledAttr: () => this.isInputReadOnly || false,
            rows: () => this.commentAreaRows,
            autoGrow: () => this.autoGrowComment,
            maxLength: () => this.getOthersMaxLength(),
            ariaRequired: () => this.a11y_input_ariaRequired,
            ariaLabel: () => this.a11y_input_ariaLabel,
            getTextValue: () => { return this.comment; },
            onTextAreaChange: (e) => { this.onCommentChange(e); },
            onTextAreaInput: (e) => { this.onCommentInput(e); },
        };
        return options;
    }
    getSurvey(live = false) {
        if (live) {
            return !!this.parent ? this.parent.getSurvey(live) : null;
        }
        if (!!this.onGetSurvey)
            return this.onGetSurvey();
        return super.getSurvey();
    }
    getValueName() {
        if (!!this.valueName)
            return this.valueName.toString();
        return this.name;
    }
    /**
     * Specifies an object property that should store the question value.
     *
     * Refer to the [Merge Question Values](https://surveyjs.io/form-library/documentation/design-survey-merge-question-values) help topic for more information.
     */
    get valueName() {
        return this.getPropertyValue("valueName", "");
    }
    set valueName(val) {
        var oldValueName = this.getValueName();
        this.setPropertyValue("valueName", val);
        this.onValueNameChanged(oldValueName);
    }
    onValueNameChanged(oldValue) {
        if (!this.survey)
            return;
        this.survey.questionRenamed(this, this.name, !!oldValue ? oldValue : this.name);
        this.initDataFromSurvey();
    }
    onNameChanged(oldValue) {
        this.locTitle.strChanged();
        if (!this.survey)
            return;
        this.survey.questionRenamed(this, oldValue, this.valueName ? this.valueName : oldValue);
    }
    get isReady() {
        return this.isReadyValue;
    }
    onAsyncRunningChanged() {
        this.updateIsReady();
    }
    ensureQuestionIsReady() {
        this.displayValue;
    }
    waitForQuestionIsReady(callback) {
        return new Promise((resolve) => {
            this.ensureQuestionIsReady();
            if (this.isReady) {
                resolve();
                if (!!callback)
                    callback();
            }
            else {
                const readyCallback = (_, options) => {
                    if (options.isReady) {
                        this.onReadyChanged.remove(readyCallback);
                        resolve();
                        if (!!callback)
                            callback();
                    }
                };
                this.onReadyChanged.add(readyCallback);
            }
        });
    }
    updateIsReady() {
        let res = this.getIsQuestionReady();
        if (res) {
            const questions = this.getIsReadyDependsOn();
            for (let i = 0; i < questions.length; i++) {
                if (!questions[i].getIsQuestionReady()) {
                    res = false;
                    break;
                }
            }
        }
        this.setIsReady(res);
    }
    getIsQuestionReady() {
        return !this.isAsyncExpressionRunning && this.getAreNestedQuestionsReady();
    }
    getAreNestedQuestionsReady() {
        const questions = this.getIsReadyNestedQuestions();
        if (!Array.isArray(questions))
            return true;
        for (let i = 0; i < questions.length; i++) {
            if (!questions[i].isReady)
                return false;
        }
        return true;
    }
    getIsReadyNestedQuestions() {
        return this.getNestedQuestions();
    }
    setIsReady(val) {
        const oldIsReady = this.isReadyValue;
        this.isReadyValue = val;
        if (oldIsReady != val) {
            this.getIsReadyDependends().forEach(q => q.updateIsReady());
            this.onReadyChanged.fire(this, {
                question: this,
                isReady: val,
                oldIsReady: oldIsReady,
            });
        }
    }
    getIsReadyDependsOn() {
        return this.getIsReadyDependendCore(true);
    }
    getIsReadyDependends() {
        return this.getIsReadyDependendCore(false);
    }
    getDependedQuestionsByValueName(isDependOn) {
        return this.survey.questionsByValueName(this.getValueName());
    }
    getIsReadyDependendCore(isDependOn) {
        if (!this.survey)
            return [];
        const questions = this.getDependedQuestionsByValueName(isDependOn);
        const res = new Array();
        questions.forEach(q => { if (q !== this)
            res.push(q); });
        if (!isDependOn) {
            if (this.parentQuestion) {
                res.push(this.parentQuestion);
            }
            if (this.dependedQuestions.length > 0) {
                this.dependedQuestions.forEach(q => res.push(q));
            }
        }
        return res;
    }
    choicesLoaded() { }
    /**
     * Returns a page to which the question belongs and allows you to move this question to a different page.
     */
    get page() {
        if (!!this.parentQuestion)
            return this.parentQuestion.page;
        return this.getPage(this.parent);
    }
    set page(val) {
        this.setPage(this.parent, val);
    }
    getPanel() {
        return null;
    }
    delete(doDispose = true) {
        this.removeFromParent();
        if (doDispose) {
            this.dispose();
        }
        else {
            this.resetDependedQuestions();
        }
    }
    removeFromParent() {
        if (!!this.parent) {
            this.removeSelfFromList(this.parent.elements);
        }
    }
    addDependedQuestion(question) {
        if (!question || this.dependedQuestions.indexOf(question) > -1)
            return;
        this.dependedQuestions.push(question);
    }
    removeDependedQuestion(question) {
        if (!question)
            return;
        var index = this.dependedQuestions.indexOf(question);
        if (index > -1) {
            this.dependedQuestions.splice(index, 1);
        }
    }
    updateDependedQuestions() {
        for (var i = 0; i < this.dependedQuestions.length; i++) {
            this.dependedQuestions[i].updateDependedQuestion();
        }
    }
    updateDependedQuestion() { }
    resetDependedQuestion() { }
    get isFlowLayout() {
        return this.getLayoutType() === "flow";
    }
    getLayoutType() {
        if (!!this.parent)
            return this.parent.getChildrenLayoutType();
        return "row";
    }
    isLayoutTypeSupported(layoutType) {
        return layoutType !== "flow";
    }
    /**
     * Gets or sets question visibility.
     *
     * If you want to display or hide a question based on a condition, specify the [`visibleIf`](https://surveyjs.io/form-library/documentation/question#visibleIf) property. Refer to the following help topic for information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see isVisible
     * @see visibleIf
     */
    get visible() {
        return this.getPropertyValue("visible", true);
    }
    set visible(val) {
        if (val == this.visible)
            return;
        this.setPropertyValue("visible", val);
        this.onVisibleChangedCore();
        this.notifySurveyVisibilityChanged();
    }
    onVisibleChanged() {
        const prevVal = this.getPropertyValue("isVisible");
        this.onVisibleChangedCore();
        const newVal = this.getPropertyValue("isVisible");
        if (prevVal !== undefined && prevVal !== newVal) {
            this.notifySurveyVisibilityChanged();
        }
    }
    onVisibleChangedCore() {
        this.updateIsVisibleProp();
        if (!this.isVisible && this.errors && this.errors.length > 0) {
            this.errors = [];
        }
    }
    notifyStateChanged(prevState) {
        super.notifyStateChanged(prevState);
        if (this.isCollapsed) {
            this.onHidingContent();
        }
    }
    updateElementVisibility() {
        this.updateIsVisibleProp();
    }
    updateIsVisibleProp() {
        const prev = this.getPropertyValue("isVisible");
        const val = this.isVisible;
        if (prev !== val) {
            this.setPropertyValue("isVisible", val);
            if (!val) {
                this.onHidingContent();
            }
        }
        if (val !== this.visible && this.areInvisibleElementsShowing) {
            this.updateQuestionCss(true);
        }
    }
    /**
     * Specifies whether to use display names for question values in placeholders.
     *
     * Default value: `true`
     *
     * This property applies to questions whose values are defined as objects with the `value` and `text` properties (for example, [choice items](https://surveyjs.io/form-library/documentation/questionradiogroupmodel#choices) in Radiogroup, Checkbox, and Dropdown questions).
     *
     * You can use question values as placeholders in the following places:
     *
     * - Survey element titles and descriptions
     * - The [`html`](https://surveyjs.io/form-library/documentation/questionhtmlmodel#html) property of the [HTML](https://surveyjs.io/form-library/documentation/questionhtmlmodel) question
     *
     * To use a question value as a placeholder, specify the question `name` in curly brackets: `{questionName}`. Refer to the following help topic for more information: [Dynamic Texts - Question Values](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#question-values).
     */
    get useDisplayValuesInDynamicTexts() {
        return this.getPropertyValue("useDisplayValuesInDynamicTexts");
    }
    set useDisplayValuesInDynamicTexts(val) {
        this.setPropertyValue("useDisplayValuesInDynamicTexts", val);
    }
    getUseDisplayValuesInDynamicTexts() { return this.useDisplayValuesInDynamicTexts; }
    /**
     * A Boolean expression. If it evaluates to `false`, this question becomes hidden.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/implement-conditional-logic-to-change-question-visibility/ (linkStyle))
     * @see visible
     * @see isVisible
     */
    get visibleIf() {
        return this.getPropertyValue("visibleIf", "");
    }
    set visibleIf(val) {
        this.setPropertyValue("visibleIf", val);
    }
    /**
     * Returns `true` if the question is visible or the survey is currently in design mode.
     *
     * If you want to display or hide a question based on a condition, specify the [`visibleIf`](https://surveyjs.io/form-library/documentation/question#visibleIf) property. Refer to the following help topic for information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see visibleIf
     * @see visible
     * @see isParentVisible
     */
    get isVisible() {
        if (this.survey && this.survey.areEmptyElementsHidden && this.isEmpty())
            return false;
        if (this.areInvisibleElementsShowing)
            return true;
        return this.isVisibleCore();
    }
    get isVisibleInSurvey() {
        return this.isVisible && this.isParentVisible;
    }
    isVisibleCore() {
        return this.visible;
    }
    /**
     * Returns the visible index of the question in the survey. It can be from 0 to all visible questions count - 1
     * The visibleIndex is -1 if the title is 'hidden' or showNumber is false
     * @see titleLocation
     * @see showNumber
     */
    get visibleIndex() {
        return this.getPropertyValue("visibleIndex", -1);
    }
    onHidingContent() { }
    /**
     * Specifies whether to show a number for this question. Setting this property to `false` hides the question number from the title and excludes the question from numbering.
     *
     * Default value: `false` (inherited from the `SurveyModel`'s [`showQuestionNumbers`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showQuestionNumbers) property)
     * @see no
     */
    get showNumber() {
        return this.getPropertyValue("showNumber");
    }
    set showNumber(val) {
        this.setPropertyValue("showNumber", val);
        this.notifySurveyVisibilityChanged();
    }
    /**
     * @deprecated Use the [`showNumber`](https://surveyjs.io/form-library/documentation/api-reference/question#showNumber) property instead.
     */
    get hideNumber() {
        return !this.showNumber;
    }
    set hideNumber(val) {
        this.showNumber = !val;
    }
    /**
     * Returns `true` if the question can display its title to the left of the input field.
     * @see titleLocation
     * @see getTitleLocation
     * @see hasTitle
     */
    get isAllowTitleLeft() {
        return true;
    }
    /**
     * Returns the question type.
     * Possible values:
     * - [*"boolean"*](https://surveyjs.io/Documentation/Library?id=questionbooleanmodel)
     * - [*"checkbox"*](https://surveyjs.io/Documentation/Library?id=questioncheckboxmodel)
     * - [*"comment"*](https://surveyjs.io/Documentation/Library?id=questioncommentmodel)
     * - [*"dropdown"*](https://surveyjs.io/Documentation/Library?id=questiondropdownmodel)
     * - [*"tagbox"*](https://surveyjs.io/form-library/documentation/questiontagboxmodel)
     * - [*"expression"*](https://surveyjs.io/Documentation/Library?id=questionexpressionmodel)
     * - [*"file"*](https://surveyjs.io/Documentation/Library?id=questionfilemodel)
     * - [*"html"*](https://surveyjs.io/Documentation/Library?id=questionhtmlmodel)
     * - [*"image"*](https://surveyjs.io/Documentation/Library?id=questionimagemodel)
     * - [*"imagepicker"*](https://surveyjs.io/Documentation/Library?id=questionimagepickermodel)
     * - [*"matrix"*](https://surveyjs.io/Documentation/Library?id=questionmatrixmodel)
     * - [*"matrixdropdown"*](https://surveyjs.io/Documentation/Library?id=questionmatrixdropdownmodel)
     * - [*"matrixdynamic"*](https://surveyjs.io/Documentation/Library?id=questionmatrixdynamicmodel)
     * - [*"multipletext"*](https://surveyjs.io/Documentation/Library?id=questionmultipletextmodel)
     * - [*"panel"*](https://surveyjs.io/Documentation/Library?id=panelmodel)
     * - [*"paneldynamic"*](https://surveyjs.io/Documentation/Library?id=questionpaneldynamicmodel)
     * - [*"radiogroup"*](https://surveyjs.io/Documentation/Library?id=questionradiogroupmodel)
     * - [*"rating"*](https://surveyjs.io/Documentation/Library?id=questionratingmodel)
     * - [*"ranking"*](https://surveyjs.io/Documentation/Library?id=questionrankingmodel)
     * - [*"signaturepad"*](https://surveyjs.io/Documentation/Library?id=questionsignaturepadmodel)
     * - [*"text"*](https://surveyjs.io/Documentation/Library?id=questiontextmodel)
     */
    getType() {
        return "question";
    }
    get isQuestion() {
        return true;
    }
    moveTo(container, insertBefore = null) {
        return this.moveToBase(this.parent, container, insertBefore);
    }
    getProgressInfo() {
        if (!this.hasInput)
            return super.getProgressInfo();
        return {
            questionCount: 1,
            answeredQuestionCount: !this.isEmpty() ? 1 : 0,
            requiredQuestionCount: this.isRequired ? 1 : 0,
            requiredAnsweredQuestionCount: !this.isEmpty() && this.isRequired ? 1 : 0,
        };
    }
    ensureSetValueExpressionRunner() {
        if (!this.setValueExpressionRunner) {
            this.setValueExpressionRunner = new ExpressionRunner(this.setValueExpression);
            this.setValueExpressionRunner.onRunComplete = (res) => {
                this.runExpressionSetValue(res);
            };
        }
        else {
            this.setValueExpressionRunner.expression = this.setValueExpression;
        }
    }
    runSetValueExpression() {
        if (!this.setValueExpression) {
            this.clearValue();
        }
        else {
            this.ensureSetValueExpressionRunner();
            this.setValueExpressionRunner.run(this.getDataFilteredValues(), this.getDataFilteredProperties());
        }
    }
    getSetValueExpressionRunner() {
        this.ensureSetValueExpressionRunner();
        return this.setValueExpressionRunner;
    }
    addTriggerInfo(name, canRun, doComplete) {
        const info = new TriggerExpressionInfo(name, canRun, doComplete);
        this.triggersInfo.push(info);
        return info;
    }
    runTriggerInfo(info, keys) {
        const expression = this[info.name];
        if (!expression && !info.getSecondRunner() || info.isRunning || !info.canRun()) {
            return;
        }
        if (!info.runner) {
            info.runner = new ExpressionRunner(expression);
            info.runner.onRunComplete = (res) => {
                if (res === true) {
                    info.doComplete();
                }
                info.isRunning = false;
            };
        }
        else {
            info.runner.expression = expression;
        }
        if (!this.canExecuteTriggerByKeys(keys, info.runner, info.getSecondRunner()))
            return;
        info.isRunning = true;
        if (!expression && info.getSecondRunner()) {
            info.doComplete();
            info.isRunning = false;
        }
        else {
            info.runner.run(this.getDataFilteredValues(), this.getDataFilteredProperties());
        }
    }
    canExecuteTriggerByKeys(keys, runner, secondRunner) {
        if (!runner && !!secondRunner) {
            runner = secondRunner;
            secondRunner = undefined;
        }
        const run1 = this.canExecuteTriggerByKeysCore(keys, runner);
        if (run1 === "var")
            return true;
        if (!secondRunner)
            return run1 === "func" || run1 === "const";
        const run2 = this.canExecuteTriggerByKeysCore(keys, secondRunner);
        return run2 !== "";
    }
    canExecuteTriggerByKeysCore(keys, runner) {
        if (!runner.expression)
            return "";
        const vars = runner.getVariables();
        if ((!Array.isArray(vars) || vars.length === 0)) {
            if (runner.hasFunction())
                return "func";
            return "const";
        }
        return new ProcessValue().isAnyKeyChanged(keys, vars) ? "var" : "";
    }
    runTriggers(name, value, keys) {
        if (this.isSettingQuestionValue || (this.parentQuestion && this.parentQuestion.getValueName() === name))
            return;
        if (!keys) {
            keys = {};
            keys[name] = value;
        }
        this.triggersInfo.forEach(info => {
            this.runTriggerInfo(info, keys);
        });
    }
    runConditions() {
        if (this.data && !this.isLoadingFromJson) {
            if (!this.isDesignMode) {
                this.runCondition(this.getDataFilteredValues(), this.getDataFilteredProperties());
            }
            this.locStrsChanged();
        }
    }
    setSurveyImpl(value, isLight) {
        super.setSurveyImpl(value);
        if (!this.survey)
            return;
        this.survey.questionCreated(this);
        if (isLight !== true) {
            this.runConditions();
        }
        if (!this.visible) {
            this.updateIsVisibleProp();
        }
        this.updateIsMobileFromSurvey();
    }
    /**
     * Returns a survey element (panel or page) that contains the question and allows you to move this question to a different survey element.
     */
    get parent() {
        return this.getPropertyValue("parent", null);
    }
    set parent(val) {
        if (this.parent === val)
            return;
        this.removeFromParent();
        this.setPropertyValue("parent", val);
        if (!!val) {
            this.updateQuestionCss();
        }
        this.onParentChanged();
    }
    onParentChanged() { }
    calculateSingleInputQuestion() {
        if (!this.isSingleInputActive) {
            return undefined;
        }
        const questions = this.getSingleInputQuestions();
        if (Array.isArray(questions) && questions.length > 0) {
            const q = questions[0];
            this.onBeforeSetSingleInputQuestion(q);
            return q;
        }
        return undefined;
    }
    get singleInputQuestion() {
        const survey = this.survey;
        if (!survey || !survey.isSingleVisibleInput)
            return undefined;
        return this.getPropertyValue("singleInputQuestion", undefined, () => this.calculateSingleInputQuestion());
    }
    get currentSingleInputQuestion() {
        let res = this.singleInputQuestion;
        while (!!res && !!res.singleInputQuestion && res.singleInputQuestion !== res) {
            res = res.singleInputQuestion;
        }
        return res;
    }
    get currentSingleInputParentQuestion() {
        const q = this.currentSingleInputQuestion;
        if (!q)
            return this;
        if (q.singleInputQuestion === q)
            return q;
        return q.parentQuestion || this;
    }
    get singleInputSummary() {
        return this.getPropertyValue("singleInputSummary", undefined, () => {
            if (!this.supportNestedSingleInput())
                return undefined;
            const q = this.singleInputQuestion;
            if (!q || q !== this)
                return undefined;
            const res = this.createSingleInputSummary();
            if (!!res) {
                this.calcSingleInputActions();
                this.resetPropertyValue("singleInputLocTitle");
            }
            return res;
        });
    }
    createSingleInputSummary() {
        return undefined;
    }
    get rootParentQuestion() {
        let res = this;
        while (!!res.parentQuestion) {
            res = res.parentQuestion;
        }
        return res;
    }
    getParentQuestions() {
        const res = new Array();
        let q = this;
        while (!!q.parentQuestion) {
            res.push(q.parentQuestion);
            q = q.parentQuestion;
        }
        return res;
    }
    resetSingleInput() {
        this.resetSingleInputCore();
    }
    resetSingleInputCore() {
        const prev = this.singleInputQuestion;
        this.resetPropertyValue("singleInputQuestion");
        if (!!prev) {
            this.onSingleInputChanged();
        }
    }
    onSingleInputChanged(resetSummary = true) {
        var _a, _b;
        if (resetSummary) {
            this.resetSingleInputSummary();
        }
        (_a = this.singleInputLocTitle) === null || _a === void 0 ? void 0 : _a.strChanged();
        this.resetPropertyValue("singleInputLocTitle");
        this.calcSingleInputActions();
        (_b = this.survey) === null || _b === void 0 ? void 0 : _b.updateNavigationElements();
    }
    resetSingleInputSummary() {
        var _a;
        (_a = this.singleInputSummary) === null || _a === void 0 ? void 0 : _a.dispose();
        this.resetPropertyValue("singleInputSummary");
    }
    validateSingleInput(fireCallback = true, rec = null) {
        const q = this.currentSingleInputQuestion;
        if (!q)
            return true;
        rec = rec || {
            fireCallback: fireCallback,
            focusOnFirstError: fireCallback,
            firstErrorQuestion: null,
            result: false,
        };
        const res = q.validate(fireCallback, rec);
        if (!res && rec.focusOnFirstError && !!rec.firstErrorQuestion) {
            rec.firstErrorQuestion.focus(true);
        }
        return res;
    }
    getSingleInputElementPos() {
        if (this.singleInputQuestion === this)
            return 0;
        const pQ = this.currentSingleInputParentQuestion;
        if (pQ !== this) {
            let res = pQ.getSingleInputElementPos();
            if (res === 2)
                return 2;
        }
        const q = this.singleInputQuestion;
        const questions = this.getSingleInputQuestions();
        if (questions.length < 2)
            return 0;
        let index = questions.indexOf(q);
        return index === 0 ? -1 : (index >= questions.length - 1 ? 1 : 2);
    }
    get isSingleInputActive() {
        const sv = this.survey;
        if (!sv || !sv.isSingleVisibleInput)
            return false;
        const ssQ = sv.currentSingleQuestion;
        return !!ssQ && ssQ === this.rootParentQuestion;
    }
    singleInputOnAddItem(isOnDataChanging) {
        if (this.isSingleInputActive) {
            if (isOnDataChanging && this.singleInputSummary) {
                this.resetSingleInputSummary();
            }
            else {
                this.setSingleQuestionOnChange(Number.MAX_VALUE);
            }
        }
    }
    singleInputOnRemoveItem(index) {
        if (this.isSingleInputActive) {
            if (!this.singleInputSummary) {
                this.setSingleQuestionOnChange(index);
            }
            else {
                this.onSingleInputChanged();
            }
        }
    }
    getSingleQuestionOnChange(index) { return null; }
    setSingleQuestionOnChange(index) {
        const q = this.getSingleQuestionOnChange(index);
        if (!!q) {
            this.setSingleInputQuestion(q);
        }
        else {
            this.resetSingleInput();
        }
    }
    onSetAsSingleInput() {
        this.isSingleInputSummaryShown = false;
        const needReset = !this.wasRendered || this.singleInputSummary;
        this.onFirstRendering();
        if (needReset) {
            this.resetSingleInputSummary();
            this.resetPropertyValue("singleInputQuestion");
            this.resetPropertyValue("singleInputLocTitle");
        }
    }
    nextSingleInput() {
        return this.nextPrevSingleInput(1);
    }
    prevSingleInput() {
        return this.nextPrevSingleInput(-1);
    }
    getSingleInputAddText() {
        const q = this.currentSingleInputQuestion;
        return !!q && !!q.singleInputSummary ? q.getSingleInputAddTextCore() : undefined;
    }
    singleInputAddItem(checkErrors) {
        const rec = { fireCallback: true, focusOnFirstError: true };
        if (checkErrors && !this.validateSingleInput(true, rec)) {
            if (rec.firstErrorQuestion) {
                rec.firstErrorQuestion.focus(true);
            }
        }
        else {
            this.currentSingleInputQuestion.singleInputAddItemCore();
        }
    }
    singleInputRemoveItem() {
        const q = this.singleInputQuestion;
        if (q && q !== this.singleInputParentQuestion) {
            this.singleInputRemoveItemCore(q);
        }
    }
    get singleInputLocTitle() {
        return this.getPropertyValue("singleInputLocTitle", undefined, () => {
            return this.getSingleQuestionLocTitle();
        });
    }
    get singleInputActions() {
        return this.getPropertyValue("singleInputActions", undefined, () => {
            return this.createSingleInputActions();
        });
    }
    get singleInputHasActions() {
        return this.getPropertyValue("singleInputHasActions", undefined, () => {
            return this.createSingleInputActions();
        });
    }
    get singleInputHideHeader() {
        var _a;
        const childQ = (_a = this.singleInputQuestion) === null || _a === void 0 ? void 0 : _a.singleInputQuestion;
        return !!childQ && this.singleInputQuestion !== this;
    }
    set sinleInputHasActions(val) {
        this.setPropertyValue("singleInputHasActions", val);
    }
    get singleInputParentQuestion() {
        var _a;
        return ((_a = this.singleInputQuestion) === null || _a === void 0 ? void 0 : _a.parentQuestion) || this;
    }
    createSingleInputActions() {
        var _a;
        if (((_a = this.survey) === null || _a === void 0 ? void 0 : _a.currentSingleQuestion) !== this)
            return undefined;
        const singleInputActions = new ActionContainer();
        singleInputActions.actions = this.getSingleQuestionActions();
        return singleInputActions;
    }
    calcSingleInputActions() {
        if (!!this.parentQuestion) {
            this.parentQuestion.calcSingleInputActions();
        }
        else {
            const actions = this.getSingleQuestionActions();
            if (this.singleInputActions) {
                this.singleInputActions.actions = actions;
            }
            this.sinleInputHasActions = actions.length > 0 ? true : undefined;
        }
    }
    getSingleQuestionActions() {
        const res = new Array();
        const p = this.currentSingleInputParentQuestion;
        if (!p || p === this)
            return res;
        const pSQs = p.getSingleInputQuestions();
        const qs = new Array();
        let summaryQ = undefined;
        if (pSQs.length > 1 && pSQs[0] === p) {
            summaryQ = p;
            qs.push(p);
        }
        let pQ = p.parentQuestion;
        while (!!pQ) {
            qs.push(pQ);
            pQ = pQ.parentQuestion;
        }
        for (let i = qs.length - 1; i >= 0; i--) {
            const q = qs[i];
            if (q !== summaryQ) {
                //const title = q == summaryQ ? q.locTitle : q.singleInputLocTitle;
                const title = q.singleInputLocTitle;
                const action = new Action({ id: "single-action" + q.id, locTitle: title,
                    css: this.cssClasses.breadcrumbsItem,
                    innerCss: this.cssClasses.breadcrumbsItemButton,
                    action: () => {
                        q.singleInputMoveToFirst();
                        /*
                        if (q == summaryQ) {
                          q.setSingleInputQuestion(q);
                        } else {
                          q.singleInputMoveToFirst();
                        }
                        */
                    }
                });
                action.cssClasses = {};
                res.push(action);
            }
        }
        return res;
    }
    singleInputMoveToFirst() {
        const q = this.singleInputQuestion;
        if (!!q && q !== this) {
            q.singleInputMoveToFirst();
        }
        this.singleInputMoveToFirstCore();
    }
    singleInputMoveToFirstCore() { }
    getSingleQuestionLocTitle() {
        return !this.singleInputSummary ? this.getSingleQuestionLocTitleCore() : undefined;
    }
    getSingleQuestionLocTitleCore() {
        return undefined;
    }
    supportNestedSingleInput() {
        var _a;
        return (_a = this.survey) === null || _a === void 0 ? void 0 : _a.supportsNestedSingleInput(this);
    }
    getSingleInputQuestions() {
        if (!this.supportNestedSingleInput())
            return [];
        const question = this.getPropertyValue("singleInputQuestion");
        if (question === this)
            return [this];
        const res = this.getSingleInputQuestionsCore(question, !question || !this.isSingleInputSummaryShown);
        res.forEach(q => { if (q !== this)
            this.onSingleInputQuestionAdded(q); });
        return res;
    }
    getSingleInputQuestionsCore(question, checkDynamic) {
        return this.getNestedQuestions(true, false);
    }
    onSingleInputQuestionAdded(question) { }
    fillSingleInputQuestionsInContainer(res, innerQuestion) { }
    getSingleInputQuestionsForDynamic(question, arr) {
        const res = new Array();
        if (!!question && question !== this && arr.indexOf(question) < 0) {
            this.fillSingleInputQuestionsInContainer(res, question);
        }
        arr.forEach(q => res.push(q));
        if (this.isSingleInputSummaryShown && res.length > 0) {
            res.unshift(this);
        }
        res.push(this);
        return res;
    }
    getSingleInputAddTextCore() { return undefined; }
    singleInputAddItemCore() { }
    singleInputRemoveItemCore(question) { }
    setSingleInputQuestionCore(question) {
        this.onBeforeSetSingleInputQuestion(question);
        this.setPropertyValue("singleInputQuestion", question);
    }
    onBeforeSetSingleInputQuestion(question) {
        question.onFirstRendering();
        if (question === this) {
            this.isSingleInputSummaryShown = true;
        }
    }
    setSingleInputQuestion(question, onPrev) {
        if (this.singleInputQuestion !== question) {
            this.setSingleInputQuestionCore(question);
            this.onSingleInputChanged(!onPrev || question !== this);
        }
    }
    nextPrevSingleInput(skip) {
        let pQ = this.currentSingleInputParentQuestion;
        while (!!pQ && pQ !== this) {
            const res = pQ.nextPrevSingleInput(skip);
            if (res)
                return true;
            pQ = pQ.parentQuestion;
        }
        const q = this.singleInputQuestion;
        if (!q)
            return false;
        const questions = this.getSingleInputQuestions();
        let index = questions.indexOf(q);
        if (index < 0) {
            if (questions.length === 0)
                return false;
            index = 0;
            skip = 0;
        }
        index += skip;
        if (index < 0 || index >= questions.length)
            return false;
        this.setSingleInputQuestion(questions[index], skip < 0);
        return true;
    }
    /**
     * Returns `false` if the `titleLocation` property is set to `"hidden"` or if the question cannot have a title (for example, an [HTML](https://surveyjs.io/form-library/documentation/questionhtmlmodel) question).
     *
     * If the `title` property is `undefined` or set to an empty string, the `hasTitle` property returns `true`, because the question uses its `name` as a title in this case.
     * @see title
     * @see titleLocation
     */
    get hasTitle() {
        return this.getTitleLocation() !== "hidden";
    }
    /**
     * Sets question title location relative to the input field. Overrides the `questionTitleLocation` property specified for the question's container (survey, page, or panel).
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the `questionTitleLocation` property specified for the question's container.
     * - `"top"` - Displays the title above the input field.
     * - `"bottom"` - Displays the title below the input field.
     * - `"left"` - Displays the title to the left of the input field.
     * - `"hidden"` - Hides the question title.
     *
     * > Certain question types (Matrix, Multiple Text) do not support the `"left"` value. For them, the `"top"` value is used.
     * @see SurveyModel.questionTitleLocation
     * @see getTitleLocation
     * @see isAllowTitleLeft
     */
    get titleLocation() {
        return this.getPropertyValue("titleLocation");
    }
    set titleLocation(value) {
        var isVisibilityChanged = this.titleLocation == "hidden" || value == "hidden";
        this.setPropertyValue("titleLocation", value.toLowerCase());
        this.updateQuestionCss();
        if (isVisibilityChanged) {
            this.notifySurveyVisibilityChanged();
        }
    }
    get showTitle() {
        return this.getTitleLocation() !== "hidden";
    }
    set showTitle(newValue) {
        this.titleLocation = newValue ? "default" : "hidden";
    }
    getTitleOwner() { return this; }
    getIsTitleRenderedAsString() { return this.titleLocation === "hidden"; }
    notifySurveyOnChildrenVisibilityChanged() { return false; }
    notifySurveyVisibilityChanged() {
        if (!this.survey || this.isLoadingFromJson)
            return;
        this.survey.questionVisibilityChanged(this, this.isVisible, !this.parentQuestion || this.parentQuestion.notifySurveyOnChildrenVisibilityChanged());
        const isClearOnHidden = this.isClearValueOnHidden;
        if (!this.visible) {
            this.clearValueOnHidding(isClearOnHidden);
        }
        if (isClearOnHidden && this.isVisibleInSurvey) {
            this.updateValueWithDefaults();
        }
    }
    clearValueOnHidding(isClearOnHidden) {
        if (isClearOnHidden) {
            this.clearValueIfInvisible();
        }
    }
    get titleWidth() {
        if (this.parent && this.getTitleLocation() === "left") {
            const columns = this.parent.getColumsForElement(this);
            const columnCount = columns.length;
            if (columnCount !== 0 && !!columns[0].questionTitleWidth)
                return columns[0].questionTitleWidth;
            const questionWidth = this.getQuestionParentTitleWidth();
            const percentWidth = this.getPercentQuestionTitleWidth(questionWidth);
            if (!percentWidth && !!this.parent) {
                let width = questionWidth;
                if (width && !isNaN(width))
                    width = width + "px";
                return width;
            }
            return (percentWidth / (columnCount || 1)) + "%";
        }
        return undefined;
    }
    getQuestionParentTitleWidth() {
        if (!this.parent)
            return undefined;
        const res = this.parent.getQuestionTitleWidth();
        if (!res && !!this.parentQuestion)
            return this.parentQuestion.getQuestionParentTitleWidth();
        return res;
    }
    getPercentQuestionTitleWidth(width) {
        if (!!width && width[width.length - 1] === "%") {
            return parseInt(width);
        }
        return undefined;
    }
    /**
     * Returns title location calculated based on the question's `titleLocation` property and the `questionTitleLocation` property of the question's containers (survey, page, or panel).
     * @see titleLocation
     * @see SurveyModel.questionTitleLocation
     */
    getTitleLocation() {
        if (this.isFlowLayout)
            return "hidden";
        var location = this.getTitleLocationCore();
        if (location === "left" && !this.isAllowTitleLeft)
            location = "top";
        return location;
    }
    getTitleLocationCore() {
        if (this.titleLocation !== "default")
            return this.titleLocation;
        if (!!this.parent)
            return this.parent.getQuestionTitleLocation();
        if (!!this.survey)
            return this.survey.questionTitleLocation;
        return "top";
    }
    get hasTitleOnLeft() {
        return this.hasTitle && this.getTitleLocation() === "left";
    }
    get hasTitleOnTop() {
        return this.hasTitle && this.getTitleLocation() === "top";
    }
    get hasTitleOnBottom() {
        return this.hasTitle && this.getTitleLocation() === "bottom";
    }
    get hasTitleOnLeftTop() {
        if (!this.hasTitle)
            return false;
        const location = this.getTitleLocation();
        return location === "left" || location === "top";
    }
    /**
     * Specifies the error message position. Overrides the `questionErrorLocation` property specified for the question's container ([survey](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionErrorLocation), [page](https://surveyjs.io/form-library/documentation/api-reference/page-model#questionErrorLocation), or [panel](https://surveyjs.io/form-library/documentation/api-reference/panel-model#questionErrorLocation)).
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the `questionErrorLocation` property specified for the question's container.
     * - `"top"` - Displays error messages above questions.
     * - `"bottom"` - Displays error messages below questions.
     */
    get errorLocation() {
        return this.getPropertyValue("errorLocation");
    }
    set errorLocation(val) {
        this.setPropertyValue("errorLocation", val);
    }
    getErrorLocation() {
        if (this.errorLocation !== "default")
            return this.errorLocation;
        if (this.parentQuestion)
            return this.parentQuestion.getChildErrorLocation(this);
        if (this.parent)
            return this.parent.getQuestionErrorLocation();
        return this.survey ? this.survey.questionErrorLocation : "top";
    }
    getChildErrorLocation(child) {
        return this.getErrorLocation();
    }
    /**
     * Returns `false` if the question has no input fields ([HTML](https://surveyjs.io/form-library/documentation/questionhtmlmodel), [Image](https://surveyjs.io/form-library/documentation/questionimagemodel), and similar question types).
     * @see hasSingleInput
     */
    get hasInput() {
        return true;
    }
    /**
     * Returns `false` if the question has no input fields ([HTML](https://surveyjs.io/form-library/documentation/questionhtmlmodel), [Image](https://surveyjs.io/form-library/documentation/questionimagemodel)) or has multiple input fields ([Matrix](https://surveyjs.io/form-library/documentation/questionmatrixmodel), [Multiple Text](https://surveyjs.io/form-library/documentation/questionmultipletextmodel)).
     * @see hasInput
     */
    get hasSingleInput() {
        return this.hasInput;
    }
    get inputId() {
        return this.id + "i";
    }
    getDefaultTitleValue() { return this.name; }
    getDefaultTitleTagName() {
        return settings.titleTags.question;
    }
    /**
     * Specifies where to display a question description.
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the Survey's [`questionDescriptionLocation`](https://surveyjs.io/form-library/documentation/surveymodel#questionDescriptionLocation) property.
     * - `"underTitle"` - Displays the description under the question title.
     * - `"underInput"` - Displays the description under the interactive area.
     * @see description
     * @see hasDescription
     */
    get descriptionLocation() {
        return this.getPropertyValue("descriptionLocation");
    }
    set descriptionLocation(val) {
        this.setPropertyValue("descriptionLocation", val);
        this.updateQuestionCss();
    }
    get hasDescriptionUnderTitle() {
        return this.getDescriptionLocation() == "underTitle" && this.hasDescription;
    }
    get hasDescriptionUnderInput() {
        return this.getDescriptionLocation() == "underInput" && this.hasDescription;
    }
    getDescriptionLocation() {
        if (this.descriptionLocation !== "default")
            return this.descriptionLocation;
        return !!this.survey
            ? this.survey.questionDescriptionLocation
            : "underTitle";
    }
    needClickTitleFunction() {
        return super.needClickTitleFunction() || this.hasInput;
    }
    processTitleClick() {
        super.processTitleClick();
        if (this.isCollapsed)
            return;
        setTimeout(() => {
            this.focus();
        }, 1);
        return true;
    }
    /**
     * Specifies a custom error message for a required form field.
     * @see isRequired
     */
    get requiredErrorText() {
        return this.getLocalizableStringText("requiredErrorText");
    }
    set requiredErrorText(val) {
        this.setLocalizableStringText("requiredErrorText", val);
    }
    get locRequiredErrorText() {
        return this.getLocalizableString("requiredErrorText");
    }
    /**
     * Specifies a caption displayed above the comment area. Applies when the `showCommentArea` property is `true`.
     * @see showCommentArea
     * @see comment
     */
    get commentText() {
        return this.getLocalizableStringText("commentText");
    }
    set commentText(val) {
        this.setLocalizableStringText("commentText", val);
    }
    get locCommentText() {
        return this.getLocalizableString("commentText");
    }
    /**
     * A placeholder for the comment area. Applies when the `showCommentArea` property is `true`.
     * @see showCommentArea
     * @see comment
     * @see commentText
     */
    get commentPlaceholder() { return this.getLocalizableStringText("commentPlaceholder"); }
    set commentPlaceholder(val) { this.setLocalizableStringText("commentPlaceholder", val); }
    get locCommentPlaceholder() { return this.getLocalizableString("commentPlaceholder"); }
    get commentPlaceHolder() {
        return this.commentPlaceholder;
    }
    set commentPlaceHolder(newValue) {
        this.commentPlaceholder = newValue;
    }
    get renderedCommentPlaceholder() {
        var _a;
        return (_a = this.getPropertyValue("renderedCommentPlaceholder")) !== null && _a !== void 0 ? _a : (!this.isReadOnly ? this.commentPlaceHolder : undefined);
    }
    resetRenderedCommentPlaceholder() {
        this.resetPropertyValue("renderedCommentPlaceholder");
    }
    /**
     * A value to show in HTML questions and in the dynamic titles and descriptions of survey elements when the question value is [empty](#isValueEmpty).
     *
     * Default value: `""`
     *
     * [Dynamic Texts](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#dynamic-texts (linkStyle))
     */
    get defaultDisplayValue() { return this.getLocalizableStringText("defaultDisplayValue"); }
    set defaultDisplayValue(val) { this.setLocalizableStringText("defaultDisplayValue", val); }
    get locDefaultDisplayValue() { return this.getLocalizableString("defaultDisplayValue"); }
    getAllErrors() {
        return this.errors.slice();
    }
    getErrorByType(errorType) {
        for (let i = 0; i < this.errors.length; i++) {
            if (this.errors[i].getErrorType() === errorType)
                return this.errors[i];
        }
        return null;
    }
    get customWidget() {
        if (!this.isCustomWidgetRequested && !this.customWidgetValue) {
            this.isCustomWidgetRequested = true;
            this.updateCustomWidget();
        }
        return this.customWidgetValue;
    }
    updateCustomWidget() {
        this.customWidgetValue = CustomWidgetCollection.Instance.getCustomWidget(this);
    }
    localeChanged() {
        super.localeChanged();
        this.resetRenderedCommentPlaceholder();
        if (!!this.localeChangedCallback) {
            this.localeChangedCallback();
        }
    }
    get isCompositeQuestion() {
        return false;
    }
    get isContainer() { return false; }
    updateCommentElements() {
    }
    onCommentInput(event) {
        if (this.isInputTextUpdate) {
            if (event.target) {
                this.comment = event.target.value;
            }
        }
        else {
            this.updateCommentElements();
        }
    }
    onCommentChange(event) {
        this.comment = event.target.value;
        if (this.comment !== event.target.value) {
            event.target.value = this.comment;
        }
    }
    afterRenderQuestionElement(el) {
        if (!this.survey || !this.hasSingleInput)
            return;
        this.survey.afterRenderQuestionInput(this, el);
    }
    afterRender(el) {
        this.afterRenderCore(el);
        if (!this.survey)
            return;
        this.survey.afterRenderQuestion(this, el);
        if (!!this.afterRenderQuestionCallback) {
            this.afterRenderQuestionCallback(this, el);
        }
        if (this.supportComment() || this.supportOther()) {
            this.commentElements = [];
            this.getCommentElementsId().forEach(id => {
                const commentEl = el === null || el === void 0 ? void 0 : el.querySelector(`#${id}`);
                if (commentEl)
                    this.commentElements.push(commentEl);
            });
            this.updateCommentElements();
        }
        this.checkForResponsiveness(el);
    }
    afterRenderCore(element) {
        super.afterRenderCore(element);
    }
    getCommentElementsId() {
        return [this.commentId];
    }
    beforeDestroyQuestionElement(el) {
        this.commentElements = undefined;
    }
    get processedTitle() {
        var res = this.locProcessedTitle.textOrHtml;
        return res ? res : this.name;
    }
    get fullTitle() {
        return this.locTitle.renderedHtml;
    }
    get titlePattern() {
        return !!this.survey ? this.survey.questionTitlePattern : "numTitleRequire";
    }
    get isRequireTextOnStart() {
        return this.isRequired && this.titlePattern == "requireNumTitle";
    }
    get isRequireTextBeforeTitle() {
        return this.isRequired && this.titlePattern == "numRequireTitle" && this.requiredMark !== "";
    }
    get isRequireTextAfterTitle() {
        return this.isRequired && this.titlePattern == "numTitleRequire" && this.requiredMark !== "";
    }
    /**
     * Disable this property if you want to render the current question on the same line or row with the previous question or panel.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/arrange-multiple-questions-in-single-line/ (linkStyle))
     */
    get startWithNewLine() {
        return this.getPropertyValue("startWithNewLine");
    }
    set startWithNewLine(val) {
        if (this.startWithNewLine == val)
            return;
        this.setPropertyValue("startWithNewLine", val);
    }
    calcCssClasses(css) {
        const classes = { error: {} };
        this.copyCssClasses(classes, css.question);
        this.copyCssClasses(classes.error, css.error);
        this.updateCssClasses(classes, css);
        return classes;
    }
    onCalcCssClasses(classes) {
        super.onCalcCssClasses(classes);
        if (this.survey) {
            this.survey.updateQuestionCssClasses(this, classes);
        }
        if (this.onUpdateCssClassesCallback) {
            this.onUpdateCssClassesCallback(classes);
        }
    }
    get cssRoot() {
        this.ensureElementCss();
        return this.getPropertyValue("cssRoot", "");
    }
    setCssRoot(val) {
        this.setPropertyValue("cssRoot", val);
    }
    getCssRoot(cssClasses) {
        const hasError = this.hasCssError();
        return new CssClassBuilder()
            .append(super.getCssRoot(cssClasses))
            .append(this.isFlowLayout && !this.isDesignMode
            ? cssClasses.flowRoot
            : cssClasses.mainRoot)
            .append(cssClasses.titleLeftRoot, !this.isFlowLayout && this.hasTitleOnLeft)
            .append(cssClasses.titleTopRoot, !this.isFlowLayout && this.hasTitleOnTop)
            .append(cssClasses.titleBottomRoot, !this.isFlowLayout && this.hasTitleOnBottom)
            .append(cssClasses.descriptionUnderInputRoot, !this.isFlowLayout && this.hasDescriptionUnderInput)
            .append(cssClasses.hasError, hasError)
            .append(cssClasses.hasErrorTop, hasError && this.getErrorLocation() == "top")
            .append(cssClasses.hasErrorBottom, hasError && this.getErrorLocation() == "bottom")
            .append(cssClasses.small, !this.width)
            .append(cssClasses.answered, this.isAnswered)
            .append(cssClasses.noPointerEventsMode, this.isReadOnlyAttr)
            .toString();
    }
    get cssHeader() {
        this.ensureElementCss();
        return this.getPropertyValue("cssHeader", "");
    }
    setCssHeader(val) {
        this.setPropertyValue("cssHeader", val);
    }
    getCssHeader(cssClasses) {
        return new CssClassBuilder()
            .append(cssClasses.header)
            .append(cssClasses.headerTop, this.hasTitleOnTop)
            .append(cssClasses.headerLeft, this.hasTitleOnLeft)
            .append(cssClasses.headerBottom, this.hasTitleOnBottom)
            .toString();
    }
    supportContainerQueries() {
        return false;
    }
    get cssContent() {
        this.ensureElementCss();
        return this.getPropertyValue("cssContent", "");
    }
    setCssContent(val) {
        this.setPropertyValue("cssContent", val);
    }
    getCssContent(cssClasses) {
        return new CssClassBuilder()
            .append(cssClasses.content)
            .append(cssClasses.contentSupportContainerQueries, this.supportContainerQueries())
            .append(cssClasses.contentLeft, this.hasTitleOnLeft)
            .toString();
    }
    get cssTitle() {
        this.ensureElementCss();
        return this.getPropertyValue("cssTitle", "");
    }
    setCssTitle(val) {
        this.setPropertyValue("cssTitle", val);
    }
    getCssTitle(cssClasses) {
        return new CssClassBuilder()
            .append(super.getCssTitle(cssClasses))
            .append(cssClasses.singleInputTitle, !!this.singleInputQuestion)
            .append(cssClasses.titleOnAnswer, !this.containsErrors && this.isAnswered)
            .append(cssClasses.titleEmpty, !this.title.trim())
            .toString();
    }
    get cssDescription() {
        this.ensureElementCss();
        return this.getPropertyValue("cssDescription", "");
    }
    setCssDescription(val) {
        this.setPropertyValue("cssDescription", val);
    }
    getCssDescription(cssClasses) {
        return new CssClassBuilder()
            .append(cssClasses.description)
            .append(cssClasses.descriptionUnderInput, this.getDescriptionLocation() == "underInput")
            .toString();
    }
    get showErrorsAboveQuestion() {
        return this.getErrorLocation() === "top";
    }
    get showErrorsBelowQuestion() {
        return this.getErrorLocation() === "bottom";
    }
    get cssError() {
        this.ensureElementCss();
        return this.getPropertyValue("cssError", "");
    }
    setCssError(val) {
        this.setPropertyValue("cssError", val);
    }
    getCssError(cssClasses) {
        return new CssClassBuilder()
            .append(cssClasses.error.root)
            .append(cssClasses.errorsContainer)
            .append(cssClasses.errorsContainerTop, this.showErrorsAboveQuestion)
            .append(cssClasses.errorsContainerBottom, this.showErrorsBelowQuestion)
            .toString();
    }
    hasCssError() {
        return this.errors.length > 0 || this.hasCssErrorCallback();
    }
    get isSingleInputQuestionMode() {
        var _a;
        return !!this.parentQuestion && ((_a = this.survey) === null || _a === void 0 ? void 0 : _a.isSingleVisibleInput);
    }
    getIsNested() {
        if (!!this.isSingleInputQuestionMode)
            return false;
        return super.getIsNested();
    }
    getHasFrameV2() {
        if (this.isSingleInputQuestionMode)
            return true;
        return super.getHasFrameV2();
    }
    getRootCss() {
        return new CssClassBuilder()
            .append(this.cssRoot, !this.singleInputQuestion)
            .append(this.cssClasses.mobile, this.isMobile)
            .append(this.cssClasses.readOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.disabled, this.isDisabledStyle)
            .append(this.cssClasses.preview, this.isPreviewStyle)
            .append(this.cssClasses.invisible, !this.isDesignMode && this.areInvisibleElementsShowing && !this.visible)
            .toString();
    }
    getQuestionRootCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.root)
            .append(this.cssClasses.rootMobile, this.isMobile)
            .toString();
    }
    updateElementCss(reNew) {
        if (this.wasRendered) {
            super.updateElementCss(reNew);
            if (reNew) {
                this.updateQuestionCss(true);
            }
        }
        else {
            this.clearCssClasses();
        }
        this.resetIndents();
    }
    updateQuestionCss(reNew) {
        if (this.isLoadingFromJson || !this.survey)
            return;
        if (this.wasRendered) {
            this.updateElementCssCore(this.cssClasses);
        }
        else {
            this.isRequireUpdateElements = true;
        }
    }
    ensureElementCss() {
        if (!this.cssClassesValue) {
            this.updateQuestionCss(true);
        }
    }
    updateElementCssCore(cssClasses) {
        this.setCssRoot(this.getCssRoot(cssClasses));
        this.setCssHeader(this.getCssHeader(cssClasses));
        this.setCssContent(this.getCssContent(cssClasses));
        this.setCssTitle(this.getCssTitle(cssClasses));
        this.setCssDescription(this.getCssDescription(cssClasses));
        this.setCssError(this.getCssError(cssClasses));
    }
    updateCssClasses(res, css) {
        if (!css.question)
            return;
        const objCss = css[this.getCssType()];
        const titleBuilder = new CssClassBuilder().append(res.title)
            .append(css.question.titleRequired, this.isRequired);
        res.title = titleBuilder.toString();
        const rootBuilder = new CssClassBuilder().append(res.root)
            .append(objCss, this.isRequired && !!css.question.required);
        if (objCss === undefined || objCss === null) {
            res.root = rootBuilder.toString();
        }
        else if (typeof objCss === "string" || objCss instanceof String) {
            res.root = rootBuilder.append(objCss.toString()).toString();
        }
        else {
            res.root = rootBuilder.toString();
            for (const key in objCss) {
                res[key] = objCss[key];
            }
        }
    }
    getCssType() {
        return this.getType();
    }
    get renderCssRoot() {
        return this.cssClasses.root || undefined;
    }
    calcPaddingLeft() {
        return this.getIndentSize(this.indent);
    }
    calcPaddingRight() {
        return this.getIndentSize(this.rightIndent);
    }
    getIndentSize(indent) {
        if (indent < 1 || !this.getSurvey() || !this.cssClasses || !this.cssClasses.indent)
            return "";
        return indent * this.cssClasses.indent + "px";
    }
    /**
     * Moves focus to the input field of this question.
     * @param onError Pass `true` if you want to focus an input field with the first validation error. Default value: `false` (focuses the first input field). Applies to question types with multiple input fields.
     */
    focus(onError = false, scrollIfVisible) {
        if (this.isDesignMode || !this.isVisible || !this.survey)
            return;
        let page = this.page;
        const shouldChangePage = !!page && this.survey.activePage !== page;
        const isSingleInput = this.survey.isSingleVisibleInput;
        if (shouldChangePage && !isSingleInput) {
            this.survey.focusQuestionByInstance(this, onError);
        }
        else {
            if (isSingleInput) {
                this.survey.currentSingleQuestion = this.rootParentQuestion;
                const parents = this.getParentQuestions();
                for (let i = parents.length - 1; i >= 1; i--) {
                    if (i === parents.length - 1) {
                        parents[i].setSingleInputQuestion(parents[i - 1]);
                    }
                }
                if (parents.length > 0) {
                    parents[0].setSingleInputQuestion(this);
                }
                this.focusInputElement(onError);
            }
            else {
                this.expandAllParents();
                const scrollOptions = this.survey["isSmoothScrollEnabled"] ? { behavior: "smooth" } : undefined;
                this.survey.scrollElementToTop(this, this, null, this.id, scrollIfVisible, scrollOptions, undefined, () => {
                    this.focusInputElement(onError);
                });
            }
        }
    }
    focusInputElement(onError) {
        var _a;
        const id = !onError ? this.getFirstInputElementId() : this.getFirstErrorInputElementId();
        const surveyRoot = (_a = this.survey) === null || _a === void 0 ? void 0 : _a.rootElement;
        if (SurveyElement.FocusElement(id, false, surveyRoot)) {
            this.fireCallback(this.focusCallback);
        }
    }
    get isValidateVisitedEmptyFields() {
        return this.supportEmptyValidation() && !!this.survey && this.survey.getValidateVisitedEmptyFields() && this.isEmpty();
    }
    supportEmptyValidation() { return false; }
    onBlur(event) {
        this.onBlurCore(event);
    }
    onFocus(event) {
        this.onFocusCore(event);
    }
    onBlurCore(event) {
        if (this.isFocusEmpty && this.isEmpty()) {
            this.validate(true);
        }
    }
    onFocusCore(event) {
        this.isFocusEmpty = this.isValidateVisitedEmptyFields;
    }
    expandAllParents() {
        this.expandAllParentsCore(this);
    }
    expandAllParentsCore(element) {
        if (!element)
            return;
        if (element.isCollapsed) {
            element.expand();
        }
        this.expandAllParentsCore(element.parent);
        this.expandAllParentsCore(element.parentQuestion);
    }
    focusIn() {
        if (!this.survey || this.isDisposed || this.isContainer)
            return;
        this.survey.whenQuestionFocusIn(this);
    }
    fireCallback(callback) {
        if (callback)
            callback();
    }
    getOthersMaxLength() {
        if (!this.survey)
            return null;
        return this.survey.maxCommentLength > 0 ? this.survey.maxCommentLength : null;
    }
    onCreating() { }
    getFirstQuestionToFocus(withError) {
        return this.hasInput && (!withError || this.currentErrorCount > 0) ? this : null;
    }
    getFirstInputElementId() {
        return this.inputId;
    }
    getFirstErrorInputElementId() {
        return this.getFirstInputElementId();
    }
    getProcessedTextValue(textValue) {
        var name = textValue.name.toLocaleLowerCase();
        textValue.isExists =
            Object.keys(Question.TextPreprocessorValuesMap).indexOf(name) !== -1 ||
                this[textValue.name] !== undefined;
        textValue.value = this[Question.TextPreprocessorValuesMap[name] || textValue.name];
    }
    supportComment() {
        const prop = this.getPropertyByName("showCommentArea");
        return !prop || prop.visible;
    }
    supportOther() {
        return false;
    }
    /**
     * Makes the question required. If a respondent skips a required question, the survey displays a validation error.
     * @see requiredIf
     * @see [Data Validation](https://surveyjs.io/form-library/documentation/data-validation)
     */
    get isRequired() {
        return this.getPropertyValue("isRequired");
    }
    set isRequired(val) {
        this.setPropertyValue("isRequired", val);
    }
    /**
     * A Boolean expression. If it evaluates to `true`, this question becomes required.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see isRequired
     */
    get requiredIf() {
        return this.getPropertyValue("requiredIf", "");
    }
    set requiredIf(val) {
        this.setPropertyValue("requiredIf", val);
    }
    /**
     * Specifies whether to display a comment area.
     * @see comment
     * @see commentText
     * @see showOtherItem
     */
    get showCommentArea() {
        return this.getPropertyValue("showCommentArea", false);
    }
    set showCommentArea(val) {
        if (!this.supportComment())
            return;
        this.setPropertyValue("showCommentArea", val);
    }
    get hasComment() {
        return this.showCommentArea;
    }
    set hasComment(val) {
        this.showCommentArea = val;
    }
    /**
     * A value to assign to the `id` attribute of the rendered HTML element. A default `id` is generated automatically.
     */
    get id() {
        return this.getPropertyValue("id");
    }
    set id(val) {
        this.setPropertyValue("id", val);
    }
    get ariaTitleId() {
        return this.id + "_ariaTitle";
    }
    get ariaDescriptionId() {
        return this.id + "_ariaDescription";
    }
    get commentId() {
        return this.id + "_comment";
    }
    get requireUpdateCommentValue() { return this.hasComment; }
    get isReadOnly() {
        const isParentReadOnly = !!this.parent && this.parent.isReadOnly;
        const isPareQuestionReadOnly = !!this.parentQuestion && this.parentQuestion.isReadOnly;
        const isSurveyReadOnly = !!this.survey && this.survey.isDisplayMode;
        const callbackVal = !!this.readOnlyCallback && this.readOnlyCallback();
        return this.readOnly || isParentReadOnly || isSurveyReadOnly || isPareQuestionReadOnly || callbackVal;
    }
    get isInputReadOnly() {
        if (this.forceIsInputReadOnly !== undefined) {
            return this.forceIsInputReadOnly;
        }
        return this.isReadOnly || this.isDesignMode;
    }
    get renderedInputReadOnly() {
        return this.isInputReadOnly ? "" : undefined;
    }
    get renderedInputDisabled() {
        return this.isInputReadOnly ? "" : undefined;
    }
    get isReadOnlyAttr() {
        return this.isReadOnly;
    }
    get isDisabledAttr() {
        return this.isDesignMode || (!!this.readOnlyCallback && this.readOnlyCallback());
    }
    onReadOnlyChanged() {
        this.setPropertyValue("isInputReadOnly", this.isInputReadOnly);
        super.onReadOnlyChanged();
        if (this.isReadOnly) {
            this.clearErrors();
        }
        this.updateQuestionCss();
        this.resetRenderedCommentPlaceholder();
    }
    /**
     * A Boolean expression. If it evaluates to `false`, this question becomes read-only.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/how-to-conditionally-make-input-field-read-only/ (linkStyle))
     * @see readOnly
     * @see isReadOnly
     */
    get enableIf() {
        return this.getPropertyValue("enableIf", "");
    }
    set enableIf(val) {
        this.setPropertyValue("enableIf", val);
    }
    surveyChoiceItemVisibilityChange() { }
    runCondition(values, properties) {
        if (this.isDesignMode)
            return;
        if (!properties)
            properties = {};
        properties["question"] = this;
        this.runConditionCore(values, properties);
        if (!this.isValueChangedDirectly && (!this.isClearValueOnHidden || this.isVisibleInSurvey)) {
            this.defaultValueRunner = this.getDefaultRunner(this.defaultValueRunner, this.defaultValueExpression);
            this.runDefaultValueExpression(this.defaultValueRunner, values, properties);
        }
    }
    get isInDesignMode() {
        return !this.isContentElement && this.isDesignMode;
    }
    /**
     * A question number or letter (depends on the `questionStartIndex` property of the question container (panel, page, or survey)).
     *
     * When the question number, title, or the entire question is invisible, this property returns an empty string.
     * @see SurveyModel.questionStartIndex
     * @see showNumber
     * @see titleLocation
     * @see visibleIf
     */
    get no() {
        return this.getPropertyValue("no");
    }
    calcNo() {
        if (!this.hasTitle || !this.showNumber)
            return "";
        let parentIndex;
        if (!!this.parent) {
            parentIndex = this.parent.visibleIndex;
        }
        let no = Helpers.getNumberByIndex(this.visibleIndex, this.getStartIndex(), parentIndex);
        if (!!this.parent) {
            no = this.parent.addNoFromChild(no);
        }
        if (!!this.survey) {
            no = this.survey.getUpdatedQuestionNo(this, no);
        }
        return no;
    }
    getStartIndex() {
        if (!!this.parent)
            return this.parent.getQuestionStartIndex();
        if (!!this.survey)
            return this.survey.questionStartIndex;
        return "";
    }
    onSurveyLoad() {
        this.isCustomWidgetRequested = false;
        this.fireCallback(this.surveyLoadCallback);
        this.updateValueWithDefaults();
        if (this.isEmpty()) {
            this.initDataFromSurvey();
        }
    }
    onSetData() {
        super.onSetData();
        if (!this.isDesignMode && !!this.survey && !this.isLoadingFromJson) {
            this.initDataFromSurvey();
            this.onSurveyValueChanged(this.value);
            this.updateValueWithDefaults();
            this.updateIsAnswered();
        }
    }
    initDataFromSurvey() {
        if (!!this.data) {
            const val = this.data.getValue(this.getValueName());
            if (!Helpers.isValueEmpty(val) || !this.isLoadingFromJson) {
                this.updateValueFromSurvey(val);
            }
            this.initCommentFromSurvey();
        }
    }
    initCommentFromSurvey() {
        if (!!this.data && this.requireUpdateCommentValue) {
            this.updateCommentFromSurvey(this.data.getComment(this.getValueName()));
        }
        else {
            this.updateCommentFromSurvey("");
        }
    }
    runExpression(expression) {
        if (!this.survey || !expression)
            return undefined;
        return this.survey.runExpression(expression);
    }
    get commentAreaRows() {
        return this.survey && this.survey.commentAreaRows;
    }
    get autoGrowComment() {
        return this.survey && this.survey.autoGrowComment;
    }
    get allowResizeComment() {
        return this.survey && this.survey.allowResizeComment;
    }
    get questionValue() {
        return this.getPropertyValueWithoutDefault("value");
    }
    set questionValue(val) {
        this.setPropertyValue("value", val);
    }
    get questionComment() {
        return this.getPropertyValueWithoutDefault("comment");
    }
    set questionComment(val) {
        this.setPropertyValue("comment", val);
        this.fireCallback(this.commentChangedCallback);
    }
    get isValueArray() { return false; }
    /**
     * Gets or sets the question value.
     *
     * The following table illustrates how the value type depends on the question type:
     *
     * | Question type | Value type(s) |
     * | ------------- | ------------- |
     * | Checkboxes | <code>Array&lt;string &#124; number&gt;</code> |
     * | Dropdown | `string` \| `number` |
     * | Dynamic Matrix | `Array<object>` |
     * | Dynamic Panel | `Array<object>` |
     * | Expression | `string` \| `number` \| `boolean` |
     * | File Upload | `File` \| `Array<File>` |
     * | HTML | (no value) |
     * | Image | (no value) |
     * | Image Picker | <code>Array&lt;string &#124; number&gt;</code> |
     * | Long Text | `string` |
     * | Multi-Select Dropdown | <code>Array&lt;string &#124; number&gt;</code> |
     * | Multi-Select Matrix | `object` |
     * | Multiple Textboxes | `Array<string>` |
     * | Panel | (no value) |
     * | Radio Button Group | `string` \| `number` |
     * | Ranking | <code>Array&lt;string &#124; number&gt;</code> |
     * | Rating Scale | `number` \| `string` |
     * | Slider | <code>Array&lt;string &#124; number&gt;</code> |
     * | Signature | `string` (base64-encoded image) |
     * | Single-Line Input | `string` \| `number` \| `Date` |
     * | Single-Select Matrix | `object` |
     * | Yes/No (Boolean) | `boolean` \| `string` |
     */
    get value() {
        return this.getValueCore();
    }
    set value(newValue) {
        this.setNewValue(newValue);
    }
    get hasFilteredValue() { return false; }
    getFilteredValue() { return this.value; }
    getFilteredName() { return this.getValueName(); }
    get valueForSurvey() {
        return this.valueForSurveyCore(this.value);
    }
    valueForSurveyCore(val) {
        if (!!this.valueToDataCallback) {
            return this.valueToDataCallback(val);
        }
        return val;
    }
    valueFromDataCore(val) {
        if (!!this.valueFromDataCallback) {
            return this.valueFromDataCallback(val);
        }
        return val;
    }
    /**
     * Sets the question's `value` and `comment` properties to `undefined`.
     * @see value
     * @see comment
     */
    clearValue(keepComment) {
        if (this.value !== undefined) {
            this.value = undefined;
        }
        if (!!this.comment && keepComment !== true) {
            this.comment = undefined;
        }
        this.setValueChangedDirectly(false);
    }
    clearValueOnly() {
        this.clearValue(true);
    }
    unbindValue() {
        this.clearValue();
    }
    createValueCopy() {
        return this.getUnbindValue(this.value);
    }
    initDataUI() { }
    getUnbindValue(value) {
        if (this.isValueSurveyElement(value))
            return value;
        return Helpers.getUnbindValue(value);
    }
    isValueSurveyElement(val) {
        if (!val)
            return false;
        if (Array.isArray(val))
            return val.length > 0 ? this.isValueSurveyElement(val[0]) : false;
        return val.isSurveyObj === true;
    }
    canClearValueAsInvisible(reason) {
        if (reason === "onHiddenContainer" && !this.isParentVisible)
            return true;
        if (this.isVisibleInSurvey)
            return false;
        if (!!this.page && this.page.isStartPage)
            return false;
        if (!this.survey)
            return true;
        return !this.survey.hasVisibleQuestionByValueName(this.getValueName());
    }
    /**
     * Returns `true` if a parent element (page or panel) is visible.
     */
    get isParentVisible() {
        if (this.parentQuestion && !this.parentQuestion.isVisible)
            return false;
        var parent = this.parent;
        while (parent) {
            if (!parent.isVisible)
                return false;
            parent = parent.parent;
        }
        return true;
    }
    clearValueIfInvisible(reason = "onHidden") {
        const clearIf = this.getClearIfInvisible();
        if (clearIf === "none")
            return;
        if (reason === "onHidden" && clearIf === "onComplete")
            return;
        if (reason === "onHiddenContainer" && clearIf !== reason)
            return;
        this.clearValueIfInvisibleCore(reason);
    }
    clearValueIfInvisibleCore(reason) {
        if (this.canClearValueAsInvisible(reason)) {
            this.clearValue();
        }
    }
    /**
     * Specifies when to clear the question value if the question becomes invisible.
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the Survey's [`clearInvisibleValues`](https://surveyjs.io/form-library/documentation/surveymodel#clearInvisibleValues) property.
     * - `"onHidden"` - Clears the value when the question becomes invisible. If a question is invisible on startup and has an initial value, this value will be cleared when the survey is complete.
     * - `"onHiddenContainer"` - Clears the value when the question or its container (page or panel) becomes invisible. If a question is invisible on startup and has an initial value, this value will be cleared when the survey is complete.
     * - `"onComplete"` - Clears the value when the survey is complete.
     * - `"none"` - Never clears the value of an invisible question.
     * @see SurveyModel.clearInvisibleValues
     * @see visible
     * @see SurveyModel.onComplete
     */
    get clearIfInvisible() {
        return this.getPropertyValue("clearIfInvisible");
    }
    set clearIfInvisible(val) {
        this.setPropertyValue("clearIfInvisible", val);
    }
    getClearIfInvisible() {
        const res = this.clearIfInvisible;
        if (!!this.survey)
            return this.survey.getQuestionClearIfInvisible(res);
        return res !== "default" ? res : "onComplete";
    }
    get displayValue() {
        if (this.isLoadingFromJson)
            return "";
        return this.getDisplayValue(true);
    }
    /**
     * Returns a display text that corresponds to the question value. For example, if you call this method for a Dropdown question, it returns an item text instead of an item value.
     * @param keysAsText Applies when the question value is an object (in Matrix, Multiple Text, and similar questions). Pass `true` if not only values in the object should be display texts, but also keys. Default value: `false`.
     * @param value Specify this parameter to get a display text for a specific value, not for the current question value. If the question value is an object, this parameter should be a similar object.
     */
    getDisplayValue(keysAsText, value = undefined) {
        var res = this.calcDisplayValue(keysAsText, value);
        if (this.survey) {
            res = this.survey.getQuestionDisplayValue(this, res);
        }
        return !!this.displayValueCallback ? this.displayValueCallback(res) : res;
    }
    calcDisplayValue(keysAsText, value = undefined) {
        if (this.customWidget) {
            var res = this.customWidget.getDisplayValue(this, value);
            if (res)
                return res;
        }
        value = value == undefined ? this.createValueCopy() : value;
        if (this.isValueEmpty(value) && !this.locDefaultDisplayValue.isEmpty) {
            value = this.defaultDisplayValue;
        }
        if (this.isValueEmpty(value, !this.allowSpaceAsAnswer))
            return this.getDisplayValueEmpty();
        return this.getDisplayValueCore(keysAsText, value);
    }
    getDisplayValueCore(keyAsText, value) {
        return value;
    }
    getDisplayValueEmpty() {
        return "";
    }
    /**
     * A default value for the question. Ignored for question types that cannot have a [value](https://surveyjs.io/form-library/documentation/question#value) (for example, HTML).
     *
     * The default value is used as a question value in the following cases:
     *
     * - While the survey is being loaded from JSON.
     * - The question is just added to the survey and does not yet have an answer.
     * - The respondent left the answer empty.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/specify-default-question-value-dynamically (linkStyle))
     * @see defaultValueExpression
     */
    get defaultValue() {
        return this.getPropertyValue("defaultValue");
    }
    set defaultValue(val) {
        if (this.isValueExpression(val)) {
            this.defaultValueExpression = val.substring(1);
            return;
        }
        this.setPropertyValue("defaultValue", this.convertDefaultValue(val));
        this.updateValueWithDefaults();
    }
    /**
     * An expression used to calculate the [`defaultValue`](https://surveyjs.io/form-library/documentation/question#defaultValue).
     *
     * This expression applies until the question [`value`](https://surveyjs.io/form-library/documentation/question#value) is specified by an end user or programmatically.
     *
     * An expression can reference other questions as follows:
     *
     * - `{other_question_name}`
     * - `{panel.other_question_name}` (to access questions inside the same dynamic panel)
     * - `{row.other_question_name}` (to access questions inside the same dynamic matrix or multi-column dropdown)
     *
     * An expression can also include built-in and custom functions for advanced calculations. For example, if the `defaultValue` should be today's date, set the `defaultValueExpression` to `"today()"`, and the corresponding built-in function will be executed each time the survey is loaded. Refer to the following help topic for more information: [Built-In Functions](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#built-in-functions).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/specify-default-question-value-dynamically (linkStyle))
     * @see defaultValue
     * @see setValueExpression
     */
    get defaultValueExpression() {
        return this.getPropertyValue("defaultValueExpression");
    }
    set defaultValueExpression(val) {
        this.setPropertyValue("defaultValueExpression", val);
        this.defaultValueRunner = undefined;
        this.updateValueWithDefaults();
    }
    /**
     * A Boolean [expression](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions). If it evaluates to `true`, the question value is reset to [default](#defaultValue).
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/set-question-value-dynamically/ (linkStyle))
     * @see setValueIf
     */
    get resetValueIf() {
        return this.getPropertyValue("resetValueIf");
    }
    set resetValueIf(val) {
        this.setPropertyValue("resetValueIf", val);
    }
    /**
     * A Boolean [expression](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions). If it evaluates to `true`, the question value is set to a value calculated using the [`setValueExpression`](#setValueExpression).
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/set-question-value-dynamically/ (linkStyle))
     * @see resetValueIf
     */
    get setValueIf() {
        return this.getPropertyValue("setValueIf");
    }
    set setValueIf(val) {
        this.setPropertyValue("setValueIf", val);
    }
    /**
     * An [expression](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions) that calculates the question value.
     *
     * The `setValueExpression` is re-evaluated whenever a referenced question's value changes. If you also specify the [`setValueIf`](#setValueIf) expression, re-evaluation occurs only when it returns `true`.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/set-question-value-dynamically/ (linkStyle))
     * @see defaultValueExpression
     * @see resetValueIf
     */
    get setValueExpression() {
        return this.getPropertyValue("setValueExpression");
    }
    set setValueExpression(val) {
        this.setPropertyValue("setValueExpression", val);
    }
    get resizeStyle() {
        return this.allowResizeComment ? "both" : "none";
    }
    /**
     * Returns the question value as an object in which the question name, title, value, and other parameters are stored as individual properties.
     *
     * If the question can have more than one value (Matrix, Multiple Text), the object enables the `isNode` flag and stores information about these values in the `data` property. Refer to the following help topic for more information: [Access Full Survey Results](https://surveyjs.io/form-library/documentation/handle-survey-results-access#access-full-survey-results).
     *
     * Pass an object with the `includeEmpty` property set to `false` if you want to skip empty answers.
     */
    getPlainData(options) {
        if (!options) {
            options = { includeEmpty: true, includeQuestionTypes: false };
        }
        if (options.includeEmpty || !this.isEmpty()) {
            var questionPlainData = {
                name: this.name,
                title: this.locTitle.renderedHtml,
                value: this.value,
                displayValue: this.displayValue,
                isNode: false,
                getString: (val) => typeof val === "object" ? JSON.stringify(val) : val,
            };
            if (options.includeQuestionTypes === true) {
                questionPlainData.questionType = this.getType();
            }
            (options.calculations || []).forEach((calculation) => {
                questionPlainData[calculation.propertyName] = this.getPlainDataCalculatedValue(calculation.propertyName);
            });
            if (this.hasComment) {
                questionPlainData.isNode = true;
                questionPlainData.data = [
                    {
                        name: 0,
                        isComment: true,
                        title: "Comment",
                        value: settings.commentSuffix,
                        displayValue: this.comment,
                        getString: (val) => typeof val === "object" ? JSON.stringify(val) : val,
                        isNode: false,
                    },
                ];
            }
            return questionPlainData;
        }
        return undefined;
    }
    getPlainDataCalculatedValue(propName) {
        return this[propName];
    }
    /**
     * A correct answer to this question. Specify this property if you want to [create a quiz](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/make-quiz-javascript/ (linkStyle))
     * @see SurveyModel.getCorrectAnswerCount
     * @see SurveyModel.getIncorrectAnswerCount
     */
    get correctAnswer() {
        return this.getPropertyValue("correctAnswer");
    }
    set correctAnswer(val) {
        this.setPropertyValue("correctAnswer", this.convertDefaultValue(val));
    }
    convertDefaultValue(val) {
        return val;
    }
    /**
     * The number of quiz questions. A question counts if it is visible, has an input field, and specifies `correctAnswer`.
     * @see [Create a Quiz](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz)
     * @see correctAnswer
     * @see SurveyModel.getQuizQuestions
     */
    get quizQuestionCount() {
        if (this.isVisible &&
            this.hasInput &&
            !this.isValueEmpty(this.correctAnswer))
            return this.getQuizQuestionCount();
        return 0;
    }
    get correctAnswerCount() {
        if (!this.isEmpty() && !this.isValueEmpty(this.correctAnswer))
            return this.getCorrectAnswerCount();
        return 0;
    }
    getQuizQuestionCount() {
        return 1;
    }
    getCorrectAnswerCount() {
        return this.checkIfAnswerCorrect() ? 1 : 0;
    }
    checkIfAnswerCorrect() {
        const isEqual = Helpers.isTwoValueEquals(this.value, this.correctAnswer, this.getAnswerCorrectIgnoreOrder(), settings.comparator.caseSensitive, true);
        const correct = isEqual ? 1 : 0;
        const incorrect = this.quizQuestionCount - correct;
        const options = {
            result: isEqual,
            correctAnswers: correct,
            correctAnswerCount: correct,
            incorrectAnswers: incorrect,
            incorrectAnswerCount: incorrect,
        };
        if (!!this.survey) {
            this.survey.onCorrectQuestionAnswer(this, options);
        }
        return options.result;
    }
    getAnswerCorrectIgnoreOrder() { return false; }
    /**
    * Returns `true` if a question answer matches the [`correctAnswer`](#correctAnswer) property value.
    *
    * [View Demo](https://surveyjs.io/form-library/examples/create-a-scored-quiz (linkStyle))
    * @see SurveyModel.getQuizQuestions
    */
    isAnswerCorrect() {
        return this.correctAnswerCount == this.quizQuestionCount;
    }
    updateValueWithDefaults() {
        if (this.isLoadingFromJson || (!this.isDesignMode && this.isDefaultValueEmpty()))
            return;
        if (!this.isDesignMode && !this.isEmpty())
            return;
        if (this.isEmpty() && this.isDefaultValueEmpty())
            return;
        if (this.isClearValueOnHidden && !this.isVisible)
            return;
        if (this.isDesignMode && this.isContentElement && this.isDefaultValueEmpty())
            return;
        this.setDefaultValue();
    }
    get isValueDefault() {
        return !this.isEmpty() && (this.isTwoValueEquals(this.defaultValue, this.value) || !this.isValueChangedDirectly && !!this.defaultValueExpression);
    }
    get isClearValueOnHidden() {
        const clearIf = this.getClearIfInvisible();
        if (clearIf === "none" || clearIf === "onComplete")
            return false;
        return clearIf === "onHidden" || clearIf === "onHiddenContainer";
    }
    getQuestionFromArray(name, index) {
        return null;
    }
    getDefaultValue() {
        return this.defaultValue;
    }
    isDefaultValueEmpty() {
        return !this.defaultValueExpression && this.isValueEmpty(this.defaultValue, !this.allowSpaceAsAnswer);
    }
    getDefaultRunner(runner, expression) {
        if (!runner && !!expression) {
            runner = this.createExpressionRunner(expression);
        }
        if (!!runner) {
            runner.expression = expression;
        }
        return runner;
    }
    setDefaultValue() {
        this.setDefaultValueCore((val) => {
            if (!this.isTwoValueEquals(this.value, val)) {
                this.value = val;
            }
        });
    }
    setDefaultValueCore(func) {
        this.defaultValueRunner = this.getDefaultRunner(this.defaultValueRunner, this.defaultValueExpression);
        this.setValueAndRunExpression(this.defaultValueRunner, this.getUnbindValue(this.defaultValue), (val) => func(val));
    }
    updateValueWithDefaultsOrClear() {
        if (this.isDesignMode || this.isLoadingFromJson)
            return;
        if (this.isDefaultValueEmpty()) {
            this.clearValue();
        }
        else {
            this.setDefaultValue();
        }
    }
    isValueExpression(val) {
        return !!val && typeof val == "string" && val.length > 0 && val[0] == "=";
    }
    setValueAndRunExpression(runner, defaultValue, setFunc, values = null, properties = null) {
        const func = (val) => {
            this.runExpressionSetValueCore(val, setFunc);
        };
        if (!this.runDefaultValueExpression(runner, values, properties, func)) {
            func(defaultValue);
        }
    }
    convertFuncValuetoQuestionValue(val) {
        return Helpers.convertValToQuestionVal(val);
    }
    runExpressionSetValueCore(val, setFunc) {
        setFunc(this.convertFuncValuetoQuestionValue(val));
    }
    runExpressionSetValue(val) {
        this.runExpressionSetValueCore(val, (val) => {
            if (!this.isTwoValueEquals(this.value, val)) {
                this.startSetValueOnExpression();
                this.value = val;
                this.finishSetValueOnExpression();
            }
        });
    }
    startSetValueOnExpression() {
        var _a;
        (_a = this.survey) === null || _a === void 0 ? void 0 : _a.startSetValueOnExpression();
    }
    finishSetValueOnExpression() {
        var _a;
        (_a = this.survey) === null || _a === void 0 ? void 0 : _a.finishSetValueOnExpression();
    }
    runDefaultValueExpression(runner, values = null, properties = null, setFunc) {
        if (!runner || !this.data)
            return false;
        if (!setFunc) {
            setFunc = (val) => {
                this.runExpressionSetValue(val);
            };
        }
        if (!values)
            values = this.defaultValueExpression ? this.data.getFilteredValues() : {};
        if (!properties) {
            properties = this.defaultValueExpression ? this.data.getFilteredProperties() : {};
            properties["question"] = this;
        }
        if (!!runner && runner.canRun) {
            runner.onRunComplete = (res) => {
                if (res == undefined)
                    res = this.defaultValue;
                this.isChangingViaDefaultValue = true;
                setFunc(res);
                this.isChangingViaDefaultValue = false;
            };
            runner.run(values, properties);
        }
        return true;
    }
    /**
     * A comment to the selected question value. Enable the `showCommentArea` property to allow users to leave comments.
     * @see showCommentArea
     * @see commentText
     */
    get comment() {
        return this.getQuestionComment();
    }
    set comment(newValue) {
        if (!!newValue) {
            const trimmedValue = newValue.toString().trim();
            if (trimmedValue !== newValue) {
                newValue = trimmedValue;
                if (newValue === this.comment) {
                    this.setPropertyValueDirectly("comment", newValue);
                }
            }
        }
        if (this.comment == newValue)
            return;
        this.setQuestionComment(newValue);
        this.updateCommentElements();
    }
    getCommentAreaCss(isOther = false) {
        return new CssClassBuilder()
            .append("form-group", isOther)
            .append(this.cssClasses.formGroup, !isOther)
            .append(this.cssClasses.commentArea)
            .toString();
    }
    getQuestionComment() {
        return this.questionComment;
    }
    setQuestionComment(newValue) {
        this.setNewComment(newValue);
    }
    /**
     * Returns `true` if the question value is an empty string, array, or object or if it equals `undefined` or `null`.
     */
    isEmpty() {
        return this.isValueEmpty(this.value, !this.allowSpaceAsAnswer);
    }
    get isAnswered() {
        return this.getPropertyValue("isAnswered") || false;
    }
    set isAnswered(val) {
        this.setPropertyValue("isAnswered", val);
    }
    updateIsAnswered() {
        const oldVal = this.isAnswered;
        this.setPropertyValue("isAnswered", this.getIsAnswered());
        if (oldVal !== this.isAnswered) {
            this.updateQuestionCss();
        }
    }
    getIsAnswered() {
        return !this.isEmpty();
    }
    /**
     * Question validators.
     *
     * [Data Validation](https://surveyjs.io/form-library/documentation/data-validation (linkStyle))
     */
    get validators() {
        return this.getPropertyValue("validators");
    }
    set validators(val) {
        this.setPropertyValue("validators", val);
    }
    getValidators() {
        return this.validators;
    }
    getSupportedValidators() {
        var res = [];
        var className = this.getType();
        while (!!className) {
            var classValidators = settings.supportedValidators[className];
            if (!!classValidators) {
                for (var i = classValidators.length - 1; i >= 0; i--) {
                    res.splice(0, 0, classValidators[i]);
                }
            }
            var classInfo = Serializer.findClass(className);
            className = classInfo.parentName;
        }
        return res;
    }
    addConditionObjectsByContext(objects, context) {
        objects.push({
            name: this.getFilteredName(),
            text: this.processedTitle,
            question: this,
        });
    }
    /**
     * Returns an array of questions nested within the current question. Use this method to obtain questions within [Multiple Text](https://surveyjs.io/form-library/documentation/api-reference/multiple-text-entry-question-model), [Dynamic Panel](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model), and [Matrix](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-question-model)-like questions.
     * @param visibleOnly A Boolean value that specifies whether to include only visible nested questions.
     * @returns An array of nested questions.
     */
    getNestedQuestions(visibleOnly = false, includeNested = true, includeItSelf = false) {
        const res = [];
        this.collectNestedQuestions(res, visibleOnly, includeNested, includeItSelf);
        if (!includeItSelf && res.length === 1 && res[0] === this)
            return [];
        return res;
    }
    collectNestedQuestions(questions, visibleOnly = false, includeNested = true, includeItSelf = false) {
        if (visibleOnly && !this.isVisible)
            return;
        this.collectNestedQuestionsCore(questions, visibleOnly, includeNested, includeItSelf);
    }
    collectNestedQuestionsCore(questions, visibleOnly, includeNested, includeItSelf) {
        questions.push(this);
    }
    addNestedQuestion(questions, visibleOnly, includeNested, includeItSelf) {
        if (includeNested) {
            this.collectNestedQuestions(questions, visibleOnly, includeNested, includeItSelf);
        }
        else {
            if (!visibleOnly || this.isVisible) {
                questions.push(this);
            }
        }
    }
    getConditionJson(operator = null, path = null) {
        const json = new JsonObject().toJsonObject(this);
        json["type"] = this.getType();
        return json;
    }
    hasErrors(fireCallback = true, rec = null) {
        const errors = this.checkForErrors(!!rec && rec.isOnValueChanged === true, fireCallback);
        if (fireCallback) {
            this.errors = errors;
            if (this.errors !== errors) {
                this.errors.forEach(er => er.locText.strChanged());
            }
        }
        this.updateContainsErrors();
        if (this.isCollapsed && rec && fireCallback && errors.length > 0) {
            this.expand();
        }
        return errors.length > 0;
    }
    /**
     * Validates this question and returns `false` if the validation fails.
     * @param fireCallback *(Optional)* Pass `false` if you do not want to show validation errors in the UI.
     * @see [Data Validation](https://surveyjs.io/form-library/documentation/data-validation)
     */
    validate(fireCallback = true, rec = null) {
        if (!!rec && rec.isOnValueChanged) {
            if (!!this.parent) {
                this.parent.validateContainerOnly();
            }
        }
        return !this.hasErrors(fireCallback, rec);
    }
    get currentErrorCount() {
        return this.errors.length;
    }
    /**
     * Returns a character or text string that indicates a required question.
     * @see SurveyModel.requiredMark
     * @see isRequired
     */
    get requiredMark() {
        return this.survey != null && this.isRequired
            ? this.survey.requiredMark
            : "";
    }
    /**
     * @deprecated Use the [`requiredMark`](https://surveyjs.io/form-library/documentation/api-reference/question#requiredMark) property instead.
     */
    get requiredText() {
        return this.requiredMark;
    }
    addError(error) {
        if (!error)
            return;
        let newError = null;
        if (typeof error === "string" || error instanceof String) {
            newError = this.addCustomError(error);
        }
        else {
            newError = error;
        }
        this.errors.push(newError);
    }
    addCustomError(error) {
        return new CustomError(error, this.survey);
    }
    removeError(error) {
        if (!error)
            return false;
        const errors = this.errors;
        const index = errors.indexOf(error);
        if (index !== -1)
            errors.splice(index, 1);
        return index !== -1;
    }
    checkForErrors(isOnValueChanged, fireCallback) {
        var qErrors = new Array();
        if (this.isVisible && this.canCollectErrors()) {
            this.collectErrors(qErrors, isOnValueChanged, fireCallback);
        }
        if (!!this.survey) {
            if (this.validateValueCallback && qErrors.length === 0) {
                const error = this.validateValueCallback();
                if (error) {
                    qErrors.push(error);
                }
            }
            this.survey.validateQuestion(this, qErrors, fireCallback);
        }
        return qErrors;
    }
    canCollectErrors() {
        return !this.isReadOnly || settings.readOnly.enableValidation;
    }
    collectErrors(qErrors, isOnValueChanged, fireCallback) {
        this.onCheckForErrors(qErrors, isOnValueChanged, fireCallback);
        if (qErrors.length > 0 || !this.canRunValidators(isOnValueChanged))
            return;
        var errors = this.runValidators();
        if (errors.length > 0) {
            //validators may change the question value.
            qErrors.length = 0;
            for (var i = 0; i < errors.length; i++) {
                qErrors.push(errors[i]);
            }
        }
    }
    canRunValidators(isOnValueChanged) {
        return true;
    }
    onCheckForErrors(errors, isOnValueChanged, fireCallback) {
        if ((!isOnValueChanged || this.isOldAnswered) && this.hasRequiredError()) {
            const err = new AnswerRequiredError(this.requiredErrorText, this);
            err.onUpdateErrorTextCallback = (err) => { err.text = this.requiredErrorText; };
            errors.push(err);
        }
        if (!this.isEmpty() && this.customWidget) {
            const text = this.customWidget.validate(this);
            if (!!text) {
                errors.push(this.addCustomError(text));
            }
        }
    }
    hasRequiredError() {
        return this.isRequired && this.isEmpty();
    }
    get isRunningValidators() {
        return this.getIsRunningValidators();
    }
    getIsRunningValidators() {
        return this.isRunningValidatorsValue;
    }
    runValidators() {
        if (!!this.validatorRunner) {
            this.validatorRunner.onAsyncCompleted = null;
        }
        this.validatorRunner = new ValidatorRunner();
        this.isRunningValidatorsValue = true;
        this.validatorRunner.onAsyncCompleted = (errors) => {
            this.doOnAsyncCompleted(errors);
        };
        return this.validatorRunner.run(this);
    }
    doOnAsyncCompleted(errors) {
        for (var i = 0; i < errors.length; i++) {
            this.errors.push(errors[i]);
        }
        this.isRunningValidatorsValue = false;
        this.raiseOnCompletedAsyncValidators();
    }
    raiseOnCompletedAsyncValidators() {
        if (!!this.onCompletedAsyncValidators && !this.isRunningValidators) {
            this.onCompletedAsyncValidators(this.getAllErrors().length > 0);
            this.onCompletedAsyncValidators = null;
        }
    }
    setNewValue(newValue) {
        if (this.isNewValueEqualsToValue(newValue))
            return;
        if (!this.checkIsValueCorrect(newValue))
            return;
        this.isOldAnswered = this.isAnswered;
        this.isSettingQuestionValue = true;
        this.setNewValueInData(newValue);
        this.allowNotifyValueChanged && this.onValueChanged();
        this.isSettingQuestionValue = false;
        if (this.isAnswered !== this.isOldAnswered) {
            this.updateQuestionCss();
        }
        this.isOldAnswered = undefined;
        if (this.parent) {
            this.parent.onQuestionValueChanged(this);
        }
    }
    checkIsValueCorrect(val) {
        const res = this.isValueEmpty(val, !this.allowSpaceAsAnswer) || this.isNewValueCorrect(val);
        if (!res) {
            ConsoleWarnings.inCorrectQuestionValue(this.name, val);
        }
        return res;
    }
    isNewValueCorrect(val) {
        return true;
    }
    isNewValueEqualsToValue(newValue) {
        const val = this.value;
        if (!this.isTwoValueEquals(newValue, val, false, false))
            return false;
        const isObj = newValue === val && !!val && (Array.isArray(val) || typeof val === "object");
        return !isObj;
    }
    isTextValue() {
        return false;
    }
    getIsInputTextUpdate() {
        return !!this.survey ? this.survey.isUpdateValueTextOnTyping : false;
    }
    get requireStrictCompare() { return false; }
    getExpressionValue(val) { return val; }
    getDataLocNotification() {
        return this.isInputTextUpdate ? "text" : false;
    }
    get isInputTextUpdate() {
        return this.getIsInputTextUpdate() && this.isTextValue();
    }
    setNewValueInData(newValue) {
        newValue = this.valueToData(newValue);
        if (!this.isValueChangedInSurvey) {
            this.setValueCore(newValue);
        }
    }
    getValueCore() {
        return this.questionValue;
    }
    setValueCore(newValue) {
        this.setQuestionValue(newValue);
        if (this.data != null && this.canSetValueToSurvey()) {
            newValue = this.valueForSurvey;
            this.data.setValue(this.getValueName(), newValue, this.getDataLocNotification(), this.allowNotifyValueChanged, this.name);
        }
        this.isMouseDown = false;
    }
    canSetValueToSurvey() {
        return true;
    }
    valueFromData(val) { return val; }
    valueToData(val) { return val; }
    convertToCorrectValue(val) { return val; }
    onValueChanged() { }
    onMouseDown() {
        this.isMouseDown = true;
    }
    setNewComment(newValue) {
        if (this.questionComment === newValue)
            return;
        this.questionComment = newValue;
        this.setCommentIntoData(newValue);
    }
    setCommentIntoData(newValue) {
        if (this.data != null) {
            this.data.setComment(this.getValueName(), newValue, this.getIsInputTextUpdate() ? "text" : false);
        }
    }
    getValidName(name) {
        return makeNameValid(name);
    }
    //IQuestion
    updateValueFromSurvey(newValue, clearData = false) {
        newValue = this.getUnbindValue(newValue);
        newValue = this.valueFromDataCore(newValue);
        if (!this.checkIsValueCorrect(newValue))
            return;
        const isEmpty = this.isValueEmpty(newValue);
        if (!isEmpty && this.defaultValueExpression) {
            this.setDefaultValueCore((val) => {
                this.updateValueFromSurveyCore(newValue, this.isTwoValueEquals(newValue, val));
            });
        }
        else {
            this.updateValueFromSurveyCore(newValue, this.data !== this.getSurvey());
            if (clearData && isEmpty) {
                this.isValueChangedDirectly = false;
            }
        }
        this.updateDependedQuestions();
        this.updateIsAnswered();
    }
    updateValueFromSurveyCore(newValue, viaDefaultVal) {
        this.isChangingViaDefaultValue = viaDefaultVal;
        newValue = this.valueFromData(newValue);
        const isEqual = this.isTwoValueEquals(this.questionValue, this.convertToCorrectValue(newValue));
        this.setQuestionValue(newValue);
        if (!isEqual) {
            this.resetSingleInput();
        }
        this.isChangingViaDefaultValue = false;
    }
    updateCommentFromSurvey(newValue) {
        this.questionComment = newValue;
    }
    onChangeQuestionValue(newValue) { }
    setValueChangedDirectly(val) {
        this.isValueChangedDirectly = val;
        if (!!this.setValueChangedDirectlyCallback) {
            this.setValueChangedDirectlyCallback(val);
        }
    }
    setQuestionValue(newValue, updateIsAnswered = true) {
        newValue = this.convertToCorrectValue(newValue);
        const isEqual = this.isTwoValueEquals(this.questionValue, newValue);
        if (!isEqual && !this.isChangingViaDefaultValue && !this.isParentChangingViaDefaultValue) {
            this.setValueChangedDirectly(true);
        }
        this.questionValue = newValue;
        if (!isEqual) {
            this.onChangeQuestionValue(newValue);
        }
        !isEqual && this.allowNotifyValueChanged &&
            this.fireCallback(this.valueChangedCallback);
        if (updateIsAnswered)
            this.updateIsAnswered();
    }
    get isParentChangingViaDefaultValue() {
        var _a;
        return ((_a = this.data) === null || _a === void 0 ? void 0 : _a.isChangingViaDefaultValue) === true;
    }
    onSurveyValueChanged(newValue) { }
    setVisibleIndex(val) {
        if (val > -1 && (!this.isVisible ||
            (!this.hasTitle && !settings.numbering.includeQuestionsWithHiddenTitle) ||
            (!this.showNumber && !settings.numbering.includeQuestionsWithHiddenNumber))) {
            val = -1;
        }
        this.setPropertyValue("visibleIndex", val);
        this.setPropertyValue("no", this.calcNo());
        return val < 0 ? 0 : 1;
    }
    removeElement(element) {
        return false;
    }
    // Obsolete
    supportGoNextPageAutomatic() { return this.supportAutoAdvance(); }
    supportAutoAdvance() {
        return false;
    }
    supportGoNextPageError() {
        return true;
    }
    /**
     * Removes values that cannot be assigned to this question, for example, choices unlisted in the `choices` array.
     *
     * Call this method after you assign new question values in code to ensure that they are acceptable.
     *
     * > This method does not remove values that fail validation. Call the `validate()` method to validate newly assigned values.
     *
     * @see validate
     */
    clearIncorrectValues() { }
    clearOnDeletingContainer() { }
    /**
     * Empties the `errors` array.
     * @see errors
     */
    clearErrors() {
        this.errors = [];
    }
    clearUnusedValues() { }
    onAnyValueChanged(name, questionName) { }
    checkBindings(valueName, value) {
        if (this.bindings.isEmpty() || !this.data)
            return;
        var props = this.bindings.getPropertiesByValueName(valueName);
        for (var i = 0; i < props.length; i++) {
            const propName = props[i];
            if (this.isValueEmpty(value) && Helpers.isNumber(this[propName])) {
                value = 0;
            }
            this.updateBindingProp(propName, value);
        }
    }
    updateBindingProp(propName, value) {
        this[propName] = value;
    }
    getComponentName() {
        return RendererFactory.Instance.getRendererByQuestion(this);
    }
    isDefaultRendering() {
        return (!!this.customWidget ||
            this.getComponentName() === "default");
    }
    get renderAs() { return this.getPropertyValue("renderAs"); }
    set renderAs(val) { this.setPropertyValue("renderAs", val); }
    get inMatrixMode() { return this.getPropertyValue("inMatrixMode", false); }
    set inMatrixMode(val) { this.setPropertyValue("inMatrixMode", val); }
    //ISurveyErrorOwner
    getErrorCustomText(text, error) {
        if (!!this.survey)
            return this.survey.getSurveyErrorCustomText(this, text, error);
        return text;
    }
    //IValidatorOwner
    getValidatorTitle() {
        return null;
    }
    get validatedValue() {
        return this.value;
    }
    set validatedValue(val) {
        this.value = val;
    }
    getAllValues() {
        return !!this.data ? this.data.getAllValues() : null;
    }
    processPopupVisiblilityChanged(popupModel, visible) {
        this.survey.processPopupVisiblityChanged(this, popupModel, visible);
    }
    processOpenDropdownMenu(options) {
        this.survey.processOpenDropdownMenu(this, options);
    }
    onTextKeyDownHandler(event) {
        if (event.keyCode === 13) {
            this.survey.questionEditFinishCallback(this, event);
        }
    }
    transformToMobileView() { }
    transformToDesktopView() { }
    needResponsiveWidth() {
        return false;
    }
    //responsiveness methods
    supportResponsiveness() {
        return false;
    }
    needResponsiveness() {
        return this.supportResponsiveness() && !this.isDesignMode;
    }
    checkForResponsiveness(el) {
        if (this.needResponsiveness()) {
            if (this.isCollapsed) {
                const onStateChanged = () => {
                    if (this.isExpanded) {
                        this.initResponsiveness(el);
                        this.unregisterPropertyChangedHandlers(["state"], "for-responsiveness");
                    }
                };
                this.registerPropertyChangedHandlers(["state"], onStateChanged, "for-responsiveness");
            }
            else {
                this.initResponsiveness(el);
            }
        }
    }
    getObservedElementSelector() {
        return ".sd-scrollable-container";
    }
    onMobileChanged() {
        this.onMobileChangedCallback && this.onMobileChangedCallback();
    }
    triggerResponsiveness(hard = true) {
        if (this.triggerResponsivenessCallback) {
            this.triggerResponsivenessCallback(hard);
        }
    }
    initResponsiveness(el) {
        if (!DomDocumentHelper.isAvailable()) {
            return;
        }
        this.destroyResizeObserver();
        if (!!el && this.isDefaultRendering()) {
            const scrollableSelector = this.getObservedElementSelector();
            if (!scrollableSelector)
                return;
            const defaultRootEl = el.querySelector(scrollableSelector);
            if (!defaultRootEl)
                return;
            let isProcessed = false;
            let requiredWidth = undefined;
            this.triggerResponsivenessCallback = (hard) => {
                if (hard) {
                    requiredWidth = undefined;
                    this.renderAs = "default";
                    isProcessed = false;
                }
                const callback = () => {
                    const rootEl = el.querySelector(scrollableSelector);
                    if (this.isDefaultRendering()) {
                        requiredWidth = rootEl.scrollWidth;
                    }
                    if (isProcessed || !isContainerVisible(rootEl)) {
                        isProcessed = false;
                    }
                    else {
                        const availableWidth = getElementWidth(rootEl);
                        isProcessed = this.processResponsiveness(requiredWidth, availableWidth);
                    }
                };
                if (hard) {
                    setTimeout(callback, 1);
                }
                else {
                    callback();
                }
            };
            this.resizeObserver = new ResizeObserver((entries) => {
                DomWindowHelper.requestAnimationFrame(() => {
                    this.triggerResponsiveness(false);
                });
            });
            this.onMobileChangedCallback = () => {
                setTimeout(() => {
                    const rootEl = el.querySelector(scrollableSelector);
                    this.processResponsiveness(requiredWidth, getElementWidth(rootEl));
                }, 0);
            };
            this.resizeObserver.observe(el);
        }
    }
    getCompactRenderAs() {
        return "default";
    }
    getDesktopRenderAs() {
        return "default";
    }
    onBeforeSetCompactRenderer() { }
    onBeforeSetDesktopRenderer() { }
    processResponsiveness(requiredWidth, availableWidth) {
        availableWidth = Math.round(availableWidth);
        if (Math.abs(requiredWidth - availableWidth) > 2) {
            const oldRenderAs = this.renderAs;
            if (requiredWidth > availableWidth) {
                this.onBeforeSetCompactRenderer();
                this.renderAs = this.getCompactRenderAs();
            }
            else {
                this.onBeforeSetDesktopRenderer();
                this.renderAs = this.getDesktopRenderAs();
            }
            return oldRenderAs !== this.renderAs;
        }
        return false;
    }
    destroyResizeObserver() {
        if (!!this.resizeObserver) {
            this.resizeObserver.disconnect();
            this.resizeObserver = undefined;
            this.onMobileChangedCallback = undefined;
            this.triggerResponsivenessCallback = undefined;
            this.renderAs = this.getDesktopRenderAs();
        }
    }
    dispose() {
        super.dispose();
        this.resetDependedQuestions();
        this.destroyResizeObserver();
    }
    resetDependedQuestions() {
        for (var i = 0; i < this.dependedQuestions.length; i++) {
            this.dependedQuestions[i].resetDependedQuestion();
        }
    }
    //a11y
    get isNewA11yStructure() {
        return false;
    }
    get ariaLabel() {
        if (this.isNewA11yStructure || (this.hasTitle && !this.parentQuestion))
            return null;
        return this.locTitle.renderedHtml;
    }
    get ariaRole() {
        if (this.isNewA11yStructure)
            return null;
        return "textbox";
    }
    get ariaRequired() {
        if (this.isNewA11yStructure)
            return null;
        return this.isRequired ? "true" : "false";
    }
    get ariaInvalid() {
        if (this.isNewA11yStructure)
            return null;
        return this.hasCssError() ? "true" : "false";
    }
    get ariaLabelledBy() {
        if (this.isNewA11yStructure || !this.hasTitle || this.parentQuestion)
            return null;
        return this.ariaTitleId;
    }
    get ariaDescribedBy() {
        if (this.isNewA11yStructure)
            return null;
        if (this.hasTitle && this.hasDescription) {
            return this.ariaDescriptionId;
        }
        else {
            return null;
        }
    }
    getContentAriaHidden() {
        return null;
    }
    get contentAriaHidden() {
        return this.getContentAriaHidden();
    }
    get ariaErrormessage() {
        if (this.isNewA11yStructure)
            return null;
        return this.hasCssError() ? this.id + "_errors" : null;
    }
    //EO a11y
    //new a11y
    get a11y_input_ariaRole() {
        return null;
    }
    get a11y_input_ariaRequired() {
        return this.isRequired ? "true" : "false";
    }
    get a11y_input_ariaInvalid() {
        return this.hasCssError() ? "true" : "false";
    }
    get a11y_input_ariaLabel() {
        if (this.hasTitle && !this.parentQuestion) {
            return null;
        }
        else {
            return this.locTitle.renderedHtml;
        }
    }
    get a11y_input_ariaLabelledBy() {
        if (this.hasTitle && !this.parentQuestion) {
            return this.ariaTitleId;
        }
        else {
            return null;
        }
    }
    get a11y_input_ariaDescribedBy() {
        if (this.hasTitle && !this.parentQuestion && this.hasDescription && this.descriptionLocation !== "hidden") {
            return this.ariaDescriptionId;
        }
        else {
            return null;
        }
    }
    get a11y_input_ariaErrormessage() {
        return this.hasCssError() ? this.id + "_errors" : null;
    }
    get a11y_input_ariaExpanded() {
        return this.getPropertyValue("ariaExpanded");
    }
    registerSychProperties(names, func) {
        this.registerFunctionOnPropertiesValueChanged(names, () => {
            if (!this._syncPropertiesChanging) {
                this._syncPropertiesChanging = true;
                func();
                this._syncPropertiesChanging = false;
            }
        });
    }
}
Question.TextPreprocessorValuesMap = {
    title: "processedTitle",
    require: "requiredMark",
};
Question.questionCounter = 100;
function makeNameValid(str) {
    if (!str)
        return str;
    str = str.trim().replace(/[\{\}]+/g, "");
    while (!!str && str[0] === settings.expressionDisableConversionChar) {
        str = str.substring(1);
    }
    return str;
}
Serializer.addClass("question", [
    { name: "!name", onSettingValue: (obj, val) => { return makeNameValid(val); } },
    {
        name: "state",
        default: "default",
        choices: ["default", "collapsed", "expanded"],
    },
    { name: "visible:switch", default: true, overridingProperty: "visibleIf" },
    { name: "useDisplayValuesInDynamicTexts:boolean", alternativeName: "useDisplayValuesInTitle", default: true, layout: "row" },
    "visibleIf:condition",
    { name: "width" },
    { name: "minWidth", defaultFunc: () => settings.minWidth },
    { name: "maxWidth", defaultFunc: () => settings.maxWidth },
    {
        name: "colSpan:number", visible: false,
        onSerializeValue: (obj) => { return obj.getPropertyValue("colSpan"); },
    },
    {
        name: "effectiveColSpan:number", minValue: 1, isSerializable: false,
        visibleIf: function (obj) { return !!obj && !!obj.survey && obj.survey.gridLayoutEnabled; }
    },
    { name: "startWithNewLine:boolean", default: true, layout: "row" },
    { name: "indent:number", default: 0, choices: [0, 1, 2, 3], layout: "row" },
    {
        name: "page",
        isSerializable: false,
        visibleIf: function (obj) {
            var survey = obj ? obj.survey : null;
            return !survey || !survey.pages || survey.pages.length > 1;
        },
        choices: function (obj) {
            var survey = obj ? obj.survey : null;
            return survey
                ? survey.pages.map((p) => {
                    return { value: p.name, text: p.title };
                })
                : [];
        },
    },
    {
        name: "title:text", serializationProperty: "locTitle", layout: "row", dependsOn: "name",
        onPropertyEditorUpdate: function (obj, editor) {
            if (!!obj && !!editor) {
                editor.placeholder = obj.locTitle.getPlaceholder();
            }
        }
    },
    {
        name: "titleLocation",
        default: "default",
        choices: ["default", "top", "bottom", "left", "hidden"],
        layout: "row",
    },
    {
        name: "showTitle:boolean",
        isSerializable: false,
        dependsOn: "titleLocation"
    },
    {
        name: "description:text",
        serializationProperty: "locDescription",
        layout: "row",
    },
    {
        name: "descriptionLocation",
        default: "default",
        choices: ["default", "underInput", "underTitle"],
    },
    {
        name: "showNumber:boolean",
        dependsOn: "titleLocation",
        default: true,
        visibleIf: function (obj) {
            if (!obj) {
                return true;
            }
            if (obj.titleLocation === "hidden") {
                return false;
            }
            var parent = obj ? obj.parent : null;
            var numberingAllowedByParent = !parent || parent.showQuestionNumbers !== "off";
            if (!numberingAllowedByParent) {
                return false;
            }
            var survey = obj ? obj.survey : null;
            return (!survey ||
                survey.showQuestionNumbers !== "off" ||
                (!!parent && parent.showQuestionNumbers === "onpanel"));
        },
    },
    { name: "hideNumber:boolean", visible: false, isSerializable: false },
    { name: "valueName", onSettingValue: (obj, val) => { return makeNameValid(val); } },
    "enableIf:condition",
    "resetValueIf:condition",
    "setValueIf:condition",
    "setValueExpression:expression",
    "defaultValue:value",
    {
        name: "defaultValueExpression:expression",
        category: "logic",
    },
    "correctAnswer:value",
    {
        name: "clearIfInvisible",
        default: "default",
        choices: ["default", "none", "onComplete", "onHidden", "onHiddenContainer"],
    },
    { name: "isRequired:switch", overridingProperty: "requiredIf" },
    "requiredIf:condition",
    {
        name: "requiredErrorText:text",
        serializationProperty: "locRequiredErrorText",
    },
    { name: "errorLocation", default: "default", choices: ["default", "top", "bottom"] },
    { name: "readOnly:switch", overridingProperty: "enableIf" },
    {
        name: "validators:validators",
        baseClassName: "surveyvalidator",
        classNamePart: "validator",
    },
    {
        name: "bindings:bindings",
        serializationProperty: "bindings",
        isSerializableFunc: (obj) => !obj.isBindingEmpty(),
        visibleIf: function (obj) {
            return obj.bindings.getNames().length > 0;
        },
    },
    { name: "renderAs", default: "default", visible: false },
    { name: "showCommentArea", visible: false, default: false, alternativeName: "hasComment", category: "general" },
    {
        name: "commentText",
        dependsOn: "showCommentArea",
        visibleIf: function (obj) {
            return obj.showCommentArea;
        },
        serializationProperty: "locCommentText"
    },
    {
        name: "commentPlaceholder",
        alternativeName: "commentPlaceHolder",
        serializationProperty: "locCommentPlaceholder",
        dependsOn: "showCommentArea",
        visibleIf: function (obj) {
            return obj.hasComment;
        }
    },
    { name: "defaultDisplayValue", serializationProperty: "locDefaultDisplayValue" }
]);
Serializer.addAlterNativeClassName("question", "questionbase");

/**
 * Array of ItemValue is used in checkbox, dropdown and radiogroup choices, matrix columns and rows.
 * It has two main properties: value and text. If text is empty, value is used for displaying.
 * The text property is localizable and support markdown.
 */
class ItemValue extends BaseAction {
    getMarkdownHtml(text, name, item) {
        return !!this.locOwner ? this.locOwner.getMarkdownHtml(text, name, item || this) : undefined;
    }
    getRenderer(name) {
        return !!this.locOwner ? this.locOwner.getRenderer(name) : null;
    }
    getRendererContext(locStr) {
        return !!this.locOwner ? this.locOwner.getRendererContext(locStr) : locStr;
    }
    getProcessedText(text) {
        return this.locOwner ? this.locOwner.getProcessedText(text) : text;
    }
    static get Separator() {
        return settings.itemValueSeparator;
    }
    static set Separator(val) {
        settings.itemValueSeparator = val;
    }
    /**
     * Resets the input array and fills it with values from the values array
     */
    static setData(items, values, type) {
        items.length = 0;
        for (let i = 0; i < values.length; i++) {
            const value = values[i];
            const itemType = !!value && typeof value.getType === "function" ? value.getType() : (type !== null && type !== void 0 ? type : "itemvalue");
            const item = Serializer.createClass(itemType);
            item.setData(value);
            if (!!value.originalItem) {
                item.originalItem = value.originalItem;
            }
            if (!!value.data) {
                item.data = value.data;
            }
            items.push(item);
        }
    }
    static getData(items) {
        var result = [];
        for (var i = 0; i < items.length; i++) {
            result.push(items[i].getData());
        }
        return result;
    }
    static getItemByValue(items, val) {
        if (!Array.isArray(items))
            return null;
        const valIsEmpty = Helpers.isValueEmpty(val);
        for (var i = 0; i < items.length; i++) {
            if (valIsEmpty && Helpers.isValueEmpty(items[i].value))
                return items[i];
            if (Helpers.isTwoValueEquals(items[i].value, val, false, true, false))
                return items[i];
        }
        return null;
    }
    static getTextOrHtmlByValue(items, val) {
        var item = ItemValue.getItemByValue(items, val);
        return item !== null ? item.textOrHtml : "";
    }
    static locStrsChanged(items) {
        for (var i = 0; i < items.length; i++) {
            items[i].locStrsChanged();
        }
    }
    static runConditionsForItems(items, filteredItems, runner, values, properties, useItemExpression = true, onItemCallBack) {
        return ItemValue.runConditionsForItemsCore(items, filteredItems, runner, values, properties, true, useItemExpression, onItemCallBack);
    }
    static runEnabledConditionsForItems(items, runner, values, properties, onItemCallBack) {
        return ItemValue.runConditionsForItemsCore(items, null, runner, values, properties, false, true, onItemCallBack);
    }
    static runConditionsForItemsCore(items, filteredItems, runner, values, properties, isVisible, useItemExpression = true, onItemCallBack) {
        if (!values) {
            values = {};
        }
        var itemValue = values["item"];
        var choiceValue = values["choice"];
        var hasChanded = false;
        for (var i = 0; i < items.length; i++) {
            var item = items[i];
            values["item"] = item.value;
            values["choice"] = item.value;
            var itemRunner = useItemExpression && !!item.getConditionRunner
                ? item.getConditionRunner(isVisible)
                : false;
            if (!itemRunner) {
                itemRunner = runner;
            }
            var newValue = true;
            if (itemRunner) {
                newValue = itemRunner.run(values, properties);
            }
            if (!!onItemCallBack) {
                newValue = onItemCallBack(item, newValue);
            }
            if (!!filteredItems && newValue) {
                filteredItems.push(item);
            }
            var oldValue = isVisible ? item.isVisible : item.isEnabled;
            if (newValue != oldValue) {
                hasChanded = true;
                if (isVisible) {
                    if (!!item.setIsVisible)
                        item.setIsVisible(newValue);
                }
                else {
                    if (!!item.setIsEnabled)
                        item.setIsEnabled(newValue);
                }
            }
        }
        if (itemValue) {
            values["item"] = itemValue;
        }
        else {
            delete values["item"];
        }
        if (choiceValue) {
            values["choice"] = choiceValue;
        }
        else {
            delete values["choice"];
        }
        return hasChanded;
    }
    constructor(value, text, typeName) {
        super();
        this.typeName = typeName;
        this.ownerPropertyName = "";
        if (text)
            this.locText.text = text;
        if (!!value && typeof value === "object") {
            this.setData(value, true);
        }
        else {
            this.setValue(value, true);
        }
        if (this.getType() != this.getBaseType()) {
            CustomPropertiesCollection.createProperties(this);
        }
        this.onCreating();
    }
    onCreating() { }
    getType() {
        return this.typeName || this.getBaseType();
    }
    getBaseType() { return "itemvalue"; }
    getSurvey(live = false) {
        return !!this.locOwner && !!this.locOwner["getSurvey"]
            ? this.locOwner.getSurvey()
            : null;
    }
    getLocale() {
        return !!this.locOwner && this.locOwner.getLocale ? this.locOwner.getLocale() : "";
    }
    getLocalizableString(name) {
        if (name === "text")
            return this.locText;
        return super.getLocalizableString(name);
    }
    get isInternal() {
        return this.isGhost === true;
    }
    createLocText() {
        const res = new LocalizableString(this, true, "text");
        res.onStrChanged = (oldValue, newValue) => {
            this.propertyValueChanged("text", oldValue, newValue);
        };
        res.onGetTextCallback = (txt) => {
            return this.onGetText(txt);
        };
        return res;
    }
    onGetText(text) {
        return text || this.getValueText();
    }
    getValueText() {
        const val = this.value;
        return !Helpers.isValueEmpty(val) ? val.toString() : null;
    }
    get locText() {
        if (!this.locTextValue) {
            this.locTextValue = this.createLocText();
        }
        return this.locTextValue;
    }
    setLocText(locText) {
        this.locTextValue = locText;
    }
    get locOwner() {
        return this._locOwner;
    }
    set locOwner(value) {
        this._locOwner = value;
    }
    get value() {
        return this.getPropertyValue("value");
    }
    set value(newValue) {
        this.setValue(newValue, false);
    }
    setValue(newValue, newItem) {
        let text = undefined;
        newValue = this.getCorrectValue(newValue);
        if (!Helpers.isValueEmpty(newValue)) {
            var str = newValue.toString();
            var index = str.indexOf(settings.itemValueSeparator);
            if (index > -1) {
                newValue = str.slice(0, index);
                text = str.slice(index + 1);
            }
        }
        if (newItem) {
            this.setPropertyValueDirectly("value", newValue);
        }
        else {
            this.setPropertyValue("value", newValue);
        }
        if (!!text) {
            this.text = text;
        }
        this.id = this.value;
    }
    getCorrectValue(value) {
        return value;
    }
    get hasText() {
        return this.pureText ? true : false;
    }
    get pureText() {
        var _a;
        return ((_a = this.locTextValue) === null || _a === void 0 ? void 0 : _a.pureText) || "";
    }
    set pureText(val) {
        this.text = val;
    }
    get text() {
        return this.calculatedText; //TODO: it will be correct to use this.locText.text, however it would require a lot of rewriting in Creator
    }
    set text(newText) {
        this.locText.text = newText;
    }
    get textOrHtml() {
        if (this.locTextValue)
            return this.locText.textOrHtml;
        return this.getValueText();
    }
    get calculatedText() {
        if (this.locTextValue)
            return this.locText.calculatedText;
        return this.getValueText();
    }
    get shortcutText() {
        return this.text;
    }
    canSerializeValue() {
        const val = this.value;
        if (val === undefined || val === null)
            return false;
        return !Array.isArray(val) && typeof val !== "object";
    }
    getData() {
        var json = this.toJSON();
        if (!!json["value"] && !!json["value"]["pos"]) {
            delete json["value"]["pos"];
        }
        if (Helpers.isValueEmpty(json.value))
            return json;
        const canSerializeVal = this.canSerializeValue();
        const canSerializeAsContant = !canSerializeVal || !settings.serialization.itemValueSerializeAsObject && !settings.serialization.itemValueSerializeDisplayText;
        if (canSerializeAsContant && Object.keys(json).length == 1)
            return this.value;
        if (settings.serialization.itemValueSerializeDisplayText && json.text === undefined && canSerializeVal) {
            json.text = this.value.toString();
        }
        return json;
    }
    toJSON() {
        var res = {};
        var properties = Serializer.getProperties(this.getType());
        if (!properties || properties.length == 0) {
            properties = Serializer.getProperties(this.getBaseType());
        }
        var jsoObj = new JsonObject();
        for (var i = 0; i < properties.length; i++) {
            const prop = properties[i];
            if (prop.name === "text" && (!this.locTextValue || !this.locTextValue.hasNonDefaultText() &&
                Helpers.isTwoValueEquals(this.value, this.locTextValue.getLocaleText(""), false, true, false)))
                continue;
            jsoObj.valueToJson(this, res, prop);
        }
        return res;
    }
    setData(value, isNewItem) {
        var _a;
        if (Helpers.isValueEmpty(value))
            return;
        if (typeof value.value === "undefined" && typeof value.text !== "undefined" && Object.keys(value).length === 1) {
            value.value = value.text;
        }
        if (typeof value.value !== "undefined") {
            let json;
            if (typeof value.toJSON === "function") {
                json = value.toJSON();
            }
            else {
                json = value;
            }
            new JsonObject().toObject(json, this);
        }
        else {
            this.setValue(value, isNewItem);
        }
        if (!isNewItem) {
            (_a = this.locTextValue) === null || _a === void 0 ? void 0 : _a.strChanged();
        }
    }
    get visibleIf() {
        return this.getPropertyValueWithoutDefault("visibleIf") || "";
    }
    set visibleIf(val) {
        this.setPropertyValue("visibleIf", val);
    }
    get enableIf() {
        return this.getPropertyValueWithoutDefault("enableIf") || "";
    }
    set enableIf(val) {
        this.setPropertyValue("enableIf", val);
    }
    get isVisible() {
        const res = this.getPropertyValueWithoutDefault("isVisible");
        return res !== undefined ? res : true;
    }
    setIsVisible(val) {
        this.setPropertyValue("isVisible", val);
    }
    get isEnabled() {
        const res = this.getPropertyValueWithoutDefault("isEnabled");
        return res !== undefined ? res : true;
    }
    setIsEnabled(val) {
        this.setPropertyValue("isEnabled", val);
    }
    addUsedLocales(locales) {
        if (this.locTextValue) {
            this.AddLocStringToUsedLocales(this.locTextValue, locales);
        }
    }
    locStrsChanged() {
        var _a;
        super.locStrsChanged();
        (_a = this.locTextValue) === null || _a === void 0 ? void 0 : _a.strChanged();
    }
    onPropertyValueChanged(name, oldValue, newValue) {
        var _a;
        if (name === "value" && !this.hasText) {
            (_a = this.locTextValue) === null || _a === void 0 ? void 0 : _a.strChanged();
        }
        var funcName = "itemValuePropertyChanged";
        if (!this.locOwner || !this.locOwner[funcName])
            return;
        this.locOwner[funcName](this, name, oldValue, newValue);
    }
    getConditionRunner(isVisible) {
        if (isVisible)
            return this.getVisibleConditionRunner();
        return this.getEnableConditionRunner();
    }
    getVisibleConditionRunner() {
        if (!this.visibleIf)
            return null;
        if (!this.visibleConditionRunner)
            this.visibleConditionRunner = new ConditionRunner(this.visibleIf);
        this.visibleConditionRunner.expression = this.visibleIf;
        return this.visibleConditionRunner;
    }
    getEnableConditionRunner() {
        if (!this.enableIf)
            return null;
        if (!this.enableConditionRunner)
            this.enableConditionRunner = new ConditionRunner(this.enableIf);
        this.enableConditionRunner.expression = this.enableIf;
        return this.enableConditionRunner;
    }
    get selected() {
        const locOwner = this._locOwner;
        if (locOwner instanceof Question && locOwner.isItemSelected && this.selectedValue === undefined) {
            this.selectedValue = (new ComputedUpdater(() => locOwner.isItemSelected(this)));
        }
        return this.selectedValue;
    }
    getComponent() {
        if (this._locOwner instanceof Question) {
            return this.componentValue || this._locOwner.itemComponent;
        }
        return this.componentValue;
    }
    setComponent(val) {
        this.componentValue = val;
    }
    setRootElement(val) {
        this._htmlElement = val;
    }
    getRootElement() {
        return this._htmlElement;
    }
    getEnabled() {
        return this.isEnabled;
    }
    setEnabled(val) {
        this.setIsEnabled(val);
    }
    getVisible() {
        const isVisible = this.isVisible === undefined ? true : this.isVisible;
        const visible = this._visible === undefined ? true : this._visible;
        return isVisible && visible;
    }
    setVisible(val) {
        if (this.visible !== val) {
            this._visible = val;
        }
    }
    get _visible() { return this.getPropertyValue("visible", true); }
    set _visible(val) { this.setPropertyValue("visible", val); }
    getLocTitle() {
        return this.locText;
    }
    getTitle() {
        return this.text;
    }
    setLocTitle(val) { }
    setTitle(val) { }
    get icon() { return this.getPropertyValue("icon", ""); }
    set icon(val) { this.setPropertyValue("icon", val); }
}
__decorate([
    property()
], ItemValue.prototype, "selectedValue", void 0);
Base.createItemValue = function (source, type) {
    var item = null;
    if (!!type) {
        item = JsonObject.metaData.createClass(type, {});
    }
    else if (typeof source.getType === "function") {
        item = new ItemValue(null, undefined, source.getType());
    }
    else {
        item = new ItemValue(null);
    }
    item.setData(source);
    return item;
};
Base.itemValueLocStrChanged = function (arr) {
    ItemValue.locStrsChanged(arr);
};
JsonObjectProperty.getItemValuesDefaultValue = (val, type) => {
    const res = new Array();
    ItemValue.setData(res, Array.isArray(val) ? val : [], type);
    return res;
};
Serializer.addClass("itemvalue", [
    { name: "!value", isUnique: true },
    {
        name: "text",
        serializationProperty: "locText",
    },
    { name: "visibleIf:condition", locationInTable: "detail" },
    {
        name: "enableIf:condition", locationInTable: "detail",
        visibleIf: (obj) => {
            return !obj || obj.ownerPropertyName !== "rateValues";
        },
    }
], (value) => new ItemValue(value));

/**
 * The calculated value is a way to define the variable in Survey Creator.
 * It has two main properties: name and expression. Based on expression the value read-only property is automatically calculated.
 * The name property should be unique though all calculated values.
 * It uses survey.getVariable/seruvey.setVariable functions to get/set its value. The class do not store its value internally.
 * You may set includeIntoResult property to true to store this calculated value into survey result.
 */
class CalculatedValue extends Base {
    constructor(name = null, expression = null) {
        super();
        this.expressionIsRunning = false;
        this.isCalculated = false;
        if (!!name) {
            this.name = name;
        }
        if (!!expression) {
            this.expression = expression;
        }
    }
    setOwner(data) {
        this.data = data;
        this.rerunExpression();
    }
    getType() {
        return "calculatedvalue";
    }
    getSurvey(live = false) {
        return !!this.data && !!this.data["getSurvey"]
            ? this.data.getSurvey()
            : null;
    }
    get owner() {
        return this.data;
    }
    /**
     * The calculated value name. It should be non empty and unique.
     */
    get name() {
        return this.getPropertyValue("name") || "";
    }
    set name(val) {
        this.setPropertyValue("name", val);
    }
    /**
     * Set this property to true to include the non-empty calculated value into survey result, survey.data property.
     */
    get includeIntoResult() {
        return this.getPropertyValue("includeIntoResult");
    }
    set includeIntoResult(val) {
        this.setPropertyValue("includeIntoResult", val);
    }
    /**
     * The Expression that used to calculate the value. You may use standard operators like +, -, * and /, squares (). Here is the example of accessing the question value {questionname}.
     * Example: "({quantity} * {price}) * (100 - {discount}) / 100"
     */
    get expression() {
        return this.getPropertyValue("expression") || "";
    }
    set expression(val) {
        this.setPropertyValue("expression", val);
        this.rerunExpression();
    }
    locCalculation() {
        this.expressionIsRunning = true;
    }
    unlocCalculation() {
        this.expressionIsRunning = false;
    }
    resetCalculation() {
        this.isCalculated = false;
    }
    doCalculation(calculatedValues, values, properties) {
        if (this.isCalculated)
            return;
        this.runExpressionCore(calculatedValues, values, properties);
        this.isCalculated = true;
    }
    runExpression(values, properties) {
        this.runExpressionCore(null, values, properties);
    }
    get value() {
        if (!this.data)
            return undefined;
        return this.data.getVariable(this.name);
    }
    setValue(val) {
        if (!this.data)
            return;
        this.data.setVariable(this.name, val);
    }
    get canRunExpression() {
        return (!!this.data &&
            !this.isLoadingFromJson &&
            !!this.expression &&
            !this.expressionIsRunning &&
            !!this.name);
    }
    rerunExpression() {
        if (!this.canRunExpression)
            return;
        this.runExpression(this.data.getFilteredValues(), this.data.getFilteredProperties());
    }
    runExpressionCore(calculatedValues, values, properties) {
        if (!this.canRunExpression)
            return;
        this.ensureExpression(values);
        this.locCalculation();
        if (!!calculatedValues) {
            this.runDependentExpressions(calculatedValues, values, properties);
        }
        this.expressionRunner.run(values, properties);
    }
    runDependentExpressions(calculatedValues, values, properties) {
        var variables = this.expressionRunner.getVariables();
        if (!variables)
            return;
        for (var i = 0; i < calculatedValues.length; i++) {
            var calcItem = calculatedValues[i];
            if (calcItem === this || variables.indexOf(calcItem.name) < 0)
                continue;
            calcItem.doCalculation(calculatedValues, values, properties);
            values[calcItem.name] = calcItem.value;
        }
    }
    ensureExpression(values) {
        if (!!this.expressionRunner)
            return;
        this.expressionRunner = new ExpressionRunner(this.expression);
        this.expressionRunner.onRunComplete = newValue => {
            if (!Helpers.isTwoValueEquals(newValue, this.value, false, true, false)) {
                this.setValue(newValue);
            }
            this.unlocCalculation();
        };
    }
}
Serializer.addClass("calculatedvalue", [
    { name: "!name", isUnique: true },
    "expression:expression",
    "includeIntoResult:boolean",
], function () {
    return new CalculatedValue();
}, "base");

/**
 * Base class for HtmlConditionItem and UrlConditionItem classes.
 */
class ExpressionItem extends Base {
    constructor(expression = null) {
        super();
        this.expression = expression;
    }
    getType() {
        return "expressionitem";
    }
    runCondition(values, properties) {
        if (!this.expression)
            return false;
        return new ConditionRunner(this.expression).run(values, properties);
    }
    /**
     * The expression property. If this expression returns true, then survey will use html property to show on complete page.
     */
    get expression() {
        return this.getPropertyValue("expression", "");
    }
    set expression(val) {
        this.setPropertyValue("expression", val);
    }
    get locHtml() {
        return this.getLocalizableString("html");
    }
    getLocale() {
        return !!this.locOwner ? this.locOwner.getLocale() : "";
    }
    getMarkdownHtml(text, name, item) {
        return !!this.locOwner ? this.locOwner.getMarkdownHtml(text, name, item) : undefined;
    }
    getRenderer(name) {
        return !!this.locOwner ? this.locOwner.getRenderer(name) : null;
    }
    getRendererContext(locStr) {
        return !!this.locOwner ? this.locOwner.getRendererContext(locStr) : locStr;
    }
    getProcessedText(text) {
        return this.locOwner ? this.locOwner.getProcessedText(text) : text;
    }
    getSurvey(isLive = false) {
        return this.locOwner;
    }
}
/**
 * A class that contains expression and html propeties. It uses in survey.completedHtmlOnCondition array.
 * If the expression returns true then html of this item uses instead of survey.completedHtml property
 * @see SurveyModel.completedHtmlOnCondition
 * @see SurveyModel.completedHtml
 */
class HtmlConditionItem extends ExpressionItem {
    constructor(expression = null, html = null) {
        super(expression);
        this.createLocalizableString("html", this);
        this.html = html;
    }
    getType() {
        return "htmlconditionitem";
    }
    /**
     * The html that shows on completed ('Thank you') page. The expression should return true
     * @see expression
     */
    get html() {
        return this.getLocalizableStringText("html");
    }
    set html(value) {
        this.setLocalizableStringText("html", value);
    }
    get locHtml() {
        return this.getLocalizableString("html");
    }
}
/**
 * A class that contains expression and url propeties. It uses in survey.navigateToUrlOnCondition array.
 * If the expression returns true then url of this item uses instead of survey.navigateToUrl property
 * @see SurveyModel.navigateToUrl
 */
class UrlConditionItem extends ExpressionItem {
    constructor(expression = null, url = null) {
        super(expression);
        this.createLocalizableString("url", this);
        this.url = url;
    }
    getType() {
        return "urlconditionitem";
    }
    /**
     * The url that survey navigates to on completing the survey. The expression should return true
     * @see expression
     */
    get url() {
        return this.getLocalizableStringText("url");
    }
    set url(value) {
        this.setLocalizableStringText("url", value);
    }
    get locUrl() {
        return this.getLocalizableString("url");
    }
}
Serializer.addClass("expressionitem", ["expression:condition"], function () {
    return new ExpressionItem();
}, "base");
Serializer.addClass("htmlconditionitem", [{ name: "html:html", serializationProperty: "locHtml" }], function () {
    return new HtmlConditionItem();
}, "expressionitem");
Serializer.addClass("urlconditionitem", [{ name: "url:string", serializationProperty: "locUrl" }], function () {
    return new UrlConditionItem();
}, "expressionitem");

class XmlParser {
    constructor() {
        this.parser = new DOMParser();
    }
    assignValue(target, name, value) {
        if (Array.isArray(target[name])) {
            target[name].push(value);
        }
        else if (target[name] !== undefined) {
            target[name] = [target[name]].concat(value);
        }
        else if (typeof value === "object" &&
            Object.keys(value).length === 1 &&
            Object.keys(value)[0] === name) {
            target[name] = value[name];
        }
        else {
            target[name] = value;
        }
    }
    xml2Json(xmlNode, result) {
        if (xmlNode.children && xmlNode.children.length > 0) {
            for (let i = 0; i < xmlNode.children.length; i++) {
                let childNode = xmlNode.children[i];
                let childObject = {};
                this.xml2Json(childNode, childObject);
                this.assignValue(result, childNode.nodeName, childObject);
            }
        }
        else {
            this.assignValue(result, xmlNode.nodeName, xmlNode.textContent);
        }
    }
    parseXmlString(xmlString) {
        let xmlRoot = this.parser.parseFromString(xmlString, "text/xml");
        let json = {};
        this.xml2Json(xmlRoot, json);
        return json;
    }
}
/**
 * Configures access to a RESTful service that returns choices for [Checkbox](https://surveyjs.io/Examples/Library?id=questiontype-checkbox), [Dropdown](https://surveyjs.io/Examples/Library?id=questiontype-dropdown), [Radiogroup](https://surveyjs.io/Examples/Library?id=questiontype-radiogroup), and other multiple-choice question types.
 *
 * Use the following properties to configure this object:
 *
 * ```js
 * {
 *   url: "http://...", // A RESTful service's URL.
 *   valueName: "value", // Specifies which field contains choice values.
 *   titleName: "title", // Specifies which field contains display texts for choice values.
 *   imageLinkName: "imageUrl", // Specifies which field contains image URLs. Used in Image Picker questions.
 *   // Path to the array of choices. Specify `path` only if the array of choices is nested within the object returned by the service.
 *   // The following path separators are allowed: semicolon `;`, comma `,`.
 *   path: "myNestedArray"
 * }
 * ```
 *
 * Typically, you should assign this object to a question's [`choicesByUrl`](https://surveyjs.io/Documentation/Library?id=QuestionSelectBase#choicesByUrl) property. You can also specify additional application-wide settings using the [`settings.web`](https://surveyjs.io/form-library/documentation/api-reference/settings#web) object.
 */
class ChoicesRestful extends Base {
    static get EncodeParameters() {
        return settings.web.encodeUrlParams;
    }
    static set EncodeParameters(val) {
        settings.web.encodeUrlParams = val;
    }
    static clearCache() {
        ChoicesRestful.itemsResult = {};
        ChoicesRestful.sendingSameRequests = {};
    }
    static addSameRequest(obj) {
        if (!obj.isUsingCache)
            return false;
        var hash = obj.objHash;
        var res = ChoicesRestful.sendingSameRequests[hash];
        if (!res) {
            ChoicesRestful.sendingSameRequests[obj.objHash] = [];
            return false;
        }
        res.push(obj);
        obj.isRunningValue = true;
        return true;
    }
    static unregisterSameRequests(obj, items) {
        if (!obj.isUsingCache)
            return;
        var res = ChoicesRestful.sendingSameRequests[obj.objHash];
        delete ChoicesRestful.sendingSameRequests[obj.objHash];
        if (!res)
            return;
        for (var i = 0; i < res.length; i++) {
            res[i].isRunningValue = false;
            if (!!res[i].getResultCallback) {
                res[i].getResultCallback(items);
            }
        }
    }
    static get onBeforeSendRequest() {
        return settings.web.onBeforeRequestChoices;
    }
    static set onBeforeSendRequest(val) {
        settings.web.onBeforeRequestChoices = val;
    }
    static getCachedItemsResult(obj) {
        var hash = obj.objHash;
        var res = ChoicesRestful.itemsResult[hash];
        if (!res)
            return false;
        if (obj.getResultCallback) {
            obj.getResultCallback(res);
        }
        return true;
    }
    constructor() {
        super();
        this.lastObjHash = "";
        this.isRunningValue = false;
        this.processedUrl = "";
        this.processedPath = "";
        this.isUsingCacheFromUrl = undefined;
        this.error = null;
        this.createItemValue = (value) => {
            return new ItemValue(value);
        };
        this.registerPropertyChangedHandlers(["url"], () => {
            if (this.owner)
                this.owner.setPropertyValue("isUsingRestful", !!this.url);
        });
    }
    getSurvey(live = false) {
        return !!this.owner ? this.owner.survey : null;
    }
    run(textProcessor = null) {
        if (!this.url || !this.getResultCallback)
            return;
        this.processedText(textProcessor);
        if (!this.processedUrl) {
            this.doEmptyResultCallback({});
            this.lastObjHash = this.objHash;
            return;
        }
        if (this.lastObjHash === this.objHash)
            return;
        this.lastObjHash = this.objHash;
        this.error = null;
        if (this.useChangedItemsResults())
            return;
        if (ChoicesRestful.addSameRequest(this))
            return;
        this.sendRequest();
    }
    get isUsingCache() {
        if (this.isUsingCacheFromUrl === true)
            return true;
        if (this.isUsingCacheFromUrl === false)
            return false;
        return settings.web.cacheLoadedChoices;
    }
    get isRunning() {
        return this.getIsRunning();
    }
    getIsRunning() {
        return this.isRunningValue;
    }
    get isWaitingForParameters() {
        return this.url && !this.processedUrl;
    }
    useChangedItemsResults() {
        return ChoicesRestful.getCachedItemsResult(this);
    }
    doEmptyResultCallback(serverResult) {
        var items = [];
        if (this.updateResultCallback) {
            items = this.updateResultCallback(items, serverResult);
        }
        this.getResultCallback(items);
    }
    processedText(textProcessor) {
        var urlText = this.url;
        if (!!urlText) {
            urlText = urlText
                .replace(ChoicesRestful.cacheText, "")
                .replace(ChoicesRestful.noCacheText, "");
        }
        if (textProcessor) {
            var pUrl = textProcessor.processTextEx({ text: urlText, runAtDesign: true });
            var pPath = textProcessor.processTextEx({ text: this.path, runAtDesign: true });
            if (!pUrl.hasAllValuesOnLastRun || !pPath.hasAllValuesOnLastRun) {
                this.processedUrl = "";
                this.processedPath = "";
            }
            else {
                this.processedUrl = pUrl.text;
                this.processedPath = pPath.text;
            }
        }
        else {
            this.processedUrl = urlText;
            this.processedPath = this.path;
        }
        if (this.onProcessedUrlCallback) {
            this.onProcessedUrlCallback(this.processedUrl, this.processedPath);
        }
    }
    parseResponse(response) {
        let parsedResponse;
        if (!!response &&
            typeof response.indexOf === "function" &&
            response.indexOf("<") === 0) {
            var parser = new XmlParser();
            parsedResponse = parser.parseXmlString(response);
        }
        else {
            try {
                parsedResponse = JSON.parse(response);
            }
            catch (_a) {
                parsedResponse = (response || "")
                    .split("\n")
                    .map((s) => s.trim(" "))
                    .filter((s) => !!s);
            }
        }
        return parsedResponse;
    }
    sendRequest() {
        if (typeof XMLHttpRequest !== "undefined") {
            this.sendXmlHttpRequest();
        }
        else if (typeof fetch !== "undefined") {
            this.sendFetchRequest();
        }
        else {
            this.error = new WebRequestError("The browser does not support XMLHttpRequest or fetch API", "", this.owner);
            this.doEmptyResultCallback("");
        }
    }
    sendXmlHttpRequest() {
        var xhr = new XMLHttpRequest();
        xhr.open("GET", this.processedUrl);
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        var self = this;
        var loadingObjHash = this.objHash;
        xhr.onload = function () {
            self.beforeLoadRequest();
            if (xhr.status === 200) {
                self.onLoad(self.parseResponse(xhr.response), loadingObjHash);
            }
            else {
                self.onError(xhr.statusText, xhr.responseText);
            }
        };
        var options = { url: this.processedUrl, request: xhr };
        if (!!settings.web.onBeforeRequestChoices) {
            settings.web.onBeforeRequestChoices(this, options);
        }
        this.beforeSendRequest();
        options.request.send();
    }
    sendFetchRequest() {
        const self = this;
        const loadingObjHash = this.objHash;
        let url = this.processedUrl;
        const fetchOptions = {
            method: "GET",
            headers: {
                "Content-Type": "application/x-www-form-urlencoded",
            },
        };
        const options = { url, fetchOptions };
        if (settings.web.onBeforeRequestChoices) {
            settings.web.onBeforeRequestChoices(this, options);
        }
        this.beforeSendRequest();
        fetch(options.url, options.fetchOptions)
            .then(response => {
            self.beforeLoadRequest();
            if (response.status === 200) {
                return response.text().then(text => {
                    self.onLoad(self.parseResponse(text), loadingObjHash);
                });
            }
            else {
                return response.text().then(errorText => {
                    self.onError(response.statusText, errorText);
                });
            }
        })
            .catch(error => {
            self.onError(error.message, "");
        });
    }
    getType() {
        return "choicesByUrl";
    }
    get isEmpty() {
        return !this.url && !this.path;
    }
    getCustomPropertiesNames() {
        var properties = this.getCustomProperties();
        var res = new Array();
        for (var i = 0; i < properties.length; i++) {
            res.push(this.getCustomPropertyName(properties[i].name));
        }
        return res;
    }
    getCustomPropertyName(propertyName) {
        return propertyName + "Name";
    }
    getCustomProperties() {
        var properties = Serializer.getProperties(this.itemValueType);
        var res = [];
        for (var i = 0; i < properties.length; i++) {
            if (properties[i].name === "value" ||
                properties[i].name === "text" ||
                properties[i].name === "visibleIf" ||
                properties[i].name === "enableIf")
                continue;
            res.push(properties[i]);
        }
        return res;
    }
    getAllPropertiesNames() {
        const res = new Array();
        Serializer.getPropertiesByObj(this).forEach(prop => res.push(prop.name));
        this.getCustomPropertiesNames().forEach(prop => res.push(prop));
        return res;
    }
    setData(json) {
        if (!json)
            json = {};
        this.getAllPropertiesNames().forEach(name => {
            this[name] = json[name];
        });
        if (json.attachOriginalItems) {
            this.attachData = json.attachOriginalItems;
        }
    }
    getData() {
        const res = {};
        let hasValue = false;
        this.getAllPropertiesNames().forEach(name => {
            const val = this[name];
            if (!this.isValueEmpty(val) && val !== this.getDefaultPropertyValue(name)) {
                res[name] = val;
                hasValue = true;
            }
        });
        return hasValue ? res : null;
    }
    /**
     * A RESTful service's URL.
     *
     * This property supports [dynamic URLs](https://surveyjs.io/Documentation/Library?id=design-survey-conditional-logic#dynamic-texts). For example, the URL below depends on the `region` question's value. When the value changes, the survey automatically loads a new dataset that corresponds to the selected region.
     *
     * ```js
     * url: "https://surveyjs.io/api/CountriesExample?region={region}"
     * ```
     *
     * [View Demo](https://surveyjs.io/Examples/Library/?id=questiontype-dropdownrestfull (linkStyle))
     * @see path
     * @see valueName
     * @see titleName
     */
    get url() {
        return this.getPropertyValue("url") || "";
    }
    set url(val) {
        this.setPropertyValue("url", val);
        this.isUsingCacheFromUrl = undefined;
        if (!val)
            return;
        if (val.indexOf(ChoicesRestful.cacheText) > -1) {
            this.isUsingCacheFromUrl = true;
        }
        else {
            if (val.indexOf(ChoicesRestful.noCacheText) > -1) {
                this.isUsingCacheFromUrl = false;
            }
        }
    }
    /**
     * Path to the array of choices. The following path separators are allowed: semicolon `;`, comma `,`.
     *
     * Specify this property only if the array of choices is nested within the object returned by the service. For example, the service returns the following object:
     *
     * ```js
     * {
     *   countries: [ ... ],
     *   capitals: [ ... ]
     * }
     * ```
     *
     * To populate choices with values from the `countries` array, set the `path` property to `"countries"`. To use the `capitals` array, set this property to `"capitals"`.
     * @see url
     * @see valueName
     * @see titleName
     */
    get path() {
        return this.getPropertyValue("path") || "";
    }
    set path(val) {
        this.setPropertyValue("path", val);
    }
    /**
     * Specifies which property in the obtained data object contains choice values.
     *
     * [View Demo](https://surveyjs.io/Examples/Library/?id=questiontype-dropdownrestfull (linkStyle))
     *
     * @see url
     * @see path
     * @see titleName
     */
    get valueName() {
        return this.getPropertyValue("valueName", "");
    }
    set valueName(val) {
        this.setPropertyValue("valueName", val);
    }
    /**
     * Specifies which property in the obtained data object contains display texts for choices.
     *
     * @see url
     * @see path
     * @see valueName
     */
    get titleName() {
        return this.getPropertyValue("titleName", "");
    }
    set titleName(val) {
        this.setPropertyValue("titleName", val);
    }
    /**
     * Specifies which property in the obtained data object contains image URLs. Used only in [Image Picker](https://surveyjs.io/Examples/Library?id=questiontype-imagepicker) questions.
     *
     * @see url
     * @see path
     * @see valueName
     */
    get imageLinkName() {
        return this.getPropertyValue("imageLinkName", "");
    }
    set imageLinkName(val) {
        this.setPropertyValue("imageLinkName", val);
    }
    /**
     * Specifies whether the service is allowed to return an empty response or an empty array in a response.
     *
     * Default value: `false`
     */
    get allowEmptyResponse() {
        return this.getPropertyValue("allowEmptyResponse");
    }
    set allowEmptyResponse(val) {
        this.setPropertyValue("allowEmptyResponse", val);
    }
    get attachOriginalItems() {
        return this.attachData;
    }
    set attachOriginalItems(val) {
        this.attachData = val;
    }
    /**
     * Specifies whether to attach original data objects to choice items.
     *
     * Default value: `false`
     *
     * If you enable this property, original data objects will be stored in the `data` property of choice items. For instance, the following code shows how to access a data object of a selected choice item in a Dropdown question:
     *
     * ```js
     * import { Model } from "survey-core";
     *
     * const surveyJson = {
     *   "elements": [{
     *     "type": "dropdown",
     *     "name": "country",
     *     "title": "Select a country",
     *     "choicesByUrl": {
     *       "url": "https://surveyjs.io/api/CountriesExample",
     *       "valueName": "name",
     *       "attachData": true
     *     }
     *   }]
     * }
     *
     * const survey = new Model(surveyJson);
     *
     * function retrieveItemData(survey, qName) {
     *   const q = survey.getQuestionByName(qName);
     *   if (q && q.selectedItem) {
     *     return q.selectedItem.data;
     *   }
     *   return null;
     * }
     * ```
     */
    get attachData() {
        return this.getPropertyValue("attachData");
    }
    set attachData(val) {
        this.setPropertyValue("attachData", val);
    }
    get itemValueType() {
        if (!this.owner)
            return "itemvalue";
        var prop = Serializer.findProperty(this.owner.getType(), "choices");
        if (!prop)
            return "itemvalue";
        if (prop.type == "itemvalue[]")
            return "itemvalue";
        return prop.type;
    }
    clear() {
        this.setData(undefined);
    }
    beforeSendRequest() {
        this.isRunningValue = true;
        if (!!this.beforeSendRequestCallback) {
            this.beforeSendRequestCallback();
        }
    }
    beforeLoadRequest() {
        this.isRunningValue = false;
    }
    onLoad(result, loadingObjHash = null) {
        if (!loadingObjHash) {
            loadingObjHash = this.objHash;
        }
        var items = new Array();
        var updatedResult = this.getResultAfterPath(result);
        if (updatedResult && updatedResult["length"]) {
            for (var i = 0; i < updatedResult.length; i++) {
                var itemValue = updatedResult[i];
                if (!itemValue)
                    continue;
                var value = !!this.getItemValueCallback
                    ? this.getItemValueCallback(itemValue)
                    : this.getValue(itemValue);
                var item = this.createItemValue(value);
                this.setTitle(item, itemValue);
                this.setCustomProperties(item, itemValue);
                if (this.attachData) {
                    item.originalItem = itemValue;
                    item.data = itemValue;
                }
                var imageLink = this.getImageLink(itemValue);
                if (!!imageLink) {
                    item.imageLink = imageLink;
                }
                items.push(item);
            }
        }
        else {
            if (!this.allowEmptyResponse) {
                this.error = new WebRequestEmptyError(null, this.owner);
            }
        }
        if (this.updateResultCallback) {
            items = this.updateResultCallback(items, result);
        }
        if (this.isUsingCache) {
            ChoicesRestful.itemsResult[loadingObjHash] = items;
        }
        this.callResultCallback(items, loadingObjHash);
        ChoicesRestful.unregisterSameRequests(this, items);
    }
    callResultCallback(items, loadingObjHash) {
        if (loadingObjHash != this.objHash)
            return;
        this.getResultCallback(items);
    }
    setCustomProperties(item, itemValue) {
        var properties = this.getCustomProperties();
        for (var i = 0; i < properties.length; i++) {
            var prop = properties[i];
            var val = this.getValueCore(itemValue, this.getPropertyBinding(prop.name));
            if (!this.isValueEmpty(val)) {
                item[prop.name] = val;
            }
        }
    }
    getPropertyBinding(propertyName) {
        if (this[this.getCustomPropertyName(propertyName)])
            return this[this.getCustomPropertyName(propertyName)];
        if (this[propertyName])
            return this[propertyName];
        return propertyName;
    }
    onError(status, response) {
        this.error = new WebRequestError(status, response, this.owner);
        this.doEmptyResultCallback(response);
        ChoicesRestful.unregisterSameRequests(this, []);
    }
    getResultAfterPath(result) {
        if (!result)
            return result;
        if (!this.processedPath)
            return result;
        var pathes = this.getPathes();
        for (var i = 0; i < pathes.length; i++) {
            result = result[pathes[i]];
            if (!result)
                return null;
        }
        return result;
    }
    getPathes() {
        var pathes = [];
        if (this.processedPath.indexOf(";") > -1) {
            pathes = this.path.split(";");
        }
        else if (this.processedPath.indexOf(",") > -1) {
            pathes = this.processedPath.split(",");
        }
        else {
            pathes = this.processedPath.split(".");
        }
        if (pathes.length == 0)
            pathes.push(this.processedPath);
        return pathes;
    }
    getValue(item) {
        if (!item)
            return null;
        if (this.valueName)
            return this.getValueCore(item, this.valueName);
        if (!(item instanceof Object))
            return item;
        var len = Object.keys(item).length;
        if (len < 1)
            return null;
        return item[Object.keys(item)[0]];
    }
    setTitle(item, itemValue) {
        var title = this.titleName ? this.titleName : "title";
        var val = this.getValueCore(itemValue, title);
        if (!val)
            return;
        if (typeof val === "string") {
            item.text = val;
        }
        else {
            item.locText.setJson(val);
        }
    }
    getImageLink(item) {
        var imageLink = this.imageLinkName ? this.imageLinkName : "imageLink";
        return this.getValueCore(item, imageLink);
    }
    getValueCore(item, property) {
        if (!item)
            return null;
        if (property.indexOf(".") < 0)
            return item[property];
        var properties = property.split(".");
        for (var i = 0; i < properties.length; i++) {
            item = item[properties[i]];
            if (!item)
                return null;
        }
        return item;
    }
    get objHash() {
        return (this.processedUrl +
            ";" +
            this.processedPath +
            ";" +
            this.valueName +
            ";" +
            this.titleName +
            ";" +
            this.imageLinkName);
    }
}
ChoicesRestful.cacheText = "{CACHE}";
ChoicesRestful.noCacheText = "{NOCACHE}";
ChoicesRestful.itemsResult = {};
ChoicesRestful.sendingSameRequests = {};
/**
 * @deprecated Use `ChoicesRestful` instead.
 */
class ChoicesRestfull extends ChoicesRestful {
    static get EncodeParameters() {
        return ChoicesRestful.EncodeParameters;
    }
    static set EncodeParameters(val) {
        ChoicesRestful.EncodeParameters = val;
    }
    static clearCache() {
        ChoicesRestful.clearCache();
    }
    static get onBeforeSendRequest() {
        return settings.web.onBeforeRequestChoices;
    }
    static set onBeforeSendRequest(val) {
        settings.web.onBeforeRequestChoices = val;
    }
}
Serializer.addClass("choicesByUrl", [
    "url",
    "path",
    "valueName",
    "titleName",
    {
        name: "imageLinkName",
        visibleIf: function (obj) {
            return !!obj && !!obj.owner && obj.owner.getType() == "imagepicker";
        },
    },
    { name: "allowEmptyResponse:boolean" },
    { name: "attachData:boolean", alternativeName: "attachOriginalItems", visible: false },
], function () {
    return new ChoicesRestful();
});

/**
 * A base class for all matrix question types.
 */
class QuestionMatrixBaseModel extends Question {
    createColumnValues() {
        return this.createItemValues("columns");
    }
    constructor(name) {
        super(name);
        this.generatedVisibleRows = null;
        this.generatedTotalRow = null;
        this.filteredRows = null;
        this.columns = this.createColumnValues();
        this.rows = this.createItemValues("rows");
    }
    getType() {
        return "matrixbase";
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        this.updateVisibilityBasedOnRows();
    }
    get isCompositeQuestion() {
        return true;
    }
    /**
     * Specifies whether to display the table header that contains column captions.
     *
     * Default value: `true`
     */
    get showHeader() {
        return this.getPropertyValue("showHeader");
    }
    set showHeader(val) {
        this.setPropertyValue("showHeader", val);
    }
    /**
     * An array of matrix columns.
     *
     * For a Single-Select Matrix, the `columns` array can contain configuration objects with the `text` (display value) and `value` (value to be saved in survey results) properties. Alternatively, the array can contain primitive values that will be used as both the display values and values to be saved in survey results.
     *
     * [Single-Select Matrix Demo](https://surveyjs.io/form-library/examples/single-selection-matrix-table-question/ (linkStyle))
     *
     * For a Multi-Select Matrix or Dynamic Matrix, the `columns` array should contain configuration objects with properties described in the [`MatrixDropdownColumn`](https://surveyjs.io/form-library/documentation/api-reference/multi-select-matrix-column-values) API Reference section.
     *
     * [Multi-Select Matrix Demo](https://surveyjs.io/form-library/examples/questiontype-matrixdropdown/ (linkStyle))
     */
    get columns() {
        return this.getPropertyValue("columns");
    }
    set columns(newValue) {
        this.setPropertyValue("columns", newValue);
    }
    get visibleColumns() {
        const res = [];
        this.columns.forEach(col => { if (this.isColumnVisible(col)) {
            res.push(col);
        } });
        return res;
    }
    isColumnVisible(column) {
        return column.isVisible;
    }
    /**
     * An array of matrix rows.
     *
     * This array can contain primitive values or objects with the `text` (display value) and `value` (value to be saved in survey results) properties.
     *
     * [Single-Select Matrix Demo](https://surveyjs.io/form-library/examples/single-selection-matrix-table-question/ (linkStyle))
     *
     * [Multi-Select Matrix Demo](https://surveyjs.io/form-library/examples/multi-select-matrix-question/ (linkStyle))
     */
    get rows() {
        return this.getPropertyValue("rows");
    }
    set rows(newValue) {
        var newRows = this.processRowsOnSet(newValue);
        this.setPropertyValue("rows", newRows);
    }
    processRowsOnSet(newRows) {
        return newRows;
    }
    getVisibleRows() {
        return [];
    }
    /**
     * Returns an array of visible matrix rows.
     * @see rowsVisibleIf
     */
    get visibleRows() {
        return this.getVisibleRows();
    }
    /**
     * A Boolean expression that is evaluated against each matrix row. If the expression evaluates to `false`, the row becomes hidden.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Use the `{item}` placeholder to reference the current row in the expression.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/change-visibility-of-rows-in-matrix-table/ (linkStyle))
     * @see visibleRows
     * @see columnsVisibleIf
     */
    get rowsVisibleIf() {
        return this.getPropertyValue("rowsVisibleIf", "");
    }
    set rowsVisibleIf(val) {
        this.setPropertyValue("rowsVisibleIf", val);
        if (!this.isLoadingFromJsonValue) {
            this.runCondition(this.getDataFilteredValues(), this.getDataFilteredProperties());
        }
    }
    /**
     * A Boolean expression that is evaluated against each matrix column. If the expression evaluates to `false`, the column becomes hidden.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Use the `{item}` placeholder to reference the current column in the expression.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/change-visibility-of-rows-in-matrix-table/ (linkStyle))
     * @see rowsVisibleIf
     */
    get columnsVisibleIf() {
        return this.getPropertyValue("columnsVisibleIf", "");
    }
    set columnsVisibleIf(val) {
        this.setPropertyValue("columnsVisibleIf", val);
        if (!this.isLoadingFromJson) {
            this.runCondition(this.getDataFilteredValues(), this.getDataFilteredProperties());
        }
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        this.runItemsCondition(values, properties);
    }
    onColumnsChanged() { }
    onRowsChanged() {
        this.updateVisibilityBasedOnRows();
        this.fireCallback(this.visibleRowsChangedCallback);
    }
    updateVisibilityBasedOnRows() {
        if (this.hideIfRowsEmpty) {
            this.onVisibleChanged();
        }
    }
    isVisibleCore() {
        var _a;
        const res = super.isVisibleCore();
        if (!res || !this.hideIfRowsEmpty)
            return res;
        return ((_a = this.visibleRows) === null || _a === void 0 ? void 0 : _a.length) > 0;
    }
    shouldRunColumnExpression() {
        return !this.survey || !this.survey.areInvisibleElementsShowing;
    }
    hasRowsAsItems() {
        return true;
    }
    runItemsCondition(values, properties) {
        let hasChanges = this.hasRowsAsItems() && this.runConditionsForRows(values, properties);
        const hasColumnsChanged = this.runConditionsForColumns(values, properties);
        hasChanges = hasColumnsChanged || hasChanges;
        if (hasChanges) {
            if (this.isClearValueOnHidden && hasColumnsChanged) {
                this.clearInvisibleColumnValues();
            }
            this.clearGeneratedRows();
            if (hasColumnsChanged) {
                this.onColumnsChanged();
            }
            this.onRowsChanged();
        }
    }
    isRowsFiltered() { return !!this.filteredRows; }
    clearGeneratedRows() {
        this.generatedVisibleRows = null;
    }
    createRowsVisibleIfRunner() { return null; }
    runConditionsForRows(values, properties) {
        const showInvisibile = !!this.survey && this.survey.areInvisibleElementsShowing;
        const runner = !showInvisibile ? this.createRowsVisibleIfRunner() : null;
        this.filteredRows = [];
        const hasChanged = ItemValue.runConditionsForItems(this.rows, this.filteredRows, runner, values, properties, !showInvisibile);
        ItemValue.runEnabledConditionsForItems(this.rows, undefined, values, properties);
        if (this.filteredRows.length === this.rows.length) {
            this.filteredRows = null;
        }
        return hasChanged;
    }
    runConditionsForColumns(values, properties) {
        const useColumnsExpression = !!this.survey && !this.survey.areInvisibleElementsShowing;
        const runner = useColumnsExpression && !!this.columnsVisibleIf ? new ConditionRunner(this.columnsVisibleIf) : null;
        return ItemValue.runConditionsForItems(this.columns, undefined, runner, values, properties, this.shouldRunColumnExpression());
    }
    clearInvisibleColumnValues() { }
    clearInvisibleValuesInRows() { }
    needResponsiveWidth() {
        //TODO: make it mor intelligent
        return true;
    }
    get columnsAutoWidth() {
        return !this.isMobile && !this.columns.some(col => !!col.width);
    }
    getTableCss() {
        var _a;
        return new CssClassBuilder()
            .append(this.cssClasses.root)
            .append(this.cssClasses.columnsAutoWidth, this.columnsAutoWidth)
            .append(this.cssClasses.noHeader, !this.showHeader)
            .append(this.cssClasses.hasFooter, !!((_a = this.renderedTable) === null || _a === void 0 ? void 0 : _a.showAddRowOnBottom))
            .append(this.cssClasses.rootAlternateRows, this.alternateRows)
            .append(this.cssClasses.rootVerticalAlignTop, (this.verticalAlign === "top"))
            .append(this.cssClasses.rootVerticalAlignMiddle, (this.verticalAlign === "middle")).toString();
    }
    /**
     * Minimum column width in CSS values.
     *
     * [Multi-Select Matrix Demo](https://surveyjs.io/form-library/examples/multi-select-matrix-question/ (linkStyle))
     *
     * [Dynamic Matrix Demo](https://surveyjs.io/form-library/examples/dynamic-matrix-add-new-rows/ (linkStyle))
     * @see width
     */
    get columnMinWidth() {
        return this.getPropertyValue("columnMinWidth") || "";
    }
    set columnMinWidth(val) {
        this.setPropertyValue("columnMinWidth", val);
    }
    /**
     * A width for the column that displays row titles (first column). Accepts CSS values.
     */
    get rowTitleWidth() {
        return this.getPropertyValue("rowTitleWidth") || "";
    }
    set rowTitleWidth(val) {
        this.setPropertyValue("rowTitleWidth", val);
    }
    /**
     * Specifies how to arrange matrix questions.
     *
     * Possible values:
     *
     * - `"table"` - Displays matrix questions in a table.
     * - `"list"` - Displays matrix questions one under another as a list.
     * - `"auto"` (default) - Uses the `"table"` mode if the survey has sufficient width to fit the table or the `"list"` mode otherwise.
     */
    set displayMode(val) {
        this.setPropertyValue("displayMode", val);
    }
    get displayMode() {
        return this.getPropertyValue("displayMode");
    }
    //a11y
    getCellAriaLabel(row, column, directRowTitle) {
        let rowTitle = row.locText && row.locText.renderedHtml ? row.locText.renderedHtml : "";
        if (directRowTitle)
            rowTitle = directRowTitle;
        const columnTitle = column.locTitle && column.locTitle.renderedHtml ? column.locTitle.renderedHtml : "";
        const rowString = (this.getLocalizationString("matrix_row") || "row").toLocaleLowerCase();
        const columnString = (this.getLocalizationString("matrix_column") || "column").toLocaleLowerCase();
        return `${rowString} ${rowTitle}, ${columnString} ${columnTitle}`;
    }
    get isNewA11yStructure() {
        return true;
    }
    // EO a11y
    getIsMobile() {
        if (this.displayMode == "auto")
            return super.getIsMobile();
        return this.displayMode === "list";
    }
}
__decorate([
    property()
], QuestionMatrixBaseModel.prototype, "verticalAlign", void 0);
__decorate([
    property()
], QuestionMatrixBaseModel.prototype, "alternateRows", void 0);
Serializer.addClass("matrixbase", [
    { name: "showCommentArea:switch", layout: "row", visible: true, category: "general" },
    "columnsVisibleIf:condition",
    "rowsVisibleIf:condition",
    "columnMinWidth",
    { name: "showHeader:boolean", default: true },
    {
        name: "verticalAlign",
        choices: ["top", "middle"],
        default: "middle",
    },
    { name: "alternateRows:boolean", default: false },
    {
        name: "displayMode",
        default: "auto",
        choices: ["auto", "table", "list"],
        visible: false
    },
], undefined, "question");

class TextPreProcessorItem {
}
class TextPreProcessorValue {
    constructor(name, returnDisplayValue) {
        this.name = name;
        this.returnDisplayValue = returnDisplayValue;
        this.isExists = false;
        this.canProcess = true;
    }
}
class TextPreProcessor {
    constructor() {
        this._unObservableValues = [undefined];
    }
    get hasAllValuesOnLastRunValue() {
        return this._unObservableValues[0];
    }
    set hasAllValuesOnLastRunValue(val) {
        this._unObservableValues[0] = val;
    }
    process(text, returnDisplayValue, doEncoding, replaceUndefinedValues) {
        this.hasAllValuesOnLastRunValue = true;
        if (!text)
            return text;
        if (!this.onProcess)
            return text;
        const items = this.getItems(text);
        for (let i = items.length - 1; i >= 0; i--) {
            const item = items[i];
            const name = this.getName(text.substring(item.start + 1, item.end));
            if (!!name) {
                const textValue = new TextPreProcessorValue(name, returnDisplayValue === true);
                this.onProcess(textValue);
                if (!textValue.isExists) {
                    if (textValue.canProcess) {
                        this.hasAllValuesOnLastRunValue = false;
                    }
                }
                if (textValue.isExists || replaceUndefinedValues) {
                    if (Helpers.isValueEmpty(textValue.value)) {
                        this.hasAllValuesOnLastRunValue = false;
                    }
                    var replacedValue = !Helpers.isValueEmpty(textValue.value)
                        ? textValue.value
                        : "";
                    if (doEncoding) {
                        replacedValue = encodeURIComponent(replacedValue);
                    }
                    text = text.substring(0, item.start) + replacedValue + text.substring(item.end + 1);
                }
            }
        }
        return text;
    }
    processValue(name, returnDisplayValue) {
        var textValue = new TextPreProcessorValue(name, returnDisplayValue);
        if (!!this.onProcess) {
            this.onProcess(textValue);
        }
        return textValue;
    }
    get hasAllValuesOnLastRun() { return !!this.hasAllValuesOnLastRunValue; }
    processText(text, returnDisplayValue) {
        return this.process(text, returnDisplayValue);
    }
    processTextEx(params) {
        const res = { hasAllValuesOnLastRun: true, text: params.text };
        res.text = this.process(params.text, params.returnDisplayValue, params.doEncoding, params.replaceUndefinedValues);
        res.hasAllValuesOnLastRun = this.hasAllValuesOnLastRun;
        return res;
    }
    getItems(text) {
        var items = [];
        var length = text.length;
        var start = -1;
        var ch = "";
        for (var i = 0; i < length; i++) {
            ch = text[i];
            if (ch == "{")
                start = i;
            if (ch == "}") {
                if (start > -1) {
                    var item = new TextPreProcessorItem();
                    item.start = start;
                    item.end = i;
                    if (this.isValidItemName(text.substring(start + 1, i - 1))) {
                        items.push(item);
                    }
                }
                start = -1;
            }
        }
        return items;
    }
    isValidItemName(name) {
        return !!name && name.indexOf(":") < 0;
    }
    getName(name) {
        if (!name)
            return;
        return name.trim();
    }
}
class QuestionTextProcessor {
    constructor(variableName) {
        this.variableName = variableName;
        this.textPreProcessor = new TextPreProcessor();
        this.textPreProcessor.onProcess = (textValue) => {
            this.getProcessedTextValue(textValue);
        };
    }
    processValue(name, returnDisplayValue) {
        return this.textPreProcessor.processValue(name, returnDisplayValue);
    }
    get survey() {
        return null;
    }
    get panel() {
        return null;
    }
    getValues() {
        return !!this.panel ? this.panel.getValue() : null;
    }
    getQuestionByName(name) {
        return !!this.panel
            ? this.panel.getQuestionByValueName(name)
            : null;
    }
    getParentTextProcessor() { return null; }
    onCustomProcessText(textValue) {
        return false;
    }
    getQuestionDisplayText(question) {
        return question.displayValue;
    }
    //ITextProcessor
    getProcessedTextValue(textValue) {
        if (!textValue)
            return;
        if (this.onCustomProcessText(textValue))
            return;
        var firstName = new ProcessValue().getFirstName(textValue.name);
        textValue.isExists = firstName == this.variableName;
        textValue.canProcess = textValue.isExists;
        if (!textValue.canProcess)
            return;
        //name should start with the variable name
        textValue.name = textValue.name.replace(this.variableName + ".", "");
        var firstName = new ProcessValue().getFirstName(textValue.name);
        var question = this.getQuestionByName(firstName);
        var values = {};
        if (question) {
            values[firstName] = textValue.returnDisplayValue
                ? this.getQuestionDisplayText(question)
                : question.value;
        }
        else {
            const allValues = this.getValues();
            if (allValues) {
                values[firstName] = allValues[firstName];
            }
        }
        textValue.value = new ProcessValue().getValue(textValue.name, values);
    }
    processText(text, returnDisplayValue) {
        const params = { text: text, returnDisplayValue: returnDisplayValue };
        return this.processTextEx(params).text;
    }
    processTextEx(params) {
        var _a;
        const res = { hasAllValuesOnLastRun: true, text: params.text };
        if (!params.runAtDesign && ((_a = this.survey) === null || _a === void 0 ? void 0 : _a.isDesignMode))
            return res;
        const processors = new Array();
        this.addTextPreProcessor(processors, this.textPreProcessor);
        this.addTextPreProcessor(processors, this.getParentTextProcessor());
        this.addTextPreProcessor(processors, this.survey);
        for (let i = 0; i < processors.length; i++) {
            const processor = processors[i];
            params.text = res.text;
            params.doEncoding = params.doEncoding || false;
            const processorRes = processor.processTextEx(params);
            res.text = processorRes.text;
            res.hasAllValuesOnLastRun = res.hasAllValuesOnLastRun && processorRes.hasAllValuesOnLastRun;
        }
        return res;
    }
    addTextPreProcessor(list, textProcessor) {
        if (!textProcessor || list.indexOf(textProcessor) > -1)
            return;
        list.push(textProcessor);
    }
}

class ComponentQuestionJSON {
    constructor(name, json) {
        this.name = name;
        this.json = json;
        var self = this;
        Serializer.addClass(name, [], function (json) {
            return ComponentCollection.Instance.createQuestion(!!json ? json.name : "", self);
        }, "question");
        this.onInit();
    }
    onInit() {
        if (!this.json.onInit)
            return;
        this.json.onInit();
    }
    onCreated(question) {
        if (!this.json.onCreated)
            return;
        this.json.onCreated(question);
    }
    onLoaded(question) {
        if (!this.json.onLoaded)
            return;
        this.json.onLoaded(question);
    }
    onAfterRender(question, htmlElement) {
        if (!this.json.onAfterRender)
            return;
        this.json.onAfterRender(question, htmlElement);
    }
    onAfterRenderContentElement(question, element, htmlElement) {
        if (!this.json.onAfterRenderContentElement)
            return;
        this.json.onAfterRenderContentElement(question, element, htmlElement);
    }
    onUpdateQuestionCssClasses(question, element, css) {
        if (!this.json.onUpdateQuestionCssClasses)
            return;
        this.json.onUpdateQuestionCssClasses(question, element, css);
    }
    onSetQuestionValue(question, newValue) {
        if (this.json.onSetQuestionValue) {
            this.json.onSetQuestionValue(question, newValue);
        }
        if (this.json.onValueSet) {
            this.json.onValueSet(question, newValue);
        }
    }
    onPropertyChanged(question, propertyName, newValue) {
        if (!this.json.onPropertyChanged)
            return;
        this.json.onPropertyChanged(question, propertyName, newValue);
    }
    onValueChanged(question, name, newValue) {
        if (!this.json.onValueChanged)
            return;
        this.json.onValueChanged(question, name, newValue);
    }
    onValueChanging(question, name, newValue) {
        if (!this.json.onValueChanging)
            return newValue;
        return this.json.onValueChanging(question, name, newValue);
    }
    onGetErrorText(question) {
        if (!this.json.getErrorText)
            return undefined;
        return this.json.getErrorText(question);
    }
    onItemValuePropertyChanged(question, item, propertyName, name, newValue) {
        if (!this.json.onItemValuePropertyChanged)
            return;
        this.json.onItemValuePropertyChanged(question, {
            obj: item,
            propertyName: propertyName,
            name: name,
            newValue: newValue,
        });
    }
    getDisplayValue(keyAsText, value, question) {
        if (!this.json.getDisplayValue)
            return question.getDisplayValue(keyAsText, value);
        return this.json.getDisplayValue(question);
    }
    get defaultQuestionTitle() {
        return this.json.defaultQuestionTitle;
    }
    setValueToQuestion(val) {
        const converter = this.json.valueToQuestion || this.json.setValue;
        return !!converter ? converter(val) : val;
    }
    getValueFromQuestion(val) {
        const converter = this.json.valueFromQuestion || this.json.getValue;
        return !!converter ? converter(val) : val;
    }
    get isComposite() {
        return !!this.json.elementsJSON || !!this.json.createElements;
    }
    getDynamicProperties() {
        if (!Array.isArray(this.dynamicProperties)) {
            this.dynamicProperties = this.calcDynamicProperties();
        }
        return this.dynamicProperties;
    }
    calcDynamicProperties() {
        const baseProps = this.json.inheritBaseProps;
        if (!baseProps || !this.json.questionJSON)
            return [];
        const type = this.json.questionJSON.type;
        if (!type)
            return [];
        if (Array.isArray(baseProps)) {
            const props = [];
            baseProps.forEach(name => {
                const prop = Serializer.findProperty(type, name);
                if (prop) {
                    props.push(prop);
                }
            });
            return props;
        }
        const invalidNames = [];
        for (let key in this.json.questionJSON) {
            invalidNames.push(key);
        }
        return Serializer.getDynamicPropertiesByTypes(this.name, type, invalidNames);
    }
}
class ComponentCollection {
    constructor() {
        this.customQuestionValues = [];
    }
    add(json) {
        if (!json)
            return;
        let name = json.name;
        if (!name) {
            throw "Attribute name is missed";
        }
        name = name.toLowerCase();
        if (!!this.getCustomQuestionByName(name)) {
            throw "There is already registered custom question with name '" +
                name +
                "'";
        }
        if (!!Serializer.findClass(name)) {
            throw "There is already class with name '" + name + "'";
        }
        var customQuestion = new ComponentQuestionJSON(name, json);
        if (!!this.onAddingJson)
            this.onAddingJson(name, customQuestion.isComposite);
        this.customQuestionValues.push(customQuestion);
    }
    remove(componentName) {
        if (!componentName)
            return false;
        const index = this.getCustomQuestionIndex(componentName.toLowerCase());
        if (index < 0)
            return false;
        this.removeByIndex(index);
        return true;
    }
    get items() {
        return this.customQuestionValues;
    }
    getCustomQuestionByName(name) {
        const index = this.getCustomQuestionIndex(name);
        return index >= 0 ? this.customQuestionValues[index] : undefined;
    }
    getCustomQuestionIndex(name) {
        for (var i = 0; i < this.customQuestionValues.length; i++) {
            if (this.customQuestionValues[i].name === name)
                return i;
        }
        return -1;
    }
    removeByIndex(index) {
        Serializer.removeClass(this.customQuestionValues[index].name);
        this.customQuestionValues.splice(index, 1);
    }
    clear(includeInternal) {
        for (let i = this.customQuestionValues.length - 1; i >= 0; i--) {
            if (includeInternal || !this.customQuestionValues[i].json.internal) {
                this.removeByIndex(i);
            }
        }
    }
    createQuestion(name, questionJSON) {
        if (!!questionJSON.isComposite)
            return this.createCompositeModel(name, questionJSON);
        return this.createCustomModel(name, questionJSON);
    }
    createCompositeModel(name, questionJSON) {
        if (!!this.onCreateComposite)
            return this.onCreateComposite(name, questionJSON);
        return new QuestionCompositeModel(name, questionJSON);
    }
    createCustomModel(name, questionJSON) {
        if (!!this.onCreateCustom)
            return this.onCreateCustom(name, questionJSON);
        return new QuestionCustomModel(name, questionJSON);
    }
}
ComponentCollection.Instance = new ComponentCollection();
class QuestionCustomModelBase extends Question {
    constructor(name, customQuestion) {
        super(name);
        this.customQuestion = customQuestion;
        CustomPropertiesCollection.createProperties(this);
        SurveyElement.CreateDisabledDesignElements = true;
        this.locQuestionTitle = this.createLocalizableString("questionTitle", this);
        this.locQuestionTitle.setJson(this.customQuestion.defaultQuestionTitle);
        this.createWrapper();
        SurveyElement.CreateDisabledDesignElements = false;
        if (!!this.customQuestion) {
            this.customQuestion.onCreated(this);
        }
    }
    getType() {
        return !!this.customQuestion ? this.customQuestion.name : "custom";
    }
    locStrsChanged() {
        super.locStrsChanged();
        if (!!this.getElement()) {
            this.getElement().locStrsChanged();
        }
    }
    localeChanged() {
        super.locStrsChanged();
        if (!!this.getElement()) {
            this.getElement().localeChanged();
        }
    }
    getDefaultTitle() {
        if (!this.locQuestionTitle.isEmpty) {
            return this.getProcessedText(this.locQuestionTitle.textOrHtml);
        }
        return super.getDefaultTitle();
    }
    addUsedLocales(locales) {
        super.addUsedLocales(locales);
        if (!!this.getElement()) {
            this.getElement().addUsedLocales(locales);
        }
    }
    needResponsiveWidth() {
        const el = this.getElement();
        return !!el ? el.needResponsiveWidth() : false;
    }
    createWrapper() { }
    onPropertyValueChanged(name, oldValue, newValue) {
        super.onPropertyValueChanged(name, oldValue, newValue);
        if (!!this.customQuestion && !this.isLoadingFromJson) {
            this.customQuestion.onPropertyChanged(this, name, newValue);
        }
    }
    itemValuePropertyChanged(item, name, oldValue, newValue) {
        super.itemValuePropertyChanged(item, name, oldValue, newValue);
        if (!!this.customQuestion && !this.isLoadingFromJson) {
            this.customQuestion.onItemValuePropertyChanged(this, item, item.ownerPropertyName, name, newValue);
        }
    }
    onFirstRenderingCore() {
        super.onFirstRenderingCore();
        const el = this.getElement();
        if (!!el) {
            el.onFirstRendering();
        }
    }
    onHidingContent() {
        super.onHidingContent();
        const el = this.getElement();
        if (!!el) {
            el.onHidingContent();
        }
    }
    getProgressInfo() {
        let res = super.getProgressInfo();
        if (!!this.getElement()) {
            res = this.getElement().getProgressInfo();
        }
        if (this.isRequired && res.requiredQuestionCount == 0) {
            res.requiredQuestionCount = 1;
            if (!this.isEmpty()) {
                res.answeredQuestionCount = 1;
            }
        }
        return res;
    }
    initElement(el) {
        if (!el)
            return;
        el.setSurveyImpl(this);
        el.disableDesignActions = true;
    }
    setSurveyImpl(value, isLight) {
        this.isSettingValOnLoading = true;
        super.setSurveyImpl(value, isLight);
        this.initElement(this.getElement());
        this.isSettingValOnLoading = false;
    }
    onSurveyLoad() {
        super.onSurveyLoad();
        if (!!this.getElement()) {
            this.getElement().onSurveyLoad();
            this.customQuestion.onLoaded(this);
        }
    }
    afterRenderQuestionElement(el) {
        //Do nothing
    }
    afterRenderCore(el) {
        super.afterRenderCore(el);
        if (!!this.customQuestion) {
            this.customQuestion.onAfterRender(this, el);
        }
    }
    onUpdateQuestionCssClasses(element, css) {
        if (!!this.customQuestion) {
            this.customQuestion.onUpdateQuestionCssClasses(this, element, css);
        }
    }
    setQuestionValue(newValue, updateIsAnswered = true) {
        super.setQuestionValue(newValue, updateIsAnswered);
        this.updateElementCss();
        if (!!this.customQuestion) {
            this.customQuestion.onSetQuestionValue(this, newValue);
        }
    }
    setNewValue(newValue) {
        super.setNewValue(newValue);
        this.updateElementCss();
    }
    onCheckForErrors(errors, isOnValueChanged, fireCallback) {
        super.onCheckForErrors(errors, isOnValueChanged, fireCallback);
        if (!!this.customQuestion) {
            const text = this.customQuestion.onGetErrorText(this);
            if (!!text) {
                errors.push(new CustomError(text, this));
            }
        }
    }
    //ISurveyImpl
    getSurveyData() {
        return this;
    }
    getTextProcessor() {
        return this.textProcessor;
    }
    //ISurveyData
    getValue(name) {
        return this.value;
    }
    setValue(name, newValue, locNotification, allowNotifyValueChanged) {
        if (!this.data)
            return;
        if (!!this.customQuestion) {
            this.customQuestion.onValueChanged(this, name, newValue);
        }
        var newName = this.convertDataName(name);
        let valueForSurvey = this.convertDataValue(name, newValue);
        if (this.valueToDataCallback) {
            valueForSurvey = this.valueToDataCallback(valueForSurvey);
        }
        this.data.setValue(newName, valueForSurvey, locNotification, allowNotifyValueChanged);
        this.updateIsAnswered();
        this.updateElementCss();
    }
    getQuestionByName(name) {
        return undefined;
    }
    isValueChanging(name, newValue) {
        if (!!this.customQuestion) {
            const qValue = newValue;
            newValue = this.customQuestion.onValueChanging(this, name, newValue);
            if (!Helpers.isTwoValueEquals(newValue, qValue)) {
                const q = this.getQuestionByName(name);
                if (!!q) {
                    q.value = newValue;
                    return true;
                }
            }
        }
        return false;
    }
    convertDataName(name) {
        return this.getValueName();
    }
    convertDataValue(name, newValue) {
        return newValue;
    }
    getVariable(name) {
        return !!this.data ? this.data.getVariable(name) : null;
    }
    setVariable(name, newValue) {
        if (!this.data)
            return;
        this.data.setVariable(name, newValue);
    }
    getComment(name) {
        return !!this.data ? this.data.getComment(this.getValueName()) : "";
    }
    setComment(name, newValue, locNotification) {
        if (!this.data)
            return;
        this.data.setComment(this.getValueName(), newValue, locNotification);
    }
    getAllValues() {
        return !!this.data ? this.data.getAllValues() : {};
    }
    getFilteredValues() {
        return !!this.data ? this.data.getFilteredValues() : {};
    }
    getFilteredProperties() {
        return !!this.data ? this.data.getFilteredProperties() : {};
    }
    findQuestionByName(name) {
        return !!this.data ? this.data.findQuestionByName(name) : null;
    }
    getEditingSurveyElement() {
        return undefined;
    }
    //IPanel
    addElement(element, index) { }
    removeElement(element) {
        return false;
    }
    getQuestionTitleLocation() {
        return "left";
    }
    getQuestionTitleWidth() {
        return undefined;
    }
    getColumsForElement(el) {
        return [];
    }
    updateColumns() { }
    getQuestionStartIndex() {
        return this.getStartIndex();
    }
    getChildrenLayoutType() {
        return "row";
    }
    elementWidthChanged(el) { }
    get elements() {
        return [];
    }
    indexOf(el) {
        return -1;
    }
    ensureRowsVisibility() {
        // do nothing
    }
    validateContainerOnly() {
        // do nothing
    }
    onQuestionValueChanged(el) {
        // do nothing
    }
    getQuestionErrorLocation() {
        return this.getErrorLocation();
    }
    getContentAriaHidden() {
        return this.isDesignMode || super.getContentAriaHidden();
    }
    getContentDisplayValueCore(keyAsText, value, question) {
        if (!question)
            return super.getDisplayValueCore(keyAsText, value);
        return this.customQuestion.getDisplayValue(keyAsText, value, question);
    }
}
class QuestionCustomModel extends QuestionCustomModelBase {
    getTemplate() {
        return "custom";
    }
    getDynamicProperties() {
        return this.customQuestion.getDynamicProperties() || [];
    }
    getDynamicType() {
        return this.questionWrapper ? this.questionWrapper.getType() : "question";
    }
    getOriginalObj() {
        return this.questionWrapper;
    }
    createWrapper() {
        this.questionWrapper = this.createQuestion();
        this.createDynamicProperties(this.questionWrapper);
        if (this.getDynamicProperties().length > 0) {
            this.questionWrapper.onPropertyValueChangedCallback = (name, oldValue, newValue, sender, arrayChanges) => {
                const prop = this.getDynamicProperty(name);
                if (prop) {
                    this.propertyValueChanged(name, oldValue, newValue, arrayChanges);
                }
            };
        }
    }
    getDynamicProperty(name) {
        const props = this.getDynamicProperties();
        for (let i = 0; i < props.length; i++) {
            if (props[i].name === name)
                return props[i];
        }
        return null;
    }
    getElement() {
        return this.contentQuestion;
    }
    onAnyValueChanged(name, questionName) {
        super.onAnyValueChanged(name, questionName);
        if (!!this.contentQuestion) {
            this.contentQuestion.onAnyValueChanged(name, questionName);
        }
    }
    getQuestionByName(name) {
        return this.contentQuestion;
    }
    getDefaultTitle() {
        if (this.hasJSONTitle && this.contentQuestion) {
            return this.getProcessedText(this.contentQuestion.title);
        }
        return super.getDefaultTitle();
    }
    setValue(name, newValue, locNotification, allowNotifyValueChanged) {
        if (this.isValueChanging(name, newValue))
            return;
        super.setValue(name, newValue, locNotification, allowNotifyValueChanged);
    }
    updateCommentFromSurvey(newValue) {
        super.updateCommentFromSurvey(newValue);
        const q = this.contentQuestion;
        if (!!q) {
            q.updateCommentFromSurvey(newValue);
        }
    }
    get requireUpdateCommentValue() { var _a; return (_a = this.contentQuestion) === null || _a === void 0 ? void 0 : _a.requireUpdateCommentValue; }
    onSetData() {
        super.onSetData();
        if (!!this.survey && !this.isEmpty()) {
            this.setValue(this.name, this.value, false, this.allowNotifyValueChanged);
        }
    }
    hasErrors(fireCallback = true, rec = null) {
        if (!this.contentQuestion)
            return false;
        var res = this.contentQuestion.hasErrors(fireCallback, rec);
        this.errors = [];
        for (var i = 0; i < this.contentQuestion.errors.length; i++) {
            this.errors.push(this.contentQuestion.errors[i]);
        }
        if (!res) {
            res = super.hasErrors(fireCallback, rec);
        }
        this.updateElementCss();
        return res;
    }
    focus(onError = false) {
        if (!!this.contentQuestion) {
            this.contentQuestion.focus(onError);
        }
        else {
            super.focus(onError);
        }
    }
    afterRenderCore(el) {
        super.afterRenderCore(el);
        if (!!this.contentQuestion) {
            this.contentQuestion.afterRender(el);
        }
    }
    get contentQuestion() {
        return this.questionWrapper;
    }
    createQuestion() {
        var json = this.customQuestion.json;
        var res = null;
        if (!!json.questionJSON) {
            this.hasJSONTitle = !!json.questionJSON.title;
            let qType = json.questionJSON.type;
            if (!qType || !Serializer.findClass(qType))
                throw "type attribute in questionJSON is empty or incorrect";
            res = Serializer.createClass(qType);
            res.fromJSON(json.questionJSON);
            res = this.checkCreatedQuestion(res);
        }
        else {
            if (!!json.createQuestion) {
                res = this.checkCreatedQuestion(json.createQuestion());
            }
        }
        this.initElement(res);
        if (!!res) {
            res.isContentElement = true;
            if (!res.name) {
                res.name = "question";
            }
            res.onUpdateCssClassesCallback = (css) => {
                this.onUpdateQuestionCssClasses(res, css);
            };
            res.hasCssErrorCallback = () => this.errors.length > 0;
            res.setValueChangedDirectlyCallback = (val) => { this.setValueChangedDirectly(val); };
        }
        return res;
    }
    checkCreatedQuestion(res) {
        if (!res)
            return res;
        if (!res.isQuestion) {
            if (Array.isArray(res.questions) && res.questions.length > 0) {
                res = res.questions[0];
            }
            else {
                res = Serializer.createClass("text");
            }
            ConsoleWarnings.error("Could not create component: '" + this.getType() + "'. questionJSON should be a question.");
        }
        return res;
    }
    onSurveyLoad() {
        super.onSurveyLoad();
        if (!this.contentQuestion)
            return;
        if (this.isEmpty() && !this.contentQuestion.isEmpty()) {
            this.value = this.getContentQuestionValue();
        }
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        if (!!this.contentQuestion) {
            this.contentQuestion.runCondition(values, properties);
        }
    }
    convertDataName(name) {
        const q = this.contentQuestion;
        if (!q || name === this.getValueName())
            return super.convertDataName(name);
        var newName = name.replace(q.getValueName(), this.getValueName());
        return newName.indexOf(this.getValueName()) == 0
            ? newName
            : super.convertDataName(name);
    }
    convertDataValue(name, newValue) {
        return this.convertDataName(name) == super.convertDataName(name)
            ? this.getContentQuestionValue()
            : newValue;
    }
    getContentQuestionValue() {
        if (!this.contentQuestion)
            return undefined;
        let val = this.contentQuestion.value;
        if (!!this.customQuestion)
            val = this.customQuestion.getValueFromQuestion(val);
        return val;
    }
    setContentQuestionValue(val) {
        if (!this.contentQuestion)
            return;
        if (!!this.customQuestion)
            val = this.customQuestion.setValueToQuestion(val);
        this.contentQuestion.value = val;
    }
    canSetValueToSurvey() {
        return false;
    }
    setQuestionValue(newValue, updateIsAnswered = true) {
        super.setQuestionValue(newValue, updateIsAnswered);
        if (!this.isLoadingFromJson && !!this.contentQuestion &&
            !this.isTwoValueEquals(this.getContentQuestionValue(), newValue)) {
            this.setContentQuestionValue(this.getUnbindValue(newValue));
        }
    }
    onSurveyValueChanged(newValue) {
        super.onSurveyValueChanged(newValue);
        if (!!this.contentQuestion) {
            this.contentQuestion.onSurveyValueChanged(newValue);
        }
    }
    getValueCore() {
        if (!!this.contentQuestion)
            return this.getContentQuestionValue();
        return super.getValueCore();
    }
    setValueChangedDirectly(val) {
        if (this.isSettingValueChanged)
            return;
        this.isSettingValueChanged = true;
        super.setValueChangedDirectly(val);
        if (!!this.contentQuestion) {
            this.contentQuestion.setValueChangedDirectly(val);
        }
        this.isSettingValueChanged = false;
    }
    createDynamicProperties(el) {
        if (!el)
            return;
        const props = this.getDynamicProperties();
        if (Array.isArray(props)) {
            Serializer.addDynamicPropertiesIntoObj(this, el, props);
        }
    }
    initElement(el) {
        super.initElement(el);
        if (!!el) {
            el.parent = this;
            el.afterRenderQuestionCallback = (question, element) => {
                if (!!this.customQuestion) {
                    this.customQuestion.onAfterRenderContentElement(this, question, element);
                }
            };
        }
    }
    updateElementCss(reNew) {
        if (!!this.contentQuestion) {
            this.questionWrapper.updateElementCss(reNew);
        }
        super.updateElementCss(reNew);
    }
    setIsMobile(val) {
        super.setIsMobile(val);
        if (!!this.contentQuestion) {
            this.contentQuestion.setIsMobile(val);
        }
    }
    updateElementCssCore(cssClasses) {
        if (!!this.contentQuestion) {
            cssClasses = this.contentQuestion.cssClasses;
        }
        super.updateElementCssCore(cssClasses);
    }
    getDisplayValueCore(keyAsText, value) {
        return super.getContentDisplayValueCore(keyAsText, value, this.contentQuestion);
    }
}
class QuestionCompositeTextProcessor extends QuestionTextProcessor {
    constructor(composite, variableName) {
        super(variableName);
        this.composite = composite;
        this.variableName = variableName;
    }
    get survey() {
        return this.composite.survey;
    }
    get panel() {
        return this.composite.contentPanel;
    }
}
class QuestionCompositeModel extends QuestionCustomModelBase {
    constructor(name, customQuestion) {
        super(name, customQuestion);
        this.customQuestion = customQuestion;
        this.settingNewValue = false;
        this.textProcessing = new QuestionCompositeTextProcessor(this, QuestionCompositeModel.ItemVariableName);
    }
    createWrapper() {
        this.panelWrapper = this.createPanel();
    }
    getTemplate() {
        return "composite";
    }
    getElement() {
        return this.contentPanel;
    }
    getCssRoot(cssClasses) {
        return new CssClassBuilder().append(super.getCssRoot(cssClasses)).append(cssClasses.composite).toString();
    }
    get contentPanel() {
        return this.panelWrapper;
    }
    hasErrors(fireCallback = true, rec = null) {
        var res = super.hasErrors(fireCallback, rec);
        if (!this.contentPanel)
            return res;
        return this.contentPanel.hasErrors(fireCallback, false, rec) || res;
    }
    updateElementCss(reNew) {
        super.updateElementCss(reNew);
        if (this.contentPanel) {
            this.contentPanel.updateElementCss(reNew);
        }
    }
    dispose() {
        this.unConnectEditingObj();
        super.dispose();
    }
    updateEditingObj() {
        var _a;
        const obj = (_a = this.data) === null || _a === void 0 ? void 0 : _a.getEditingSurveyElement();
        if (!obj)
            return undefined;
        let newObj = obj[this.getValueName()];
        if (!!newObj && !newObj.onPropertyChanged) {
            newObj = undefined;
        }
        if (newObj !== this.editingObjValue) {
            this.unConnectEditingObj();
            this.editingObjValue = newObj;
            if (!!newObj) {
                this.onEditingObjPropertyChanged = (sender, options) => {
                    this.setNewValueIntoQuestion(options.name, this.editingObjValue[options.name]);
                };
                newObj.onPropertyChanged.add(this.onEditingObjPropertyChanged);
            }
        }
        return this.editingObjValue;
    }
    unConnectEditingObj() {
        if (!!this.editingObjValue && !this.editingObjValue.isDisposed) {
            this.editingObjValue.onPropertyChanged.remove(this.onEditingObjPropertyChanged);
        }
    }
    getEditingSurveyElement() {
        return this.editingObjValue;
    }
    getTextProcessor() {
        return this.textProcessing;
    }
    findQuestionByName(name) {
        const res = this.getQuestionByName(name);
        if (!!res)
            return res;
        return super.findQuestionByName(name);
    }
    clearValueIfInvisibleCore(reason) {
        super.clearValueIfInvisibleCore(reason);
        const questions = this.contentPanel.questions;
        for (var i = 0; i < questions.length; i++) {
            questions[i].clearValueIfInvisible(reason);
        }
    }
    onAnyValueChanged(name, questionName) {
        super.onAnyValueChanged(name, questionName);
        var questions = this.contentPanel.questions;
        for (var i = 0; i < questions.length; i++) {
            questions[i].onAnyValueChanged(name, questionName);
        }
    }
    get hasSingleInput() { return false; }
    get isContainer() { return true; }
    createPanel() {
        var res = Serializer.createClass("panel");
        res.showQuestionNumbers = "off";
        res.renderWidth = "100%";
        var json = this.customQuestion.json;
        if (!!json.elementsJSON) {
            res.fromJSON({ elements: json.elementsJSON });
        }
        if (!!json.createElements) {
            json.createElements(res, this);
        }
        this.initElement(res);
        res.readOnly = this.isReadOnly;
        res.questions.forEach(q => {
            q.setParentQuestion(this);
            q.onUpdateCssClassesCallback = (css) => { this.onUpdateQuestionCssClasses(q, css); };
        });
        this.setAfterRenderCallbacks(res);
        return res;
    }
    onReadOnlyChanged() {
        if (!!this.contentPanel) {
            this.contentPanel.readOnly = this.isReadOnly;
        }
        super.onReadOnlyChanged();
    }
    updateValueFromSurvey(newValue, clearData = false) {
        this.updateEditingObj();
        super.updateValueFromSurvey(newValue, clearData);
    }
    onSurveyLoad() {
        this.isSettingValOnLoading = true;
        if (!!this.contentPanel) {
            this.contentPanel.readOnly = this.isReadOnly;
            this.setIsContentElement(this.contentPanel);
        }
        super.onSurveyLoad();
        if (!!this.contentPanel) {
            const val = this.getContentPanelValue();
            if (!Helpers.isValueEmpty(val)) {
                this.value = val;
            }
        }
        this.isSettingValOnLoading = false;
    }
    setIsContentElement(panel) {
        panel.isContentElement = true;
        var elements = panel.elements;
        for (var i = 0; i < elements.length; i++) {
            var el = elements[i];
            if (el.isPanel) {
                this.setIsContentElement(el);
            }
            else {
                el.isContentElement = true;
            }
        }
    }
    setVisibleIndex(val) {
        var res = super.setVisibleIndex(val);
        if (this.isVisible && !!this.contentPanel) {
            res += this.contentPanel.setVisibleIndex(val);
        }
        return res;
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        if (!!this.contentPanel) {
            var oldComposite = values[QuestionCompositeModel.ItemVariableName];
            values[QuestionCompositeModel.ItemVariableName] = this.contentPanel.getValue();
            this.contentPanel.runCondition(values, properties);
            delete values[QuestionCompositeModel.ItemVariableName];
            if (!!oldComposite) {
                values[QuestionCompositeModel.ItemVariableName] = oldComposite;
            }
        }
    }
    onSurveyValueChanged(newValue) {
        super.onSurveyValueChanged(newValue);
        const val = !!newValue ? newValue : {};
        if (!!this.contentPanel) {
            this.contentPanel.questions.forEach(q => {
                q.onSurveyValueChanged(val[q.getValueName()]);
            });
        }
    }
    getValue(name) {
        var val = this.value;
        return !!val ? val[name] : null;
    }
    getQuestionByName(name) {
        return !!this.contentPanel ? this.contentPanel.getQuestionByName(name) : undefined;
    }
    setValue(name, newValue, locNotification, allowNotifyValueChanged) {
        if (this.settingNewValue) {
            this.setNewValueIntoQuestion(name, newValue);
            return;
        }
        if (this.isValueChanging(name, newValue))
            return;
        this.settingNewValue = true;
        if (!this.isEditingSurveyElement && !!this.contentPanel) {
            let index = 0;
            const maxTimes = this.contentPanel.questions.length + 1;
            while (index < maxTimes && this.updateValueCoreWithPanelValue())
                index++;
        }
        this.setNewValueIntoQuestion(name, newValue);
        super.setValue(name, newValue, locNotification, allowNotifyValueChanged);
        this.settingNewValue = false;
        this.runPanelTriggers(QuestionCompositeModel.ItemVariableName + "." + name, newValue);
    }
    setComment(name, newValue, locNotification) {
        let val = this.getUnbindValue(this.value);
        const commentName = this.getCommentName(name);
        if (!val && !newValue || !!newValue && !!val && val[commentName] === newValue)
            return;
        if (!!newValue) {
            if (!val) {
                val = {};
            }
            val[commentName] = newValue;
        }
        else {
            delete val[commentName];
        }
        const q = this.getQuestionByName(name);
        if (!!q && q.comment !== newValue) {
            q.comment = newValue;
        }
        if (!this.settingNewValue) {
            this.value = val;
        }
    }
    getComment(name) {
        const q = this.getQuestionByName(name);
        if (!!q)
            return q.comment;
        const val = this.value;
        return !!val && val[this.getCommentName(name)] || "";
    }
    getCommentName(name) {
        return name + settings.commentSuffix;
    }
    runPanelTriggers(name, value) {
        if (!!this.contentPanel) {
            this.contentPanel.questions.forEach(q => {
                q.runTriggers(name, value);
            });
        }
    }
    getFilteredValues() {
        const values = !!this.data ? this.data.getFilteredValues() : {};
        if (!!this.contentPanel) {
            values[QuestionCompositeModel.ItemVariableName] = this.contentPanel.getValue();
        }
        return values;
    }
    updateValueCoreWithPanelValue() {
        const panelValue = this.getContentPanelValue();
        if (this.isTwoValueEquals(this.getValueCore(), panelValue))
            return false;
        this.setValueCore(panelValue);
        return true;
    }
    getContentPanelValue(val) {
        if (!val)
            val = this.contentPanel.getValue();
        return this.customQuestion.setValueToQuestion(val);
    }
    getValueForContentPanel(val) {
        return this.customQuestion.getValueFromQuestion(val);
    }
    setNewValueIntoQuestion(name, newValue) {
        var q = this.getQuestionByName(name);
        if (!!q && !this.isTwoValueEquals(newValue, q.value)) {
            q.value = newValue;
        }
    }
    addConditionObjectsByContext(objects, context) {
        if (!this.contentPanel)
            return;
        var questions = this.contentPanel.questions;
        var prefixName = this.name;
        var prefixText = this.title;
        for (var i = 0; i < questions.length; i++) {
            objects.push({
                name: prefixName + "." + questions[i].name,
                text: prefixText + "." + questions[i].title,
                question: questions[i],
            });
        }
    }
    collectNestedQuestionsCore(questions, visibleOnly, includeNested, includeItSelf) {
        if (!this.contentPanel)
            return;
        if (includeItSelf) {
            questions.push(this);
        }
        this.contentPanel.questions.forEach(q => q.addNestedQuestion(questions, visibleOnly, includeNested, includeItSelf));
    }
    convertDataValue(name, newValue) {
        var val = !!this.contentPanel && !this.isEditingSurveyElement ?
            this.contentPanel.getValue() : this.getValueForContentPanel(this.value);
        if (!val)
            val = {};
        if (!val.getType) {
            val = Helpers.getUnbindValue(val);
        }
        if (this.isValueEmpty(newValue) && !this.isEditingSurveyElement) {
            delete val[name];
        }
        else {
            val[name] = newValue;
        }
        return this.getContentPanelValue(val);
    }
    setQuestionValue(newValue, updateIsAnswered = true) {
        this.setValuesIntoQuestions(newValue);
        if (!this.isEditingSurveyElement && !!this.contentPanel) {
            newValue = this.getContentPanelValue();
        }
        super.setQuestionValue(newValue, updateIsAnswered);
    }
    setValuesIntoQuestions(newValue) {
        if (!this.contentPanel || this.settingNewValue)
            return;
        newValue = this.getValueForContentPanel(newValue);
        const oldSettingNewValue = this.settingNewValue;
        this.settingNewValue = true;
        const questions = this.contentPanel.questions;
        for (var i = 0; i < questions.length; i++) {
            const q = questions[i];
            const key = q.getValueName();
            const commentKey = this.getCommentName(key);
            const val = !!newValue ? newValue[key] : undefined;
            const commentVal = !!newValue && newValue[commentKey] || "";
            if (!this.isTwoValueEquals(q.value, val) && (val !== undefined || !q.isEmpty())) {
                q.value = val;
            }
            if (q.comment !== commentVal) {
                q.comment = commentVal;
            }
        }
        this.settingNewValue = oldSettingNewValue;
    }
    getDisplayValueCore(keyAsText, value) {
        return super.getContentDisplayValueCore(keyAsText, value, this.contentPanel);
    }
    setAfterRenderCallbacks(panel) {
        if (!panel || !this.customQuestion)
            return;
        var questions = panel.questions;
        for (var i = 0; i < questions.length; i++) {
            questions[i].afterRenderQuestionCallback = (question, element) => {
                this.customQuestion.onAfterRenderContentElement(this, question, element);
            };
        }
    }
    get ariaRole() {
        return "group";
    }
    setIsMobile(val) {
        super.setIsMobile(val);
        if (!!this.contentPanel) {
            this.contentPanel.questions.forEach(q => {
                q.setIsMobile(val);
            });
        }
    }
}
QuestionCompositeModel.ItemVariableName = "composite";

class QuestionFactory {
    static get DefaultChoices() {
        const choice = getLocaleString("choices_Item");
        return [choice + "1", choice + "2", choice + "3"];
    }
    static get DefaultColums() {
        var colName = getLocaleString("matrix_column") + " ";
        return [colName + "1", colName + "2", colName + "3"];
    }
    static get DefaultRows() {
        var rowName = getLocaleString("matrix_row") + " ";
        return [rowName + "1", rowName + "2"];
    }
    static get DefaultMutlipleTextItems() {
        var itemName = getLocaleString("multipletext_itemname");
        return [itemName + "1", itemName + "2"];
    }
    registerQuestion(questionType, questionCreator, showInToolbox = true) {
        ElementFactory.Instance.registerElement(questionType, questionCreator, showInToolbox);
    }
    registerCustomQuestion(questionType) {
        ElementFactory.Instance.registerCustomQuestion(questionType);
    }
    unregisterElement(elementType, removeFromSerializer = false) {
        ElementFactory.Instance.unregisterElement(elementType, removeFromSerializer);
    }
    clear() {
        ElementFactory.Instance.clear();
    }
    getAllTypes() {
        return ElementFactory.Instance.getAllTypes();
    }
    createQuestion(questionType, name) {
        return ElementFactory.Instance.createElement(questionType, name);
    }
}
QuestionFactory.Instance = new QuestionFactory();
class ElementFactory {
    constructor() {
        this.creatorHash = {};
        this.registerCustomQuestion = (questionType, showInToolbox = true) => {
            const creator = (name) => {
                const el = Serializer.createClass(questionType);
                if (!!el)
                    el.name = name;
                return el;
            };
            this.registerElement(questionType, creator, showInToolbox);
        };
    }
    registerElement(elementType, elementCreator, showInToolbox = true) {
        this.creatorHash[elementType] = { showInToolbox: showInToolbox, creator: elementCreator };
    }
    clear() {
        this.creatorHash = {};
    }
    unregisterElement(elementType, removeFromSerializer = false) {
        delete this.creatorHash[elementType];
        if (removeFromSerializer) {
            Serializer.removeClass(elementType);
        }
    }
    getAllToolboxTypes() {
        return this.getAllTypesCore(true);
    }
    getAllTypes() {
        return this.getAllTypesCore(false);
    }
    createElement(elementType, name) {
        var item = this.creatorHash[elementType];
        if (!!item && !!item.creator)
            return item.creator(name);
        const compJSON = ComponentCollection.Instance.getCustomQuestionByName(elementType);
        if (!!compJSON)
            return ComponentCollection.Instance.createQuestion(name, compJSON);
        return null;
    }
    getAllTypesCore(showInToolboxOnly) {
        var result = new Array();
        for (var key in this.creatorHash) {
            if (!showInToolboxOnly || this.creatorHash[key].showInToolbox) {
                result.push(key);
            }
        }
        return result.sort();
    }
}
ElementFactory.Instance = new ElementFactory();

/**
 * A class that describes the Expression question type. It is a read-only question type that calculates a value based on a specified expression.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-expression/ (linkStyle))
 */
class QuestionExpressionModel extends Question {
    constructor(name) {
        super(name);
        this.createLocalizableString("format", this);
        this.registerPropertyChangedHandlers(["expression"], () => {
            if (this.expressionRunner) {
                this.expressionRunner = this.createRunner();
            }
        });
        this.registerPropertyChangedHandlers(["format", "currency", "displayStyle"], () => {
            this.updateFormatedValue();
        });
    }
    getType() {
        return "expression";
    }
    get hasInput() {
        return false;
    }
    /**
     * A string that formats a question value. Use `{0}` to reference the question value in the format string.
     * @see displayStyle
     */
    get format() {
        return this.getLocalizableStringText("format", "");
    }
    set format(val) {
        this.setLocalizableStringText("format", val);
    }
    get locFormat() {
        return this.getLocalizableString("format");
    }
    /**
     * An expression used to calculate the question value.
     *
     * Refer to the following help topic for more information: [Expressions](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#expressions).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/expression-question-for-dynamic-form-calculations/ (linkStyle))
     */
    get expression() {
        return this.getPropertyValue("expression", "");
    }
    set expression(val) {
        this.setPropertyValue("expression", val);
    }
    locCalculation() {
        this.expressionIsRunning = true;
    }
    unlocCalculation() {
        this.expressionIsRunning = false;
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        if (!this.expression ||
            this.expressionIsRunning ||
            (!this.runIfReadOnly && this.isReadOnly))
            return;
        this.locCalculation();
        if (!this.expressionRunner) {
            this.expressionRunner = this.createRunner();
        }
        this.expressionRunner.run(values, properties);
    }
    canCollectErrors() {
        return true;
    }
    hasRequiredError() {
        return false;
    }
    createRunner() {
        const res = this.createExpressionRunner(this.expression);
        res.onRunComplete = (newValue) => {
            this.value = this.roundValue(newValue);
            this.unlocCalculation();
        };
        return res;
    }
    /**
     * The maximum number of fraction digits. Applies only if the `displayStyle` property is not `"none"`. Accepts values in the range from -1 to 20, where -1 disables the property.
     *
     * Default value: -1
     * @see displayStyle
     * @see minimumFractionDigits
     * @see precision
     */
    get maximumFractionDigits() {
        return this.getPropertyValue("maximumFractionDigits");
    }
    set maximumFractionDigits(val) {
        if (val < -1 || val > 20)
            return;
        this.setPropertyValue("maximumFractionDigits", val);
    }
    /**
     * The minimum number of fraction digits. Applies only if the `displayStyle` property is not `"none"`. Accepts values in the range from -1 to 20, where -1 disables the property.
     *
     * Default value: -1
     * @see displayStyle
     * @see maximumFractionDigits
     */
    get minimumFractionDigits() {
        return this.getPropertyValue("minimumFractionDigits");
    }
    set minimumFractionDigits(val) {
        if (val < -1 || val > 20)
            return;
        this.setPropertyValue("minimumFractionDigits", val);
    }
    get runIfReadOnly() {
        return this.runIfReadOnlyValue === true;
    }
    set runIfReadOnly(val) {
        this.runIfReadOnlyValue = val;
    }
    get formatedValue() {
        return this.getPropertyValue("formatedValue", "");
    }
    updateFormatedValue() {
        this.setPropertyValue("formatedValue", this.getDisplayValueCore(false, this.value));
    }
    onValueChanged() {
        this.updateFormatedValue();
    }
    updateValueFromSurvey(newValue, clearData) {
        super.updateValueFromSurvey(newValue, clearData);
        this.updateFormatedValue();
    }
    getDisplayValueCore(keysAsText, value) {
        var val = value === undefined || value === null ? this.defaultValue : value;
        var res = "";
        if (!this.isValueEmpty(val)) {
            var str = this.getValueAsStr(val);
            res = !this.format ? str : this.format["format"](str);
        }
        if (!!this.survey) {
            res = this.survey.getExpressionDisplayValue(this, val, res);
        }
        return res;
    }
    /**
     * Specifies a display style for the question value.
     *
     * Possible values:
     *
     * - `"decimal"`
     * - `"currency"`
     * - `"percent"`
     * - `"date"`
     * - `"none"` (default)
     *
     * If you use the `"currency"` display style, you can also set the `currency` property to specify a currency other than USD.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/expression-question-for-dynamic-form-calculations/ (linkStyle))
     * @see currency
     * @see minimumFractionDigits
     * @see maximumFractionDigits
     * @see format
     */
    get displayStyle() {
        return this.getPropertyValue("displayStyle");
    }
    set displayStyle(val) {
        this.setPropertyValue("displayStyle", val);
    }
    /**
     * A three-letter currency code. Applies only if the `displayStyle` property is set to `"currency"`.
     *
     * Default value: "USD".
     * @see displayStyle
     * @see minimumFractionDigits
     * @see maximumFractionDigits
     * @see format
     */
    get currency() {
        return this.getPropertyValue("currency");
    }
    set currency(val) {
        if (getCurrecyCodes().indexOf(val) < 0)
            return;
        this.setPropertyValue("currency", val);
    }
    /**
     * Specifies whether to use grouping separators in number representation. Separators depend on the selected [locale](https://surveyjs.io/form-library/documentation/surveymodel#locale).
     *
     * Default value: `true`
     */
    get useGrouping() {
        return this.getPropertyValue("useGrouping");
    }
    set useGrouping(val) {
        this.setPropertyValue("useGrouping", val);
    }
    /**
     * Specifies how many decimal digits to keep in the expression value.
     *
     * Default value: -1 (unlimited)
     * @see maximumFractionDigits
     */
    get precision() {
        return this.getPropertyValue("precision");
    }
    set precision(val) {
        this.setPropertyValue("precision", val);
    }
    roundValue(val) {
        if (val === Infinity)
            return undefined;
        if (this.precision < 0)
            return val;
        if (!Helpers.isNumber(val))
            return val;
        return parseFloat(val.toFixed(this.precision));
    }
    getValueAsStr(val) {
        if (this.displayStyle == "date") {
            const d = createDate("question-expression", val);
            if (!!d && !!d.toLocaleDateString)
                return d.toLocaleDateString();
        }
        if (this.displayStyle != "none" && Helpers.isNumber(val)) {
            var locale = this.getLocale();
            if (!locale)
                locale = "en";
            var options = {
                style: this.displayStyle,
                currency: this.currency,
                useGrouping: this.useGrouping,
            };
            if (this.maximumFractionDigits > -1) {
                options["maximumFractionDigits"] = this.maximumFractionDigits;
            }
            if (this.minimumFractionDigits > -1) {
                options["minimumFractionDigits"] = this.minimumFractionDigits;
            }
            return val.toLocaleString(locale, options);
        }
        return val.toString();
    }
}
function getCurrecyCodes() {
    return [
        "AED",
        "AFN",
        "ALL",
        "AMD",
        "ANG",
        "AOA",
        "ARS",
        "AUD",
        "AWG",
        "AZN",
        "BAM",
        "BBD",
        "BDT",
        "BGN",
        "BHD",
        "BIF",
        "BMD",
        "BND",
        "BOB",
        "BOV",
        "BRL",
        "BSD",
        "BTN",
        "BWP",
        "BYN",
        "BZD",
        "CAD",
        "CDF",
        "CHE",
        "CHF",
        "CHW",
        "CLF",
        "CLP",
        "CNY",
        "COP",
        "COU",
        "CRC",
        "CUC",
        "CUP",
        "CVE",
        "CZK",
        "DJF",
        "DKK",
        "DOP",
        "DZD",
        "EGP",
        "ERN",
        "ETB",
        "EUR",
        "FJD",
        "FKP",
        "GBP",
        "GEL",
        "GHS",
        "GIP",
        "GMD",
        "GNF",
        "GTQ",
        "GYD",
        "HKD",
        "HNL",
        "HRK",
        "HTG",
        "HUF",
        "IDR",
        "ILS",
        "INR",
        "IQD",
        "IRR",
        "ISK",
        "JMD",
        "JOD",
        "JPY",
        "KES",
        "KGS",
        "KHR",
        "KMF",
        "KPW",
        "KRW",
        "KWD",
        "KYD",
        "KZT",
        "LAK",
        "LBP",
        "LKR",
        "LRD",
        "LSL",
        "LYD",
        "MAD",
        "MDL",
        "MGA",
        "MKD",
        "MMK",
        "MNT",
        "MOP",
        "MRO",
        "MUR",
        "MVR",
        "MWK",
        "MXN",
        "MXV",
        "MYR",
        "MZN",
        "NAD",
        "NGN",
        "NIO",
        "NOK",
        "NPR",
        "NZD",
        "OMR",
        "PAB",
        "PEN",
        "PGK",
        "PHP",
        "PKR",
        "PLN",
        "PYG",
        "QAR",
        "RON",
        "RSD",
        "RUB",
        "RWF",
        "SAR",
        "SBD",
        "SCR",
        "SDG",
        "SEK",
        "SGD",
        "SHP",
        "SLL",
        "SOS",
        "SRD",
        "SSP",
        "STD",
        "SVC",
        "SYP",
        "SZL",
        "THB",
        "TJS",
        "TMT",
        "TND",
        "TOP",
        "TRY",
        "TTD",
        "TWD",
        "TZS",
        "UAH",
        "UGX",
        "USD",
        "USN",
        "UYI",
        "UYU",
        "UZS",
        "VEF",
        "VND",
        "VUV",
        "WST",
        "XAF",
        "XAG",
        "XAU",
        "XBA",
        "XBB",
        "XBC",
        "XBD",
        "XCD",
        "XDR",
        "XOF",
        "XPD",
        "XPF",
        "XPT",
        "XSU",
        "XTS",
        "XUA",
        "XXX",
        "YER",
        "ZAR",
        "ZMW",
        "ZWL",
    ];
}
function getCorrectMinMax$2(min, max, isMax) {
    let val = isMax ? max : min;
    if (min == -1 || max == -1)
        return val;
    if (min > max)
        return isMax ? min : max;
    return val;
}
Serializer.addClass("expression", [
    "expression:expression",
    { name: "format", serializationProperty: "locFormat" },
    {
        name: "displayStyle",
        default: "none",
        choices: ["none", "decimal", "currency", "percent", "date"],
    },
    {
        name: "currency",
        choices: () => {
            return getCurrecyCodes();
        },
        default: "USD",
        visibleIf: (obj) => {
            return obj.displayStyle === "currency";
        }
    },
    {
        name: "maximumFractionDigits:number",
        onSettingValue: (obj, val) => {
            return getCorrectMinMax$2(obj.minimumFractionDigits, val, true);
        },
        default: -1
    },
    {
        name: "minimumFractionDigits:number",
        onSettingValue: (obj, val) => {
            return getCorrectMinMax$2(val, obj.maximumFractionDigits, false);
        },
        default: -1
    },
    { name: "useGrouping:boolean", default: true },
    { name: "precision:number", default: -1, category: "data" },
    { name: "enableIf", visible: false, isSerializable: false },
    { name: "isRequired", visible: false, isSerializable: false },
    { name: "readOnly", visible: false, isSerializable: false },
    { name: "requiredErrorText", visible: false, isSerializable: false },
    { name: "resetValueIf", visible: false, isSerializable: false },
    { name: "setValueIf", visible: false, isSerializable: false },
    { name: "setValueExpression", visible: false, isSerializable: false },
    { name: "defaultValueExpression", visible: false, isSerializable: false },
    { name: "defaultValue", visible: false, isSerializable: false },
    { name: "correctAnswer", visible: false, isSerializable: false },
    { name: "requiredIf", visible: false, isSerializable: false }
], function () {
    return new QuestionExpressionModel("");
}, "question");
QuestionFactory.Instance.registerQuestion("expression", (name) => {
    return new QuestionExpressionModel(name);
});

function onUpdateSelectBaseCellQuestion(cellQuestion, column, question, data) {
    cellQuestion.storeOthersAsComment = !!question
        ? question.storeOthersAsComment
        : false;
    if ((!cellQuestion.choices || cellQuestion.choices.length == 0) &&
        cellQuestion.choicesByUrl.isEmpty) {
        cellQuestion.choices = question.choices;
    }
    if (!cellQuestion.choicesByUrl.isEmpty) {
        cellQuestion.choicesByUrl.run(data.getTextProcessor());
    }
}
function onUpdateSelectDropdownCellQuestion(cellQuestion, column, question, data) {
    onUpdateSelectBaseCellQuestion(cellQuestion, column, question, data);
    if (!!cellQuestion.locPlaceholder && cellQuestion.locPlaceholder.isEmpty && !question.locPlaceholder.isEmpty) {
        cellQuestion.optionsCaption = question.optionsCaption;
    }
}
var matrixDropdownColumnTypes = {
    dropdown: {
        onCellQuestionUpdate: (cellQuestion, column, question, data) => {
            onUpdateSelectDropdownCellQuestion(cellQuestion, column, question, data);
        }
    },
    checkbox: {
        onCellQuestionUpdate: (cellQuestion, column, question, data) => {
            onUpdateSelectBaseCellQuestion(cellQuestion, column, question, data);
            cellQuestion.colCount =
                column.colCount > -1 ? column.colCount : question.columnColCount;
        },
    },
    radiogroup: {
        onCellQuestionUpdate: (cellQuestion, column, question, data) => {
            onUpdateSelectBaseCellQuestion(cellQuestion, column, question, data);
            cellQuestion.colCount =
                column.colCount > -1 ? column.colCount : question.columnColCount;
        },
    },
    tagbox: {
        onCellQuestionUpdate: (cellQuestion, column, question, data) => {
            onUpdateSelectBaseCellQuestion(cellQuestion, column, question, data);
        }
    },
    text: {},
    comment: {},
    boolean: {
        onCellQuestionUpdate: (cellQuestion, column, question, data) => {
            cellQuestion.renderAs = column.renderAs;
        },
    },
    expression: {},
    rating: {},
};
/**
 * An auxiliary class that describes a column in a [Multi-Select Matrix](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list) or [Dynamic Matrix](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model).
 *
 * You can get an object of this class from the [`columns`](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list#columns) array or by calling the [`getColumnByName()`](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list#getColumnByName) method on a matrix instance.
 */
class MatrixDropdownColumn extends Base {
    static getColumnTypes() {
        var res = [];
        for (var key in matrixDropdownColumnTypes) {
            res.push(key);
        }
        return res;
    }
    constructor(name, title, colOwner) {
        super();
        this.indexValue = -1;
        this._hasVisibleCell = true;
        this.isColumnsVisibleIf = true;
        this.previousChoicesId = undefined;
        this.colOwnerValue = colOwner;
        this.createLocalizableString("totalFormat", this);
        this.createLocalizableString("cellHint", this);
        this.registerPropertyChangedHandlers(["showInMultipleColumns"], () => { this.doShowInMultipleColumnsChanged(); });
        this.registerPropertyChangedHandlers(["visible"], () => { this.doColumnVisibilityChanged(); });
        this.updateTemplateQuestion(undefined, name, title);
    }
    getOriginalObj() {
        return this.templateQuestion;
    }
    getClassNameProperty() {
        return "cellType";
    }
    getSurvey(live = false) {
        return !!this.colOwner ? this.colOwner.survey : null;
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        this.templateQuestion.autoOtherMode = this.isShowInMultipleColumns;
        this.templateQuestion.endLoadingFromJson();
        this.templateQuestion.onGetSurvey = () => {
            return this.getSurvey();
        };
    }
    getDynamicPropertyName() {
        return "cellType";
    }
    getDynamicType() {
        if (this.cellType === "default")
            return "question";
        return this.calcCellQuestionType(null);
    }
    get colOwner() {
        return this.colOwnerValue;
    }
    set colOwner(value) {
        this.colOwnerValue = value;
        if (!!value) {
            this.updateTemplateQuestion();
            this.setParentQuestionToTemplate(this.templateQuestion);
        }
    }
    locStrsChanged() {
        super.locStrsChanged();
        this.locTitle.strChanged();
    }
    addUsedLocales(locales) {
        super.addUsedLocales(locales);
        this.templateQuestion.addUsedLocales(locales);
    }
    get index() {
        return this.indexValue;
    }
    setIndex(val) {
        this.indexValue = val;
    }
    getType() {
        return "matrixdropdowncolumn";
    }
    /**
     * Specifies the type of column cells.
     *
     * Possible values:
     *
     * - [`"dropdown"`](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model)
     * - [`"checkbox"`](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model)
     * - [`"radiogroup"`](https://surveyjs.io/form-library/documentation/api-reference/radio-button-question-model)
     * - [`"tagbox"`](https://surveyjs.io/form-library/documentation/api-reference/dropdown-tag-box-model)
     * - [`"text"`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model)
     * - [`"comment"`](https://surveyjs.io/form-library/documentation/api-reference/comment-field-model)
     * - [`"boolean"`](https://surveyjs.io/form-library/documentation/api-reference/boolean-question-model)
     * - [`"expression"`](https://surveyjs.io/form-library/documentation/api-reference/expression-model)
     * - [`"rating"`](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model)
     * - `"default"` (default) - Inherits the input type from the [`cellType`](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list#cellType) property specified for the parent matrix.
     *
     * The input types are based upon standalone question types. Depending on the selected input type, the matrix column can have additional configuration properties inherited from the corresponding question type. For instance, Dropdown, Checkboxes, Radio Button Group, and Tag Box columns can specify the [`choices`](https://surveyjs.io/form-library/documentation/api-reference/radio-button-question-model#choices) array, similar to the question types upon which they are based. Refer to the API Reference of these question types for a full list of available properties.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/aggregate-data-within-form/ (linkStyle))
     */
    get cellType() {
        return this.getPropertyValue("cellType");
    }
    set cellType(val) {
        val = val.toLocaleLowerCase();
        this.updateTemplateQuestion(val);
        this.setPropertyValue("cellType", val);
        if (!!this.colOwner) {
            this.colOwner.onColumnCellTypeChanged(this);
        }
    }
    get templateQuestion() {
        return this.templateQuestionValue;
    }
    get value() {
        return this.templateQuestion.name;
    }
    //For filtering columns
    get isVisible() {
        return true;
    }
    get isColumnVisible() {
        if (this.isDesignMode)
            return true;
        return this.visible && this.hasVisibleCell;
    }
    /**
     * Gets or sets column visibility.
     *
     * If you want to display or hide a column based on a condition, specify the [`visibleIf`](#visibleIf) property.
     * @see isRequired
     * @see readOnly
     */
    get visible() { return this.templateQuestion.visible; }
    set visible(val) {
        this.templateQuestion.visible = val;
    }
    get hasVisibleCell() {
        return this._hasVisibleCell;
    }
    set hasVisibleCell(newVal) {
        this._hasVisibleCell = newVal;
    }
    getVisibleMultipleChoices() {
        const choices = this.templateQuestion.visibleChoices;
        if (!Array.isArray(choices))
            return [];
        if (!Array.isArray(this._visiblechoices))
            return choices;
        const res = new Array();
        for (let i = 0; i < choices.length; i++) {
            const item = choices[i];
            if (this._visiblechoices.indexOf(item.value) > -1)
                res.push(item);
        }
        return res;
    }
    get getVisibleChoicesInCell() {
        if (Array.isArray(this._visiblechoices))
            return this._visiblechoices;
        const res = this.templateQuestion.visibleChoices;
        return Array.isArray(res) ? res : [];
    }
    setVisibleChoicesInCell(val) {
        this._visiblechoices = val;
    }
    get isFilteredMultipleColumns() {
        if (!this.showInMultipleColumns)
            return false;
        const choices = this.templateQuestion.choices;
        if (!Array.isArray(choices))
            return false;
        for (let i = 0; i < choices.length; i++) {
            if (choices[i].visibleIf)
                return true;
        }
        return false;
    }
    /**
     * A column ID that is not visible to respondents.
     *
     * > Column IDs must be unique.
     * @see title
     */
    get name() {
        return this.templateQuestion.name;
    }
    set name(val) {
        this.templateQuestion.name = val;
    }
    /**
     * A user-friendly column caption to display. If `title` is undefined, [`name`](#name) is displayed instead.
     */
    get title() {
        return this.templateQuestion.title;
    }
    set title(val) {
        this.templateQuestion.title = val;
    }
    get locTitle() {
        return this.templateQuestion.locTitle;
    }
    get fullTitle() {
        return this.locTitle.textOrHtml;
    }
    /**
     * A value to show in HTML questions and in the dynamic titles and descriptions of survey elements when the cell value is empty.
     *
     * Default value: `""`
     *
     * [Dynamic Texts](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#dynamic-texts (linkStyle))
     */
    get defaultDisplayValue() {
        return this.templateQuestion.defaultDisplayValue;
    }
    set defaultDisplayValue(val) {
        this.templateQuestion.defaultDisplayValue = val;
    }
    get locDefaultDisplayValue() {
        return this.templateQuestion.locDefaultDisplayValue;
    }
    /**
     * Marks the column as required. If a respondent skips any cell in a required column, the matrix displays a [validation error](#requiredErrorText).
     *
     * If you want to mark the column as required based on a condition, specify the [`requiredIf`](#requiredIf) property.
     * @see visible
     * @see readOnly
     */
    get isRequired() {
        return this.getPropertyValue("isRequired");
    }
    set isRequired(val) {
        this.setPropertyValue("isRequired", val);
        this.templateQuestion.isRequired = val;
    }
    get isRenderedRequired() {
        return this.getPropertyValue("isRenderedRequired", this.isRequired);
    }
    set isRenderedRequired(val) {
        this.setPropertyValue("isRenderedRequired", val);
    }
    updateIsRenderedRequired(val) {
        this.isRenderedRequired = val || this.isRequired;
    }
    get requiredMark() {
        return this.isRenderedRequired && this.getSurvey() ? this.getSurvey().requiredMark : this.templateQuestion.requiredMark;
    }
    /**
     * Specifies a custom error message for a required column.
     * @see isRequired
     */
    get requiredErrorText() {
        return this.templateQuestion.requiredErrorText;
    }
    set requiredErrorText(val) {
        this.templateQuestion.requiredErrorText = val;
    }
    get locRequiredErrorText() {
        return this.templateQuestion.locRequiredErrorText;
    }
    /**
     * Makes the column read-only.
     *
     * If you want to switch the column to the read-only state based on a condition, specify the [`enableIf`](#enableIf) property.
     * @see visible
     * @see isRequired
     */
    get readOnly() {
        return this.templateQuestion.readOnly;
    }
    set readOnly(val) {
        this.templateQuestion.readOnly = val;
    }
    get hasOther() {
        return this.templateQuestion.hasOther;
    }
    set hasOther(val) {
        this.templateQuestion.hasOther = val;
    }
    /**
     * A Boolean expression. If it evaluates to `false`, this column becomes hidden.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see visible
     */
    get visibleIf() {
        return this.templateQuestion.visibleIf;
    }
    set visibleIf(val) {
        this.templateQuestion.visibleIf = val;
    }
    /**
     * A Boolean expression. If it evaluates to `false`, this column becomes read-only.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/multi-select-matrix-question/ (linkStyle))
     * @see readOnly
     */
    get enableIf() {
        return this.templateQuestion.enableIf;
    }
    set enableIf(val) {
        this.templateQuestion.enableIf = val;
    }
    /**
     * A Boolean expression. If it evaluates to `true`, this column becomes required.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see isRequired
     */
    get requiredIf() {
        return this.templateQuestion.requiredIf;
    }
    set requiredIf(val) {
        this.templateQuestion.requiredIf = val;
    }
    /**
     * A Boolean expression. If it evaluates to `true`, all cells in this column are set to a value calculated using the [`defaultValueExpression`](#defaultValueExpression).
     *
     * [Expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions (linkStyle))
     * @see setValueIf
     */
    get resetValueIf() {
        return this.templateQuestion.resetValueIf;
    }
    set resetValueIf(val) {
        this.templateQuestion.resetValueIf = val;
    }
    /**
     * An expression used to calculate the column's default value. This expression applies to all cells of this column until the cell value is specified by an end user or programmatically.
     *
     * [Expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions (linkStyle))
     * @see setValueExpression
     */
    get defaultValueExpression() {
        return this.templateQuestion.defaultValueExpression;
    }
    set defaultValueExpression(val) {
        this.templateQuestion.defaultValueExpression = val;
    }
    /**
     * A Boolean expression. If it evaluates to `true`, all cells in this column are set to a value calculated using the [`setValueExpression`](#setValueExpression).
     *
     * [Expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions (linkStyle))
     * @see resetValueIf
     */
    get setValueIf() {
        return this.templateQuestion.setValueIf;
    }
    set setValueIf(val) {
        this.templateQuestion.setValueIf = val;
    }
    /**
     * An expression that calculates a value for all cells in this column.
     *
     * The `setValueExpression` is re-evaluated whenever a referenced question's value changes. If you also specify the [`setValueIf`](#setValueIf) expression, re-evaluation occurs only when it returns `true`.
     *
     * [Expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions (linkStyle))
     * @see defaultValueExpression
     * @see resetValueIf
     */
    get setValueExpression() {
        return this.templateQuestion.setValueExpression;
    }
    set setValueExpression(val) {
        this.templateQuestion.setValueExpression = val;
    }
    /**
     * Specifies whether a respondent is required to provide a unique response for each question within this column.
     *
     * Default value: `false`
     */
    get isUnique() {
        return this.getPropertyValue("isUnique");
    }
    set isUnique(val) {
        this.setPropertyValue("isUnique", val);
    }
    /**
     * Specifies whether to create an individual column for each choice option. Applies only to columns of `"checkbox"` or `"radiogroup"` [`cellType`](#cellType).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/columnize-choice-options-of-matrix-cell/ (linkStyle))
     */
    get showInMultipleColumns() {
        return this.getPropertyValue("showInMultipleColumns");
    }
    set showInMultipleColumns(val) {
        this.setPropertyValue("showInMultipleColumns", val);
    }
    get isSupportMultipleColumns() {
        return ["checkbox", "radiogroup"].indexOf(this.cellType) > -1;
    }
    get isShowInMultipleColumns() {
        return this.showInMultipleColumns && this.isSupportMultipleColumns;
    }
    /**
     * Column validators.
     *
     * [Data Validation](https://surveyjs.io/form-library/documentation/data-validation (linkStyle))
     * @see isRequired
     */
    get validators() {
        return this.templateQuestion.validators;
    }
    set validators(val) {
        this.templateQuestion.validators = val;
    }
    /**
     * An aggregation method used to calculate the column total.
     *
     * Possible values:
     *
     * - `"none"` (default) - Disables total calculations.
     * - `"sum"`
     * - `"count"`
     * - `"min"`
     * - `"max"`
     * - `"avg"`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/aggregate-data-within-form/ (linkStyle))
     * @see totalFormat
     * @see totalDisplayStyle
     */
    get totalType() {
        return this.getPropertyValue("totalType");
    }
    set totalType(val) {
        this.setPropertyValue("totalType", val);
    }
    /**
     * An expression used to calculate total values. Overrides the [`totalType`](#totalType) property.
     *
     * [Expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions (linkStyle))
     */
    get totalExpression() {
        return this.getPropertyValue("totalExpression");
    }
    set totalExpression(val) {
        this.setPropertyValue("totalExpression", val);
    }
    get hasTotal() {
        return this.totalType != "none" || !!this.totalExpression;
    }
    /**
     * A string pattern used to display column totals. To reference a total value within this pattern, use the `{0}` placeholder.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/aggregate-data-within-form/ (linkStyle))
     * @see totalType
     * @see totalDisplayStyle
     */
    get totalFormat() {
        return this.getLocalizableStringText("totalFormat", "");
    }
    set totalFormat(val) {
        this.setLocalizableStringText("totalFormat", val);
    }
    get locTotalFormat() {
        return this.getLocalizableString("totalFormat");
    }
    get cellHint() {
        return this.getLocalizableStringText("cellHint", "");
    }
    set cellHint(val) {
        this.setLocalizableStringText("cellHint", val);
    }
    get locCellHint() {
        return this.getLocalizableString("cellHint");
    }
    get renderAs() {
        return this.getPropertyValue("renderAs");
    }
    set renderAs(val) {
        this.setPropertyValue("renderAs", val);
        if (!!this.templateQuestion) {
            this.templateQuestion.renderAs = val;
        }
    }
    get totalMaximumFractionDigits() {
        return this.getPropertyValue("totalMaximumFractionDigits");
    }
    set totalMaximumFractionDigits(val) {
        if (val < -1 || val > 20)
            return;
        this.setPropertyValue("totalMaximumFractionDigits", val);
    }
    get totalMinimumFractionDigits() {
        return this.getPropertyValue("totalMinimumFractionDigits");
    }
    set totalMinimumFractionDigits(val) {
        if (val < -1 || val > 20)
            return;
        this.setPropertyValue("totalMinimumFractionDigits", val);
    }
    /**
     * A format for calculated total values.
     *
     * Possible values:
     *
     * - `"none"` (default)
     * - `"decimal"`
     * - `"currency"`
     * - `"percent"`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/aggregate-data-within-form/ (linkStyle))
     * @see totalType
     * @see totalFormat
     * @see totalCurrency
     */
    get totalDisplayStyle() {
        return this.getPropertyValue("totalDisplayStyle");
    }
    set totalDisplayStyle(val) {
        this.setPropertyValue("totalDisplayStyle", val);
    }
    /**
     * An alignment for calculated total values.
     *
     * Possible values:
     *
     * - `"left"`
     * - `"center"`
     * - `"right"`
     * - `"auto"` (default) - Applies one of the values above based on the column's [cell type](#cellType).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/aggregate-data-within-form/ (linkStyle))
     * @see totalType
     * @see totalFormat
     * @see totalCurrency
     * @see totalDisplayStyle
     */
    get totalAlignment() {
        return this.getPropertyValue("totalAlignment");
    }
    set totalAlignment(val) {
        this.setPropertyValue("totalAlignment", val);
    }
    /**
     * Specifies a currency used to display calculated total values. Applies only if [`totalDisplayStyle`](#totalDisplayStyle) is set to `"currency"`.
     * @see totalType
     */
    get totalCurrency() {
        return this.getPropertyValue("totalCurrency");
    }
    set totalCurrency(val) {
        if (getCurrecyCodes().indexOf(val) < 0)
            return;
        this.setPropertyValue("totalCurrency", val);
    }
    /**
     * Gets or sets minimum column width in CSS values. By default, the matrix calculates column widths to optimally fit the content of all columns.
     * @see width
     */
    get minWidth() {
        return this.getPropertyValue("minWidth", "");
    }
    set minWidth(val) {
        this.setPropertyValue("minWidth", val);
    }
    /**
     * Gets or sets column width in CSS values. By default, the matrix calculates column widths to optimally fit the content of all columns.
     * @see minWidth
    */
    get width() {
        return this.templateQuestion.width;
    }
    set width(val) {
        this.templateQuestion.width = val;
    }
    /**
     * Gets or sets the number of columns used to arrange choice options. Applies only to columns of `"checkbox"` or `"radiogroup"` [`cellType`](#cellType).
     *
     * Default value: -1 (inherits the actual value from the parent matrix's [`columnColCount`](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list#columnColCount) property)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/multi-select-matrix-question/ (linkStyle))
     */
    get colCount() {
        return this.getPropertyValue("colCount");
    }
    set colCount(val) {
        if (val < -1 || val > 4)
            return;
        this.setPropertyValue("colCount", val);
    }
    getLocale() {
        return this.colOwner ? this.colOwner.getLocale() : "";
    }
    getMarkdownHtml(text, name, item) {
        return this.colOwner ? this.colOwner.getMarkdownHtml(text, name, item) : undefined;
    }
    getRenderer(name) {
        return !!this.colOwner ? this.colOwner.getRenderer(name) : null;
    }
    getRendererContext(locStr) {
        return !!this.colOwner ? this.colOwner.getRendererContext(locStr) : locStr;
    }
    getProcessedText(text) {
        return this.colOwner ? this.colOwner.getProcessedText(text) : text;
    }
    createCellQuestion(row) {
        var qType = this.calcCellQuestionType(row);
        var cellQuestion = this.createNewQuestion(qType);
        this.callOnCellQuestionUpdate(cellQuestion, row);
        return cellQuestion;
    }
    startLoadingFromJson(json) {
        super.startLoadingFromJson(json);
        if (!!json && !json.cellType && !!json.choices) {
            json.cellType = this.colOwner.getCellType();
        }
    }
    updateCellQuestion(cellQuestion, data, onUpdateJson = null) {
        this.setQuestionProperties(cellQuestion, onUpdateJson);
    }
    callOnCellQuestionUpdate(cellQuestion, data) {
        var qType = cellQuestion.getType();
        var qDefinition = matrixDropdownColumnTypes[qType];
        if (qDefinition && qDefinition["onCellQuestionUpdate"]) {
            qDefinition["onCellQuestionUpdate"](cellQuestion, this, this.colOwner, data);
        }
    }
    defaultCellTypeChanged() {
        this.updateTemplateQuestion();
    }
    calcCellQuestionType(row) {
        let cellType = this.getDefaultCellQuestionType();
        if (!!row && !!this.colOwner) {
            cellType = this.colOwner.getCustomCellType(this, row, cellType);
        }
        return cellType;
    }
    getDefaultCellQuestionType(cellType) {
        if (!cellType)
            cellType = this.cellType;
        if (cellType !== "default")
            return cellType;
        if (this.colOwner)
            return this.colOwner.getCellType();
        return settings.matrix.defaultCellType;
    }
    updateTemplateQuestion(newCellType, name, title) {
        const curCellType = this.getDefaultCellQuestionType(newCellType);
        const prevCellType = this.templateQuestion
            ? this.templateQuestion.getType()
            : "";
        if (curCellType === prevCellType)
            return;
        if (this.templateQuestion) {
            this.removeProperties(prevCellType);
        }
        this.templateQuestionValue = this.createNewQuestion(curCellType);
        this.templateQuestion.locOwner = this;
        this.addProperties(curCellType);
        if (!!name) {
            this.name = name;
        }
        if (!!title) {
            this.title = title;
        }
        else {
            this.templateQuestion.locTitle.strChanged();
        }
        if (settings.serialization.matrixDropdownColumnSerializeTitle) {
            this.templateQuestion.locTitle.serializeCallBackText = true;
        }
        this.templateQuestion.onPropertyChanged.add((sender, options) => {
            this.propertyValueChanged(options.name, options.oldValue, options.newValue, options.arrayChanges, options.target);
        });
        this.templateQuestion.onNestedPropertyChanged.add((sender, options) => {
            if (this.colOwner && !this.isLoadingFromJson) {
                this.colOwner.onColumnNestedPropertyChanged(this, options.name, options.nestedName, options.newValue);
            }
        });
        this.templateQuestion.onItemValuePropertyChanged.add((sender, options) => {
            this.doItemValuePropertyChanged(options.propertyName, options.obj, options.name, options.newValue, options.oldValue);
        });
        this.templateQuestion.isContentElement = true;
        if (!this.isLoadingFromJson) {
            this.templateQuestion.onGetSurvey = () => {
                return this.getSurvey();
            };
        }
        this.templateQuestion.locTitle.strChanged();
    }
    createNewQuestion(cellType) {
        var question = Serializer.createClass(cellType);
        if (!question) {
            question = Serializer.createClass("text");
        }
        question.loadingOwner = this;
        question.isEditableTemplateElement = true;
        question.autoOtherMode = this.isShowInMultipleColumns;
        this.setQuestionProperties(question);
        this.setParentQuestionToTemplate(question);
        return question;
    }
    setParentQuestionToTemplate(question) {
        if (!!this.colOwner && this.colOwner.isQuestion) {
            question.setParentQuestion(this.colOwner);
        }
    }
    setQuestionProperties(question, onUpdateJson = null) {
        if (this.templateQuestion) {
            var json = new JsonObject().toJsonObject(this.templateQuestion, true);
            if (onUpdateJson) {
                onUpdateJson(json);
            }
            json.type = question.getType();
            if (this.cellType === "default" && !!this.colOwner && this.colOwner.hasChoices()) {
                delete json["choices"];
            }
            delete json["itemComponent"];
            if (this.jsonObj && json.type === "rating" && this.isLoadingFromJson) {
                Object.keys(this.jsonObj).forEach((prop) => {
                    json[prop] = this.jsonObj[prop];
                });
            }
            if (json["choicesOrder"] === "random") {
                json["choicesOrder"] = "none";
                const visChoices = this.templateQuestion["visibleChoices"];
                if (Array.isArray(visChoices)) {
                    json["choices"] = visChoices;
                }
            }
            new JsonObject().toObject(json, question);
            question.isContentElement = this.templateQuestion.isContentElement;
            this.previousChoicesId = undefined;
            question.loadedChoicesFromServerCallback = () => {
                if (!this.isShowInMultipleColumns)
                    return;
                if (!!this.previousChoicesId && this.previousChoicesId !== question.id)
                    return;
                this.previousChoicesId = question.id;
                const choices = question.visibleChoices;
                this.templateQuestion.choices = choices;
                this.propertyValueChanged("choices", choices, choices);
            };
        }
    }
    propertyValueChanged(name, oldValue, newValue, arrayChanges, target) {
        super.propertyValueChanged(name, oldValue, newValue, arrayChanges, target);
        if (name === "isRequired") {
            this.updateIsRenderedRequired(newValue);
        }
        if (!this.colOwner || this.isLoadingFromJson)
            return;
        if (this.isShowInMultipleColumns) {
            if (name === "choicesOrder")
                return;
            if (["visibleChoices", "choices"].indexOf(name) > -1) {
                this.colOwner.onShowInMultipleColumnsChanged(this);
            }
        }
        if (!Serializer.hasOriginalProperty(this, name))
            return;
        this.colOwner.onColumnPropertyChanged(this, name, newValue);
    }
    doItemValuePropertyChanged(propertyName, obj, name, newValue, oldValue) {
        if (!Serializer.hasOriginalProperty(obj, name))
            return;
        if (this.colOwner != null && !this.isLoadingFromJson) {
            this.colOwner.onColumnItemValuePropertyChanged(this, propertyName, obj, name, newValue, oldValue);
        }
    }
    doShowInMultipleColumnsChanged() {
        if (this.colOwner != null) {
            this.colOwner.onShowInMultipleColumnsChanged(this);
        }
        if (this.templateQuestion) {
            this.templateQuestion.autoOtherMode = this.isShowInMultipleColumns;
        }
    }
    doColumnVisibilityChanged() {
        if (this.colOwner != null && !this.isDesignMode) {
            this.colOwner.onColumnVisibilityChanged(this);
        }
    }
    getProperties(curCellType) {
        return Serializer.getDynamicPropertiesByObj(this, curCellType);
    }
    removeProperties(curCellType) {
        var properties = this.getProperties(curCellType);
        for (var i = 0; i < properties.length; i++) {
            var prop = properties[i];
            delete this[prop.name];
            if (prop.serializationProperty) {
                delete this[prop.serializationProperty];
            }
        }
    }
    addProperties(curCellType) {
        const props = this.getProperties(curCellType);
        Serializer.addDynamicPropertiesIntoObj(this, this.templateQuestion, props);
    }
}
Serializer.addClass("matrixdropdowncolumn", [
    { name: "!name", isUnique: true },
    {
        name: "title", serializationProperty: "locTitle", dependsOn: "name",
        onPropertyEditorUpdate: function (obj, editor) {
            if (!!obj && !!editor) {
                editor.placeholder = obj.locTitle.getPlaceholder();
            }
        }
    },
    { name: "cellHint", serializationProperty: "locCellHint", visible: false },
    {
        name: "cellType",
        default: "default",
        choices: () => {
            var res = MatrixDropdownColumn.getColumnTypes();
            res.splice(0, 0, "default");
            return res;
        },
    },
    { name: "colCount", default: -1, choices: [-1, 0, 1, 2, 3, 4] },
    { name: "isRequired:boolean", defaultFunc: (obj) => {
            const q = obj === null || obj === void 0 ? void 0 : obj.templateQuestion;
            if (!!q) {
                return Serializer.findProperty(q.getType(), "isRequired").getDefaultValue(q) || false;
            }
            return false;
        } },
    "isUnique:boolean",
    {
        name: "requiredErrorText:text",
        serializationProperty: "locRequiredErrorText",
    },
    "readOnly:boolean",
    {
        name: "minWidth",
        onPropertyEditorUpdate: function (obj, editor) {
            if (!!obj && !!editor) {
                editor.value = obj.minWidth;
            }
        }
    },
    "width",
    { name: "visible:switch", default: true, overridingProperty: "visibleIf" },
    "visibleIf:condition",
    "enableIf:condition",
    "requiredIf:condition",
    "resetValueIf:condition",
    "setValueIf:condition",
    "setValueExpression:expression",
    {
        name: "showInMultipleColumns:boolean",
        dependsOn: "cellType",
        visibleIf: (obj) => {
            return obj.isSupportMultipleColumns;
        },
    },
    {
        name: "validators:validators",
        baseClassName: "surveyvalidator",
        classNamePart: "validator",
    },
    {
        name: "totalType", visibleIf: (obj) => !obj.isShowInMultipleColumns,
        default: "none",
        choices: ["none", "sum", "count", "min", "max", "avg"],
    },
    { name: "totalExpression:expression", visibleIf: (obj) => !obj.isShowInMultipleColumns },
    { name: "totalFormat", serializationProperty: "locTotalFormat", visibleIf: (obj) => obj.hasTotal },
    {
        name: "totalDisplayStyle", visibleIf: (obj) => obj.hasTotal,
        default: "none",
        choices: ["none", "decimal", "currency", "percent"],
    },
    {
        name: "totalAlignment", visibleIf: (obj) => obj.hasTotal,
        default: "auto",
        choices: ["auto", "left", "center", "right"],
    },
    {
        name: "totalCurrency", visibleIf: (obj) => obj.hasTotal,
        choices: () => {
            return getCurrecyCodes();
        },
        default: "USD",
    },
    { name: "totalMaximumFractionDigits:number", default: -1, visibleIf: (obj) => obj.hasTotal },
    { name: "totalMinimumFractionDigits:number", default: -1, visibleIf: (obj) => obj.hasTotal },
    { name: "renderAs", default: "default", visible: false },
    { name: "defaultDisplayValue", serializationProperty: "locDefaultDisplayValue" },
], function () {
    return new MatrixDropdownColumn("");
});

function getId(id, isError, isDetail) {
    return id + (isError ? "-error" : "") + (isDetail ? "-detail" : "");
}
class QuestionMatrixDropdownRenderedCell {
    constructor() {
        this.minWidth = "";
        this.width = "";
        this.colSpans = 1;
        this.isActionsCell = false;
        this.isErrorsCell = false;
        this.isDragHandlerCell = false;
        this.isDetailRowCell = false;
        this.classNameValue = "";
        this.idValue = QuestionMatrixDropdownRenderedCell.counter++;
    }
    get requiredMark() {
        return this.column && this.column.isRenderedRequired ? this.column.requiredMark : undefined;
    }
    get hasQuestion() {
        return !!this.question && !this.isErrorsCell;
    }
    get hasTitle() {
        return !!this.locTitle;
    }
    get hasPanel() {
        return !!this.panel;
    }
    get id() {
        let id = this.question ? this.question.id : this.idValue.toString();
        if (this.isChoice) {
            id += "-" + (Number.isInteger(this.choiceIndex) ? "index" + this.choiceIndex.toString() : this.item.id);
        }
        return getId(id, this.isErrorsCell, this.isDetailRowCell);
    }
    get item() {
        return this.itemValue;
    }
    set item(val) {
        this.itemValue = val;
        if (!!val) {
            val.hideCaption = true;
        }
    }
    get isChoice() {
        return !!this.item;
    }
    get isItemChoice() {
        return this.isChoice && !this.isOtherChoice;
    }
    get choiceValue() {
        return this.isChoice ? this.item.value : null;
    }
    get isCheckbox() {
        return this.isItemChoice && this.question.isDescendantOf("checkbox");
    }
    get isRadio() {
        return this.isItemChoice && this.question.isDescendantOf("radiogroup");
    }
    get isFirstChoice() {
        return this.choiceIndex === 0;
    }
    set className(val) {
        this.classNameValue = val;
    }
    get className() {
        const builder = new CssClassBuilder().append(this.classNameValue);
        if (this.hasQuestion) {
            builder
                .append(this.question.cssClasses.hasError, this.question.errors.length > 0)
                .append(this.question.cssClasses.answered, this.question.isAnswered);
        }
        return builder.toString();
    }
    get cellQuestionWrapperClassName() {
        return this.cell.getQuestionWrapperClassName(this.matrix.cssClasses.cellQuestionWrapper);
    }
    get isVisible() {
        var _a;
        return (!this.hasQuestion && !this.isErrorsCell) || !((_a = this.matrix) === null || _a === void 0 ? void 0 : _a.isMobile) || this.question.isVisible;
    }
    get showResponsiveTitle() {
        var _a;
        return this.hasQuestion && ((_a = this.matrix) === null || _a === void 0 ? void 0 : _a.isMobile);
    }
    get responsiveTitleCss() {
        return new CssClassBuilder().append(this.matrix.cssClasses.cellResponsiveTitle).toString();
    }
    get responsiveLocTitle() {
        return this.cell.column.locTitle;
    }
    get headers() {
        if (this.cell && this.cell.column) {
            if (this.matrix.IsMultiplyColumn(this.cell.column)) {
                if (!!this.item) {
                    return this.item.locText.renderedHtml;
                }
                else {
                    return "";
                }
            }
            let cellHint = this.cell.column.cellHint;
            if (!!cellHint) {
                if (cellHint.trim() === "")
                    return "";
                return this.cell.column.locCellHint.renderedHtml;
            }
            if (this.hasQuestion && this.question.isVisible && this.question.title)
                return this.question.title;
            return this.cell.column.title;
        }
        if (this.hasQuestion && this.question.isVisible) {
            return this.question.locTitle.renderedHtml;
        }
        if (this.hasTitle) {
            return this.locTitle.renderedHtml || "";
        }
        return "";
    }
    getTitle() {
        return (this.matrix && this.matrix.showHeader) ? this.headers : "";
    }
    calculateFinalClassName(matrixCssClasses) {
        const questionCss = this.cell.question.cssClasses;
        // 'text-align': $data.isChoice ? 'center':
        const builder = new CssClassBuilder()
            .append(questionCss.itemValue, !!questionCss)
            .append(questionCss.asCell, !!questionCss);
        return builder.append(matrixCssClasses.cell, builder.isEmpty() && !!matrixCssClasses)
            .append(matrixCssClasses.choiceCell, this.isChoice)
            .toString();
    }
    focusIn() {
        if (this.question) {
            this.question.focusIn();
        }
    }
}
QuestionMatrixDropdownRenderedCell.counter = 1;
class QuestionMatrixDropdownRenderedRow extends Base {
    constructor(cssClasses, isDetailRow = false) {
        super();
        this.cssClasses = cssClasses;
        this.isDetailRow = isDetailRow;
        this.hasEndActions = false;
        this.isErrorsRow = false;
        this.cells = [];
        this.idValue = QuestionMatrixDropdownRenderedRow.counter++;
    }
    get id() {
        var _a;
        return getId(((_a = this.row) === null || _a === void 0 ? void 0 : _a.id) || this.idValue.toString(), this.isErrorsRow, this.isDetailRow);
    }
    get dropTargetId() {
        var _a;
        return (_a = this.row) === null || _a === void 0 ? void 0 : _a.id;
    }
    get attributes() {
        if (!this.row)
            return {};
        return { "data-sv-drop-target-matrix-row": this.row.id };
    }
    get className() {
        var _a, _b;
        return new CssClassBuilder()
            .append(this.cssClasses.row)
            .append(this.cssClasses.detailRow, this.isDetailRow)
            .append(this.cssClasses.rowHasPanel, (_a = this.row) === null || _a === void 0 ? void 0 : _a.hasPanel)
            .append(this.cssClasses.expandedRow, ((_b = this.row) === null || _b === void 0 ? void 0 : _b.isDetailPanelShowing) && !this.isDetailRow)
            .append(this.cssClasses.rowHasEndActions, this.hasEndActions)
            .append(this.cssClasses.ghostRow, this.isGhostRow)
            .append(this.cssClasses.rowAdditional, this.isAdditionalClasses)
            .toString();
    }
    setRootElement(val) {
        this.rootElement = val;
    }
    getRootElement() {
        return this.rootElement;
    }
    focusCell(cellIndex) {
        if (this.rootElement) {
            const inputElementSelector = `:scope td:nth-of-type(${cellIndex + 1}) input, :scope td:nth-of-type(${cellIndex + 1}) button`;
            const inputElement = this.rootElement.querySelectorAll(inputElementSelector)[0];
            if (inputElement) {
                inputElement.focus();
            }
        }
    }
}
QuestionMatrixDropdownRenderedRow.counter = 1;
__decorate([
    property({ defaultValue: false })
], QuestionMatrixDropdownRenderedRow.prototype, "isGhostRow", void 0);
__decorate([
    property({ defaultValue: false })
], QuestionMatrixDropdownRenderedRow.prototype, "isAdditionalClasses", void 0);
__decorate([
    property({ defaultValue: true })
], QuestionMatrixDropdownRenderedRow.prototype, "visible", void 0);
class QuestionMatrixDropdownRenderedErrorRow extends QuestionMatrixDropdownRenderedRow {
    constructor(cssClasses) {
        super(cssClasses);
        this.isErrorsRow = true;
    }
    get attributes() {
        return {};
    }
    get className() {
        return new CssClassBuilder()
            .append(this.cssClasses.row)
            .append(this.cssClasses.errorRow)
            .toString();
    }
    onAfterCreated() {
        const callback = () => {
            this.visible = this.cells.some((cell) => cell.question && cell.question.hasVisibleErrors);
        };
        this.cells.forEach((cell) => {
            if (cell.question) {
                cell.question.registerFunctionOnPropertyValueChanged("hasVisibleErrors", callback);
            }
        });
        callback();
    }
}
class QuestionMatrixDropdownRenderedEmptyRow extends QuestionMatrixDropdownRenderedRow {
    constructor(cssClasses, customId) {
        super(cssClasses);
        this.customId = customId;
        this.isErrorsRow = false;
    }
    get attributes() {
        return {};
    }
    get dropTargetId() {
        return this.customId;
    }
    get className() {
        return new CssClassBuilder()
            .append(this.cssClasses.row)
            .append(this.cssClasses.rowEmpty)
            .toString();
    }
}
class QuestionMatrixDropdownRenderedTable extends Base {
    getIsAnimationAllowed() {
        return super.getIsAnimationAllowed() && this.matrix.animationAllowed;
    }
    getRenderedRowsAnimationOptions() {
        const onBeforeRunAnimation = (el) => {
            el.querySelectorAll(":scope > td > *").forEach((el) => {
                prepareElementForVerticalAnimation(el);
            });
        };
        const onAfterRunAnimation = (el) => {
            el.querySelectorAll(":scope > td > *").forEach((el) => {
                cleanHtmlElementAfterAnimation(el);
            });
        };
        return {
            isAnimationEnabled: () => {
                return this.animationAllowed;
            },
            getRerenderEvent: () => this.onElementRerendered,
            getAnimatedElement(el) {
                return el.getRootElement();
            },
            getLeaveOptions: () => {
                return { cssClass: this.cssClasses.rowLeave, onBeforeRunAnimation, onAfterRunAnimation };
            },
            getEnterOptions: (_, info) => {
                return { cssClass: this.cssClasses.rowEnter, onBeforeRunAnimation, onAfterRunAnimation };
            },
            getKey: (item) => {
                return item.id;
            }
        };
    }
    updateRenderedRows() {
        this.renderedRows = this.rows;
    }
    get renderedRows() {
        return this._renderedRows;
    }
    set renderedRows(val) {
        this.renderedRowsAnimation.sync(val);
    }
    constructor(matrix) {
        super();
        this.matrix = matrix;
        this._renderedRows = [];
        this.renderedRowsAnimation = new AnimationGroup(this.getRenderedRowsAnimationOptions(), (val) => {
            this._renderedRows = val;
        }, () => this._renderedRows);
        this.hasActionCellInRowsValues = {};
        this.build();
    }
    get showTable() {
        return this.getPropertyValue("showTable", true);
    }
    get showHeader() {
        return this.getPropertyValue("showHeader");
    }
    get showAddRow() {
        return this.getPropertyValue("showAddRow", false);
    }
    get showAddRowOnTop() {
        return this.getPropertyValue("showAddRowOnTop", false);
    }
    get showAddRowOnBottom() {
        return this.getPropertyValue("showAddRowOnBottom", false);
    }
    get showFooter() {
        return this.matrix.hasFooter && this.matrix.isColumnLayoutHorizontal;
    }
    get hasFooter() {
        return !!this.footerRow;
    }
    get hasRemoveRows() {
        return this.hasRemoveRowsValue;
    }
    isRequireReset() {
        return this.isRequireResetValue || this.hasRemoveRows != this.matrix.canRemoveRows || !this.matrix.isColumnLayoutHorizontal;
    }
    requireReset() {
        this.isRequireResetValue = true;
    }
    get headerRow() {
        return this.headerRowValue;
    }
    get footerRow() {
        return this.footerRowValue;
    }
    get isRowsDragAndDrop() {
        return this.matrix.isRowsDragAndDrop && this.matrix.isColumnLayoutHorizontal;
    }
    get showCellErrorsTop() {
        //todo
        return this.matrix.getErrorLocation() === "top";
    }
    get showCellErrorsBottom() {
        //todo
        return this.matrix.getErrorLocation() === "bottom";
    }
    build() {
        this.hasRemoveRowsValue = this.matrix.canRemoveRows;
        //build rows now
        this.matrix.visibleRows;
        this.cssClasses = this.matrix.cssClasses;
        this.buildRowsActions();
        this.buildHeader();
        this.buildRows();
        this.buildFooter();
        this.updateShowTableAndAddRow();
    }
    updateShowTableAndAddRow() {
        const showTable = this.rows.length > 0 ||
            this.matrix.isDesignMode ||
            !this.matrix.getShowColumnsIfEmpty();
        this.setPropertyValue("showTable", showTable);
        const isDesignMode = this.matrix.isDesignMode;
        const showAddRow = !isDesignMode && this.matrix.canAddRow && showTable;
        let showAddRowOnTop = showAddRow;
        let showAddRowOnBottom = showAddRow;
        if (showAddRowOnTop) {
            if (this.matrix.getAddRowLocation() === "default") {
                showAddRowOnTop = !this.matrix.isColumnLayoutHorizontal;
            }
            else {
                showAddRowOnTop = this.matrix.getAddRowLocation() !== "bottom";
            }
        }
        if (showAddRowOnBottom && this.matrix.getAddRowLocation() !== "topBottom") {
            showAddRowOnBottom = !showAddRowOnTop;
        }
        this.setPropertyValue("showAddRow", !isDesignMode && this.matrix.canAddRow);
        this.setPropertyValue("showAddRowOnTop", showAddRowOnTop);
        this.setPropertyValue("showAddRowOnBottom", showAddRowOnBottom);
    }
    onAddedRow(row, index) {
        if (this.getRenderedDataRowCount() >= this.matrix.visibleRows.length)
            return;
        let rowIndex = this.getRenderedRowIndexByIndex(index);
        this.rowsActions.splice(index, 0, this.buildRowActions(row));
        this.addHorizontalRow(this.rows, row, rowIndex);
        this.updateShowTableAndAddRow();
    }
    getRenderedRowIndexByIndex(index) {
        let res = 0;
        let dataRowIndex = 0;
        for (var i = 0; i < this.rows.length; i++) {
            if (dataRowIndex === index) {
                if (this.rows[i].isErrorsRow || this.rows[i].isDetailRow) {
                    res++;
                    if (i + 1 < this.rows.length && this.rows[i + 1].isDetailRow) {
                        res++;
                    }
                }
                break;
            }
            res++;
            if (!(this.rows[i].isErrorsRow) && !this.rows[i].isDetailRow)
                dataRowIndex++;
        }
        if (dataRowIndex < index)
            return this.rows.length;
        return res;
    }
    getRenderedDataRowCount() {
        var res = 0;
        for (var i = 0; i < this.rows.length; i++) {
            if (!(this.rows[i].isErrorsRow) && !this.rows[i].isDetailRow)
                res++;
        }
        return res;
    }
    onRemovedRow(row) {
        var rowIndex = this.getRenderedRowIndex(row);
        if (rowIndex < 0)
            return;
        this.rowsActions.splice(rowIndex, 1);
        var removeCount = 1;
        if (rowIndex < this.rows.length - 1 && this.showCellErrorsBottom &&
            this.rows[rowIndex + 1].isErrorsRow) {
            removeCount++;
        }
        if (rowIndex < this.rows.length - 1 &&
            (this.rows[rowIndex + 1].isDetailRow ||
                this.showCellErrorsBottom && rowIndex + 1 < this.rows.length - 1 && this.rows[rowIndex + 2].isDetailRow)) {
            removeCount++;
        }
        if (rowIndex > 0 && this.showCellErrorsTop && this.rows[rowIndex - 1].isErrorsRow) {
            rowIndex--;
            removeCount++;
        }
        this.rows.splice(rowIndex, removeCount);
        this.updateShowTableAndAddRow();
    }
    onDetailPanelChangeVisibility(row, isShowing) {
        const rowIndex = this.getRenderedRowIndex(row);
        if (rowIndex < 0)
            return;
        let currentIndex = rowIndex;
        if (this.showCellErrorsBottom)
            currentIndex++;
        var panelRowIndex = currentIndex < this.rows.length - 1 && this.rows[currentIndex + 1].isDetailRow
            ? currentIndex + 1
            : -1;
        if ((isShowing && panelRowIndex > -1) || (!isShowing && panelRowIndex < 0))
            return;
        if (isShowing) {
            var detailRow = this.createDetailPanelRow(row, this.rows[rowIndex]);
            this.rows.splice(currentIndex + 1, 0, detailRow);
        }
        else {
            this.rows.splice(panelRowIndex, 1);
        }
    }
    focusActionCell(row, actionCellIndex) {
        let row2Focus = this.rows[this.rows.length - 1];
        if (this.matrix.isColumnLayoutHorizontal) {
            const nextRenderedRowIndex = this.getRenderedRowIndex(row);
            row2Focus = this.rows[nextRenderedRowIndex];
        }
        row2Focus === null || row2Focus === void 0 ? void 0 : row2Focus.focusCell(actionCellIndex);
    }
    getRenderedRowIndex(row) {
        for (var i = 0; i < this.rows.length; i++) {
            if (this.rows[i].row == row)
                return i;
        }
        return -1;
    }
    buildRowsActions() {
        this.rowsActions = [];
        var rows = this.matrix.visibleRows;
        for (var i = 0; i < rows.length; i++) {
            this.rowsActions.push(this.buildRowActions(rows[i]));
        }
    }
    createRenderedRow(cssClasses, isDetailRow = false) {
        return new QuestionMatrixDropdownRenderedRow(cssClasses, isDetailRow);
    }
    createErrorRenderedRow(cssClasses) {
        return new QuestionMatrixDropdownRenderedErrorRow(cssClasses);
    }
    createEmptyRenderedRow(cssClasses) {
        return new QuestionMatrixDropdownRenderedEmptyRow(cssClasses, this.matrix.id);
    }
    buildHeader() {
        var colHeaders = this.matrix.isColumnLayoutHorizontal && this.matrix.showHeader;
        var isShown = colHeaders ||
            (this.matrix.hasRowText && !this.matrix.isColumnLayoutHorizontal);
        this.setPropertyValue("showHeader", isShown);
        if (!isShown)
            return;
        this.headerRowValue = this.createRenderedRow(this.cssClasses);
        if (this.isRowsDragAndDrop) {
            this.headerRow.cells.push(this.createHeaderCell(null, "action", this.cssClasses.actionsCellDrag));
        }
        if (this.hasActionCellInRows("start")) {
            this.headerRow.cells.push(this.createHeaderCell(null, "action"));
        }
        if (this.matrix.hasRowText && this.matrix.showHeader) {
            this.headerRow.cells.push(this.createHeaderCell(null));
        }
        if (this.matrix.isColumnLayoutHorizontal) {
            for (var i = 0; i < this.matrix.columns.length; i++) {
                var column = this.matrix.columns[i];
                if (!column.isColumnVisible)
                    continue;
                if (this.matrix.IsMultiplyColumn(column)) {
                    this.createMutlipleColumnsHeader(column);
                }
                else {
                    this.headerRow.cells.push(this.createHeaderCell(column));
                }
            }
        }
        else {
            var rows = this.matrix.visibleRows;
            for (var i = 0; i < rows.length; i++) {
                const cell = this.createTextCell(rows[i].locText);
                this.setHeaderCellCssClasses(cell);
                cell.row = rows[i];
                this.headerRow.cells.push(cell);
            }
            if (this.matrix.hasFooter) {
                const cell = this.createTextCell(this.matrix.getFooterText());
                this.setHeaderCellCssClasses(cell);
                this.headerRow.cells.push(cell);
            }
        }
        if (this.hasActionCellInRows("end")) {
            this.headerRow.cells.push(this.createHeaderCell(null, "action"));
        }
    }
    buildFooter() {
        if (!this.showFooter)
            return;
        this.footerRowValue = this.createRenderedRow(this.cssClasses);
        if (this.isRowsDragAndDrop) {
            this.footerRow.cells.push(this.createHeaderCell(null));
        }
        if (this.hasActionCellInRows("start")) {
            this.footerRow.cells.push(this.createHeaderCell(null, "action"));
        }
        if (this.matrix.hasRowText) {
            const cell = this.createTextCell(this.matrix.getFooterText());
            cell.className = new CssClassBuilder().append(cell.className)
                .append(this.cssClasses.footerTotalCell).toString();
            this.footerRow.cells.push(cell);
        }
        var cells = this.matrix.visibleTotalRow.cells;
        for (var i = 0; i < cells.length; i++) {
            var cell = cells[i];
            if (!cell.column.isColumnVisible)
                continue;
            if (this.matrix.IsMultiplyColumn(cell.column)) {
                this.createMutlipleColumnsFooter(this.footerRow, cell);
            }
            else {
                var editCell = this.createEditCell(cell);
                if (cell.column) {
                    this.setCellWidth(cell.column, editCell);
                }
                editCell.className = new CssClassBuilder().append(editCell.className)
                    .append(this.cssClasses.footerCell).toString();
                this.footerRow.cells.push(editCell);
            }
        }
        if (this.hasActionCellInRows("end")) {
            this.footerRow.cells.push(this.createHeaderCell(null, "action"));
        }
    }
    buildRows() {
        this.blockAnimations();
        var rows = this.matrix.isColumnLayoutHorizontal
            ? this.buildHorizontalRows()
            : this.buildVerticalRows();
        this.rows = rows;
        this.releaseAnimations();
    }
    hasActionCellInRows(location) {
        if (this.hasActionCellInRowsValues[location] === undefined) {
            this.hasActionCellInRowsValues[location] = this.hasActionsCellInLocaltion(location);
        }
        return this.hasActionCellInRowsValues[location];
    }
    hasActionsCellInLocaltion(location) {
        if (location == "end" && this.hasRemoveRows)
            return true;
        return this.matrix.visibleRows.some((row, index) => !this.isValueEmpty(this.getRowActions(index, location)));
    }
    canRemoveRow(row) {
        return this.matrix.canRemoveRow(row);
    }
    buildHorizontalRows() {
        var rows = this.matrix.visibleRows;
        var renderedRows = [];
        if (rows.length == 0 && this.matrix.allowRowReorder && this.matrix.allowRowDragIn) {
            const row = this.createEmptyRow();
            const cell = this.createTextCell(this.matrix.locNoRowsText);
            cell.colSpans = this.headerRow && this.headerRow.cells.length || 1;
            row.cells.push(cell);
            renderedRows.push(row);
        }
        for (var i = 0; i < rows.length; i++) {
            this.addHorizontalRow(renderedRows, rows[i]);
        }
        return renderedRows;
    }
    addHorizontalRow(renderedRows, row, index = -1) {
        const renderedRow = this.createHorizontalRow(row);
        const errorRow = this.createErrorRow(renderedRow);
        renderedRow.row = row;
        if (index < 0) {
            index = renderedRows.length;
        }
        if (this.matrix.isMobile) {
            const cells = [];
            for (let i = 0; i < renderedRow.cells.length; i++) {
                if (this.showCellErrorsTop && !errorRow.cells[i].isEmpty) {
                    cells.push(errorRow.cells[i]);
                }
                cells.push(renderedRow.cells[i]);
                if (this.showCellErrorsBottom && !errorRow.cells[i].isEmpty) {
                    cells.push(errorRow.cells[i]);
                }
            }
            renderedRow.cells = cells;
            renderedRows.splice(index, 0, renderedRow);
        }
        else {
            renderedRows.splice(index, 0, ...(this.showCellErrorsTop ? [errorRow, renderedRow] : [renderedRow, errorRow]));
            index++;
        }
        if (row.isDetailPanelShowing) {
            renderedRows.splice(index + 1, 0, this.createDetailPanelRow(row, renderedRow));
        }
    }
    getRowDragCell(rowIndex) {
        const cell = new QuestionMatrixDropdownRenderedCell();
        const lockedRows = this.matrix.lockedRowCount;
        cell.isDragHandlerCell = lockedRows < 1 || rowIndex >= lockedRows;
        cell.isEmpty = !cell.isDragHandlerCell;
        cell.className = this.getActionsCellClassName(cell);
        cell.row = this.matrix.visibleRows[rowIndex];
        return cell;
    }
    getActionsCellClassName(cell = null) {
        const classBuilder = new CssClassBuilder()
            .append(this.cssClasses.actionsCell)
            .append(this.cssClasses.actionsCellDrag, cell === null || cell === void 0 ? void 0 : cell.isDragHandlerCell)
            .append(this.cssClasses.detailRowCell, cell === null || cell === void 0 ? void 0 : cell.isDetailRowCell)
            .append(this.cssClasses.verticalCell, !this.matrix.isColumnLayoutHorizontal);
        if (cell.isActionsCell) {
            const actions = cell.item.value.actions;
            if (this.cssClasses.actionsCellPrefix) {
                actions.forEach(action => {
                    classBuilder.append(this.cssClasses.actionsCellPrefix + "--" + action.id);
                });
            }
        }
        return classBuilder.toString();
    }
    getRowActionsCell(rowIndex, location, isDetailRow = false) {
        const rowActions = this.getRowActions(rowIndex, location);
        if (!this.isValueEmpty(rowActions)) {
            const cell = new QuestionMatrixDropdownRenderedCell();
            const actionContainer = this.matrix.allowAdaptiveActions ? new AdaptiveActionContainer() : new ActionContainer();
            if (!!this.matrix.survey && this.matrix.survey.getCss().actionBar) {
                actionContainer.cssClasses = this.matrix.survey.getCss().actionBar;
            }
            actionContainer.setItems(rowActions);
            const itemValue = new ItemValue(actionContainer);
            cell.item = itemValue;
            cell.isActionsCell = true;
            cell.isDragHandlerCell = false;
            cell.isDetailRowCell = isDetailRow;
            cell.className = this.getActionsCellClassName(cell);
            cell.row = this.matrix.visibleRows[rowIndex];
            return cell;
        }
        return null;
    }
    getRowActions(rowIndex, location) {
        var actions = this.rowsActions[rowIndex];
        if (!Array.isArray(actions))
            return [];
        return actions.filter((action) => {
            if (!action.location) {
                action.location = "start";
            }
            return action.location === location;
        });
    }
    buildRowActions(row) {
        var actions = [];
        this.setDefaultRowActions(row, actions);
        if (!!this.matrix.survey) {
            actions = this.matrix.survey.getUpdatedMatrixRowActions(this.matrix, row, actions);
        }
        return actions;
    }
    get showRemoveButtonAsIcon() {
        return (settings.matrix.renderRemoveAsIcon && this.matrix.survey && this.matrix.survey.css.root === "sd-root-modern");
    }
    setDefaultRowActions(row, actions) {
        const matrix = this.matrix;
        if (this.hasRemoveRows && this.canRemoveRow(row)) {
            if (!this.showRemoveButtonAsIcon) {
                actions.push(new Action({
                    id: "remove-row",
                    location: "end",
                    enabled: !this.matrix.isInputReadOnly,
                    component: "sv-matrix-remove-button",
                    data: { row: row, question: this.matrix },
                }));
            }
            else {
                actions.push(new Action({
                    id: "remove-row",
                    iconName: "icon-delete-24x24",
                    iconSize: "auto",
                    component: "sv-action-bar-item",
                    innerCss: new CssClassBuilder().append(this.matrix.cssClasses.button).append(this.matrix.cssClasses.buttonRemove).toString(),
                    location: "end",
                    showTitle: false,
                    title: matrix.removeRowText,
                    enabled: !matrix.isInputReadOnly,
                    data: { row: row, question: matrix },
                    action: () => {
                        matrix.removeRowUI(row);
                    },
                }));
            }
        }
        if (row.hasPanel) {
            if (this.matrix.isMobile) {
                actions.unshift(new Action({
                    id: "show-detail-mobile",
                    title: new ComputedUpdater(() => row.isDetailPanelShowing ? this.matrix.getLocalizationString("hideDetails") : this.matrix.getLocalizationString("showDetails")),
                    showTitle: true,
                    location: "end",
                    action: (context) => {
                        row.showHideDetailPanelClick();
                    },
                }));
            }
            else {
                actions.push(new Action({
                    id: "show-detail",
                    title: new ComputedUpdater(() => row.isDetailPanelShowing ? this.matrix.getLocalizationString("hideDetails") : this.matrix.getLocalizationString("showDetails")),
                    showTitle: false,
                    location: "start",
                    component: "sv-matrix-detail-button",
                    data: { row: row, question: this.matrix },
                }));
            }
        }
    }
    createErrorRow(row) {
        const res = this.createErrorRenderedRow(this.cssClasses);
        for (let i = 0; i < row.cells.length; i++) {
            const cell = row.cells[i];
            if (!cell.hasQuestion) {
                res.cells.push(this.createEmptyCell(true));
            }
            else if (this.matrix.IsMultiplyColumn(cell.cell.column)) {
                if (cell.isFirstChoice) {
                    res.cells.push(this.createErrorCell(cell.cell));
                }
                else {
                    res.cells.push(this.createEmptyCell(true));
                }
            }
            else {
                res.cells.push(this.createErrorCell(cell.cell));
            }
        }
        res.onAfterCreated();
        return res;
    }
    createEmptyRow() {
        const res = this.createEmptyRenderedRow(this.cssClasses);
        return res;
    }
    createHorizontalRow(row) {
        var res = this.createRenderedRow(this.cssClasses);
        if (this.isRowsDragAndDrop) {
            var rowIndex = this.matrix.visibleRows.indexOf(row);
            res.cells.push(this.getRowDragCell(rowIndex));
        }
        this.addRowActionsCell(row, res, "start");
        if (this.matrix.hasRowText) {
            var renderedCell = this.createTextCell(row.locText);
            renderedCell.row = row;
            res.cells.push(renderedCell);
            this.setCellWidth(null, renderedCell);
            renderedCell.className = new CssClassBuilder()
                .append(renderedCell.className)
                .append(this.cssClasses.rowTextCell)
                .append(this.cssClasses.columnTitleCell, !this.matrix.isColumnLayoutHorizontal)
                .append(this.cssClasses.detailRowText, row.hasPanel)
                .toString();
        }
        for (var i = 0; i < row.cells.length; i++) {
            let cell = row.cells[i];
            if (!cell.column.isColumnVisible)
                continue;
            if (this.matrix.IsMultiplyColumn(cell.column)) {
                this.createMutlipleEditCells(res, cell);
            }
            else {
                if (cell.column.isShowInMultipleColumns) {
                    cell.question.visibleChoices.map((c) => c.hideCaption = false);
                }
                var renderedCell = this.createEditCell(cell);
                res.cells.push(renderedCell);
                this.setCellWidth(cell.column, renderedCell);
            }
        }
        this.addRowActionsCell(row, res, "end");
        return res;
    }
    addRowActionsCell(row, renderedRow, location) {
        var rowIndex = this.matrix.visibleRows.indexOf(row);
        if (this.hasActionCellInRows(location)) {
            const actions = this.getRowActionsCell(rowIndex, location, renderedRow.isDetailRow);
            if (!!actions) {
                renderedRow.cells.push(actions);
                renderedRow.hasEndActions = true;
            }
            else {
                var cell = new QuestionMatrixDropdownRenderedCell();
                cell.isEmpty = true;
                cell.isDetailRowCell = renderedRow.isDetailRow;
                renderedRow.cells.push(cell);
            }
        }
    }
    createDetailPanelRow(row, renderedRow) {
        const panelFullWidth = this.matrix.isDesignMode;
        var res = this.createRenderedRow(this.cssClasses, true);
        res.row = row;
        var buttonCell = new QuestionMatrixDropdownRenderedCell();
        if (this.matrix.hasRowText) {
            buttonCell.colSpans = 2;
        }
        buttonCell.isEmpty = true;
        if (!panelFullWidth)
            res.cells.push(buttonCell);
        var actionsCell = null;
        if (this.hasActionCellInRows("end")) {
            actionsCell = new QuestionMatrixDropdownRenderedCell();
            actionsCell.isEmpty = true;
        }
        var cell = new QuestionMatrixDropdownRenderedCell();
        cell.panel = row.detailPanel;
        cell.colSpans =
            renderedRow.cells.length -
                (!panelFullWidth ? buttonCell.colSpans : 0) -
                (!!actionsCell ? actionsCell.colSpans : 0);
        cell.className = this.cssClasses.detailPanelCell;
        res.cells.push(cell);
        if (!!actionsCell) {
            if (this.matrix.isMobile) {
                this.addRowActionsCell(row, res, "end");
            }
            else {
                res.cells.push(actionsCell);
            }
        }
        if (typeof this.matrix.onCreateDetailPanelRenderedRowCallback === "function") {
            this.matrix.onCreateDetailPanelRenderedRowCallback(res);
        }
        return res;
    }
    buildVerticalRows() {
        var columns = this.matrix.columns;
        var renderedRows = [];
        for (var i = 0; i < columns.length; i++) {
            var col = columns[i];
            if (col.isColumnVisible) {
                if (this.matrix.IsMultiplyColumn(col)) {
                    this.createMutlipleVerticalRows(renderedRows, col, i);
                }
                else {
                    const renderedRow = this.createVerticalRow(col, i);
                    const errorRow = this.createErrorRow(renderedRow);
                    if (this.showCellErrorsTop) {
                        renderedRows.push(errorRow);
                        renderedRows.push(renderedRow);
                    }
                    else {
                        renderedRows.push(renderedRow);
                        renderedRows.push(errorRow);
                    }
                }
            }
        }
        if (this.hasActionCellInRows("end")) {
            renderedRows.push(this.createEndVerticalActionRow());
        }
        return renderedRows;
    }
    createMutlipleVerticalRows(renderedRows, column, index) {
        var choices = this.getMultipleColumnChoices(column);
        if (!choices)
            return;
        for (var i = 0; i < choices.length; i++) {
            const renderedRow = this.createVerticalRow(column, index, choices[i], i);
            const errorRow = this.createErrorRow(renderedRow);
            if (this.showCellErrorsTop) {
                renderedRows.push(errorRow);
                renderedRows.push(renderedRow);
            }
            else {
                renderedRows.push(renderedRow);
                renderedRows.push(errorRow);
            }
        }
    }
    createVerticalRow(column, index, choice = null, choiceIndex = -1) {
        var res = this.createRenderedRow(this.cssClasses);
        if (this.matrix.showHeader) {
            var lTitle = !!choice ? choice.locText : column.locTitle;
            var hCell = this.createTextCell(lTitle);
            hCell.column = column;
            hCell.className = new CssClassBuilder()
                .append(hCell.className)
                .append(this.cssClasses.rowTextCell)
                .append(this.cssClasses.columnTitleCell).toString();
            res.cells.push(hCell);
        }
        var rows = this.matrix.visibleRows;
        for (var i = 0; i < rows.length; i++) {
            var rChoice = choice;
            var rChoiceIndex = choiceIndex >= 0 ? choiceIndex : i;
            var cell = rows[i].cells[index];
            var visChoices = !!choice ? cell.question.visibleChoices : undefined;
            if (!!visChoices && rChoiceIndex < visChoices.length) {
                rChoice = visChoices[rChoiceIndex];
            }
            var rCell = this.createEditCell(cell, rChoice);
            rCell.item = rChoice;
            rCell.choiceIndex = rChoiceIndex;
            res.cells.push(rCell);
        }
        if (this.matrix.hasTotal) {
            res.cells.push(this.createEditCell(this.matrix.visibleTotalRow.cells[index]));
        }
        return res;
    }
    createEndVerticalActionRow() {
        var res = this.createRenderedRow(this.cssClasses);
        if (this.matrix.showHeader) {
            res.cells.push(this.createEmptyCell());
        }
        var rows = this.matrix.visibleRows;
        for (var i = 0; i < rows.length; i++) {
            res.cells.push(this.getRowActionsCell(i, "end"));
        }
        if (this.matrix.hasTotal) {
            res.cells.push(this.createEmptyCell());
        }
        return res;
    }
    createMutlipleEditCells(rRow, cell, isFooter = false) {
        var choices = isFooter
            ? this.getMultipleColumnChoices(cell.column)
            : cell.question.visibleChoices;
        if (!choices)
            return;
        for (var i = 0; i < choices.length; i++) {
            var rCell = this.createEditCell(cell, !isFooter ? choices[i] : undefined);
            if (!isFooter) {
                //rCell.item = choices[i];
                this.setItemCellCssClasses(rCell);
                rCell.choiceIndex = i;
            }
            rRow.cells.push(rCell);
        }
    }
    setItemCellCssClasses(cell) {
        cell.className = new CssClassBuilder()
            .append(this.cssClasses.cell)
            .append(this.cssClasses.itemCell)
            .append(this.cssClasses.radioCell, cell.isRadio)
            .append(this.cssClasses.checkboxCell, cell.isCheckbox)
            .toString();
    }
    createEditCell(cell, choiceItem = undefined) {
        var res = new QuestionMatrixDropdownRenderedCell();
        res.cell = cell;
        res.row = cell.row;
        res.column = cell.column;
        res.question = cell.question;
        res.matrix = this.matrix;
        res.item = choiceItem;
        res.isOtherChoice = !!choiceItem && !!cell.question && cell.question.otherItem === choiceItem;
        res.className = res.calculateFinalClassName(this.cssClasses);
        return res;
    }
    createErrorCell(cell, choiceItem = undefined) {
        var res = new QuestionMatrixDropdownRenderedCell();
        res.question = cell.question;
        res.row = cell.row;
        res.matrix = this.matrix;
        res.isErrorsCell = true;
        res.className = new CssClassBuilder()
            .append(this.cssClasses.cell)
            .append(this.cssClasses.errorsCell)
            .append(this.cssClasses.errorsCellTop, this.showCellErrorsTop)
            .append(this.cssClasses.errorsCellBottom, this.showCellErrorsBottom)
            .toString();
        return res;
    }
    createMutlipleColumnsFooter(rRow, cell) {
        this.createMutlipleEditCells(rRow, cell, true);
    }
    createMutlipleColumnsHeader(column) {
        var choices = this.getMultipleColumnChoices(column);
        if (!choices)
            return;
        for (var i = 0; i < choices.length; i++) {
            var cell = this.createTextCell(choices[i].locText);
            this.setHeaderCell(column, cell);
            this.setHeaderCellCssClasses(cell);
            this.headerRow.cells.push(cell);
        }
    }
    getMultipleColumnChoices(column) {
        var choices = column.templateQuestion.choices;
        if (!!choices && Array.isArray(choices) && choices.length == 0)
            return [].concat(this.matrix.choices, column.getVisibleMultipleChoices());
        choices = column.getVisibleMultipleChoices();
        if (!choices || !Array.isArray(choices))
            return null;
        return choices;
    }
    setHeaderCellCssClasses(cell, cellType, classMod) {
        cell.className = new CssClassBuilder()
            .append(this.cssClasses.headerCell)
            .append(this.cssClasses.columnTitleCell, this.matrix.isColumnLayoutHorizontal)
            .append(this.cssClasses.emptyCell, !!cell.isEmpty)
            .append(this.cssClasses.cell + "--" + cellType, !!cellType)
            .append(classMod, !!classMod)
            .toString();
    }
    createHeaderCell(column, cellType = null, classMod) {
        let cell = !!column ? this.createTextCell(column.locTitle) : this.createEmptyCell();
        cell.column = column;
        this.setHeaderCell(column, cell);
        if (!cellType)
            cellType = (!!column && column.cellType !== "default") ? column.cellType : this.matrix.cellType;
        this.setHeaderCellCssClasses(cell, cellType, classMod);
        return cell;
    }
    setHeaderCell(column, cell) {
        this.setCellWidth(column, cell);
    }
    setCellWidth(column, cell) {
        cell.minWidth = column != null ? this.matrix.getColumnWidth(column) : this.matrix.getRowTitleWidth();
        cell.width = column != null ? column.width : this.matrix.getRowTitleWidth();
    }
    createTextCell(locTitle) {
        var cell = new QuestionMatrixDropdownRenderedCell();
        cell.locTitle = locTitle;
        if (!!this.cssClasses.cell) {
            cell.className = this.cssClasses.cell;
        }
        return cell;
    }
    createEmptyCell(isError = false) {
        const res = this.createTextCell(null);
        res.isEmpty = true;
        res.className = new CssClassBuilder()
            .append(this.cssClasses.cell)
            .append(this.cssClasses.emptyCell)
            .append(this.cssClasses.errorsCell, isError)
            .toString();
        return res;
    }
}
__decorate([
    propertyArray({
        onPush: (_, i, target) => {
            target.updateRenderedRows();
        },
        onRemove: (_, i, target) => {
            target.updateRenderedRows();
        }
    })
], QuestionMatrixDropdownRenderedTable.prototype, "rows", void 0);
__decorate([
    propertyArray()
], QuestionMatrixDropdownRenderedTable.prototype, "_renderedRows", void 0);

class MatrixDropdownCell {
    constructor(column, row, data) {
        this.column = column;
        this.row = row;
        this.data = data;
        this.questionValue = this.createQuestion(column, row, data);
        this.questionValue.updateCustomWidget();
        this.updateCellQuestionTitleDueToAccessebility(row);
    }
    updateCellQuestionTitleDueToAccessebility(row) {
        this.questionValue.locTitle.onGetTextCallback = (str) => {
            const survey = row === null || row === void 0 ? void 0 : row.getSurvey();
            if (!survey || survey.isSingleVisibleInput)
                return this.questionValue.title;
            const rowTitle = row.getAccessbilityText();
            if (!rowTitle)
                return this.questionValue.title;
            return this.column.colOwner.getCellAriaLabel(row, this.column, rowTitle);
        };
    }
    locStrsChanged() {
        this.question.locStrsChanged();
    }
    createQuestion(column, row, data) {
        const res = data.createQuestion(this.row, this.column);
        res.readOnlyCallback = () => !this.row.isRowEnabled();
        res.validateValueCallback = function () {
            return data.validateCell(row, column.name, row.value);
        };
        CustomPropertiesCollection.getProperties(column.getType()).forEach((property) => {
            let propertyName = property.name;
            if (column[propertyName] !== undefined) {
                res[propertyName] = column[propertyName];
            }
        });
        return res;
    }
    get question() {
        return this.questionValue;
    }
    get value() {
        return this.question.value;
    }
    set value(value) {
        this.question.value = value;
    }
    getQuestionWrapperClassName(className) {
        return className;
    }
    runCondition(values, properties) {
        this.question.runCondition(values, properties);
    }
}
class MatrixDropdownTotalCell extends MatrixDropdownCell {
    constructor(column, row, data) {
        super(column, row, data);
        this.column = column;
        this.row = row;
        this.data = data;
        this.updateCellQuestion();
    }
    createQuestion(column, row, data) {
        var res = Serializer.createClass("expression");
        res.setSurveyImpl(row);
        return res;
    }
    locStrsChanged() {
        this.updateCellQuestion();
        super.locStrsChanged();
    }
    updateCellQuestion() {
        this.question.locCalculation();
        this.column.updateCellQuestion(this.question, null, function (json) {
            delete json["defaultValue"];
        });
        this.question.expression = this.getTotalExpression();
        this.question.format = this.column.totalFormat;
        this.question.currency = this.column.totalCurrency;
        this.question.displayStyle = this.column.totalDisplayStyle;
        this.question.maximumFractionDigits = this.column.totalMaximumFractionDigits;
        this.question.minimumFractionDigits = this.column.totalMinimumFractionDigits;
        this.question.unlocCalculation();
        this.question.runIfReadOnly = true;
    }
    getQuestionWrapperClassName(className) {
        let result = super.getQuestionWrapperClassName(className);
        if (!result) {
            return result;
        }
        if (this.question.expression && this.question.expression != "''") {
            result += " " + className + "--expression";
        }
        let alignment = this.column.totalAlignment;
        if (alignment === "auto") {
            if (this.column.cellType === "dropdown") {
                alignment = "left";
            }
        }
        return result + " " + className + "--" + alignment;
    }
    getTotalExpression() {
        if (!!this.column.totalExpression)
            return this.column.totalExpression;
        if (this.column.totalType == "none")
            return "''";
        var funName = this.column.totalType + "InArray";
        if (!FunctionFactory.Instance.hasFunction(funName))
            return "";
        return funName + "({self}, '" + this.column.name + "')";
    }
}
class MatrixDropdownRowTextProcessor extends QuestionTextProcessor {
    constructor(data, row, variableName) {
        super(variableName);
        this.data = data;
        this.row = row;
        this.variableName = variableName;
        this.sharedQuestions = {};
        this.parentTextProcessor = data === null || data === void 0 ? void 0 : data.getParentTextProcessor();
    }
    getParentTextProcessor() { return this.parentTextProcessor; }
    get survey() {
        return this.row.getSurvey();
    }
    getValues() {
        return this.row.getAllValues();
    }
    getQuestionByName(name) {
        let res = this.row.getQuestionByName(name);
        if (!!res)
            return res;
        const index = this.row.rowIndex - 1;
        res = index > -1 ? this.data.getSharedQuestionFromArray(name, index) : undefined;
        const qName = !!res ? res.name : name;
        this.sharedQuestions[qName] = name;
        return res;
    }
    getQuestionDisplayText(question) {
        const name = this.sharedQuestions[question.name];
        if (!name)
            return super.getQuestionDisplayText(question);
        const val = this.row.getAllValues()[name];
        return question.getDisplayValue(true, val);
    }
    onCustomProcessText(textValue) {
        if (textValue.name == MatrixDropdownRowModelBase.IndexVariableName) {
            textValue.isExists = true;
            textValue.value = this.row.rowIndex;
            return true;
        }
        if ([MatrixDropdownRowModelBase.RowValueVariableName, MatrixDropdownRowModelBase.RowNameVariableName].indexOf(textValue.name) > -1) {
            textValue.isExists = true;
            textValue.value = this.row.rowName;
            return true;
        }
        if (textValue.name == MatrixDropdownRowModelBase.RowTitleVariableName) {
            textValue.isExists = true;
            textValue.value = this.row.rowTitle;
            return true;
        }
        return false;
    }
}
class MatrixDropdownRowModelBase {
    static getId() {
        return "srow_" + MatrixDropdownRowModelBase.idCounter++;
    }
    constructor(data, value) {
        this.isSettingValue = false;
        this.detailPanelValue = null;
        this.visibleValue = true;
        this.cells = [];
        this.visibleIndex = -1;
        this.isCreatingDetailPanel = false;
        this.data = data;
        this.subscribeToChanges(value);
        this.textPreProcessor = new MatrixDropdownRowTextProcessor(data, this, MatrixDropdownRowModelBase.RowVariableName);
        this.showHideDetailPanelClick = () => {
            if (this.getSurvey().isDesignMode)
                return true;
            this.showHideDetailPanel();
        };
        this.idValue = MatrixDropdownRowModelBase.getId();
    }
    get id() {
        return this.idValue;
    }
    get rowName() {
        return null;
    }
    get rowTitle() {
        return this.rowName;
    }
    get dataName() {
        return this.rowName;
    }
    get text() {
        return this.rowName;
    }
    isRowEnabled() { return true; }
    isRowHasEnabledCondition() { return false; }
    get isVisible() { return this.visible && this.isItemVisible(); }
    get visible() { return this.visibleValue; }
    set visible(val) {
        var _a;
        if (this.visible !== val) {
            this.visibleValue = val;
            (_a = this.data) === null || _a === void 0 ? void 0 : _a.onRowVisibilityChanged(this);
        }
    }
    isItemVisible() { return true; }
    get value() {
        var result = {};
        var questions = this.questions;
        for (var i = 0; i < questions.length; i++) {
            var question = questions[i];
            if (!question.isEmpty()) {
                result[question.getValueName()] = question.value;
            }
            if (!!question.comment &&
                !!this.getSurvey() &&
                this.getSurvey().storeOthersAsComment) {
                result[question.getValueName() + Base.commentSuffix] =
                    question.comment;
            }
        }
        return result;
    }
    set value(value) {
        this.isSettingValue = true;
        this.subscribeToChanges(value);
        var questions = this.questions;
        for (var i = 0; i < questions.length; i++) {
            var question = questions[i];
            var val = this.getCellValue(value, question.getValueName());
            var oldComment = question.comment;
            var comment = !!value
                ? value[question.getValueName() + Base.commentSuffix]
                : "";
            if (comment == undefined)
                comment = "";
            question.updateValueFromSurvey(val);
            if (!!comment || this.isTwoValueEquals(oldComment, question.comment)) {
                question.updateCommentFromSurvey(comment);
            }
            question.onSurveyValueChanged(val);
        }
        this.isSettingValue = false;
    }
    get locText() {
        return null;
    }
    getAccessbilityText() {
        return this.locText && this.locText.renderedHtml;
    }
    get hasPanel() {
        if (!this.data)
            return false;
        return this.data.hasDetailPanel(this);
    }
    get detailPanel() {
        return this.detailPanelValue;
    }
    get detailPanelId() {
        return !!this.detailPanel ? this.detailPanel.id : "";
    }
    get isDetailPanelShowing() {
        return !!this.data ? this.data.getIsDetailPanelShowing(this) : false;
    }
    setIsDetailPanelShowing(val) {
        if (!val && this.detailPanel) {
            this.detailPanel.onHidingContent();
        }
        if (!!this.data) {
            this.data.setIsDetailPanelShowing(this, val);
        }
        if (val && this.detailPanel) {
            this.detailPanel.onFirstRendering();
        }
        if (!!this.onDetailPanelShowingChanged) {
            this.onDetailPanelShowingChanged();
        }
    }
    showHideDetailPanel() {
        if (this.isDetailPanelShowing) {
            this.hideDetailPanel();
        }
        else {
            this.showDetailPanel();
        }
    }
    showDetailPanel() {
        this.ensureDetailPanel();
        if (!this.detailPanelValue)
            return;
        this.setIsDetailPanelShowing(true);
    }
    hideDetailPanel(destroyPanel = false) {
        this.setIsDetailPanelShowing(false);
        if (destroyPanel) {
            this.detailPanelValue = null;
        }
    }
    ensureDetailPanel() {
        if (this.isCreatingDetailPanel)
            return;
        if (!!this.detailPanelValue || !this.hasPanel || !this.data)
            return;
        this.isCreatingDetailPanel = true;
        this.detailPanelValue = this.data.createRowDetailPanel(this);
        var questions = this.detailPanelValue.questions;
        var value = this.getDataRowValue();
        if (!Helpers.isValueEmpty(value)) {
            for (var i = 0; i < questions.length; i++) {
                const key = questions[i].getValueName();
                const val = !!this.editingObj ? Serializer.getObjPropertyValue(this.editingObj, key) : value[key];
                if (!Helpers.isValueEmpty(val)) {
                    questions[i].value = val;
                }
            }
        }
        this.detailPanelValue.setSurveyImpl(this);
        this.isCreatingDetailPanel = false;
    }
    getAllValues() {
        const res = this.value;
        if (this.data) {
            const rowVal = this.getDataRowValue();
            if (rowVal) {
                for (var key in rowVal) {
                    if (res[key] === undefined) {
                        res[key] = rowVal[key];
                    }
                }
            }
        }
        return res;
    }
    getFilteredValues() {
        const res = this.data ? this.data.getDataFilteredValues() : {};
        var values = this.validationValues;
        if (values) {
            for (var key in values) {
                res[key] = values[key];
            }
        }
        res.row = this.getAllValues();
        this.applyRowVariablesToValues(res, this.rowIndex);
        return res;
    }
    getFilteredProperties() {
        return { survey: this.getSurvey(), row: this };
    }
    getDataRowValue() {
        if (!this.data)
            return null;
        return this.data.getRowValue(this.data.getRowIndex(this));
    }
    applyRowVariablesToValues(res, rowIndex) {
        res[MatrixDropdownRowModelBase.IndexVariableName] = rowIndex;
        res[MatrixDropdownRowModelBase.RowValueVariableName] = this.rowName;
        res[MatrixDropdownRowModelBase.RowNameVariableName] = this.rowName;
        res[MatrixDropdownRowModelBase.RowTitleVariableName] = this.rowTitle;
    }
    runCondition(values, properties, rowsVisibleIf) {
        if (!this.data)
            return;
        values[MatrixDropdownRowModelBase.OwnerVariableName] = this.data.getFilteredData();
        const rowIndex = this.rowIndex;
        this.applyRowVariablesToValues(values, rowIndex);
        const newProps = Helpers.createCopy(properties);
        newProps[MatrixDropdownRowModelBase.RowVariableName] = this;
        const rowValues = rowIndex > 0 ? this.getDataRowValue() : this.value;
        if (!!rowsVisibleIf) {
            values[MatrixDropdownRowModelBase.RowVariableName] = rowValues;
            this.setRowsVisibleIfValues(values);
            this.visible = new ConditionRunner(rowsVisibleIf).run(values, properties);
        }
        else {
            this.visible = true;
        }
        for (var i = 0; i < this.cells.length; i++) {
            if (i > 0) {
                mergeValues(this.value, rowValues);
            }
            values[MatrixDropdownRowModelBase.RowVariableName] = rowValues;
            this.cells[i].runCondition(values, newProps);
        }
        if (!!this.detailPanel) {
            this.detailPanel.runCondition(values, newProps);
        }
        if (this.isRowHasEnabledCondition()) {
            this.onQuestionReadOnlyChanged();
        }
    }
    updateElementVisibility() {
        this.cells.forEach(cell => cell.question.updateElementVisibility());
        if (!!this.detailPanel) {
            this.detailPanel.updateElementVisibility();
        }
    }
    setRowsVisibleIfValues(values) { }
    getNamesWithDefaultValues() {
        const res = [];
        this.questions.forEach(q => {
            if (q.isValueDefault) {
                res.push(q.getValueName());
            }
        });
        return res;
    }
    clearValue(keepComment) {
        var questions = this.questions;
        for (var i = 0; i < questions.length; i++) {
            questions[i].clearValue(keepComment);
        }
    }
    onAnyValueChanged(name, questionName) {
        var questions = this.questions;
        for (var i = 0; i < questions.length; i++) {
            questions[i].onAnyValueChanged(name, questionName);
        }
    }
    getDataValueCore(valuesHash, key) {
        var survey = this.getSurvey();
        if (!!survey) {
            return survey.getDataValueCore(valuesHash, key);
        }
        else {
            return valuesHash[key];
        }
    }
    getValue(name) {
        var question = this.getQuestionByName(name);
        return !!question ? question.value : null;
    }
    setValue(name, newColumnValue) {
        this.setValueCore(name, newColumnValue, false);
    }
    getVariable(name) {
        return undefined;
    }
    setVariable(name, newValue) { }
    getComment(name) {
        var question = this.getQuestionByName(name);
        return !!question ? question.comment : "";
    }
    setComment(name, newValue, locNotification) {
        this.setValueCore(name, newValue, true);
    }
    findQuestionByName(name) {
        if (!name)
            return undefined;
        const prefix = MatrixDropdownRowModelBase.RowVariableName + ".";
        if (name.indexOf(prefix) === 0) {
            return this.getQuestionByName(name.substring(prefix.length));
        }
        const survey = this.getSurvey();
        return !!survey ? survey.getQuestionByName(name) : null;
    }
    getEditingSurveyElement() { return undefined; }
    setValueCore(name, newColumnValue, isComment) {
        if (this.isSettingValue)
            return;
        this.updateQuestionsValue(name, newColumnValue, isComment);
        if (!isComment) {
            this.updateSharedQuestionsValue(name, newColumnValue);
        }
        var newValue = this.value;
        var changedName = isComment ? name + Base.commentSuffix : name;
        var changedValue = newColumnValue;
        var changedQuestion = this.getQuestionByName(name);
        var changingValue = this.data.onRowChanging(this, changedName, newValue);
        if (!!changedQuestion &&
            !this.isTwoValueEquals(changingValue, changedValue)) {
            this.isSettingValue = true;
            if (isComment) {
                changedQuestion.comment = changingValue;
            }
            else {
                changedQuestion.value = changingValue;
            }
            this.isSettingValue = false;
            newValue = this.value;
        }
        if (this.data.isValidateOnValueChanging && this.hasQuestonError(changedQuestion))
            return;
        const isDeleting = newColumnValue == null && !changedQuestion ||
            isComment && !newColumnValue && !!changedQuestion;
        this.data.onRowChanged(this, changedName, newValue, isDeleting);
        if (changedName) {
            this.runTriggers(MatrixDropdownTotalRowModel.RowVariableName + "." + changedName, newValue);
        }
        this.onAnyValueChanged(MatrixDropdownRowModelBase.RowVariableName, "");
    }
    updateQuestionsValue(name, newColumnValue, isComment) {
        if (!this.detailPanel)
            return;
        var colQuestion = this.getQuestionByColumnName(name);
        var detailQuestion = this.detailPanel.getQuestionByName(name);
        if (!colQuestion || !detailQuestion)
            return;
        var isColQuestion = this.isTwoValueEquals(newColumnValue, isComment ? colQuestion.comment : colQuestion.value);
        var question = isColQuestion ? detailQuestion : colQuestion;
        this.isSettingValue = true;
        if (!isComment) {
            question.value = newColumnValue;
        }
        else {
            question.comment = newColumnValue;
        }
        this.isSettingValue = false;
    }
    updateSharedQuestionsValue(name, value) {
        const questions = this.getQuestionsByValueName(name);
        if (questions.length > 1) {
            for (let i = 0; i < questions.length; i++) {
                if (!Helpers.isTwoValueEquals(questions[i].value, value)) {
                    this.isSettingValue = true;
                    questions[i].updateValueFromSurvey(value);
                    this.isSettingValue = false;
                }
            }
        }
    }
    runTriggers(name, value, keys) {
        if (!name && !keys)
            return;
        this.questions.forEach(q => q.runTriggers(name, value, keys));
    }
    hasQuestonError(question) {
        if (!question)
            return false;
        if (question.hasErrors(true, {
            isOnValueChanged: !this.data.isValidateOnValueChanging,
        }))
            return true;
        if (question.isEmpty())
            return false;
        var cell = this.getCellByColumnName(question.name);
        if (!cell || !cell.column || !cell.column.isUnique)
            return false;
        return this.data.checkIfValueInRowDuplicated(this, question);
    }
    get isEmpty() {
        var val = this.value;
        if (Helpers.isValueEmpty(val))
            return true;
        for (var key in val) {
            if (val[key] !== undefined && val[key] !== null)
                return false;
        }
        return true;
    }
    hasValueAnyQuestion(visibleOnly) {
        const questions = visibleOnly ? this.visibleQuestions : this.questions;
        for (let i = 0; i < questions.length; i++) {
            if (!questions[i].isEmpty())
                return true;
        }
        return false;
    }
    getQuestionByColumn(column) {
        var cell = this.getCellByColumn(column);
        return !!cell ? cell.question : null;
    }
    getCellByColumn(column) {
        for (var i = 0; i < this.cells.length; i++) {
            if (this.cells[i].column == column)
                return this.cells[i];
        }
        return null;
    }
    getCellByColumnName(columnName) {
        for (var i = 0; i < this.cells.length; i++) {
            if (this.cells[i].column.name == columnName)
                return this.cells[i];
        }
        return null;
    }
    getQuestionByColumnName(columnName) {
        var cell = this.getCellByColumnName(columnName);
        return !!cell ? cell.question : null;
    }
    get questions() {
        var res = [];
        for (var i = 0; i < this.cells.length; i++) {
            res.push(this.cells[i].question);
        }
        var detailQuestions = !!this.detailPanel ? this.detailPanel.questions : [];
        for (var i = 0; i < detailQuestions.length; i++) {
            res.push(detailQuestions[i]);
        }
        return res;
    }
    get visibleQuestions() {
        const res = [];
        this.questions.forEach(q => {
            if (q.isVisible) {
                res.push(q);
            }
        });
        return res;
    }
    getQuestionByName(name) {
        var res = this.getQuestionByColumnName(name);
        if (!!res)
            return res;
        return !!this.detailPanel ? this.detailPanel.getQuestionByName(name) : null;
    }
    getQuestionsByName(name) {
        let res = [];
        let q = this.getQuestionByColumnName(name);
        if (!!q)
            res.push(q);
        if (!!this.detailPanel) {
            q = this.detailPanel.getQuestionByName(name);
            if (!!q)
                res.push(q);
        }
        return res;
    }
    getQuestionsByValueName(name) {
        let res = [];
        for (var i = 0; i < this.cells.length; i++) {
            const cell = this.cells[i];
            if (cell.question && cell.question.getValueName() === name) {
                res.push(cell.question);
            }
        }
        if (!!this.detailPanel) {
            res = res.concat(this.detailPanel.getQuestionsByValueName(name));
        }
        return res;
    }
    getSharedQuestionByName(columnName) {
        return !!this.data
            ? this.data.getSharedQuestionByName(columnName, this)
            : null;
    }
    clearIncorrectValues(val) {
        for (var key in val) {
            var question = this.getQuestionByName(key);
            if (question) {
                var qVal = question.value;
                question.clearIncorrectValues();
                if (!this.isTwoValueEquals(qVal, question.value)) {
                    this.setValue(key, question.value);
                }
            }
            else {
                if (!this.getSharedQuestionByName(key) &&
                    key.indexOf(settings.matrix.totalsSuffix) < 0) {
                    this.setValue(key, null);
                }
            }
        }
    }
    getLocale() {
        return this.data ? this.data.getLocale() : "";
    }
    getMarkdownHtml(text, name, item) {
        return this.data ? this.data.getMarkdownHtml(text, name, item) : undefined;
    }
    getRenderer(name) {
        return this.data ? this.data.getRenderer(name) : null;
    }
    getRendererContext(locStr) {
        return this.data ? this.data.getRendererContext(locStr) : locStr;
    }
    getProcessedText(text) {
        return this.data ? this.data.getProcessedText(text) : text;
    }
    locStrsChanged() {
        for (var i = 0; i < this.cells.length; i++) {
            this.cells[i].locStrsChanged();
        }
        if (!!this.detailPanel) {
            this.detailPanel.locStrsChanged();
        }
    }
    updateCellQuestionOnColumnChanged(column, name, newValue) {
        var cell = this.getCellByColumn(column);
        if (!cell)
            return;
        this.updateCellOnColumnChanged(cell, name, newValue);
    }
    updateCellQuestionOnColumnItemValueChanged(column, propertyName, obj, name, newValue, oldValue) {
        var cell = this.getCellByColumn(column);
        if (!cell)
            return;
        this.updateCellOnColumnItemValueChanged(cell, propertyName, obj, name, newValue, oldValue);
    }
    onQuestionReadOnlyChanged() {
        const questions = this.questions;
        for (var i = 0; i < questions.length; i++) {
            const q = questions[i];
            q.setPropertyValue("isReadOnly", q.isReadOnly);
        }
        if (!!this.detailPanel) {
            const parentIsReadOnly = !!this.data && this.data.isMatrixReadOnly();
            this.detailPanel.readOnly = parentIsReadOnly || !this.isRowEnabled();
        }
    }
    hasErrors(fireCallback, rec, raiseOnCompletedAsyncValidators) {
        var res = false;
        var cells = this.cells;
        if (!cells)
            return res;
        this.validationValues = rec.validationValues;
        const focusOnFirstError = rec === null || rec === void 0 ? void 0 : rec.focusOnFirstError;
        //firstErrorQuestion: <any>null,
        for (var colIndex = 0; colIndex < cells.length; colIndex++) {
            if (!cells[colIndex])
                continue;
            var question = cells[colIndex].question;
            if (!question || !question.visible)
                continue;
            question.onCompletedAsyncValidators = (hasErrors) => {
                raiseOnCompletedAsyncValidators();
            };
            if (!!rec && rec.isOnValueChanged === true && question.isEmpty())
                continue;
            res = question.hasErrors(fireCallback, rec) || res;
            if (res && focusOnFirstError && !rec.firstErrorQuestion) {
                rec.firstErrorQuestion = question;
            }
        }
        if (this.hasPanel) {
            this.ensureDetailPanel();
            var panelHasError = this.detailPanel.hasErrors(fireCallback, false, rec);
            if (!rec.hideErroredPanel && panelHasError && fireCallback) {
                if (rec.isSingleDetailPanel) {
                    rec.hideErroredPanel = true;
                }
                this.showDetailPanel();
            }
            res = panelHasError || res;
        }
        this.validationValues = undefined;
        return res;
    }
    updateCellOnColumnChanged(cell, name, newValue) {
        if (name === "choices" && Array.isArray(newValue) && newValue.length === 0 && this.data) {
            newValue = this.data.choices;
        }
        cell.question[name] = newValue;
    }
    updateCellOnColumnItemValueChanged(cell, propertyName, obj, name, newValue, oldValue) {
        var items = cell.question[propertyName];
        if (!Array.isArray(items))
            return;
        var val = name === "value" ? oldValue : obj["value"];
        var item = ItemValue.getItemByValue(items, val);
        if (!item)
            return;
        item[name] = newValue;
    }
    buildCells(value) {
        this.isSettingValue = true;
        var columns = this.data.columns;
        for (var i = 0; i < columns.length; i++) {
            var column = columns[i];
            var cell = this.createCell(column);
            this.cells.push(cell);
            var cellValue = this.getCellValue(value, column.name);
            if (!Helpers.isValueEmpty(cellValue)) {
                cell.question.value = cellValue;
                var commentKey = column.name + Base.commentSuffix;
                if (!!value && !Helpers.isValueEmpty(value[commentKey])) {
                    cell.question.comment = value[commentKey];
                }
            }
        }
        this.isSettingValue = false;
    }
    isTwoValueEquals(val1, val2) {
        return Helpers.isTwoValueEquals(val1, val2, false, true, false);
    }
    getCellValue(value, name) {
        if (!!this.editingObj)
            return Serializer.getObjPropertyValue(this.editingObj, name);
        return !!value ? value[name] : undefined;
    }
    createCell(column) {
        return new MatrixDropdownCell(column, this, this.data);
    }
    getSurveyData() {
        return this;
    }
    getSurvey() {
        return this.data ? this.data.getSurvey() : null;
    }
    getTextProcessor() {
        return this.textPreProcessor;
    }
    get rowIndex() {
        return this.getRowIndex();
    }
    getRowIndex() {
        return !!this.data ? this.data.getRowIndex(this) + 1 : -1;
    }
    get editingObj() {
        return this.editingObjValue;
    }
    dispose() {
        if (!!this.editingObj) {
            this.editingObj.onPropertyChanged.remove(this.onEditingObjPropertyChanged);
            this.editingObjValue = null;
        }
    }
    subscribeToChanges(value) {
        if (!value || !value.getType || !value.onPropertyChanged)
            return;
        if (value === this.editingObj)
            return;
        this.editingObjValue = value;
        this.onEditingObjPropertyChanged = (sender, options) => {
            this.updateOnSetValue(options.name, options.newValue);
        };
        this.editingObj.onPropertyChanged.add(this.onEditingObjPropertyChanged);
    }
    updateOnSetValue(name, newValue) {
        this.isSettingValue = true;
        let questions = this.getQuestionsByName(name);
        for (let i = 0; i < questions.length; i++) {
            questions[i].value = newValue;
        }
        this.isSettingValue = false;
    }
}
MatrixDropdownRowModelBase.RowVariableName = "row";
MatrixDropdownRowModelBase.OwnerVariableName = "self";
MatrixDropdownRowModelBase.IndexVariableName = "rowIndex";
MatrixDropdownRowModelBase.RowValueVariableName = "rowValue";
MatrixDropdownRowModelBase.RowNameVariableName = "rowName";
MatrixDropdownRowModelBase.RowTitleVariableName = "rowTitle";
MatrixDropdownRowModelBase.idCounter = 1;
class MatrixDropdownTotalRowModel extends MatrixDropdownRowModelBase {
    constructor(data) {
        super(data, null);
        this.buildCells(null);
    }
    createCell(column) {
        return new MatrixDropdownTotalCell(column, this, this.data);
    }
    setValue(name, newValue) {
        if (!!this.data && !this.isSettingValue) {
            this.data.onTotalValueChanged();
        }
    }
    runCondition(values, properties, rowsVisibleIf) {
        var counter = 0;
        var prevValue;
        do {
            prevValue = Helpers.getUnbindValue(this.value);
            super.runCondition(values, properties, "");
            counter++;
        } while (!Helpers.isTwoValueEquals(prevValue, this.value) && counter < 3);
    }
    updateCellOnColumnChanged(cell, name, newValue) {
        cell.updateCellQuestion();
    }
}
/**
 * A base class for the [`QuestionMatrixDropdownModel`](https://surveyjs.io/form-library/documentation/questionmatrixdropdownmodel) and [`QuestionMatrixDynamicModel`](https://surveyjs.io/form-library/documentation/questionmatrixdynamicmodel) classes.
 */
class QuestionMatrixDropdownModelBase extends QuestionMatrixBaseModel {
    static get defaultCellType() {
        return settings.matrix.defaultCellType;
    }
    static set defaultCellType(val) {
        settings.matrix.defaultCellType = val;
    }
    static addDefaultColumns(matrix) {
        var colNames = QuestionFactory.DefaultColums;
        for (var i = 0; i < colNames.length; i++)
            matrix.addColumn(colNames[i]);
    }
    createColumnValues() {
        return this.createNewArray("columns", (item) => {
            item.colOwner = this;
            if (this.onAddColumn)
                this.onAddColumn(item);
            if (this.survey) {
                this.survey.matrixColumnAdded(this, item);
            }
        }, (item) => {
            item.colOwner = null;
            if (this.onRemoveColumn)
                this.onRemoveColumn(item);
        });
    }
    constructor(name) {
        super(name);
        this.isRowChanging = false;
        this.lockResetRenderedTable = false;
        this.createItemValues("choices");
        this.createLocalizableString("placeholder", this, false, true);
        this.createLocalizableString("keyDuplicationError", this, false, true);
        this.createLocalizableString("singleInputTitleTemplate", this, true, this.getSingleInputTitleTemplate()).onGetTextCallback = (text) => {
            return this.processSingleInputTitle(text);
        };
        this.detailPanelValue = this.createNewDetailPanel();
        this.detailPanel.selectedElementInDesign = this;
        this.detailPanel.renderWidth = "100%";
        this.detailPanel.isInteractiveDesignElement = false;
        this.detailPanel.showTitle = false;
        this.registerPropertyChangedHandlers(["columns", "cellType"], () => { this.updateColumnsAndRows(); });
        this.registerPropertyChangedHandlers(["placeholder", "columnColCount", "rowTitleWidth", "choices"], () => {
            this.clearRowsAndResetRenderedTable();
        });
        this.registerPropertyChangedHandlers([
            "transposeData",
            "addRowButtonLocation",
            "hideColumnsIfEmpty",
            "showHeader",
            "minRowCount",
            "isReadOnly",
            "rowCount",
            "hasFooter",
            "detailPanelMode",
            "displayMode"
        ], () => {
            this.resetRenderedTable();
        });
    }
    getType() {
        return "matrixdropdownbase";
    }
    dispose() {
        super.dispose();
        this.clearGeneratedRows();
    }
    get hasSingleInput() { return false; }
    get isContainer() { return true; }
    get isRowsDynamic() {
        return false;
    }
    get isUpdateLocked() {
        return this.isLoadingFromJson || this.isUpdating;
    }
    beginUpdate() {
        this.isUpdating = true;
    }
    endUpdate() {
        this.isUpdating = false;
        this.updateColumnsAndRows();
    }
    updateColumnsAndRows() {
        this.updateColumnsIndexes(this.columns);
        this.updateColumnsCellType();
        this.generatedTotalRow = null;
        this.clearRowsAndResetRenderedTable();
    }
    itemValuePropertyChanged(item, name, oldValue, newValue) {
        super.itemValuePropertyChanged(item, name, oldValue, newValue);
        if (item.ownerPropertyName === "choices") {
            this.clearRowsAndResetRenderedTable();
        }
    }
    /**
     * Specifies whether to display [`columns`](#columns) as rows and [`rows`](#rows) as columns.
     *
     * Default value: `false`
     *
     * [Multi-Select Matrix Demo](https://surveyjs.io/form-library/examples/multi-select-matrix-question/ (linkStyle))
     *
     * [Dynamic Matrix Demo](https://surveyjs.io/form-library/examples/transpose-dynamic-rows-to-columns-in-matrix/ (linkStyle))
     */
    get transposeData() {
        return this.getPropertyValue("transposeData");
    }
    set transposeData(val) {
        this.setPropertyValue("transposeData", val);
    }
    /**
     * @deprecated Use the [`transposeData`](#transposeData) property instead.
     */
    get columnLayout() {
        return this.transposeData ? "vertical" : "horizontal";
    }
    set columnLayout(val) {
        this.transposeData = val === "vertical";
    }
    get columnsLocation() {
        return this.columnLayout;
    }
    set columnsLocation(val) {
        this.columnLayout = val;
    }
    /**
     * Specifies the error message position for questions within detail sections.
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the [`errorLocation`](#errorLocation) property.
     * - `"top"` - Displays error messages above questions.
     * - `"bottom"` - Displays error messages below questions.
     * @see cellErrorLocation
     */
    get detailErrorLocation() {
        return this.getPropertyValue("detailErrorLocation");
    }
    set detailErrorLocation(value) {
        this.setPropertyValue("detailErrorLocation", value.toLowerCase());
    }
    /**
     * Specifies the error message position relative to matrix cells.
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the [`errorLocation`](#errorLocation) property.
     * - `"top"` - Displays error messages above matrix cells.
     * - `"bottom"` - Displays error messages below matrix cells.
     * @see detailErrorLocation
     */
    get cellErrorLocation() {
        return this.getPropertyValue("cellErrorLocation");
    }
    set cellErrorLocation(value) {
        this.setPropertyValue("cellErrorLocation", value.toLowerCase());
    }
    getChildErrorLocation(child) {
        const errLocation = !!child.parent ? this.detailErrorLocation : this.cellErrorLocation;
        if (errLocation !== "default")
            return errLocation;
        return super.getChildErrorLocation(child);
    }
    /**
     * Returns `true` if [`columns`](#columns) are placed in the horizontal direction and [`rows`](#columns) in the vertical direction.
     *
     * To specify the layout, use the [`transposeData`](#transposeData) property. If you set it to `true`, the survey applies it only when the screen has enough space. Otherwise, the survey falls back to the original layout, but the `transposeData` property remains set to `true`. Unlike `transposeData`, the `isColumnLayoutHorizontal` property always indicates the current layout.
     * @see transposeData
     */
    get isColumnLayoutHorizontal() {
        return this.isMobile ? true : !this.transposeData;
    }
    /**
     * Enables case-sensitive comparison in columns with the `isUnique` property set to `true`.
     *
     * When this property is `true`, `"ABC"` and `"abc"` are considered different values.
     *
     * Default value: `false`
     * @see keyDuplicationError
     */
    get useCaseSensitiveComparison() {
        return this.useCaseSensitiveComparisonValue !== undefined ? this.useCaseSensitiveComparisonValue : settings.comparator.caseSensitive;
    }
    set useCaseSensitiveComparison(val) {
        this.useCaseSensitiveComparisonValue = val;
    }
    /**
     * @deprecated Use the [`useCaseSensitiveComparison`](#useCaseSensitiveComparison) property instead.
     */
    get isUniqueCaseSensitive() {
        return this.useCaseSensitiveComparison;
    }
    set isUniqueCaseSensitive(val) {
        this.useCaseSensitiveComparison = val;
    }
    /**
     * Specifies the location of detail sections.
     *
     * Possible values:
     *
     * - `"underRow"` - Displays detail sections under their respective rows. Users can expand any number of detail sections.
     * - `"underRowSingle"` - Displays detail sections under their respective rows, but only one detail section can be expanded at a time.
     * - `"none"` (default) - Hides detail sections.
     *
     * Use the [`detailElements`](#detailElements) property to specify content of detail sections.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-expandable-details-section-under-matrix-rows/ (linkStyle))
     * @see detailPanel
     */
    get detailPanelMode() {
        return this.getPropertyValue("detailPanelMode");
    }
    set detailPanelMode(val) {
        this.setPropertyValue("detailPanelMode", val);
    }
    /**
     * Contains a [`PanelModel`](https://surveyjs.io/form-library/documentation/panelmodel) instance that represents a detail section template.
     * @see detailElements
     * @see detailPanelMode
     */
    get detailPanel() {
        return this.detailPanelValue;
    }
    getPanel() {
        return this.detailPanel;
    }
    /**
     * An array of survey elements (questions and panels) to be displayed in detail sections.
     *
     * Detail sections are expandable panels displayed under each matrix row. You can use them to display questions that do not fit into the row.
     *
     * Set the [`detailPanelMode`](#detailPanelMode) property to `"underRow"` or `"underRowSingle"` to display detail sections.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-expandable-details-section-under-matrix-rows/ (linkStyle))
     * @see detailPanel
     */
    get detailElements() {
        return this.detailPanel.elements;
    }
    createNewDetailPanel() {
        return Serializer.createClass("panel");
    }
    get hasRowText() {
        return true;
    }
    getFooterText() {
        return null;
    }
    get canAddRow() {
        return false;
    }
    get canRemoveRows() {
        return false;
    }
    canRemoveRow(row) {
        return true;
    }
    onPointerDown(pointerDownEvent, row) { }
    onRowsChanged() {
        this.clearVisibleRows();
        this.resetRenderedTable();
        super.onRowsChanged();
        const rows = this.visibleRows;
        for (let i = 0; i < rows.length; i++) {
            rows[i].visibleIndex = i;
        }
    }
    onStartRowAddingRemoving() {
        this.lockResetRenderedTable = true;
        this.setValueChangedDirectly(true);
    }
    onEndRowAdding() {
        this.lockResetRenderedTable = false;
        if (!this.renderedTable)
            return;
        if (this.renderedTable.isRequireReset()) {
            this.resetRenderedTable();
        }
        else {
            const index = this.visibleRows.length - 1;
            this.renderedTable.onAddedRow(this.visibleRows[index], index);
        }
    }
    onEndRowRemoving(row) {
        this.lockResetRenderedTable = false;
        if (this.renderedTable.isRequireReset()) {
            this.resetRenderedTable();
        }
        else {
            if (!!row) {
                this.renderedTable.onRemovedRow(row);
            }
        }
    }
    get renderedTableValue() {
        return this.getPropertyValue("renderedTable", null);
    }
    set renderedTableValue(val) {
        this.setPropertyValue("renderedTable", val);
    }
    clearRowsAndResetRenderedTable() {
        this.clearGeneratedRows();
        this.resetRenderedTable();
        this.fireCallback(this.columnsChangedCallback);
    }
    //For internal use
    resetRenderedTable(columnVisibilityChanged) {
        if (!this.renderedTableValue)
            return;
        if (this.lockResetRenderedTable || this.isUpdateLocked) {
            if (columnVisibilityChanged) {
                this.renderedTableValue.requireReset();
            }
        }
        else {
            this.renderedTableValue = null;
            this.fireCallback(this.onRenderedTableResetCallback);
        }
    }
    clearGeneratedRows() {
        this.clearVisibleRows();
        if (!this.generatedVisibleRows)
            return;
        for (var i = 0; i < this.generatedVisibleRows.length; i++) {
            this.generatedVisibleRows[i].dispose();
        }
        super.clearGeneratedRows();
    }
    get isRendredTableCreated() {
        return !!this.renderedTableValue;
    }
    get renderedTable() {
        if (!this.renderedTableValue) {
            this.renderedTableValue = this.createRenderedTable();
            if (!!this.onRenderedTableCreatedCallback) {
                this.onRenderedTableCreatedCallback(this.renderedTableValue);
            }
        }
        return this.renderedTableValue;
    }
    createRenderedTable() {
        return new QuestionMatrixDropdownRenderedTable(this);
    }
    getRowByQuestion(question) {
        if (!question)
            return undefined;
        return question.data;
    }
    onMatrixRowCreated(row) {
        if (!this.survey)
            return;
        var options = {
            rowValue: row.value,
            row: row,
            column: null,
            columnName: null,
            cell: null,
            cellQuestion: null,
            value: null,
        };
        for (var i = 0; i < this.columns.length; i++) {
            options.column = this.columns[i];
            options.columnName = options.column.name;
            var cell = row.cells[i];
            options.cell = cell;
            options.cellQuestion = cell.question;
            options.value = cell.value;
            if (!!this.onCellCreatedCallback) {
                this.onCellCreatedCallback(options);
            }
            this.survey.matrixCellCreated(this, options);
        }
    }
    /**
     * Specifies the type of matrix cells. You can override this property for individual columns.
     *
     * Possible values:
     *
     * - [`"dropdown"`](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model)
     * - [`"checkbox"`](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model)
     * - [`"radiogroup"`](https://surveyjs.io/form-library/documentation/api-reference/radio-button-question-model)
     * - [`"tagbox"`](https://surveyjs.io/form-library/documentation/api-reference/dropdown-tag-box-model)
     * - [`"text"`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model)
     * - [`"comment"`](https://surveyjs.io/form-library/documentation/api-reference/comment-field-model)
     * - [`"boolean"`](https://surveyjs.io/form-library/documentation/api-reference/boolean-question-model)
     * - [`"expression"`](https://surveyjs.io/form-library/documentation/api-reference/expression-model)
     * - [`"rating"`](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model)
     *
     * Default value: `"dropdown"` (inherited from [`settings.matrix.defaultCellType`](https://surveyjs.io/form-library/documentation/settings#matrixDefaultCellType))
     *
     * [Multi-Select Matrix Demo](https://surveyjs.io/form-library/examples/multi-select-matrix-question/ (linkStyle))
     *
     * [Dynamic Matrix Demo](https://surveyjs.io/form-library/examples/dynamic-matrix-add-new-rows/ (linkStyle))
     */
    get cellType() {
        return this.getPropertyValue("cellType", settings.matrix.defaultCellType);
    }
    set cellType(val) {
        val = val.toLowerCase();
        this.setPropertyValue("cellType", val);
    }
    isSelectCellType() {
        return Serializer.isDescendantOf(this.cellType, "selectbase");
    }
    updateColumnsCellType() {
        for (var i = 0; i < this.columns.length; i++) {
            this.columns[i].defaultCellTypeChanged();
        }
    }
    updateColumnsIndexes(cols) {
        for (var i = 0; i < cols.length; i++) {
            cols[i].setIndex(i);
        }
    }
    /**
     * Specifies the number of columns in Radiogroup and Checkbox cells.
     *
     * Default value: 0 (the number of columns is selected automatically based on the available column width)
     * @see cellType
     */
    get columnColCount() {
        return this.getPropertyValue("columnColCount");
    }
    set columnColCount(value) {
        if (value < 0 || value > 4)
            return;
        this.setPropertyValue("columnColCount", value);
    }
    get horizontalScroll() {
        return this.getPropertyValue("horizontalScroll");
    }
    set horizontalScroll(val) {
        this.setPropertyValue("horizontalScroll", val);
    }
    get allowAdaptiveActions() {
        return this.getPropertyValue("allowAdaptiveActions");
    }
    set allowAdaptiveActions(val) {
        this.setPropertyValue("allowAdaptiveActions", val);
        if (!!this.detailPanel) {
            this.detailPanel.allowAdaptiveActions = val;
        }
    }
    hasChoices() {
        return this.choices.length > 0;
    }
    onColumnPropertyChanged(column, name, newValue) {
        this.updateHasFooter();
        if (!this.generatedVisibleRows)
            return;
        for (var i = 0; i < this.generatedVisibleRows.length; i++) {
            this.generatedVisibleRows[i].updateCellQuestionOnColumnChanged(column, name, newValue);
        }
        if (!!this.generatedTotalRow) {
            this.generatedTotalRow.updateCellQuestionOnColumnChanged(column, name, newValue);
        }
        this.onColumnsChanged();
        if (name == "isRequired") {
            this.resetRenderedTable();
        }
    }
    onColumnNestedPropertyChanged(column, name, nestedName, newValue) {
        if (!this.generatedVisibleRows)
            return;
        for (var i = 0; i < this.generatedVisibleRows.length; i++) {
            const row = this.generatedVisibleRows[i];
            const q = row.getQuestionByColumn(column);
            if (!!q && !!q[name]) {
                q[name][nestedName] = newValue;
            }
        }
    }
    onColumnItemValuePropertyChanged(column, propertyName, obj, name, newValue, oldValue) {
        if (!this.generatedVisibleRows)
            return;
        for (var i = 0; i < this.generatedVisibleRows.length; i++) {
            this.generatedVisibleRows[i].updateCellQuestionOnColumnItemValueChanged(column, propertyName, obj, name, newValue, oldValue);
        }
    }
    onShowInMultipleColumnsChanged(column) {
        this.resetTableAndRows();
    }
    onColumnVisibilityChanged(column) {
        this.resetTableAndRows();
    }
    onColumnCellTypeChanged(column) {
        this.updateDefaultRowValue(column);
        this.resetTableAndRows();
    }
    updateDefaultRowValue(column) {
        let val = this.defaultRowValue;
        if (!!val) {
            if (column.cellType === "file" && val[column.name]) {
                delete val[column.name];
                if (Object.keys(val).length === 0) {
                    val = undefined;
                }
                this.defaultRowValue = val;
            }
        }
    }
    resetTableAndRows() {
        this.clearGeneratedRows();
        this.resetRenderedTable();
    }
    getRowTitleWidth() {
        return "";
    }
    get hasFooter() {
        return this.getPropertyValue("hasFooter", false);
    }
    getAddRowLocation() {
        return "default";
    }
    getShowColumnsIfEmpty() {
        return false;
    }
    updateShowTableAndAddRow() {
        if (!!this.renderedTable) {
            this.renderedTable.updateShowTableAndAddRow();
        }
    }
    updateHasFooter() {
        this.setPropertyValue("hasFooter", this.hasTotal);
    }
    get hasTotal() {
        for (var i = 0; i < this.columns.length; i++) {
            if (this.columns[i].hasTotal)
                return true;
        }
        return false;
    }
    getCellType() {
        return this.cellType;
    }
    getCustomCellType(column, row, cellType) {
        if (!this.survey)
            return cellType;
        var options = {
            rowValue: row.value,
            row: row,
            column: column,
            columnName: column.name,
            cellType: cellType
        };
        this.survey.matrixCellCreating(this, options);
        return options.cellType;
    }
    getConditionJson(operator = null, path = null) {
        if (!path)
            return super.getConditionJson(operator);
        let columnName = "";
        for (let i = path.length - 1; i >= 0; i--) {
            if (path[i] == ".")
                break;
            columnName = path[i] + columnName;
        }
        let question = undefined;
        let column = this.getColumnByName(columnName);
        if (!!column) {
            question = column.createCellQuestion(null);
        }
        else {
            if (this.detailPanelMode !== "none") {
                question = this.detailPanel.getQuestionByName(columnName);
            }
        }
        return !!question ? question.getConditionJson(operator) : null;
    }
    clearIncorrectValues() {
        if (!Array.isArray(this.visibleRows))
            return;
        const rows = this.generatedVisibleRows;
        for (let i = 0; i < rows.length; i++) {
            rows[i].clearIncorrectValues(this.getRowValue(i));
        }
    }
    clearErrors() {
        super.clearErrors();
        this.runFuncForCellQuestions((q) => { q.clearErrors(); });
    }
    localeChanged() {
        super.localeChanged();
        this.runFuncForCellQuestions((q) => { q.localeChanged(); });
    }
    runFuncForCellQuestions(func) {
        const rows = this.generatedVisibleRows;
        if (!!rows) {
            for (let i = 0; i < rows.length; i++) {
                const row = rows[i];
                if (row.isVisible) {
                    for (let j = 0; j < row.cells.length; j++) {
                        func(row.cells[j].question);
                    }
                }
            }
        }
    }
    runConditionCore(values, properties) {
        const oldRowVariables = values[MatrixDropdownRowModelBase.RowVariableName];
        super.runConditionCore(values, properties);
        var counter = 0;
        var prevTotalValue;
        do {
            prevTotalValue = Helpers.getUnbindValue(this.totalValue);
            this.runCellsCondition(values, properties);
            this.runTotalsCondition(values, properties);
            counter++;
        } while (!Helpers.isTwoValueEquals(prevTotalValue, this.totalValue) &&
            counter < 3);
        this.updateVisibilityBasedOnRows();
        values[MatrixDropdownRowModelBase.RowVariableName] = oldRowVariables;
    }
    runTriggers(name, value, keys) {
        super.runTriggers(name, value, keys);
        this.runFuncForCellQuestions((q) => { q.runTriggers(name, value, keys); });
    }
    updateElementVisibility() {
        super.updateElementVisibility();
        const rows = this.generatedVisibleRows;
        if (!!rows) {
            rows.forEach(row => row.updateElementVisibility());
        }
        this.updateShowTableAndAddRow();
    }
    shouldRunColumnExpression() {
        return false;
    }
    runCellsCondition(values, properties) {
        if (this.isDesignMode)
            return;
        const rows = this.generatedVisibleRows;
        if (!!rows) {
            const newValues = this.getRowConditionValues(values);
            for (var i = 0; i < rows.length; i++) {
                rows[i].runCondition(newValues, properties, this.rowsVisibleIf);
            }
        }
        this.checkColumnsVisibility();
        this.checkColumnsRenderedRequired();
    }
    runConditionsForColumns(values, properties) {
        this.columns.forEach(column => {
            if (!this.columnsVisibleIf) {
                column.isColumnsVisibleIf = true;
            }
            else {
                const condition = new ConditionRunner(this.columnsVisibleIf);
                values["item"] = column.name;
                column.isColumnsVisibleIf = condition.run(values, properties) === true;
            }
        });
        return false;
    }
    checkColumnsVisibility() {
        if (this.isDesignMode)
            return;
        var hasChanged = false;
        for (var i = 0; i < this.columns.length; i++) {
            const column = this.columns[i];
            const isCellsVisibilty = !!column.visibleIf || column.isFilteredMultipleColumns;
            if (!isCellsVisibilty && !this.columnsVisibleIf && column.isColumnVisible)
                continue;
            hasChanged = this.isColumnVisibilityChanged(column, isCellsVisibilty) || hasChanged;
        }
        if (hasChanged) {
            this.resetRenderedTable(true);
        }
    }
    checkColumnsRenderedRequired() {
        const rows = this.generatedVisibleRows;
        if (!rows)
            return;
        for (var i = 0; i < this.columns.length; i++) {
            const column = this.columns[i];
            if (!column.requiredIf || !column.isColumnVisible)
                continue;
            let required = rows.length > 0;
            for (var j = 0; j < rows.length; j++) {
                if (!rows[j].cells[i].question.isRequired) {
                    required = false;
                    break;
                }
            }
            column.updateIsRenderedRequired(required);
        }
    }
    isColumnVisibilityChanged(column, checkCellsVisiblity) {
        const curVis = column.isColumnVisible;
        let hasVisCell = !checkCellsVisiblity;
        const rows = this.generatedVisibleRows;
        const checkRows = checkCellsVisiblity && rows;
        const isMultipleColumnsVisibility = checkRows && column.isFilteredMultipleColumns;
        const curVisibleChoices = isMultipleColumnsVisibility ? column.getVisibleChoicesInCell : [];
        const newVisibleChoices = new Array();
        if (checkRows) {
            for (let i = 0; i < rows.length; i++) {
                const cell = rows[i].cells[column.index];
                const q = cell === null || cell === void 0 ? void 0 : cell.question;
                if (!!q && q.isVisible) {
                    hasVisCell = true;
                    if (isMultipleColumnsVisibility) {
                        this.updateNewVisibleChoices(q, newVisibleChoices);
                    }
                    else
                        break;
                }
            }
        }
        column.hasVisibleCell = hasVisCell && column.isColumnsVisibleIf;
        if (isMultipleColumnsVisibility) {
            column.setVisibleChoicesInCell(newVisibleChoices);
            if (!Helpers.isArraysEqual(curVisibleChoices, newVisibleChoices, true, false, false))
                return true;
        }
        return curVis !== column.isColumnVisible;
    }
    updateNewVisibleChoices(q, dest) {
        const choices = q.visibleChoices;
        if (!Array.isArray(choices))
            return;
        for (let i = 0; i < choices.length; i++) {
            const ch = choices[i];
            if (dest.indexOf(ch.value) < 0)
                dest.push(ch.value);
        }
    }
    runTotalsCondition(values, properties) {
        if (!this.generatedTotalRow)
            return;
        this.generatedTotalRow.runCondition(this.getRowConditionValues(values), properties);
    }
    getRowConditionValues(values) {
        var newValues = values;
        if (!newValues)
            newValues = {};
        /*
        var newValues: { [index: string]: any } = {};
        if (values && values instanceof Object) {
          newValues = JSON.parse(JSON.stringify(values));
        }
        */
        var totalRow = {};
        if (!this.isValueEmpty(this.totalValue)) {
            totalRow = JSON.parse(JSON.stringify(this.totalValue));
        }
        newValues["row"] = {};
        newValues["totalRow"] = totalRow;
        return newValues;
    }
    IsMultiplyColumn(column) {
        return column.isShowInMultipleColumns && !this.isMobile;
    }
    locStrsChanged() {
        super.locStrsChanged();
        var columns = this.columns;
        for (var i = 0; i < columns.length; i++) {
            columns[i].locStrsChanged();
        }
        var rows = this.generatedVisibleRows;
        if (!rows)
            return;
        for (var i = 0; i < rows.length; i++) {
            rows[i].locStrsChanged();
        }
        if (!!this.generatedTotalRow) {
            this.generatedTotalRow.locStrsChanged();
        }
    }
    /**
     * Returns a matrix column with a given `name` or `null` if a column with this is not found.
     * @param columnName A column name.
     */
    getColumnByName(columnName) {
        for (var i = 0; i < this.columns.length; i++) {
            if (this.columns[i].name == columnName)
                return this.columns[i];
        }
        return null;
    }
    getColumnName(columnName) {
        return this.getColumnByName(columnName);
    }
    getColumnWidth(column) {
        var _a;
        return column.minWidth ? column.minWidth : this.columnMinWidth ? this.columnMinWidth : (((_a = settings.matrix.columnWidthsByType[column.cellType]) === null || _a === void 0 ? void 0 : _a.minWidth) || "");
    }
    /**
     * Gets or sets choice items for Dropdown, Checkbox, and Radiogroup matrix cells. You can override this property for individual columns.
     *
     * This property accepts an array of objects with the following structure:
     *
     * ```js
     * {
     *   "value": any, // A value to be saved in survey results
     *   "text": String, // A display text. This property supports Markdown. When `text` is undefined, `value` is used.
     *   "customProperty": any // Any property that you find useful.
     * }
     * ```
     *
     * To enable Markdown support for the `text` property, implement Markdown-to-HTML conversion in the [onTextMarkdown](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onTextMarkdown) event handler. For an example, refer to the following demo: [Convert Markdown to HTML with markdown-it](https://surveyjs.io/form-library/examples/edit-survey-questions-markdown/).
     *
     * If you add custom properties, refer to the following help topic to learn how to serialize them into JSON: [Add Custom Properties to Property Grid](https://surveyjs.io/survey-creator/documentation/property-grid#add-custom-properties-to-the-property-grid).
     *
     * If you need to specify only the `value` property, you can set the `choices` property to an array of primitive values, for example, `[ "item1", "item2", "item3" ]`. These values are both saved in survey results and used as display text.
     * @see cellType
     */
    get choices() {
        return this.getPropertyValue("choices");
    }
    set choices(val) {
        this.setPropertyValue("choices", val);
    }
    /**
     * A placeholder for Dropdown matrix cells.
     * @see cellType
     */
    get placeholder() {
        return this.getLocalizableStringText("placeholder");
    }
    set placeholder(val) {
        this.setLocalizableStringText("placeholder", val);
    }
    get locPlaceholder() {
        return this.getLocalizableString("placeholder");
    }
    get optionsCaption() {
        return this.placeholder;
    }
    set optionsCaption(val) {
        this.placeholder = val;
    }
    /**
     * An error message displayed when users enter a duplicate value into a column that accepts only unique values (`isUnique` is set to `true` or `keyName` is specified).
     *
     * A default value for this property is taken from a [localization dictionary](https://github.com/surveyjs/survey-library/tree/01bd8abd0c574719956d4d579d48c8010cd389d4/packages/survey-core/src/localization). Refer to the following help topic for more information: [Localization & Globalization](https://surveyjs.io/form-library/documentation/localization).
     * @see useCaseSensitiveComparison
     */
    get keyDuplicationError() {
        return this.getLocalizableStringText("keyDuplicationError");
    }
    set keyDuplicationError(val) {
        this.setLocalizableStringText("keyDuplicationError", val);
    }
    get locKeyDuplicationError() {
        return this.getLocalizableString("keyDuplicationError");
    }
    /**
     * A title template that applies when the survey is in [input-per-page mode](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionsOnPageMode).
     *
     * Default value: `"Row {rowIndex}"` for Dynamic Matrix | `"{rowTitle}"` for Multi-Select Matrix
     *
     * The template can contain the following placeholders:
     *
     * - `{rowIndex}` - A row index within the collection of all rows. Starts with 1.
     * - `{rowName}` - A row name (the `value` property within objects in the [`rows`](#rows) array). Use this placeholder if you need to distinguish between matrix rows.
     * - `{rowTitle}` - A row title (the `text` property within objects in the `rows` array).
     * - `{row.columnname}` - The value of a cell in the same row.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/loop-and-merge/ (linkStyle))
     */
    get singleInputTitleTemplate() {
        return this.getLocalizableStringText("singleInputTitleTemplate");
    }
    set singleInputTitleTemplate(val) {
        this.setLocalizableStringText("singleInputTitleTemplate", val);
    }
    get locSingleInputTitleTemplate() {
        return this.getLocalizableString("singleInputTitleTemplate");
    }
    getSingleQuestionLocTitleCore() {
        return this.locSingleInputTitleTemplate;
    }
    getSingleInputTitleTemplate() { return ""; }
    processSingleInputTitle(text) {
        const row = this.getRowByQuestion(this.singleInputQuestion);
        if (row) {
            return row.getTextProcessor().processText(text, true);
        }
        return "";
    }
    singleInputMoveToFirstCore() {
        var _a;
        const data = (_a = this.singleInputQuestion) === null || _a === void 0 ? void 0 : _a.data;
        this.singleInputEditRow(data);
    }
    singleInputEditRow(row) {
        if (!row)
            return;
        const qs = row.visibleQuestions;
        if (Array.isArray(qs) && qs.length > 0) {
            this.setSingleInputQuestion(qs[0]);
        }
    }
    get storeOthersAsComment() {
        return !!this.survey ? this.survey.storeOthersAsComment : false;
    }
    addColumn(name, title) {
        var column = new MatrixDropdownColumn(name, title, this);
        this.columns.push(column);
        return column;
    }
    clearVisibleRows() {
        this.visibleRowsArray = null;
    }
    isColumnVisible(column) {
        return column.isColumnVisible;
    }
    getVisibleRows() {
        if (this.isUpdateLocked)
            return null;
        if (this.isGenereatingRows)
            return [];
        if (!!this.visibleRowsArray)
            return this.visibleRowsArray;
        this.generateVisibleRowsIfNeeded();
        this.visibleRowsArray = this.getVisibleFromGenerated(this.generatedVisibleRows);
        return this.visibleRowsArray;
    }
    generateVisibleRowsIfNeeded() {
        if (!this.isUpdateLocked && !this.generatedVisibleRows) {
            this.isGenereatingRows = true;
            this.generatedVisibleRows = this.generateRows();
            this.isGenereatingRows = false;
            for (var i = 0; i < this.generatedVisibleRows.length; i++) {
                const row = this.generatedVisibleRows[i];
                row.visibleIndex = i;
                this.onMatrixRowCreated(row);
            }
            if (this.data) {
                this.runCellsCondition(this.data.getFilteredValues(), this.data.getFilteredProperties());
                if (this.isValueChangedWithoutRows) {
                    this.isValueChangedWithoutRows = false;
                    this.runTriggersOnNewRows();
                }
            }
            if (!!this.generatedVisibleRows) {
                this.updateValueOnRowsGeneration(this.generatedVisibleRows);
                this.updateIsAnswered();
            }
        }
    }
    runTriggersOnNewRows() {
        const val = this.value;
        this.generatedVisibleRows.forEach((row) => {
            const rowValue = this.getRowValueCore(row, val);
            if (!Helpers.isValueEmpty(rowValue)) {
                const triggeredValue = Helpers.createCopyWithPrefix(rowValue, MatrixDropdownRowModelBase.RowVariableName + ".");
                row.runTriggers("", undefined, triggeredValue);
            }
        });
    }
    getVisibleFromGenerated(rows) {
        const res = [];
        if (!rows)
            return res;
        rows.forEach(row => { if (row.isVisible)
            res.push(row); });
        return res.length === rows.length ? rows : res;
    }
    updateValueOnRowsGeneration(rows) {
        var oldValue = this.createNewValue(true);
        var newValue = this.createNewValue();
        for (var i = 0; i < rows.length; i++) {
            var row = rows[i];
            if (!!row.editingObj)
                continue;
            var rowValue = this.getRowValue(i);
            var rValue = row.value;
            if (this.isTwoValueEquals(rowValue, rValue))
                continue;
            newValue = this.getNewValueOnRowChanged(row, "", rValue, false, newValue)
                .value;
        }
        if (this.isTwoValueEquals(oldValue, newValue))
            return;
        this.isRowChanging = true;
        this.setNewValue(newValue);
        this.isRowChanging = false;
    }
    get totalValue() {
        if (!this.hasTotal || !this.visibleTotalRow)
            return {};
        return this.visibleTotalRow.value;
    }
    getVisibleTotalRow() {
        if (this.isUpdateLocked)
            return null;
        if (this.hasTotal) {
            if (!this.generatedTotalRow) {
                this.generatedTotalRow = this.generateTotalRow();
                if (this.data) {
                    var properties = { survey: this.survey };
                    this.runTotalsCondition(this.data.getAllValues(), properties);
                }
            }
        }
        else {
            this.generatedTotalRow = null;
        }
        return this.generatedTotalRow;
    }
    get visibleTotalRow() {
        return this.getVisibleTotalRow();
    }
    onSurveyLoad() {
        super.onSurveyLoad();
        this.updateColumnsIndexes(this.columns);
        this.clearGeneratedRows();
        this.generatedTotalRow = null;
        this.updateHasFooter();
    }
    /**
     * Returns an object with row values. If a row has no answers, this method returns an empty object.
     * @param rowIndex A zero-based row index.
     * @see setRowValue
     */
    getRowValue(rowIndex) {
        if (rowIndex < 0 || !Array.isArray(this.visibleRows))
            return null;
        var rows = this.generatedVisibleRows;
        if (rowIndex >= rows.length)
            return null;
        const val = this.value;
        const rowVal = this.getRowValueCore(rows[rowIndex], val);
        if (this.isValueSurveyElement(val))
            return rowVal;
        return Helpers.getUnbindValue(rowVal);
    }
    checkIfValueInRowDuplicated(checkedRow, cellQuestion) {
        if (!this.generatedVisibleRows)
            return false;
        return this.isValueInColumnDuplicated(cellQuestion.name, true, checkedRow);
    }
    /**
     * Assigns values to a row.
     * @param rowIndex A zero-based row index.
     * @param rowValue An object with the following structure: `{ "column_name": columnValue, ... }`
     * @see getRowValue
     */
    setRowValue(rowIndex, rowValue) {
        if (rowIndex < 0)
            return null;
        var visRows = this.visibleRows;
        if (rowIndex >= visRows.length)
            return null;
        visRows[rowIndex].value = rowValue;
        this.onRowChanged(visRows[rowIndex], "", rowValue, false);
    }
    generateRows() {
        return null;
    }
    generateTotalRow() {
        return new MatrixDropdownTotalRowModel(this);
    }
    createNewValue(nullOnEmpty = false) {
        var res = !this.value ? {} : this.createValueCopy();
        if (nullOnEmpty && this.isMatrixValueEmpty(res))
            return null;
        return res;
    }
    getRowValueCore(row, questionValue, create = false) {
        var result = !!questionValue && !!questionValue[row.rowName]
            ? questionValue[row.rowName]
            : null;
        if (!result && create) {
            result = {};
            if (!!questionValue) {
                questionValue[row.rowName] = result;
            }
        }
        return result;
    }
    getRowObj(row) {
        var obj = this.getRowValueCore(row, this.value);
        return !!obj && !!obj.getType ? obj : null;
    }
    getRowDisplayValue(keysAsText, row, rowValue) {
        if (!rowValue)
            return rowValue;
        if (!!row.editingObj)
            return rowValue;
        var keys = Object.keys(rowValue);
        for (var i = 0; i < keys.length; i++) {
            var key = keys[i];
            var question = row.getQuestionByName(key);
            if (!question) {
                question = this.getSharedQuestionByName(key, row);
            }
            if (!!question) {
                var displayvalue = question.getDisplayValue(keysAsText, rowValue[key]);
                if (keysAsText && !!question.title && question.title !== key) {
                    rowValue[question.title] = displayvalue;
                    delete rowValue[key];
                }
                else {
                    rowValue[key] = displayvalue;
                }
            }
        }
        return rowValue;
    }
    getPlainData(options = { includeEmpty: true }) {
        var questionPlainData = super.getPlainData(options);
        if (!!questionPlainData) {
            questionPlainData.isNode = true;
            const prevData = Array.isArray(questionPlainData.data) ? [].concat(questionPlainData.data) : [];
            questionPlainData.data = this.visibleRows.map((row) => {
                var rowDataItem = {
                    name: row.dataName,
                    title: row.text,
                    value: row.value,
                    displayValue: this.getRowDisplayValue(false, row, row.value),
                    getString: (val) => typeof val === "object" ? JSON.stringify(val) : val,
                    isNode: true,
                    data: row.cells
                        .map((cell) => cell.question.getPlainData(options))
                        .filter((d) => !!d),
                };
                (options.calculations || []).forEach((calculation) => {
                    rowDataItem[calculation.propertyName] = row[calculation.propertyName];
                });
                return rowDataItem;
            });
            questionPlainData.data = questionPlainData.data.concat(prevData);
        }
        return questionPlainData;
    }
    addConditionObjectsByContext(objects, context) {
        let rowElements = [].concat(this.columns);
        if (this.detailPanelMode !== "none") {
            rowElements = rowElements.concat(this.detailPanel.questions);
        }
        const hasColumnContext = !!context && rowElements.indexOf(context) > -1;
        const hasContext = context === true || hasColumnContext;
        const rowsIndeces = this.getConditionObjectsRowIndeces();
        if (hasContext) {
            rowsIndeces.push(-1);
        }
        for (var i = 0; i < rowsIndeces.length; i++) {
            const index = rowsIndeces[i];
            const rowName = index > -1 ? this.getConditionObjectRowName(index) : "row";
            if (!rowName)
                continue;
            const rowTitle = index > -1 ? this.getConditionObjectRowText(index) : "row";
            const hasQuestionPrefix = index > -1 || context === true;
            const dot = hasQuestionPrefix && index === -1 ? "." : "";
            const prefixName = (hasQuestionPrefix ? this.getValueName() : "") + dot + rowName + ".";
            const prefixTitle = (hasQuestionPrefix ? this.processedTitle : "") + dot + rowTitle + ".";
            for (var j = 0; j < rowElements.length; j++) {
                const rowElement = rowElements[j];
                if (index === -1 && context === rowElement)
                    continue;
                const obj = {
                    name: prefixName + rowElement.name,
                    text: prefixTitle + rowElement.fullTitle,
                    question: this
                };
                if (index === -1 && context === true) {
                    obj.context = this;
                }
                else {
                    if (hasColumnContext && prefixName.startsWith("row.")) {
                        obj.context = context;
                    }
                }
                objects.push(obj);
            }
        }
    }
    onHidingContent() {
        super.onHidingContent();
        if (!this.generatedVisibleRows)
            return;
        const questions = [];
        this.collectNestedQuestions(questions, true);
        questions.forEach(q => q.onHidingContent());
    }
    getIsReadyNestedQuestions() {
        if (!this.generatedVisibleRows)
            return [];
        const res = new Array();
        this.collectNestedQuestonsInRows(this.generatedVisibleRows, res, false, true, false);
        if (!!this.generatedTotalRow) {
            this.collectNestedQuestonsInRows([this.generatedTotalRow], res, false, true, false);
        }
        return res;
    }
    collectNestedQuestionsCore(questions, visibleOnly, includeNested, includeItSelf) {
        if (includeItSelf) {
            questions.push(this);
        }
        this.collectNestedQuestonsInRows(this.visibleRows, questions, visibleOnly, includeNested, includeItSelf);
    }
    collectNestedQuestonsInRows(rows, questions, visibleOnly, includeNested, includeItSelf) {
        if (!Array.isArray(rows))
            return;
        rows.forEach(row => {
            row.questions.forEach(q => q.addNestedQuestion(questions, visibleOnly, includeNested, includeItSelf));
        });
    }
    getConditionObjectRowName(index) {
        return "";
    }
    getConditionObjectRowText(index) {
        return this.getConditionObjectRowName(index);
    }
    getConditionObjectsRowIndeces() {
        return [];
    }
    getProgressInfo() {
        this.getIsRequireToGenerateRows() && this.generateVisibleRowsIfNeeded();
        if (!!this.generatedVisibleRows)
            return SurveyElement.getProgressInfoByElements(this.getCellQuestions(), this.isRequired);
        const res = Base.createProgressInfo();
        this.updateProgressInfoByValues(res);
        if (res.requiredQuestionCount === 0 && this.isRequired) {
            res.requiredQuestionCount = 1;
            res.requiredAnsweredQuestionCount = !this.isEmpty() ? 1 : 0;
        }
        return res;
    }
    getIsRequireToGenerateRows() {
        return !!this.rowsVisibleIf;
    }
    updateProgressInfoByValues(res) { }
    updateProgressInfoByRow(res, rowValue) {
        for (var i = 0; i < this.columns.length; i++) {
            const col = this.columns[i];
            if (!col.templateQuestion.hasInput)
                continue;
            const hasValue = !Helpers.isValueEmpty(rowValue[col.name]);
            if (!hasValue && !!col.templateQuestion.visibleIf)
                continue;
            res.questionCount += 1;
            res.requiredQuestionCount += col.isRequired;
            res.answeredQuestionCount += hasValue ? 1 : 0;
            res.requiredAnsweredQuestionCount += hasValue && col.isRequired ? 1 : 0;
        }
    }
    getCellQuestions() {
        const res = [];
        this.runFuncForCellQuestions((q) => { res.push(q); });
        return res;
    }
    onBeforeValueChanged(val) { }
    onSetQuestionValue() {
        if (this.isRowChanging)
            return;
        this.onBeforeValueChanged(this.value);
        if (!this.generatedVisibleRows || this.generatedVisibleRows.length == 0)
            return;
        this.isRowChanging = true;
        var val = this.createNewValue();
        for (var i = 0; i < this.generatedVisibleRows.length; i++) {
            var row = this.generatedVisibleRows[i];
            this.generatedVisibleRows[i].value = this.getRowValueCore(row, val);
        }
        this.isRowChanging = false;
    }
    setQuestionValue(newValue) {
        super.setQuestionValue(newValue, false);
        this.onSetQuestionValue();
        this.updateIsAnswered();
    }
    supportAutoAdvance() {
        var rows = this.generatedVisibleRows;
        if (!rows)
            rows = this.visibleRows;
        if (!rows)
            return true;
        for (var i = 0; i < rows.length; i++) {
            var cells = this.generatedVisibleRows[i].cells;
            if (!cells)
                continue;
            for (var colIndex = 0; colIndex < cells.length; colIndex++) {
                var question = cells[colIndex].question;
                if (question &&
                    (!question.supportAutoAdvance() || !question.value))
                    return false;
            }
        }
        return true;
    }
    getContainsErrors() {
        return (super.getContainsErrors() ||
            this.checkForAnswersOrErrors((question) => question.containsErrors, false));
    }
    getIsAnswered() {
        return (super.getIsAnswered() &&
            this.checkForAnswersOrErrors((question) => question.isAnswered, true));
    }
    checkForAnswersOrErrors(predicate, every = false) {
        var rows = this.generatedVisibleRows;
        if (!rows)
            return false;
        for (var i = 0; i < rows.length; i++) {
            var cells = rows[i].cells;
            if (!cells)
                continue;
            for (var colIndex = 0; colIndex < cells.length; colIndex++) {
                if (!cells[colIndex])
                    continue;
                var question = cells[colIndex].question;
                if (question && question.isVisible)
                    if (predicate(question)) {
                        if (!every)
                            return true;
                    }
                    else {
                        if (every)
                            return false;
                    }
            }
        }
        return every ? true : false;
    }
    hasErrors(fireCallback = true, rec = null) {
        var errosInRows = this.hasErrorInRows(fireCallback, rec);
        var isDuplicated = this.isValueDuplicated();
        return super.hasErrors(fireCallback, rec) || errosInRows || isDuplicated;
    }
    getIsRunningValidators() {
        if (super.getIsRunningValidators())
            return true;
        if (!this.generatedVisibleRows)
            return false;
        for (var i = 0; i < this.generatedVisibleRows.length; i++) {
            var cells = this.generatedVisibleRows[i].cells;
            if (!cells)
                continue;
            for (var colIndex = 0; colIndex < cells.length; colIndex++) {
                if (!cells[colIndex])
                    continue;
                var question = cells[colIndex].question;
                if (!!question && question.isRunningValidators)
                    return true;
            }
        }
        return false;
    }
    getAllErrors() {
        var result = super.getAllErrors();
        var rows = this.generatedVisibleRows;
        if (rows === null)
            return result;
        for (var i = 0; i < rows.length; i++) {
            var row = rows[i];
            for (var j = 0; j < row.cells.length; j++) {
                var errors = row.cells[j].question.getAllErrors();
                if (errors && errors.length > 0) {
                    result = result.concat(errors);
                }
            }
        }
        return result;
    }
    hasErrorInRows(fireCallback, rec) {
        let rows = this.generatedVisibleRows;
        if (!this.generatedVisibleRows) {
            rows = this.visibleRows;
        }
        var res = false;
        if (!rec)
            rec = {};
        if (!rows)
            return rec;
        rec.validationValues = this.getDataFilteredValues();
        rec.isSingleDetailPanel = this.detailPanelMode === "underRowSingle";
        for (var i = 0; i < rows.length; i++) {
            if (rows[i].isVisible) {
                res = rows[i].hasErrors(fireCallback, rec, () => {
                    this.raiseOnCompletedAsyncValidators();
                }) || res;
            }
        }
        return res;
    }
    isValueDuplicated() {
        if (!this.generatedVisibleRows)
            return false;
        var names = this.getUniqueColumnsNames();
        var res = false;
        for (var i = 0; i < names.length; i++) {
            res = this.isValueInColumnDuplicated(names[i], true) || res;
        }
        return res;
    }
    getUniqueColumnsNames() {
        var res = new Array();
        for (var i = 0; i < this.columns.length; i++) {
            if (this.columns[i].isUnique) {
                res.push(this.columns[i].name);
            }
        }
        return res;
    }
    isValueInColumnDuplicated(columnName, showErrors, row) {
        const rows = this.getDuplicatedRows(columnName);
        if (showErrors) {
            this.showDuplicatedErrorsInRows(rows, columnName);
        }
        this.removeDuplicatedErrorsInRows(rows, columnName);
        return !!row ? rows.indexOf(row) > -1 : rows.length > 0;
    }
    getDuplicatedRows(columnName) {
        const keyValues = {};
        const res = [];
        const rows = this.generatedVisibleRows;
        for (var i = 0; i < rows.length; i++) {
            let val = undefined;
            const question = rows[i].getQuestionByName(columnName);
            if (!!question) {
                val = question.value;
            }
            else {
                const rowVal = this.getRowValue(i);
                val = !!rowVal ? rowVal[columnName] : undefined;
            }
            if (!this.isValueEmpty(val)) {
                if (!this.useCaseSensitiveComparison && typeof val === "string") {
                    val = val.toLocaleLowerCase();
                }
                if (!keyValues[val]) {
                    keyValues[val] = [];
                }
                keyValues[val].push(rows[i]);
            }
        }
        for (let key in keyValues) {
            if (keyValues[key].length > 1) {
                keyValues[key].forEach(row => res.push(row));
            }
        }
        return res;
    }
    showDuplicatedErrorsInRows(duplicatedRows, columnName) {
        duplicatedRows.forEach(row => {
            let question = row.getQuestionByName(columnName);
            const inDetailPanel = this.detailPanel.getQuestionByName(columnName);
            if (!question && inDetailPanel) {
                row.showDetailPanel();
                if (row.detailPanel) {
                    question = row.detailPanel.getQuestionByName(columnName);
                }
            }
            if (question) {
                if (inDetailPanel) {
                    row.showDetailPanel();
                }
                this.addDuplicationError(question);
            }
        });
    }
    removeDuplicatedErrorsInRows(duplicatedRows, columnName) {
        this.generatedVisibleRows.forEach(row => {
            if (duplicatedRows.indexOf(row) < 0) {
                const question = row.getQuestionByName(columnName);
                if (question) {
                    this.removeDuplicationError(row, question);
                }
            }
        });
    }
    getDuplicationError(question) {
        const errors = question.errors;
        for (let i = 0; i < errors.length; i++) {
            if (errors[i].getErrorType() === "keyduplicationerror")
                return errors[i];
        }
        return null;
    }
    addDuplicationError(question) {
        if (!this.getDuplicationError(question)) {
            question.addError(new KeyDuplicationError(this.keyDuplicationError, this));
        }
    }
    removeDuplicationError(row, question) {
        if (question.removeError(this.getDuplicationError(question)) && question.errors.length === 0 && !!row.editingObj) {
            row.editingObj[question.getValueName()] = question.value;
        }
    }
    getFirstQuestionToFocus(withError) {
        return this.getFirstCellQuestion(withError);
    }
    getFirstInputElementId() {
        var question = this.getFirstCellQuestion(false);
        return question ? question.inputId : super.getFirstInputElementId();
    }
    getFirstErrorInputElementId() {
        var question = this.getFirstCellQuestion(true);
        return question ? question.inputId : super.getFirstErrorInputElementId();
    }
    getFirstCellQuestion(onError) {
        if (!this.generatedVisibleRows)
            return null;
        for (var i = 0; i < this.generatedVisibleRows.length; i++) {
            var cells = this.generatedVisibleRows[i].cells;
            for (var colIndex = 0; colIndex < cells.length; colIndex++) {
                if (!onError)
                    return cells[colIndex].question;
                if (cells[colIndex].question.currentErrorCount > 0)
                    return cells[colIndex].question;
            }
        }
        return null;
    }
    onReadOnlyChanged() {
        super.onReadOnlyChanged();
        if (!this.generateRows)
            return;
        for (var i = 0; i < this.visibleRows.length; i++) {
            this.visibleRows[i].onQuestionReadOnlyChanged();
        }
    }
    //IMatrixDropdownData
    createQuestion(row, column) {
        return this.createQuestionCore(row, column);
    }
    createQuestionCore(row, column) {
        var question = column.createCellQuestion(row);
        question.setSurveyImpl(row);
        question.setParentQuestion(this);
        question.inMatrixMode = true;
        return question;
    }
    deleteRowValue(newValue, row) {
        if (!newValue)
            return newValue;
        delete newValue[row.rowName];
        return this.isObject(newValue) && Object.keys(newValue).length == 0
            ? null
            : newValue;
    }
    onAnyValueChanged(name, questionName) {
        if (this.isUpdateLocked || this.isDoingonAnyValueChanged)
            return;
        if (!this.generatedVisibleRows) {
            if (name === this.getValueName()) {
                this.isValueChangedWithoutRows = true;
            }
            return;
        }
        this.isDoingonAnyValueChanged = true;
        var rows = this.generatedVisibleRows;
        for (var i = 0; i < rows.length; i++) {
            rows[i].onAnyValueChanged(name, questionName);
        }
        var totalRow = this.visibleTotalRow;
        if (!!totalRow) {
            totalRow.onAnyValueChanged(name, questionName);
        }
        this.isDoingonAnyValueChanged = false;
    }
    isObject(value) {
        return value !== null && typeof value === "object";
    }
    getOnCellValueChangedOptions(row, columnName, rowValue) {
        const getQuestion = (colName) => {
            return row.getQuestionByName(colName);
        };
        return {
            row: row,
            columnName: columnName,
            rowValue: rowValue,
            value: !!rowValue ? rowValue[columnName] : null,
            getCellQuestion: getQuestion,
            cellQuestion: row.getQuestionByName(columnName),
            column: this.getColumnByName(columnName)
        };
    }
    onCellValueChanged(row, columnName, rowValue) {
        if (!this.survey)
            return;
        var options = this.getOnCellValueChangedOptions(row, columnName, rowValue);
        if (!!this.onCellValueChangedCallback) {
            this.onCellValueChangedCallback(options);
        }
        this.survey.matrixCellValueChanged(this, options);
    }
    validateCell(row, columnName, rowValue) {
        if (!this.survey)
            return;
        var options = this.getOnCellValueChangedOptions(row, columnName, rowValue);
        return this.survey.matrixCellValidate(this, options);
    }
    get isValidateOnValueChanging() {
        return !!this.survey ? this.survey.isValidateOnValueChanging : false;
    }
    get hasInvisibleRows() {
        const rows = this.generatedVisibleRows;
        if (!Array.isArray(rows))
            return false;
        for (let i = 0; i < rows.length; i++) {
            if (!rows[i].isVisible)
                return true;
        }
        return false;
    }
    getFilteredData() {
        if (this.isEmpty() || !this.generatedVisibleRows || !this.hasInvisibleRows)
            return this.value;
        return this.getFilteredDataCore();
    }
    getFilteredDataCore() { return this.value; }
    onRowChanging(row, columnName, rowValue) {
        if (!this.survey && !this.cellValueChangingCallback)
            return !!rowValue ? rowValue[columnName] : null;
        var options = this.getOnCellValueChangedOptions(row, columnName, rowValue);
        var oldRowValue = this.getRowValueCore(row, this.createNewValue(), true);
        options.oldValue = !!oldRowValue ? oldRowValue[columnName] : null;
        if (!!this.cellValueChangingCallback) {
            options.value = this.cellValueChangingCallback(row, columnName, options.value, options.oldValue);
        }
        if (!!this.survey) {
            this.survey.matrixCellValueChanging(this, options);
        }
        return options.value;
    }
    getSharedQuestionFromArray(name, rowIndex) {
        return !!this.survey && !!this.valueName ? (this.survey.getQuestionByValueNameFromArray(this.valueName, name, rowIndex)) : null;
    }
    onRowChanged(row, columnName, newRowValue, isDeletingValue) {
        var rowObj = !!columnName ? this.getRowObj(row) : null;
        if (!!rowObj) {
            var columnValue = null;
            if (!!newRowValue && !isDeletingValue) {
                columnValue = newRowValue[columnName];
            }
            this.isRowChanging = true;
            Serializer.setObjPropertyValue(rowObj, columnName, columnValue);
            this.isRowChanging = false;
            this.onCellValueChanged(row, columnName, rowObj);
        }
        else {
            var oldValue = this.createNewValue(true);
            var combine = this.getNewValueOnRowChanged(row, columnName, newRowValue, isDeletingValue, this.createNewValue());
            if (this.isTwoValueEquals(oldValue, combine.value))
                return;
            this.isRowChanging = true;
            this.setNewValue(combine.value);
            this.isRowChanging = false;
            if (columnName) {
                this.onCellValueChanged(row, columnName, combine.rowValue);
            }
        }
        if (this.getUniqueColumnsNames().indexOf(columnName) > -1) {
            this.isValueInColumnDuplicated(columnName, !!rowObj);
        }
    }
    getNewValueOnRowChanged(row, columnName, newRowValue, isDeletingValue, newValue) {
        const rowValue = this.getRowValueCore(row, newValue, true);
        if (isDeletingValue) {
            delete rowValue[columnName];
        }
        row.questions.forEach(q => {
            delete rowValue[q.getValueName()];
        });
        if (newRowValue) {
            newRowValue = JSON.parse(JSON.stringify(newRowValue));
            for (var key in newRowValue) {
                if (!this.isValueEmpty(newRowValue[key])) {
                    rowValue[key] = newRowValue[key];
                }
            }
        }
        if (this.isObject(rowValue) && Object.keys(rowValue).length === 0) {
            newValue = this.deleteRowValue(newValue, row);
        }
        return { value: newValue, rowValue: rowValue };
    }
    getRowIndex(row) {
        if (!Array.isArray(this.generatedVisibleRows))
            return -1;
        return this.generatedVisibleRows.indexOf(row);
    }
    getElementsInDesign(includeHidden = false) {
        let elements;
        if (this.detailPanelMode == "none") {
            elements = super.getElementsInDesign(includeHidden);
        }
        else {
            elements = includeHidden ? [this.detailPanel] : this.detailElements;
        }
        return this.columns.concat(elements);
    }
    hasDetailPanel(row) {
        if (this.detailPanelMode == "none")
            return false;
        if (this.isDesignMode)
            return true;
        if (!!this.onHasDetailPanelCallback)
            return this.onHasDetailPanelCallback(row);
        return this.detailElements.length > 0;
    }
    getIsDetailPanelShowing(row) {
        if (this.detailPanelMode == "none")
            return false;
        if (this.isDesignMode) {
            var res = this.visibleRows.indexOf(row) == 0;
            if (res) {
                if (!row.detailPanel) {
                    row.showDetailPanel();
                }
            }
            return res;
        }
        return this.getPropertyValue("isRowShowing" + row.id, false);
    }
    setIsDetailPanelShowing(row, val) {
        if (val == this.getIsDetailPanelShowing(row))
            return;
        this.setPropertyValue("isRowShowing" + row.id, val);
        this.updateDetailPanelButtonCss(row);
        if (!!this.renderedTable) {
            this.renderedTable.onDetailPanelChangeVisibility(row, val);
        }
        if (this.survey) {
            this.survey.matrixDetailPanelVisibleChanged(this, row.rowIndex - 1, row, val);
        }
        if (val && this.detailPanelMode === "underRowSingle") {
            var rows = this.visibleRows;
            for (var i = 0; i < rows.length; i++) {
                if (rows[i].id !== row.id && rows[i].isDetailPanelShowing) {
                    rows[i].hideDetailPanel();
                }
            }
        }
    }
    getDetailPanelButtonCss(row) {
        const builder = new CssClassBuilder().append(this.getPropertyValue("detailButtonCss" + row.id));
        return builder.append(this.cssClasses.detailButton, builder.toString() === "").toString();
    }
    getDetailPanelIconCss(row) {
        const builder = new CssClassBuilder().append(this.getPropertyValue("detailIconCss" + row.id));
        return builder.append(this.cssClasses.detailIcon, builder.toString() === "").toString();
    }
    getDetailPanelIconId(row) {
        return this.getIsDetailPanelShowing(row) ? this.cssClasses.detailIconExpandedId : this.cssClasses.detailIconId;
    }
    updateDetailPanelButtonCss(row) {
        const classes = this.cssClasses;
        const isPanelShowing = this.getIsDetailPanelShowing(row);
        const iconBuilder = new CssClassBuilder().append(classes.detailIcon)
            .append(classes.detailIconExpanded, isPanelShowing);
        this.setPropertyValue("detailIconCss" + row.id, iconBuilder.toString());
        const buttonBuilder = new CssClassBuilder().append(classes.detailButton)
            .append(classes.detailButtonExpanded, isPanelShowing);
        this.setPropertyValue("detailButtonCss" + row.id, buttonBuilder.toString());
    }
    createRowDetailPanel(row) {
        if (this.isDesignMode)
            return this.detailPanel;
        var panel = this.createNewDetailPanel();
        panel.readOnly = this.isReadOnly || !row.isRowEnabled();
        panel.setSurveyImpl(row);
        var json = this.detailPanel.toJSON();
        new JsonObject().toObject(json, panel);
        panel.renderWidth = "100%";
        panel.updateCustomWidgets();
        if (!!this.onCreateDetailPanelCallback) {
            this.onCreateDetailPanelCallback(row, panel);
        }
        panel.questions.forEach(q => q.setParentQuestion(this));
        panel.onSurveyLoad();
        return panel;
    }
    getSharedQuestionByName(columnName, row) {
        if (!this.survey || !this.valueName)
            return null;
        var index = this.getRowIndex(row);
        if (index < 0)
            return null;
        return (this.survey.getQuestionByValueNameFromArray(this.valueName, columnName, index));
    }
    onTotalValueChanged() {
        if (!!this.data &&
            !!this.visibleTotalRow &&
            !this.isUpdateLocked &&
            !this.isSett) {
            this.data.setValue(this.getValueName() + settings.matrix.totalsSuffix, this.totalValue, false);
        }
    }
    getDataFilteredValues() {
        return this.data ? this.data.getFilteredValues() : {};
    }
    getParentTextProcessor() {
        if (!this.parentQuestion || !this.parent)
            return null;
        const data = this.parent.data;
        if (!!data && !!data.getTextProcessor)
            return data.getTextProcessor();
        return null;
    }
    isMatrixReadOnly() { return this.isReadOnly; }
    onRowVisibilityChanged(row) {
        this.clearVisibleRows();
        this.resetRenderedTable();
        this.resetSingleInput();
    }
    clearValueIfInvisibleCore(reason) {
        super.clearValueIfInvisibleCore(reason);
        this.clearInvisibleValuesInRows();
    }
    clearInvisibleValuesInRows() {
        var _a;
        if (this.isEmpty() || !this.isRowsFiltered())
            return;
        const sharedQuestions = ((_a = this.survey) === null || _a === void 0 ? void 0 : _a.questionsByValueName(this.getValueName())) || [];
        if (sharedQuestions.length < 2) {
            this.value = this.getFilteredData();
        }
    }
    isRowsFiltered() {
        return super.isRowsFiltered() || (this.visibleRows !== this.generatedVisibleRows);
    }
    getQuestionFromArray(name, index) {
        if (index >= this.visibleRows.length)
            return null;
        return this.visibleRows[index].getQuestionByName(name);
    }
    isMatrixValueEmpty(val) {
        if (!val)
            return;
        if (Array.isArray(val)) {
            for (var i = 0; i < val.length; i++) {
                if (this.isObject(val[i]) && Object.keys(val[i]).length > 0)
                    return false;
            }
            return true;
        }
        return Object.keys(val).length == 0;
    }
    get SurveyModel() {
        return this.survey;
    }
    getCellTemplateData(cell) {
        // return cell.cell.column.templateQuestion;
        return this.SurveyModel.getMatrixCellTemplateData(cell);
    }
    getCellWrapperComponentName(cell) {
        return this.SurveyModel.getElementWrapperComponentName(cell, cell.row instanceof MatrixDropdownTotalRowModel ? "row-footer" : "cell");
    }
    getCellWrapperComponentData(cell) {
        return this.SurveyModel.getElementWrapperComponentData(cell, cell.row instanceof MatrixDropdownTotalRowModel ? "row-footer" : "cell");
    }
    getColumnHeaderWrapperComponentName(cell) {
        return this.SurveyModel.getElementWrapperComponentName(cell, "column-header");
    }
    getColumnHeaderWrapperComponentData(cell) {
        return this.SurveyModel.getElementWrapperComponentData(cell, "column-header");
    }
    getRowHeaderWrapperComponentName(cell) {
        return this.SurveyModel.getElementWrapperComponentName(cell, "row-header");
    }
    getRowHeaderWrapperComponentData(cell) {
        return this.SurveyModel.getElementWrapperComponentData(cell, "row-header");
    }
    onMobileChanged() {
        super.onMobileChanged();
        this.resetRenderedTable();
    }
    getRootCss() {
        return new CssClassBuilder().append(super.getRootCss()).append(this.cssClasses.rootScroll, this.horizontalScroll).toString();
    }
    afterRenderQuestionElement(el) {
        super.afterRenderQuestionElement(el);
        this.setRootElement(el === null || el === void 0 ? void 0 : el.parentElement);
    }
    beforeDestroyQuestionElement(el) {
        super.beforeDestroyQuestionElement(el);
        this.setRootElement(undefined);
    }
    setRootElement(val) {
        this.rootElement = val;
    }
    getRootElement() {
        return this.rootElement;
    }
}
Serializer.addClass("matrixdropdownbase", [
    {
        name: "columns:matrixdropdowncolumns",
        className: "matrixdropdowncolumn", isArray: true
    },
    {
        name: "columnLayout",
        alternativeName: "columnsLocation",
        choices: ["horizontal", "vertical"],
        visible: false, isSerializable: false
    },
    {
        name: "transposeData:boolean", version: "1.9.130", oldName: "columnLayout"
    },
    {
        name: "detailElements",
        baseClassName: "question",
        visible: false,
        isLightSerializable: false,
    },
    {
        name: "detailPanelMode",
        choices: ["none", "underRow", "underRowSingle"],
        default: "none",
    },
    { name: "cellErrorLocation", default: "default", choices: ["default", "top", "bottom"] },
    {
        name: "detailErrorLocation", default: "default", choices: ["default", "top", "bottom"],
        visibleIf: (obj) => { return !!obj && obj.detailPanelMode != "none"; }
    },
    { name: "horizontalScroll:boolean", visible: false, },
    {
        name: "choices:itemvalue[]", uniqueProperty: "value", visibleIf: (obj) => obj.isSelectCellType()
    },
    { name: "placeholder", alternativeName: "optionsCaption", serializationProperty: "locPlaceholder" },
    { name: "keyDuplicationError", serializationProperty: "locKeyDuplicationError", },
    {
        name: "singleInputTitleTemplate", serializationProperty: "locSingleInputTitleTemplate",
        visibleIf(obj) { var _a; return ((_a = obj.survey) === null || _a === void 0 ? void 0 : _a.questionsOnPageMode) === "inputPerPage"; }
    },
    {
        name: "cellType",
        default: "dropdown",
        choices: () => {
            return MatrixDropdownColumn.getColumnTypes();
        },
    },
    { name: "columnColCount", default: 0, choices: [0, 1, 2, 3, 4] },
    "columnMinWidth",
    { name: "allowAdaptiveActions:boolean", default: false, visible: false },
], function () {
    return new QuestionMatrixDropdownModelBase("");
}, "matrixbase");

class MatrixDropdownRowModel extends MatrixDropdownRowModelBase {
    constructor(name, item, data, value) {
        super(data, value);
        this.name = name;
        this.item = item;
        this.buildCells(value);
    }
    get rowName() {
        return this.name;
    }
    get rowTitle() {
        return this.text;
    }
    get text() {
        return this.item.text;
    }
    get locText() {
        return this.item.locText;
    }
    isItemVisible() { return this.item.isVisible; }
    isRowEnabled() { return this.item.isEnabled; }
    isRowHasEnabledCondition() { return !!this.item.enableIf; }
    setRowsVisibleIfValues(values) {
        values["item"] = this.item.value;
        values["choice"] = this.item.value;
    }
}
/**
  * A class that describes the Multi-Select Matrix question type. Multi-Select Matrix allows you to use the [Dropdown](https://surveyjs.io/form-library/documentation/questiondropdownmodel), [Checkbox](https://surveyjs.io/form-library/documentation/questioncheckboxmodel), [Radiogroup](https://surveyjs.io/form-library/documentation/questionradiogroupmodel), [Text](https://surveyjs.io/form-library/documentation/questiontextmodel), and [Comment](https://surveyjs.io/form-library/documentation/questioncommentmodel) question types as cell editors.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-matrixdropdown/ (linkStyle))
 */
class QuestionMatrixDropdownModel extends QuestionMatrixDropdownModelBase {
    constructor(name) {
        super(name);
        this.defaultValuesInRows = {};
        this.createLocalizableString("totalText", this, true);
        this.registerPropertyChangedHandlers(["rows"], () => {
            if (!this.generatedVisibleRows)
                return;
            this.clearGeneratedRows();
            this.resetRenderedTable();
            this.getVisibleRows();
            this.clearIncorrectValues();
        });
        this.registerPropertyChangedHandlers(["hideIfRowsEmpty"], () => {
            this.updateVisibilityBasedOnRows();
        });
    }
    getType() {
        return "matrixdropdown";
    }
    /**
     * A title for the total row. Applies if at least one column displays total values.
     * @see rowTitleWidth
     * @see columns
     */
    get totalText() {
        return this.getLocalizableStringText("totalText", "");
    }
    set totalText(val) {
        this.setLocalizableStringText("totalText", val);
    }
    get locTotalText() {
        return this.getLocalizableString("totalText");
    }
    getFooterText() {
        return this.locTotalText;
    }
    getRowTitleWidth() {
        return this.rowTitleWidth;
    }
    /**
     * Specifies whether to hide the question when the matrix has no visible rows.
     * @see rowsVisibleIf
     */
    get hideIfRowsEmpty() {
        return this.getPropertyValue("hideIfRowsEmpty");
    }
    set hideIfRowsEmpty(val) {
        this.setPropertyValue("hideIfRowsEmpty", val);
    }
    getSingleInputTitleTemplate() { return "rowNameTemplateTitle"; }
    getDisplayValueCore(keysAsText, value) {
        if (!value)
            return value;
        var rows = this.visibleRows;
        var res = {};
        if (!rows)
            return res;
        for (var i = 0; i < rows.length; i++) {
            var rowName = rows[i].rowName;
            var val = value[rowName];
            if (!val)
                continue;
            if (keysAsText) {
                var displayRowValue = ItemValue.getTextOrHtmlByValue(this.rows, rowName);
                if (!!displayRowValue) {
                    rowName = displayRowValue;
                }
            }
            res[rowName] = this.getRowDisplayValue(keysAsText, rows[i], val);
        }
        return res;
    }
    getConditionObjectRowName(index) {
        return "." + this.rows[index].value;
    }
    getConditionObjectRowText(index) {
        return "." + this.rows[index].calculatedText;
    }
    getConditionObjectsRowIndeces() {
        const res = [];
        for (var i = 0; i < this.rows.length; i++)
            res.push(i);
        return res;
    }
    isNewValueCorrect(val) {
        return Helpers.isValueObject(val, true);
    }
    clearIncorrectValues() {
        if (!this.isEmpty()) {
            this.getVisibleRows();
            const newVal = {};
            const val = this.value;
            for (let key in val) {
                const row = this.getRowByKey(key);
                if (!!row && row.isVisible) {
                    newVal[key] = val[key];
                }
            }
            this.value = newVal;
        }
        super.clearIncorrectValues();
    }
    getRowByKey(val) {
        const rows = this.generatedVisibleRows;
        if (!rows)
            return null;
        for (let i = 0; i < rows.length; i++) {
            if (rows[i].rowName === val)
                return rows[i];
        }
        return null;
    }
    clearGeneratedRows() {
        if (!this.generatedVisibleRows)
            return;
        if (!this.isDisposed) {
            this.generatedVisibleRows.forEach(row => {
                this.defaultValuesInRows[row.rowName] = row.getNamesWithDefaultValues();
            });
        }
        super.clearGeneratedRows();
    }
    getRowValueForCreation(val, rowName) {
        const res = val[rowName];
        if (!res)
            return res;
        const names = this.defaultValuesInRows[rowName];
        if (!Array.isArray(names) || names.length === 0)
            return res;
        names.forEach(name => {
            delete res[name];
        });
        return res;
    }
    generateRows() {
        var result = new Array();
        var rows = this.rows;
        if (!rows || rows.length === 0)
            return result;
        var val = this.value;
        if (!val)
            val = {};
        for (var i = 0; i < rows.length; i++) {
            const row = rows[i];
            if (this.isValueEmpty(row.value))
                continue;
            result.push(this.createMatrixRow(row, this.getRowValueForCreation(val, row.value)));
        }
        return result;
    }
    createMatrixRow(item, value) {
        return new MatrixDropdownRowModel(item.value, item, this, value);
    }
    getFilteredDataCore() {
        const res = {};
        const val = this.createValueCopy();
        this.generatedVisibleRows.forEach(row => {
            const rowVal = val[row.rowName];
            if (row.isVisible && !Helpers.isValueEmpty(rowVal)) {
                res[row.rowName] = rowVal;
            }
        });
        return res;
    }
    getSearchableItemValueKeys(keys) {
        keys.push("rows");
    }
    getIsRequireToGenerateRows() {
        if (super.getIsRequireToGenerateRows())
            return true;
        for (let i = 0; i < this.rows.length; i++) {
            if (!!this.rows[i].visibleIf)
                return true;
        }
        return false;
    }
    updateProgressInfoByValues(res) {
        let val = this.value;
        if (!val)
            val = {};
        for (var i = 0; i < this.rows.length; i++) {
            const row = this.rows[i];
            const rowName = val[row.value];
            this.updateProgressInfoByRow(res, !!rowName ? rowName : {});
        }
    }
}
Serializer.addClass("matrixdropdown", [
    {
        name: "rows:itemvalue[]", uniqueProperty: "value"
    },
    "rowsVisibleIf:condition",
    "rowTitleWidth",
    { name: "totalText", serializationProperty: "locTotalText" },
    "hideIfRowsEmpty:boolean"
], function () {
    return new QuestionMatrixDropdownModel("");
}, "matrixdropdownbase");
QuestionFactory.Instance.registerQuestion("matrixdropdown", (name) => {
    var q = new QuestionMatrixDropdownModel(name);
    q.choices = [1, 2, 3, 4, 5];
    q.rows = QuestionFactory.DefaultRows;
    QuestionMatrixDropdownModelBase.addDefaultColumns(q);
    return q;
});

/* eslint-disable no-restricted-globals */
// WebKit requires cancelable `touchmove` events to be added as early as possible
// see https://bugs.webkit.org/show_bug.cgi?id=184250
if (typeof window !== "undefined") {
    window.addEventListener("touchmove", (event) => {
        if (!DragDropDOMAdapter.PreventScrolling) {
            return;
        }
        // Prevent scrolling
        event.preventDefault();
    }, { passive: false });
}
class DragDropDOMAdapter {
    constructor(dd, longTap = true, fitToContainer = false) {
        this.dd = dd;
        this.longTap = longTap;
        this.fitToContainer = fitToContainer;
        this.scrollIntervalId = null;
        this.stopLongTapIfMoveEnough = (pointerMoveEvent) => {
            pointerMoveEvent.preventDefault();
            this.currentX = pointerMoveEvent.pageX;
            this.currentY = pointerMoveEvent.pageY;
            if (this.isMicroMovement)
                return;
            this.returnUserSelectBack();
            this.stopLongTap();
        };
        this.stopLongTap = (e) => {
            clearTimeout(this.timeoutID);
            this.timeoutID = null;
            document.removeEventListener("pointerup", this.stopLongTap);
            document.removeEventListener("pointermove", this.stopLongTapIfMoveEnough);
        };
        this.handlePointerCancel = (event) => {
            this.clear();
        };
        this.handleEscapeButton = (event) => {
            if (event.keyCode == 27) {
                this.clear();
            }
        };
        this.onContextMenu = (event) => {
            event.preventDefault();
            event.stopPropagation();
        };
        this.dragOver = (event) => {
            this.moveShortcutElement(event);
            this.draggedElementShortcut.style.cursor = "grabbing";
            this.dd.dragOver(event);
        };
        this.clear = () => {
            cancelAnimationFrame(this.scrollIntervalId);
            document.removeEventListener("pointermove", this.dragOver);
            document.removeEventListener("pointercancel", this.handlePointerCancel);
            document.removeEventListener("keydown", this.handleEscapeButton);
            document.removeEventListener("pointerup", this.drop);
            this.draggedElementShortcut.removeEventListener("pointerup", this.drop);
            if (IsTouch) {
                this.draggedElementShortcut.removeEventListener("contextmenu", this.onContextMenu);
            }
            this.draggedElementShortcut.parentElement.removeChild(this.draggedElementShortcut);
            this.dd.clear();
            this.draggedElementShortcut = null;
            this.scrollIntervalId = null;
            if (IsTouch) {
                this.savedTargetNode.style.cssText = null;
                this.savedTargetNode && this.savedTargetNode.parentElement.removeChild(this.savedTargetNode);
                this.insertNodeToParentAtIndex(this.savedTargetNodeParent, this.savedTargetNode, this.savedTargetNodeIndex);
                DragDropDOMAdapter.PreventScrolling = false;
            }
            this.savedTargetNode = null;
            this.savedTargetNodeParent = null;
            this.savedTargetNodeIndex = null;
            this.returnUserSelectBack();
        };
        this.drop = () => {
            this.dd.drop();
            this.clear();
        };
        this.draggedElementShortcut = null;
    }
    get documentOrShadowRoot() {
        const rootNode = this.rootElement.getRootNode();
        return rootNode instanceof Document || rootNode instanceof ShadowRoot ? rootNode : undefined;
    }
    get rootElement() {
        if (isShadowDOM(settings.environment.root)) {
            return this.rootContainer || settings.environment.root;
        }
        else {
            return this.rootContainer || settings.environment.root.documentElement || document.body;
        }
    }
    get viewRootElement() {
        return isShadowDOM(this.rootElement) ? this.rootElement.host : this.rootElement;
    }
    // see https://stackoverflow.com/questions/6042202/how-to-distinguish-mouse-click-and-drag
    get isMicroMovement() {
        const delta = 5;
        const diffX = Math.abs(this.currentX - this.startX);
        const diffY = Math.abs(this.currentY - this.startY);
        return diffX < delta && diffY < delta;
    }
    startLongTapProcessing(event, draggedElement, parentElement, draggedElementNode, preventSaveTargetNode = false) {
        this.startX = event.pageX;
        this.startY = event.pageY;
        document.body.style.setProperty("touch-action", "none", "important");
        //document.body.style.setProperty("-webkit-touch-callout", "none", "important");
        this.timeoutID = setTimeout(() => {
            this.doStartDrag(event, draggedElement, parentElement, draggedElementNode);
            if (!preventSaveTargetNode) {
                this.savedTargetNode = event.target;
                this.savedTargetNode.style.cssText =
                    `
          position: absolute;
          height: 1px!important;
          width: 1px!important;
          overflow: hidden;
          clip: rect(1px 1px 1px 1px);
          clip: rect(1px, 1px, 1px, 1px);
        `;
                this.savedTargetNodeParent = this.savedTargetNode.parentElement;
                this.savedTargetNodeIndex = this.getNodeIndexInParent(this.savedTargetNode);
                this.rootElement.appendChild(this.savedTargetNode);
            }
            this.stopLongTap();
        }, this.longTap ? 500 : 0);
        document.addEventListener("pointerup", this.stopLongTap);
        document.addEventListener("pointermove", this.stopLongTapIfMoveEnough);
    }
    moveShortcutElement(event) {
        let rootElementX = this.viewRootElement.getBoundingClientRect().x;
        let rootElementY = this.viewRootElement.getBoundingClientRect().y;
        let rootElementScrollLeft = this.viewRootElement.scrollLeft;
        let rootElementScrollTop = this.viewRootElement.scrollTop;
        this.doScroll(event.clientY, event.clientX);
        const shortcutHeight = this.draggedElementShortcut.offsetHeight;
        const shortcutWidth = this.draggedElementShortcut.offsetWidth;
        let shortcutXOffset = this.draggedElementShortcut.shortcutXOffset || shortcutWidth / 2;
        let shortcutYOffset = this.draggedElementShortcut.shortcutYOffset || shortcutHeight / 2;
        // TODO this is hot fix for RTL support. Probably we need better global strategy for it. https://github.com/surveyjs/survey-library/issues/4554
        if (document.querySelectorAll("[dir='rtl']").length !== 0) {
            shortcutXOffset = shortcutWidth / 2;
            shortcutYOffset = shortcutHeight / 2;
        }
        const documentBottom = document.documentElement.clientHeight;
        const documentRight = document.documentElement.clientWidth;
        const pageX = event.pageX;
        const pageY = event.pageY;
        const clientX = event.clientX;
        const clientY = event.clientY;
        //https://github.com/surveyjs/survey-creator/issues/5484
        rootElementX -= rootElementScrollLeft;
        rootElementY -= rootElementScrollTop;
        const shortcutBottomCoordinate = this.getShortcutBottomCoordinate(clientY, shortcutHeight, shortcutYOffset);
        const shortcutRightCoordinate = this.getShortcutRightCoordinate(clientX, shortcutWidth, shortcutXOffset);
        if (shortcutRightCoordinate >= documentRight) { // right boundary
            this.draggedElementShortcut.style.left =
                // pageX -
                // clientX +
                documentRight -
                    shortcutWidth -
                    rootElementX +
                    "px";
            this.draggedElementShortcut.style.top =
                /*pageY*/ clientY - shortcutYOffset - rootElementY + "px";
            return;
        }
        if (clientX - shortcutXOffset <= 0) { // left boundary
            this.draggedElementShortcut.style.left =
                pageX - clientX - rootElementX + "px";
            this.draggedElementShortcut.style.top =
                /*pageY*/ clientY - rootElementY - shortcutYOffset + "px";
            return;
        }
        if (shortcutBottomCoordinate >= documentBottom) { // bottom boundary
            this.draggedElementShortcut.style.left =
                /*pageX*/ clientX - shortcutXOffset - rootElementX + "px";
            this.draggedElementShortcut.style.top =
                // pageY -
                // clientY +
                documentBottom -
                    shortcutHeight -
                    rootElementY +
                    "px";
            return;
        }
        if (clientY - shortcutYOffset <= 0) { // top  boundary
            this.draggedElementShortcut.style.left =
                clientX - shortcutXOffset - rootElementX + "px";
            this.draggedElementShortcut.style.top =
                pageY - clientY - rootElementY + "px";
            return;
        }
        this.draggedElementShortcut.style.left =
            clientX - rootElementX - shortcutXOffset + "px";
        this.draggedElementShortcut.style.top =
            clientY - rootElementY - shortcutYOffset + "px";
    }
    getShortcutBottomCoordinate(currentY, shortcutHeight, shortcutYOffset) {
        return currentY + shortcutHeight - shortcutYOffset;
    }
    getShortcutRightCoordinate(currentX, shortcutWidth, shortcutXOffset) {
        return currentX + shortcutWidth - shortcutXOffset;
    }
    requestAnimationFrame(callback) {
        return requestAnimationFrame(callback);
    }
    scrollByDrag(scrollableParentNode, clientY, clientX) {
        const startScrollBoundary = 100;
        let top;
        let bottom;
        let left;
        let right;
        if (scrollableParentNode.tagName === "HTML") {
            top = 0;
            bottom = document.documentElement.clientHeight;
            left = 0;
            right = document.documentElement.clientWidth;
        }
        else {
            top = scrollableParentNode.getBoundingClientRect().top;
            bottom = scrollableParentNode.getBoundingClientRect().bottom;
            left = scrollableParentNode.getBoundingClientRect().left;
            right = scrollableParentNode.getBoundingClientRect().right;
        }
        const repeat = () => {
            const isTop = clientY - top <= startScrollBoundary;
            const isBottom = bottom - clientY <= startScrollBoundary;
            const isLeft = clientX - left <= startScrollBoundary;
            const isRight = right - clientX <= startScrollBoundary;
            if (isTop && !isLeft && !isRight) {
                scrollableParentNode.scrollTop -= 15;
            }
            else if (isBottom && !isLeft && !isRight) {
                scrollableParentNode.scrollTop += 15;
            }
            else if (isRight && !isTop && !isBottom) {
                scrollableParentNode.scrollLeft += 15;
            }
            else if (isLeft && !isTop && !isBottom) {
                scrollableParentNode.scrollLeft -= 15;
            }
            this.scrollIntervalId = this.requestAnimationFrame(repeat);
        };
        this.scrollIntervalId = this.requestAnimationFrame(repeat);
    }
    doScroll(clientY, clientX) {
        cancelAnimationFrame(this.scrollIntervalId);
        const displayProp = this.draggedElementShortcut.style.display;
        //this.draggedElementShortcut.hidden = true;
        this.draggedElementShortcut.style.display = "none";
        let dragOverNode = this.documentOrShadowRoot.elementFromPoint(clientX, clientY);
        //this.draggedElementShortcut.hidden = false;
        this.draggedElementShortcut.style.display = displayProp || "block";
        let scrollableParentNode = findScrollableParent(dragOverNode);
        this.scrollByDrag(scrollableParentNode, clientY, clientX);
    }
    doStartDrag(event, draggedElement, parentElement, draggedElementNode) {
        if (IsTouch) {
            DragDropDOMAdapter.PreventScrolling = true;
        }
        if (event.which === 3)
            return; //right mouse btn
        this.dd.dragInit(event, draggedElement, parentElement, draggedElementNode);
        this.rootElement.append(this.draggedElementShortcut);
        this.moveShortcutElement(event);
        document.addEventListener("pointermove", this.dragOver);
        document.addEventListener("pointercancel", this.handlePointerCancel);
        document.addEventListener("keydown", this.handleEscapeButton);
        document.addEventListener("pointerup", this.drop);
        if (!IsTouch) {
            this.draggedElementShortcut.addEventListener("pointerup", this.drop);
        }
        else {
            this.draggedElementShortcut.addEventListener("contextmenu", this.onContextMenu);
        }
    }
    returnUserSelectBack() {
        document.body.style.setProperty("touch-action", "auto");
        document.body.style.setProperty("user-select", "auto");
        document.body.style.setProperty("-webkit-user-select", "auto");
        //document.body.style.setProperty("-webkit-touch-callout", "default");
    }
    startDrag(event, draggedElement, parentElement, draggedElementNode, preventSaveTargetNode = false) {
        document.body.style.setProperty("user-select", "none", "important");
        document.body.style.setProperty("-webkit-user-select", "none", "important");
        if (IsTouch) {
            this.startLongTapProcessing(event, draggedElement, parentElement, draggedElementNode, preventSaveTargetNode);
            return;
        }
        this.doStartDrag(event, draggedElement, parentElement, draggedElementNode);
    }
    getNodeIndexInParent(node) {
        return [...node.parentElement.childNodes].indexOf(node);
    }
    insertNodeToParentAtIndex(parent, node, index) {
        parent.insertBefore(node, parent.childNodes[index]);
    }
}
DragDropDOMAdapter.PreventScrolling = false;

class DragDropCore {
    get isBottom() {
        return !!this._isBottom;
    }
    set isBottom(val) {
        this._isBottom = val;
        this.ghostPositionChanged();
    }
    ghostPositionChanged() {
        this.onGhostPositionChanged.fire({}, {});
    }
    get dropTargetDataAttributeName() {
        return `[data-sv-drop-target-${this.draggedElementType}]`;
    }
    get survey() {
        var _a;
        return this.surveyValue || ((_a = this.creator) === null || _a === void 0 ? void 0 : _a.survey);
    }
    constructor(surveyValue, creator, longTap, domAdapter) {
        var _a;
        this.surveyValue = surveyValue;
        this.creator = creator;
        this._isBottom = null;
        this.onGhostPositionChanged = new EventBase();
        this.onDragStart = new EventBase();
        this.onDragEnd = new EventBase();
        this.onDragClear = new EventBase();
        this.onBeforeDrop = this.onDragStart;
        this.onAfterDrop = this.onDragEnd;
        this.draggedElement = null;
        this.dropTarget = null;
        this.prevDropTarget = null;
        this.allowDropHere = false;
        this.banDropHere = () => {
            this.allowDropHere = false;
            this.doBanDropHere();
            this.dropTarget = null;
            this.domAdapter.draggedElementShortcut.style.cursor = "not-allowed";
            this.isBottom = null;
        };
        this.doBanDropHere = () => { };
        this.domAdapter = domAdapter || new DragDropDOMAdapter(this, longTap, (_a = this.survey) === null || _a === void 0 ? void 0 : _a.fitToContainer);
    }
    startDrag(event, draggedElement, parentElement, draggedElementNode, preventSaveTargetNode = false) {
        this.domAdapter.rootContainer = this.getRootElement(this.survey, this.creator);
        this.domAdapter.startDrag(event, draggedElement, parentElement, draggedElementNode, preventSaveTargetNode);
    }
    getRootElement(survey, creator) {
        return creator ? creator.rootElement : survey.rootElement;
    }
    dragInit(event, draggedElement, parentElement, draggedElementNode) {
        this.draggedElement = draggedElement;
        this.parentElement = parentElement;
        const shortcutText = this.getShortcutText(this.draggedElement);
        this.domAdapter.draggedElementShortcut = this.createDraggedElementShortcut(shortcutText, draggedElementNode, event);
        this.onStartDrag(event);
        const fromElement = this.draggedElement && this.draggedElement.parent;
        this.onDragStart.fire(this, { fromElement: fromElement, draggedElement: this.draggedElement });
    }
    onStartDrag(event) {
    }
    isDropTargetDoesntChanged(newIsBottom) {
        return (this.dropTarget === this.prevDropTarget && newIsBottom === this.isBottom);
    }
    getShortcutText(draggedElement) {
        return draggedElement === null || draggedElement === void 0 ? void 0 : draggedElement.shortcutText;
    }
    createDraggedElementShortcut(text, draggedElementNode, event) {
        const draggedElementShortcut = DomDocumentHelper.createElement("div");
        if (!!draggedElementShortcut) {
            draggedElementShortcut.innerText = text;
            draggedElementShortcut.className = this.getDraggedElementClass();
        }
        return draggedElementShortcut;
    }
    getDraggedElementClass() {
        return "sv-dragged-element-shortcut";
    }
    doDragOver() { }
    afterDragOver(dropTargetNode) { }
    findDropTargetNodeFromPoint(clientX, clientY) {
        const displayProp = this.domAdapter.draggedElementShortcut.style.display;
        this.domAdapter.draggedElementShortcut.style.display = "none";
        if (!DomDocumentHelper.isAvailable())
            return null;
        let dragOverNodes = this.domAdapter.documentOrShadowRoot.elementsFromPoint(clientX, clientY);
        this.domAdapter.draggedElementShortcut.style.display = displayProp || "block";
        let index = 0;
        let dragOverNode = dragOverNodes[index];
        while (dragOverNode && dragOverNode.className && typeof dragOverNode.className.indexOf == "function" && dragOverNode.className.indexOf("sv-drag-target-skipped") != -1) {
            index++;
            dragOverNode = dragOverNodes[index];
        }
        if (!dragOverNode)
            return null;
        return this.findDropTargetNodeByDragOverNode(dragOverNode);
    }
    getDataAttributeValueByNode(node) {
        let datasetName = "svDropTarget";
        const words = this.draggedElementType.split("-");
        words.forEach((word) => {
            datasetName += this.capitalizeFirstLetter(word);
        });
        return node.dataset[datasetName];
    }
    getDropTargetByNode(dropTargetNode, event) {
        let dataAttributeValue = this.getDataAttributeValueByNode(dropTargetNode);
        return this.getDropTargetByDataAttributeValue(dataAttributeValue, dropTargetNode, event);
    }
    capitalizeFirstLetter(string) {
        return string.charAt(0).toUpperCase() + string.slice(1);
    }
    calculateVerticalMiddleOfHTMLElement(HTMLElement) {
        const rect = HTMLElement.getBoundingClientRect();
        return rect.y + rect.height / 2;
    }
    calculateHorizontalMiddleOfHTMLElement(HTMLElement) {
        const rect = HTMLElement.getBoundingClientRect();
        return rect.x + rect.width / 2;
    }
    calculateIsBottom(clientY, dropTargetNode) {
        return false;
    }
    findDropTargetNodeByDragOverNode(dragOverNode) {
        const dropTargetNode = dragOverNode.closest(this.dropTargetDataAttributeName);
        return dropTargetNode;
    }
    dragOver(event) {
        const dropTargetNode = this.findDropTargetNodeFromPoint(event.clientX, event.clientY);
        if (!dropTargetNode) {
            this.banDropHere();
            return;
        }
        this.dropTarget = this.getDropTargetByNode(dropTargetNode, event);
        const isDropTargetValid = this.isDropTargetValid(this.dropTarget, dropTargetNode);
        this.doDragOver();
        if (!isDropTargetValid) {
            this.banDropHere();
            return;
        }
        let isBottom = this.calculateIsBottom(event.clientY, dropTargetNode);
        this.allowDropHere = true;
        if (this.isDropTargetDoesntChanged(isBottom))
            return;
        this.isBottom = null; //TODO need for property change trigger with guarantee but it would be better not to watch on isBottom property but have some event like onValidTargetDragOver
        this.isBottom = isBottom;
        if (this.draggedElement != this.dropTarget) {
            this.afterDragOver(dropTargetNode);
        }
        this.prevDropTarget = this.dropTarget;
    }
    drop() {
        if (this.allowDropHere) {
            const fromElement = this.draggedElement.parent;
            const newElement = this.doDrop();
            this.onDragEnd.fire(this, { fromElement: fromElement, draggedElement: newElement, toElement: this.dropTarget });
        }
    }
    clear() {
        const options = {
            draggedElement: this.draggedElement
        };
        this.dropTarget = null;
        this.prevDropTarget = null;
        this.draggedElement = null;
        this.isBottom = null;
        this.parentElement = null;
        this.onDragClear.fire(this, options);
    }
}

class DragDropMatrixRows extends DragDropCore {
    constructor() {
        super(...arguments);
        this.dropIsBanned = false;
        this.matrixRowMap = {};
        this.fromIndex = null;
        this.toIndex = null;
        this.toMatrix = null;
        this.doBanDropHere = () => {
            if (!this.dropIsBanned) {
                this.removeGhost();
                this.parentElement.renderedTable.rows.splice(this.initialDraggedElementIndex, 0, this.draggedRenderedRow);
                this.dropIsBanned = true;
                this.lastDropTargetParentElement = this.parentElement;
            }
        };
        this.doDrop = () => {
            if (this.parentElement == this.toMatrix) {
                if (this.fromIndex < this.toIndex) {
                    this.toIndex--;
                }
                this.parentElement.moveRowByIndex(this.fromIndex, this.toIndex);
            }
            else if (this.toMatrix) {
                const row = Object.assign({}, this.parentElement.value[this.fromIndex]);
                this.toMatrix.addRowByIndex(row, this.toIndex);
                this.parentElement.removeRowByIndex(this.fromIndex);
            }
            return this.parentElement;
        };
    }
    get draggedElementType() {
        return "matrix-row";
    }
    patchUserSelect() {
        const _body = DomDocumentHelper.getBody();
        if (!!_body) {
            this.restoreUserSelectValue = _body.style.userSelect;
            _body.style.userSelect = "none";
        }
    }
    onStartDrag() {
        this.patchUserSelect();
        const renderedRows = this.parentElement.renderedTable.rows;
        let index = renderedRows.findIndex(r => r.row === this.draggedElement);
        if (index >= 0) {
            this.draggedRenderedRow = renderedRows[index];
            this.initialDraggedElementIndex = index;
            this.draggedRenderedRow.isGhostRow = true;
            this.lastDropTargetParentElement = this.parentElement;
        }
        const matrices = [];
        function fillMatricies(questions) {
            const ms = questions.filter(q => q.isDescendantOf("matrixdynamic") && q.allowRowReorder);
            ms.forEach((m) => {
                matrices.push(m);
                if (m.detailPanelMode !== "none") {
                    m.visibleRows.forEach(r => {
                        if (r.isDetailPanelShowing) {
                            fillMatricies(r.questions);
                        }
                    });
                }
            });
        }
        if (this.survey.onMatrixRowDragOver.isEmpty) {
            matrices.push(this.parentElement);
        }
        else {
            fillMatricies(this.survey.getAllQuestions());
        }
        this.matrixRowMap = {};
        matrices.forEach(matrix => {
            matrix.visibleRows.forEach(row => {
                this.matrixRowMap[row.id] = { row, matrix };
            });
            if (matrix.visibleRows.length == 0) {
                this.matrixRowMap[matrix.id] = { row: matrix, matrix };
            }
        });
        this.fromIndex = this.parentElement.visibleRows.indexOf(this.draggedElement);
    }
    get shortcutClass() {
        return new CssClassBuilder()
            .append(this.parentElement.cssClasses.draggedRow)
            //.append(this.parentElement.cssClasses.dragShortcutMobileMod, IsMobile)
            .toString();
    }
    createDraggedElementShortcut(text, draggedElementNode, event) {
        const draggedElementShortcut = DomDocumentHelper.createElement("div");
        if (!draggedElementShortcut)
            return;
        draggedElementShortcut.className = this.shortcutClass;
        const isDeepClone = true;
        if (!!draggedElementNode) {
            const row = (draggedElementNode
                .closest("[data-sv-drop-target-matrix-row]"));
            const clone = (row.cloneNode(isDeepClone));
            clone.style.cssText = `
        width: ${row.offsetWidth}px;
      `;
            clone.classList.remove("sv-matrix__drag-drop--moveup");
            clone.classList.remove("sv-matrix__drag-drop--movedown");
            this.draggedElement.isDragDropMoveDown = false;
            this.draggedElement.isDragDropMoveUp = false;
            draggedElementShortcut.appendChild(clone);
            const rect = draggedElementNode.getBoundingClientRect();
            draggedElementShortcut.shortcutXOffset = event.clientX - rect.x;
            draggedElementShortcut.shortcutYOffset = event.clientY - rect.y;
        }
        return draggedElementShortcut;
    }
    getDropTargetByDataAttributeValue(dataAttributeValue) {
        const mapData = this.matrixRowMap[dataAttributeValue];
        return (mapData === null || mapData === void 0 ? void 0 : mapData.row) || (mapData === null || mapData === void 0 ? void 0 : mapData.matrix);
    }
    canInsertIntoThisRow(row) {
        const lockedRows = this.parentElement.lockedRowCount;
        return lockedRows <= 0 || row.rowIndex > lockedRows;
    }
    isDropTargetValid(dropTarget, dropTargetNode) {
        return this.canInsertIntoThisRow(dropTarget);
    }
    calculateIsBottom(clientY, dropTargetNode) {
        const rect = dropTargetNode.getBoundingClientRect();
        return clientY >= rect.y + rect.height / 2;
    }
    removeGhost() {
        const lastRenderedRows = this.lastDropTargetParentElement.renderedTable.rows;
        const draggedRenderedRowIndex = lastRenderedRows.indexOf(this.draggedRenderedRow);
        if (draggedRenderedRowIndex >= 0)
            lastRenderedRows.splice(draggedRenderedRowIndex, 1);
    }
    afterDragOver(dropTargetNode) {
        if (!this.dropTarget)
            return;
        const dropTargetMatrix = this.matrixRowMap[this.dropTarget.id].matrix;
        const dropTargetRow = this.matrixRowMap[this.dropTarget.id].row;
        const bottomOffset = this.isBottom ? 1 : 0;
        let toIndex = 0;
        const options = {
            allow: dropTargetMatrix == this.parentElement,
            row: dropTargetRow,
            fromMatrix: this.parentElement,
            toMatrix: dropTargetMatrix,
        };
        this.survey.onMatrixRowDragOver.fire(this.survey, options);
        if (!options.allow)
            return;
        this.removeGhost();
        this.lastDropTargetParentElement = dropTargetMatrix;
        const renderedRows = dropTargetMatrix.renderedTable.rows;
        if (dropTargetMatrix.visibleRows.length > 0) {
            const dropTargetRenderedRowIndex = renderedRows.findIndex(r => r.row == this.dropTarget);
            if (dropTargetRenderedRowIndex >= 0) {
                renderedRows.splice(dropTargetRenderedRowIndex + bottomOffset, 0, this.draggedRenderedRow);
            }
            toIndex = dropTargetMatrix.visibleRows.indexOf(this.dropTarget) + bottomOffset;
        }
        else {
            if (!dropTargetMatrix.renderedTable.headerRow)
                renderedRows[0].cells[0].colSpans = this.draggedRenderedRow.cells.length;
            renderedRows.splice(0, 0, this.draggedRenderedRow);
        }
        this.toIndex = toIndex;
        this.toMatrix = dropTargetMatrix;
        this.dropIsBanned = false;
        super.ghostPositionChanged();
    }
    clear() {
        this.matrixRowMap = {};
        const renderedRows = this.parentElement.renderedTable.rows;
        renderedRows.forEach((renderedRow) => {
            renderedRow.isGhostRow = false;
        });
        this.parentElement.clearOnDrop();
        if (this.toMatrix)
            this.toMatrix.clearOnDrop();
        this.fromIndex = null;
        this.toIndex = null;
        const _body = DomDocumentHelper.getBody();
        if (!!_body) {
            _body.style.userSelect = this.restoreUserSelectValue || "initial";
        }
        super.clear();
    }
}

class DragOrClickHelper {
    constructor(dragHandler, preventOnTouch = true) {
        this.dragHandler = dragHandler;
        this.preventOnTouch = preventOnTouch;
        this.onPointerUp = (pointerUpEvent) => {
            this.clearListeners();
        };
        this.tryToStartDrag = (pointerMoveEvent) => {
            this.currentX = pointerMoveEvent.pageX;
            this.currentY = pointerMoveEvent.pageY;
            if (this.isMicroMovement)
                return;
            this.clearListeners();
            this.dragHandler(this.pointerDownEvent, this.targets, this.itemModel);
            return true;
        };
    }
    onPointerDown(pointerDownEvent, itemModel) {
        this.targets = { currentTarget: pointerDownEvent.currentTarget, target: pointerDownEvent.target };
        if (IsTouch && this.preventOnTouch) {
            this.dragHandler(pointerDownEvent, this.targets, itemModel); //TODO handle inside in the library's drag drop core, need refactoring
            return;
        }
        this.pointerDownEvent = pointerDownEvent;
        this.startX = pointerDownEvent.pageX;
        this.startY = pointerDownEvent.pageY;
        this.targets.currentTarget.getRootNode().addEventListener("pointermove", this.tryToStartDrag);
        this.targets.currentTarget.addEventListener("pointerup", this.onPointerUp);
        this.itemModel = itemModel;
    }
    // see https://stackoverflow.com/questions/6042202/how-to-distinguish-mouse-click-and-drag
    get isMicroMovement() {
        const delta = 10;
        const diffX = Math.abs(this.currentX - this.startX);
        const diffY = Math.abs(this.currentY - this.startY);
        return diffX < delta && diffY < delta;
    }
    clearListeners() {
        if (!this.pointerDownEvent)
            return;
        this.targets.currentTarget.getRootNode().removeEventListener("pointermove", this.tryToStartDrag);
        this.targets.currentTarget.removeEventListener("pointerup", this.onPointerUp);
    }
}

class QuestionSingleInputSummaryItem {
    constructor(locText, btnEdit, btnRemove) {
        this.locText = locText;
        this.btnEdit = btnEdit;
        this.btnRemove = btnRemove;
    }
    get showRemove() { return !!this.btnRemove; }
}
class QuestionSingleInputSummary {
    constructor(question, noEntry) {
        this.question = question;
        this.noEntry = noEntry;
        this.items = [];
    }
    isEmpty() {
        return this.items.length == 0;
    }
    dispose() {
        this.items.forEach((item) => {
            var _a, _b;
            (_a = item.btnEdit) === null || _a === void 0 ? void 0 : _a.dispose();
            (_b = item.btnRemove) === null || _b === void 0 ? void 0 : _b.dispose();
        });
    }
}

class MatrixDynamicRowModel extends MatrixDropdownRowModelBase {
    constructor(index, data, value) {
        super(data, value);
        this.index = index;
        this.buildCells(value);
    }
    getRowIndex() {
        const res = super.getRowIndex();
        return res > 0 ? res : this.index + 1;
    }
    get rowName() {
        return this.id;
    }
    get dataName() {
        return "row" + (this.index + 1);
    }
    get text() {
        return "row " + (this.visibleIndex + 1);
    }
    getAccessbilityText() {
        return (this.visibleIndex + 1).toString();
    }
    get shortcutText() {
        const matrix = this.data;
        const index = matrix.visibleRows.indexOf(this) + 1;
        const questionValue1 = this.cells.length > 1 ? this.cells[1]["questionValue"] : undefined;
        const questionValue0 = this.cells.length > 0 ? this.cells[0]["questionValue"] : undefined;
        return (questionValue1 && questionValue1.value ||
            questionValue0 && questionValue0.value ||
            "" + index);
    }
}
/**
  * A class that describes the Dynamic Matrix question type.
  *
  * Dynamic Matrix allows respondents to add and delete matrix rows. You can use the [Dropdown](https://surveyjs.io/form-library/documentation/questiondropdownmodel), [Checkboxes](https://surveyjs.io/form-library/documentation/questioncheckboxmodel), [Radio Button Group](https://surveyjs.io/form-library/documentation/questionradiogroupmodel), [Single-Line Input](https://surveyjs.io/form-library/documentation/questiontextmodel), [Long Text](https://surveyjs.io/form-library/documentation/questioncommentmodel), and other question types as cell editors.
  *
  * [View Demo](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/ (linkStyle))
  */
class QuestionMatrixDynamicModel extends QuestionMatrixDropdownModelBase {
    constructor(name) {
        super(name);
        this.rowCounter = 0;
        this.setRowCountValueFromData = false;
        this.startDragMatrixRow = (event, targets) => {
            this.dragDropMatrixRows.startDrag(event, this.draggedRow, this, targets.target);
        };
        this.initialRowCount = this.getDefaultPropertyValue("rowCount");
        this.createLocalizableString("confirmDeleteText", this, false, "confirmDelete");
        var locAddRowText = this.createLocalizableString("addRowText", this);
        locAddRowText.onGetTextCallback = (text) => {
            return !!text ? text : this.defaultAddRowText;
        };
        this.createLocalizableString("removeRowText", this, false, "removeRow");
        this.createLocalizableString("noRowsText", this, false, true);
        this.createLocalizableString("editRowText", this, false, "editText");
        this.registerPropertyChangedHandlers(["hideColumnsIfEmpty", "allowAddRows"], () => { this.updateShowTableAndAddRow(); });
        this.registerPropertyChangedHandlers(["allowRowReorder", "isReadOnly", "lockedRowCount"], () => { this.resetRenderedTable(); });
        this.registerPropertyChangedHandlers(["minRowCount"], () => { this.onMinRowCountChanged(); });
        this.registerPropertyChangedHandlers(["maxRowCount"], () => { this.onMaxRowCountChanged(); });
        this.dragOrClickHelper = new DragOrClickHelper(this.startDragMatrixRow);
    }
    setSurveyImpl(value, isLight) {
        super.setSurveyImpl(value, isLight);
        this.dragDropMatrixRows = new DragDropMatrixRows(this.survey, null, true);
    }
    isBanStartDrag(pointerDownEvent) {
        const target = pointerDownEvent.target;
        return target.getAttribute("contenteditable") === "true" || target.nodeName === "INPUT" || !this.isDragHandleAreaValid(target);
    }
    isDragHandleAreaValid(node) {
        if (this.survey.matrixDragHandleArea === "icon") {
            return node.classList.contains(this.cssClasses.dragElementDecorator);
        }
        return true;
    }
    onPointerDown(pointerDownEvent, row) {
        if (!row || !this.isRowsDragAndDrop || this.isDesignMode)
            return;
        if (this.isBanStartDrag(pointerDownEvent))
            return;
        if (row.isDetailPanelShowing)
            return;
        this.draggedRow = row;
        this.dragOrClickHelper.onPointerDown(pointerDownEvent);
    }
    getType() {
        return "matrixdynamic";
    }
    get isRowsDynamic() {
        return true;
    }
    /**
     * Specifies whether to display a confirmation dialog when a respondent wants to delete a row.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-expandable-details-section-under-matrix-rows/ (linkStyle))
     * @see confirmDeleteText
     */
    get confirmDelete() {
        return this.getPropertyValue("confirmDelete");
    }
    set confirmDelete(val) {
        this.setPropertyValue("confirmDelete", val);
    }
    get isValueArray() { return true; }
    /**
     * Specifies a key column. Set this property to a column name, and the question will display `keyDuplicationError` if a user tries to enter a duplicate value in this column.
     * @see keyDuplicationError
     */
    get keyName() {
        return this.getPropertyValue("keyName", "");
    }
    set keyName(val) {
        this.setPropertyValue("keyName", val);
    }
    /**
     * If it is not empty, then this value is set to every new row, including rows created initially, unless the defaultValue is not empty
     * @see defaultValue
     * @see copyDefaultValueFromLastEntry
     */
    get defaultRowValue() {
        return this.getPropertyValue("defaultRowValue");
    }
    set defaultRowValue(val) {
        this.setPropertyValue("defaultRowValue", val);
    }
    /**
     * Specifies whether default values for a new row/column should be copied from the last row/column.
     *
     * If you also specify `defaultValue`, it will be merged with the copied values.
     * @see defaultValue
     */
    get copyDefaultValueFromLastEntry() {
        return this.getPropertyValue("copyDefaultValueFromLastEntry");
    }
    set copyDefaultValueFromLastEntry(val) {
        this.setPropertyValue("copyDefaultValueFromLastEntry", val);
    }
    /**
     * @deprecated Use the [`copyDefaultValueFromLastEntry`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model#copyDefaultValueFromLastEntry) property instead.
     */
    get defaultValueFromLastRow() {
        return this.copyDefaultValueFromLastEntry;
    }
    set defaultValueFromLastRow(val) {
        this.copyDefaultValueFromLastEntry = val;
    }
    isDefaultValueEmpty() {
        return (super.isDefaultValueEmpty() && this.isValueEmpty(this.defaultRowValue));
    }
    valueFromData(val) {
        if (this.minRowCount < 1 || this.isEmpty())
            return super.valueFromData(val);
        if (!Array.isArray(val))
            val = [];
        for (var i = val.length; i < this.minRowCount; i++)
            val.push({});
        return val;
    }
    isNewValueCorrect(val) {
        return Array.isArray(val);
    }
    setDefaultValue() {
        if (this.isValueEmpty(this.defaultRowValue) ||
            !this.isValueEmpty(this.defaultValue)) {
            super.setDefaultValue();
            return;
        }
        if (!this.isEmpty() || this.rowCount == 0)
            return;
        var newValue = [];
        for (var i = 0; i < this.rowCount; i++) {
            newValue.push(this.defaultRowValue);
        }
        this.value = newValue;
    }
    moveRowByIndex(fromIndex, toIndex) {
        const value = this.createNewValue();
        if (!Array.isArray(value) && Math.max(fromIndex, toIndex) >= value.length)
            return;
        const movableRow = value[fromIndex];
        value.splice(fromIndex, 1);
        value.splice(toIndex, 0, movableRow);
        this.value = value;
    }
    addRowByIndex(rowData, toIndex) {
        const value = this.createNewValue();
        if (!Array.isArray(value) && toIndex >= value.length)
            return;
        value.splice(toIndex, 0, rowData);
        this.rowCount++;
        this.value = value;
    }
    removeRowByIndex(fromIndex) {
        const value = this.createNewValue();
        if (!Array.isArray(value) && fromIndex >= value.length)
            return;
        value.splice(fromIndex, 1);
        this.rowCount--;
        this.value = value;
    }
    clearOnDrop() {
        if (!this.isEditingSurveyElement) {
            this.resetRenderedTable();
        }
    }
    initDataUI() {
        if (!this.generatedVisibleRows) {
            this.getVisibleRows();
        }
    }
    /**
     * The number of rows in the matrix.
     *
     * Default value: 2
     *
     * [View Demo](https://surveyjs.io/form-library/examples/dynamic-matrix-add-new-rows/ (linkStyle))
     * @see minRowCount
     * @see maxRowCount
     */
    get rowCount() {
        return this.rowCountValue;
    }
    set rowCount(val) {
        val = Helpers.getNumber(val);
        if (val < 0 || val > settings.matrix.maxRowCount || val === this.rowCount)
            return;
        this.setRowCountValueFromData = false;
        var prevValue = this.rowCountValue;
        this.rowCountValue = val;
        if (this.value && this.value.length > val) {
            var qVal = this.value;
            qVal.splice(val);
            this.value = qVal;
        }
        if (this.isUpdateLocked) {
            this.initialRowCount = val;
            return;
        }
        if (this.generatedVisibleRows || prevValue == 0) {
            if (!this.generatedVisibleRows) {
                this.clearGeneratedRows();
                this.generatedVisibleRows = [];
            }
            this.generatedVisibleRows.splice(val);
            for (var i = prevValue; i < val; i++) {
                var newRow = this.createMatrixRow(this.getValueForNewRow());
                this.generatedVisibleRows.push(newRow);
                this.onMatrixRowCreated(newRow);
            }
            this.runCondition(this.getDataFilteredValues(), this.getDataFilteredProperties());
        }
        this.onRowsChanged();
    }
    updateBindingProp(propName, value) {
        super.updateBindingProp(propName, value);
        const rows = this.generatedVisibleRows;
        if (propName !== "rowCount" || !Array.isArray(rows))
            return;
        const val = this.getUnbindValue(this.value) || [];
        if (val.length < rows.length) {
            let hasValue = false;
            for (let i = val.length; i < rows.length; i++) {
                hasValue || (hasValue = !rows[i].isEmpty);
                val.push(rows[i].value || {});
            }
            if (hasValue) {
                this.value = val;
            }
        }
    }
    updateProgressInfoByValues(res) {
        let val = this.value;
        if (!Array.isArray(val))
            val = [];
        for (var i = 0; i < this.rowCount; i++) {
            const rowValue = i < val.length ? val[i] : {};
            this.updateProgressInfoByRow(res, rowValue);
        }
    }
    getValueForNewRow() {
        var res = null;
        if (!!this.onGetValueForNewRowCallBack) {
            res = this.onGetValueForNewRowCallBack(this);
        }
        return res;
    }
    /**
     * Specifies whether users can drag and drop matrix rows to reorder them. Applies only if [`transposeData`](#transposeData) is `false`.
     *
     * Default value: `false`
     */
    get allowRowReorder() {
        return this.getPropertyValue("allowRowReorder");
    }
    set allowRowReorder(val) {
        this.setPropertyValue("allowRowReorder", val);
    }
    /**
     * @deprecated Use the [`allowRowReorder`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model#allowRowReorder) property instead.
     */
    get allowRowsDragAndDrop() {
        return this.allowRowReorder;
    }
    set allowRowsDragAndDrop(val) {
        this.allowRowReorder = val;
    }
    get allowRowDragIn() {
        var _a, _b;
        return !((_b = (_a = this.survey) === null || _a === void 0 ? void 0 : _a.onMatrixRowDragOver) === null || _b === void 0 ? void 0 : _b.isEmpty);
    }
    get isRowsDragAndDrop() {
        return this.allowRowReorder && !this.isReadOnly;
    }
    get lockedRowCount() {
        return this.getPropertyValue("lockedRowCount", 0);
    }
    set lockedRowCount(val) {
        this.setPropertyValue("lockedRowCount", val);
    }
    get iconDragElement() {
        return this.cssClasses.iconDragElement;
    }
    createRenderedTable() {
        return new QuestionMatrixDynamicRenderedTable(this);
    }
    get rowCountValue() {
        return this.getPropertyValue("rowCount");
    }
    set rowCountValue(val) {
        this.setPropertyValue("rowCount", val);
    }
    /**
     * A minimum number of rows in the matrix. Users cannot delete rows if `rowCount` equals `minRowCount`.
     *
     * Default value: 0
     *
     * [View Demo](https://surveyjs.io/form-library/examples/dynamic-matrix-add-new-rows/ (linkStyle))
     * @see rowCount
     * @see maxRowCount
     * @see allowRemoveRows
     */
    get minRowCount() {
        return this.getPropertyValue("minRowCount");
    }
    set minRowCount(val) {
        if (val < 0)
            val = 0;
        this.setPropertyValue("minRowCount", val);
    }
    onMinRowCountChanged() {
        const val = this.minRowCount;
        if (val > this.maxRowCount)
            this.maxRowCount = val;
        if (this.initialRowCount < val)
            this.initialRowCount = val;
        if (this.rowCount < val)
            this.rowCount = val;
    }
    /**
     * A maximum number of rows in the matrix. Users cannot add new rows if `rowCount` equals `maxRowCount`.
     *
     * Default value: 1000 (inherited from [`settings.matrix.maxRowCount`](https://surveyjs.io/form-library/documentation/settings#matrixMaximumRowCount))
     *
     * [View Demo](https://surveyjs.io/form-library/examples/dynamic-matrix-add-new-rows/ (linkStyle))
     * @see rowCount
     * @see minRowCount
     * @see allowAddRows
     */
    get maxRowCount() {
        return this.getPropertyValue("maxRowCount");
    }
    set maxRowCount(val) {
        if (val <= 0)
            return;
        if (val > settings.matrix.maxRowCount)
            val = settings.matrix.maxRowCount;
        if (val == this.maxRowCount)
            return;
        this.setPropertyValue("maxRowCount", val);
    }
    onMaxRowCountChanged() {
        const val = this.maxRowCount;
        if (val < this.minRowCount)
            this.minRowCount = val;
        if (this.rowCount > val)
            this.rowCount = val;
    }
    /**
     * Specifies whether users are allowed to add new rows.
     *
     * Default value: `true`
     * @see canAddRow
     * @see allowRemoveRows
     */
    get allowAddRows() {
        return this.getPropertyValue("allowAddRows");
    }
    set allowAddRows(val) {
        this.setPropertyValue("allowAddRows", val);
    }
    /**
     * Specifies whether users are allowed to delete rows.
     *
     * Default value: `true`
     * @see canRemoveRows
     * @see allowAddRows
     */
    get allowRemoveRows() {
        return this.getPropertyValue("allowRemoveRows");
    }
    set allowRemoveRows(val) {
        this.setPropertyValue("allowRemoveRows", val);
        if (!this.isUpdateLocked) {
            this.resetRenderedTable();
        }
    }
    /**
     * Indicates whether it is possible to add a new row.
     *
     * This property returns `true` when all of the following conditions apply:
     *
     * - Users are allowed to add new rows (`allowAddRows` is `true`).
     * - The question, its parent panel, or survey is not in read-only state.
     * - `rowCount` is less than `maxRowCount`.
     * @see allowAddRows
     * @see isReadOnly
     * @see rowCount
     * @see maxRowCount
     * @see canRemoveRows
     */
    get canAddRow() {
        return (this.allowAddRows && !this.isReadOnly && this.rowCount < this.maxRowCount);
    }
    /**
     * Indicates whether it is possible to delete rows.
     *
     * This property returns `true` when all of the following conditions apply:
     *
     * - Users are allowed to delete rows (`allowRemoveRows` is `true`).
     * - The question, its parent panel, or survey is not in read-only state.
     * - `rowCount` exceeds `minRowCount`.
     * @see allowRemoveRows
     * @see isReadOnly
     * @see rowCount
     * @see minRowCount
     * @see canAddRow
     */
    get canRemoveRows() {
        var res = this.allowRemoveRows &&
            !this.isReadOnly &&
            this.rowCount > this.minRowCount;
        return !!this.canRemoveRowsCallback ? this.canRemoveRowsCallback(res) : res;
    }
    canRemoveRow(row) {
        if (!this.survey)
            return true;
        const index = row.rowIndex - 1;
        if (this.lockedRowCount > 0 && index < this.lockedRowCount)
            return false;
        return this.survey.matrixAllowRemoveRow(this, index, row);
    }
    addRowUI() {
        this.addRow(true);
    }
    getQuestionToFocusOnAddingRow() {
        if (this.visibleRows.length === 0)
            return null;
        var row = this.visibleRows[this.visibleRows.length - 1];
        for (var i = 0; i < row.cells.length; i++) {
            var q = row.cells[i].question;
            if (!!q && q.isVisible && !q.isReadOnly) {
                return q;
            }
        }
        return null;
    }
    /**
     * Creates and adds a new row to the matrix.
     * @param setFocus *(Optional)* Pass `true` to focus the cell in the first column.
     */
    addRow(setFocus) {
        const oldRowCount = this.rowCount;
        const allow = this.canAddRow;
        var options = { question: this, canAddRow: allow, allow: allow };
        if (!!this.survey) {
            this.survey.matrixBeforeRowAdded(options);
        }
        const newAllow = allow !== options.allow ? options.allow :
            (allow !== options.canAddRow ? options.canAddRow : allow);
        if (!newAllow)
            return;
        this.onStartRowAddingRemoving();
        this.addRowCore();
        this.onEndRowAdding();
        this.singleInputOnAddItem(false);
        if (this.detailPanelShowOnAdding && this.visibleRows.length > 0) {
            this.visibleRows[this.visibleRows.length - 1].showDetailPanel();
        }
        if (setFocus && oldRowCount !== this.rowCount) {
            const q = this.getQuestionToFocusOnAddingRow();
            if (!!q) {
                q.focus();
            }
        }
    }
    /**
     * Specifies whether to expand the detail section immediately when a respondent adds a new row.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-expandable-details-section-under-matrix-rows/ (linkStyle))
     * @see detailPanelMode
     */
    get detailPanelShowOnAdding() {
        return this.getPropertyValue("detailPanelShowOnAdding");
    }
    set detailPanelShowOnAdding(val) {
        this.setPropertyValue("detailPanelShowOnAdding", val);
    }
    hasRowsAsItems() {
        return false;
    }
    unbindValue() {
        this.clearGeneratedRows();
        this.clearPropertyValue("value");
        this.rowCountValue = 0;
        super.unbindValue();
    }
    isValueSurveyElement(val) {
        return this.isEditingSurveyElement || super.isValueSurveyElement(val);
    }
    addRowCore() {
        var prevRowCount = this.rowCount;
        this.rowCount = this.rowCount + 1;
        var defaultValue = this.getDefaultRowValue(true);
        var newValue = null;
        if (!this.isValueEmpty(defaultValue)) {
            newValue = this.createNewValue();
            if (newValue.length == this.rowCount) {
                newValue[newValue.length - 1] = defaultValue;
                this.value = newValue;
            }
        }
        if (this.data) {
            this.runCellsCondition(this.getDataFilteredValues(), this.getDataFilteredProperties());
            const rows = this.visibleRows;
            if (this.isValueEmpty(defaultValue) && rows.length > 0) {
                const row = rows[rows.length - 1];
                if (!this.isValueEmpty(row.value)) {
                    if (!newValue) {
                        newValue = this.createNewValue();
                    }
                    if (!this.isValueSurveyElement(newValue) &&
                        !this.isTwoValueEquals(newValue[newValue.length - 1], row.value)) {
                        newValue[newValue.length - 1] = row.value;
                        this.value = newValue;
                    }
                }
            }
        }
        if (this.survey) {
            const rows = this.visibleRows;
            if (prevRowCount + 1 == this.rowCount && rows.length > 0) {
                const row = rows[rows.length - 1];
                this.survey.matrixRowAdded(this, row);
                this.onRowsChanged();
            }
        }
    }
    getDefaultRowValue(isRowAdded) {
        var res = null;
        for (var i = 0; i < this.columns.length; i++) {
            var q = this.columns[i].templateQuestion;
            if (!!q && !this.isValueEmpty(q.getDefaultValue())) {
                res = res || {};
                res[this.columns[i].name] = q.getDefaultValue();
            }
        }
        if (!this.isValueEmpty(this.defaultRowValue)) {
            for (var key in this.defaultRowValue) {
                res = res || {};
                res[key] = this.defaultRowValue[key];
            }
        }
        if (isRowAdded && this.copyDefaultValueFromLastEntry) {
            var val = this.value;
            if (!!val && Array.isArray(val) && val.length >= this.rowCount - 1) {
                var rowValue = val[this.rowCount - 2];
                for (var key in rowValue) {
                    res = res || {};
                    res[key] = rowValue[key];
                }
            }
        }
        return res;
    }
    focusAddBUtton() {
        const rootElement = this.getRootElement();
        if (!!rootElement && !!this.cssClasses.buttonAdd) {
            const addButton = rootElement.querySelectorAll("." + this.cssClasses.buttonAdd)[0];
            addButton && addButton.focus();
        }
    }
    getActionCellIndex(row) {
        const headerShift = this.showHeader ? 1 : 0;
        if (this.isColumnLayoutHorizontal) {
            return row.cells.length - 1 + headerShift;
        }
        return this.visibleRows.indexOf(row) + headerShift;
    }
    removeRowUI(value) {
        if (!!value && !!value.rowName) {
            var index = this.visibleRows.indexOf(value);
            if (index < 0)
                return;
            value = index;
        }
        this.removeRow(value, undefined, () => {
            const rowCount = this.visibleRows.length;
            const nextIndex = index >= rowCount ? rowCount - 1 : index;
            const nextRow = nextIndex > -1 ? this.visibleRows[nextIndex] : undefined;
            setTimeout(() => {
                if (nextRow) {
                    this.renderedTable.focusActionCell(nextRow, this.getActionCellIndex(nextRow));
                }
                else {
                    this.focusAddBUtton();
                }
            }, 10);
        });
    }
    isRequireConfirmOnRowDelete(index) {
        if (!this.confirmDelete)
            return false;
        if (index < 0 || index >= this.rowCount)
            return false;
        var value = this.createNewValue();
        if (this.isValueEmpty(value) || !Array.isArray(value))
            return false;
        if (index >= value.length)
            return false;
        return !this.isValueEmpty(value[index]);
    }
    /**
     * Removes a matrix row with a specified index.
     * @param index A zero-based row index.
     * @param confirmDelete *(Optional)* A Boolean value that specifies whether to display a confirmation dialog. If you do not specify this parameter, the [`confirmDelete`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model#confirmDelete) property value is used.
     */
    removeRow(index, confirmDelete, onRowRemoved) {
        if (!this.canRemoveRows)
            return;
        if (index < 0 || index >= this.rowCount)
            return;
        var row = !!this.visibleRows && index < this.visibleRows.length
            ? this.visibleRows[index]
            : null;
        if (confirmDelete === undefined) {
            confirmDelete = this.isRequireConfirmOnRowDelete(index);
        }
        if (confirmDelete) {
            confirmActionAsync({
                message: this.confirmDeleteText,
                funcOnYes: () => {
                    this.removeRowAsync(index, row);
                    onRowRemoved && onRowRemoved();
                },
                locale: this.getLocale(),
                rootElement: this.survey.rootElement,
                cssClass: this.cssClasses.confirmDialog
            });
            return;
        }
        this.removeRowAsync(index, row);
        onRowRemoved && onRowRemoved();
    }
    removeRowAsync(index, row) {
        if (!!row && !!this.survey && !this.survey.matrixRowRemoving(this, index, row))
            return;
        this.onStartRowAddingRemoving();
        this.removeRowCore(index);
        this.singleInputOnRemoveItem(index);
        this.onEndRowRemoving(row);
    }
    removeRowCore(index) {
        var row = this.generatedVisibleRows
            ? this.generatedVisibleRows[index]
            : null;
        if (this.generatedVisibleRows && index < this.generatedVisibleRows.length) {
            this.generatedVisibleRows.splice(index, 1);
        }
        this.rowCountValue--;
        if (this.value) {
            var val = [];
            if (Array.isArray(this.value) && index < this.value.length) {
                val = this.createValueCopy();
            }
            else {
                val = this.createNewValue();
            }
            val.splice(index, 1);
            val = this.deleteRowValue(val, null);
            this.isRowChanging = true;
            this.value = val;
            this.isRowChanging = false;
        }
        this.onRowsChanged();
        if (this.survey) {
            this.survey.matrixRowRemoved(this, index, row);
        }
    }
    onSingleInputQuestionAdded(question) {
        if (!this.showHeader) {
            question.titleLocation = "hidden";
        }
    }
    getSingleInputQuestionsCore(question, checkDynamic) {
        const res = new Array();
        const rows = this.visibleRows;
        if (checkDynamic) {
            for (let i = 0; i < rows.length; i++) {
                const row = rows[i];
                if (!row.hasValueAnyQuestion(true) || row.hasErrors(false, {}, () => { })) {
                    this.fillSingleInputQuestionsByRow(res, row);
                }
            }
        }
        return this.getSingleInputQuestionsForDynamic(question, res);
    }
    fillSingleInputQuestionsInContainer(res, innerQuestion) {
        const row = this.getRowByQuestion(innerQuestion);
        this.fillSingleInputQuestionsByRow(res, row);
    }
    fillSingleInputQuestionsByRow(res, row) {
        if (row) {
            row.questions.forEach(q => q.addNestedQuestion(res, true, false, false));
        }
    }
    getSingleInputAddTextCore() {
        if (!this.canAddRow)
            return undefined;
        return this.addRowText;
    }
    singleInputAddItemCore() {
        this.addRowUI();
    }
    singleInputRemoveItemCore(question) {
        this.removeRowUI(this.getRowByQuestion(question));
    }
    getSingleQuestionOnChange(index) {
        const rows = this.visibleRows;
        if (rows.length > 0) {
            if (index < 0 || index >= rows.length)
                index = rows.length - 1;
            const row = rows[index];
            const vQs = row.visibleQuestions;
            if (vQs.length > 0) {
                return vQs[0];
            }
        }
        return null;
    }
    createSingleInputSummary() {
        const res = new QuestionSingleInputSummary(this, this.locNoRowsText);
        const items = new Array();
        const canRemoveRows = this.canRemoveRows;
        this.visibleRows.forEach((row) => {
            const locText = new LocalizableString(this, true, undefined, this.getSingleInputTitleTemplate());
            locText.setJson(this.locSingleInputTitleTemplate.getJson());
            locText.onGetTextCallback = (text) => {
                return row.getTextProcessor().processText(text, true);
            };
            const bntEdit = new Action({ locTitle: this.getLocalizableString("editRowText"), action: () => { this.singleInputEditRow(row); } });
            const btnRemove = canRemoveRows && this.canRemoveRow(row) ?
                new Action({ locTitle: this.locRemoveRowText, action: () => { this.removeRowUI(row); } }) : undefined;
            items.push(new QuestionSingleInputSummaryItem(locText, bntEdit, btnRemove));
        });
        res.items = items;
        return res;
    }
    /**
     * A message displayed in a confirmation dialog that appears when a respondent wants to delete a row.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-expandable-details-section-under-matrix-rows/ (linkStyle))
     * @see confirmDelete
     */
    get confirmDeleteText() {
        return this.getLocalizableStringText("confirmDeleteText");
    }
    set confirmDeleteText(val) {
        this.setLocalizableStringText("confirmDeleteText", val);
    }
    get locConfirmDeleteText() {
        return this.getLocalizableString("confirmDeleteText");
    }
    /**
     * A caption for the Add Row button.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/dynamic-matrix-add-new-rows/ (linkStyle))
     * @see addRowButtonLocation
     */
    get addRowText() {
        return this.getLocalizableStringText("addRowText", this.defaultAddRowText);
    }
    set addRowText(val) {
        this.setLocalizableStringText("addRowText", val);
    }
    get locAddRowText() {
        return this.getLocalizableString("addRowText");
    }
    get defaultAddRowText() {
        return this.getLocalizationString(this.isColumnLayoutHorizontal ? "addRow" : "addColumn");
    }
    getSingleInputTitleTemplate() { return "rowIndexTemplateTitle"; }
    /**
     * Specifies the location of the Add Row button.
     *
     * Possible values:
     *
     * - `"top"` - Displays the Add Row button at the top of the matrix.
     * - `"bottom"` - Displays the Add Row button at the bottom of the matrix.
     * - `"topBottom"` - Displays the Add Row button at the top and bottom of the matrix.
     *
     * Default value: `"top"` if [`transposeData`](#transposeData) is `true`; `"bottom"` if `transposeData` is `false` or the matrix is in compact mode.
     * @see addRowText
     */
    get addRowButtonLocation() {
        return this.getPropertyValue("addRowButtonLocation");
    }
    set addRowButtonLocation(val) {
        this.setPropertyValue("addRowButtonLocation", val);
    }
    /**
     * @deprecated Use the [`addRowButtonLocation`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model#addRowButtonLocation) property instead.
     */
    get addRowLocation() {
        return this.addRowButtonLocation;
    }
    set addRowLocation(val) {
        this.addRowButtonLocation = val;
    }
    getAddRowLocation() {
        return this.addRowButtonLocation;
    }
    /**
     * Specifies whether to hide columns when the matrix does not contain any rows. If you enable this property, the matrix displays the `noRowsText` message and the Add Row button.
     *
     * Default value: `false`
     * @see noRowsText
     */
    get hideColumnsIfEmpty() {
        return this.getPropertyValue("hideColumnsIfEmpty");
    }
    set hideColumnsIfEmpty(val) {
        this.setPropertyValue("hideColumnsIfEmpty", val);
    }
    getShowColumnsIfEmpty() {
        return this.hideColumnsIfEmpty;
    }
    /**
     * Use this property to change the default value of remove row button text.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-expandable-details-section-under-matrix-rows/ (linkStyle))
     */
    get removeRowText() {
        return this.getLocalizableStringText("removeRowText");
    }
    set removeRowText(val) {
        this.setLocalizableStringText("removeRowText", val);
    }
    get locRemoveRowText() {
        return this.getLocalizableString("removeRowText");
    }
    /**
     * A message displayed when the matrix does not contain any rows. Applies only if `hideColumnsIfEmpty` is enabled.
     * @see hideColumnsIfEmpty
     */
    get noRowsText() {
        return this.getLocalizableStringText("noRowsText");
    }
    set noRowsText(val) {
        this.setLocalizableStringText("noRowsText", val);
    }
    get locNoRowsText() {
        return this.getLocalizableString("noRowsText");
    }
    /**
     * @deprecated Use the [`noRowsText`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model#noRowsText) property instead.
     */
    get emptyRowsText() {
        return this.noRowsText;
    }
    set emptyRowsText(val) {
        this.noRowsText = val;
    }
    get locEmptyRowsText() {
        return this.locNoRowsText;
    }
    getDisplayValueCore(keysAsText, value) {
        if (!value || !Array.isArray(value))
            return value;
        var values = this.getUnbindValue(value);
        var rows = this.visibleRows;
        for (var i = 0; i < rows.length && i < values.length; i++) {
            var val = values[i];
            if (!val)
                continue;
            values[i] = this.getRowDisplayValue(keysAsText, rows[i], val);
        }
        return values;
    }
    getConditionObjectRowName(index) {
        return "[" + index.toString() + "]";
    }
    getConditionObjectsRowIndeces() {
        const res = [];
        const rowCount = Math.max(this.rowCount, 1);
        for (var i = 0; i < Math.min(settings.matrix.maxRowCountInCondition, rowCount); i++) {
            res.push(i);
        }
        return res;
    }
    supportAutoAdvance() {
        return false;
    }
    get hasRowText() {
        return false;
    }
    onCheckForErrors(errors, isOnValueChanged, fireCallback) {
        super.onCheckForErrors(errors, isOnValueChanged, fireCallback);
        if (!isOnValueChanged && this.hasErrorInMinRows()) {
            errors.push(new MinRowCountError(this.minRowCount, this));
        }
    }
    hasErrorInMinRows() {
        if (this.minRowCount <= 0 || !this.isRequired || !this.generatedVisibleRows)
            return false;
        var setRowCount = 0;
        for (var rowIndex = 0; rowIndex < this.generatedVisibleRows.length; rowIndex++) {
            var row = this.generatedVisibleRows[rowIndex];
            if (!row.isEmpty)
                setRowCount++;
        }
        return setRowCount < this.minRowCount;
    }
    getUniqueColumnsNames() {
        var res = super.getUniqueColumnsNames();
        const name = this.keyName;
        if (!!name && res.indexOf(name) < 0) {
            res.push(name);
        }
        return res;
    }
    generateRows() {
        var result = new Array();
        if (this.rowCount === 0)
            return result;
        var val = this.createNewValue();
        for (var i = 0; i < this.rowCount; i++) {
            result.push(this.createMatrixRow(this.getRowValueByIndex(val, i)));
        }
        if (!this.isValueEmpty(this.getDefaultRowValue(false))) {
            this.value = val;
        }
        return result;
    }
    createMatrixRow(value) {
        return new MatrixDynamicRowModel(this.rowCounter++, this, value);
    }
    getInsertedDeletedIndex(rows, val) {
        const len = Math.min(rows.length, val.length);
        for (let i = 0; i < len; i++) {
            if (val[i] !== rows[i].editingObj)
                return i;
        }
        return len;
    }
    isEditingObjectValueChanged() {
        const val = this.value;
        if (!this.generatedVisibleRows || !this.isValueSurveyElement(val))
            return false;
        let lastDelRow = this.lastDeletedRow;
        this.lastDeletedRow = undefined;
        const rows = this.generatedVisibleRows;
        if (!Array.isArray(val) || Math.abs(rows.length - val.length) > 1 || rows.length === val.length)
            return false;
        const index = this.getInsertedDeletedIndex(rows, val);
        if (rows.length > val.length) {
            this.lastDeletedRow = rows[index];
            const row = rows[index];
            rows.splice(index, 1);
            if (this.isRendredTableCreated) {
                this.renderedTable.onRemovedRow(row);
            }
        }
        else {
            let newRow = undefined;
            if (!!lastDelRow && lastDelRow.editingObj === val[index]) {
                newRow = lastDelRow;
            }
            else {
                lastDelRow = undefined;
                newRow = this.createMatrixRow(val[index]);
            }
            rows.splice(index, 0, newRow);
            if (!lastDelRow) {
                this.onMatrixRowCreated(newRow);
            }
            if (this.isRendredTableCreated) {
                this.renderedTable.onAddedRow(newRow, index);
            }
        }
        this.setPropertyValueDirectly("rowCount", val.length);
        return true;
    }
    updateValueFromSurvey(newValue, clearData = false) {
        this.setRowCountValueFromData = true;
        if (this.minRowCount > 0 && Helpers.isValueEmpty(newValue) && !Helpers.isValueEmpty(this.defaultRowValue)) {
            newValue = [];
            for (let i = 0; i < this.minRowCount; i++) {
                newValue.push(Helpers.createCopy(this.defaultRowValue));
            }
        }
        super.updateValueFromSurvey(newValue, clearData);
        this.setRowCountValueFromData = false;
    }
    getFilteredDataCore() {
        const res = [];
        const val = this.createValueCopy();
        if (!Array.isArray(val))
            return res;
        const rows = this.generatedVisibleRows;
        for (let i = 0; i < rows.length && i < val.length; i++) {
            const rowVal = val[i];
            if (rows[i].isVisible && !Helpers.isValueEmpty(rowVal)) {
                res.push(rowVal);
            }
        }
        return res;
    }
    onBeforeValueChanged(val) {
        if (!val || !Array.isArray(val))
            return;
        var newRowCount = val.length;
        if (newRowCount == this.rowCount)
            return;
        if (!this.setRowCountValueFromData && newRowCount < this.initialRowCount)
            return;
        if (this.isEditingObjectValueChanged())
            return;
        this.setRowCountValueFromData = true;
        this.rowCountValue = newRowCount;
        if (!this.generatedVisibleRows)
            return;
        if (newRowCount == this.generatedVisibleRows.length + 1) {
            this.onStartRowAddingRemoving();
            const newValue = this.getRowValueByIndex(val, newRowCount - 1);
            const newRow = this.createMatrixRow(newValue);
            this.generatedVisibleRows.push(newRow);
            this.onMatrixRowCreated(newRow);
            this.onEndRowAdding();
        }
        else {
            this.clearGeneratedRows();
            this.getVisibleRows();
            this.onRowsChanged();
        }
        this.setRowCountValueFromData = false;
    }
    createNewValue() {
        var result = this.createValueCopy();
        if (!result || !Array.isArray(result))
            result = [];
        if (result.length > this.rowCount)
            result.splice(this.rowCount);
        var rowValue = this.getDefaultRowValue(false);
        rowValue = rowValue || {};
        for (var i = result.length; i < this.rowCount; i++) {
            result.push(this.getUnbindValue(rowValue));
        }
        return result;
    }
    deleteRowValue(newValue, row) {
        if (!Array.isArray(newValue))
            return newValue;
        var isEmpty = true;
        for (var i = 0; i < newValue.length; i++) {
            if (this.isObject(newValue[i]) && Object.keys(newValue[i]).length > 0) {
                isEmpty = false;
                break;
            }
        }
        return isEmpty ? null : newValue;
    }
    getRowValueByIndex(questionValue, index) {
        return Array.isArray(questionValue) &&
            index >= 0 &&
            index < questionValue.length
            ? questionValue[index]
            : null;
    }
    getRowValueCore(row, questionValue, create = false) {
        if (!this.generatedVisibleRows)
            return {};
        var res = this.getRowValueByIndex(questionValue, this.generatedVisibleRows.indexOf(row));
        if (!res && create)
            res = {};
        return res;
    }
    getAddRowButtonCss(isEmptySection = false) {
        return new CssClassBuilder()
            .append(this.cssClasses.button)
            .append(this.cssClasses.buttonAdd)
            .append(this.cssClasses.emptyRowsButton, isEmptySection)
            .toString();
    }
    getRemoveRowButtonCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.button)
            .append(this.cssClasses.buttonRemove)
            .toString();
    }
    getRootCss() {
        var _a;
        return new CssClassBuilder().append(super.getRootCss()).append(this.cssClasses.empty, !((_a = this.renderedTable) === null || _a === void 0 ? void 0 : _a.showTable)).toString();
    }
}
class QuestionMatrixDynamicRenderedTable extends QuestionMatrixDropdownRenderedTable {
    setDefaultRowActions(row, actions) {
        super.setDefaultRowActions(row, actions);
    }
}
Serializer.addClass("matrixdynamic", [
    { name: "allowAddRows:boolean", default: true },
    { name: "allowRemoveRows:boolean", default: true },
    { name: "rowCount:number", default: 2, minValue: 0, isBindable: true },
    { name: "minRowCount:number", default: 0, minValue: 0 },
    {
        name: "maxRowCount:number",
        default: settings.matrix.maxRowCount,
    },
    { name: "keyName" },
    "defaultRowValue:rowvalue",
    { name: "copyDefaultValueFromLastEntry:boolean", alternativeName: "defaultValueFromLastRow" },
    { name: "confirmDelete:boolean" },
    {
        name: "confirmDeleteText",
        dependsOn: "confirmDelete",
        visibleIf: function (obj) {
            return !obj || obj.confirmDelete;
        },
        serializationProperty: "locConfirmDeleteText",
    },
    {
        name: "addRowButtonLocation", alternativeName: "addRowLocation",
        default: "default",
        choices: ["default", "top", "bottom", "topBottom"],
    },
    { name: "addRowText", serializationProperty: "locAddRowText" },
    { name: "removeRowText", serializationProperty: "locRemoveRowText" },
    "hideColumnsIfEmpty:boolean",
    {
        name: "noRowsText:text", alternativeName: "emptyRowsText",
        serializationProperty: "locNoRowsText",
        dependsOn: "hideColumnsIfEmpty",
        visibleIf: function (obj) {
            return !obj || obj.hideColumnsIfEmpty;
        },
    },
    {
        name: "detailPanelShowOnAdding:boolean",
        dependsOn: "detailPanelMode",
        visibleIf: function (obj) {
            return obj.detailPanelMode !== "none";
        },
    },
    { name: "allowRowReorder:switch", alternativeName: "allowRowsDragAndDrop" },
], function () {
    return new QuestionMatrixDynamicModel("");
}, "matrixdropdownbase");
QuestionFactory.Instance.registerQuestion("matrixdynamic", (name) => {
    var q = new QuestionMatrixDynamicModel(name);
    q.choices = [1, 2, 3, 4, 5];
    QuestionMatrixDropdownModelBase.addDefaultColumns(q);
    return q;
});

var surveyCss = {
    currentType: "default",
    getCss: function () {
        var loc = this.currentType ? this[this.currentType] : defaultCss;
        if (!loc)
            loc = defaultCss;
        return loc;
    },
    getAvailableThemes: function () {
        return Object.keys(this).filter(propertyName => ["currentType", "getCss", "getAvailableThemes"].indexOf(propertyName) === -1);
    }
};
var defaultCss = {
    root: "sd-root-modern",
    rootProgress: "sd-progress",
    rootMobile: "sd-root-modern--mobile",
    rootAnimationDisabled: "sd-root-modern--animation-disabled",
    rootReadOnly: "sd-root--readonly",
    rootCompact: "sd-root--compact",
    rootFitToContainer: "sd-root-modern--full-container",
    rootWrapper: "sd-root-modern__wrapper",
    rootWrapperFixed: "sd-root-modern__wrapper--fixed",
    rootWrapperHasImage: "sd-root-modern__wrapper--has-image",
    rootBackgroundImage: "sd-root_background-image",
    container: "sd-container-modern",
    header: "sd-title sd-container-modern__title",
    bodyContainer: "sv-components-row",
    body: "sd-body",
    bodyWithTimer: "sd-body--with-timer",
    clockTimerRoot: "sd-timer",
    clockTimerRootTop: "sd-timer--top",
    clockTimerRootBottom: "sd-timer--bottom",
    clockTimerProgress: "sd-timer__progress",
    clockTimerProgressAnimation: "sd-timer__progress--animation",
    clockTimerTextContainer: "sd-timer__text-container",
    clockTimerMinorText: "sd-timer__text--minor",
    clockTimerMajorText: "sd-timer__text--major",
    bodyEmpty: "sd-body sd-body--empty",
    bodyLoading: "sd-body--loading",
    footer: "sd-footer sd-body__navigation sd-clearfix",
    title: "sd-title",
    description: "sd-description",
    logo: "sd-logo",
    logoImage: "sd-logo__image",
    headerText: "sd-header__text",
    headerClose: "sd-hidden",
    navigationButton: "",
    bodyNavigationButton: "sd-btn",
    completedPage: "sd-completedpage",
    completedBeforePage: "sd-completed-before-page",
    timerRoot: "sd-body__timer",
    navigation: {
        complete: "sd-btn--action sd-navigation__complete-btn",
        prev: "sd-navigation__prev-btn",
        next: "sd-navigation__next-btn",
        start: "sd-navigation__start-btn",
        preview: "sd-navigation__preview-btn",
        edit: "sd-btn sd-btn--small",
    },
    panel: {
        contentEnter: "sd-element__content--enter",
        contentLeave: "sd-element__content--leave",
        enter: "sd-element-wrapper--enter",
        leave: "sd-element-wrapper--leave",
        asPage: "sd-panel--as-page",
        number: "sd-element__num",
        title: "sd-title sd-element__title sd-panel__title",
        titleExpandable: "sd-element__title--expandable",
        titleExpandableSvg: "sd-element__title-expandable-svg",
        titleNumInline: "sd-element__title--num-inline",
        titleExpanded: "sd-element__title--expanded",
        titleCollapsed: "sd-element__title--collapsed",
        titleDisabled: "sd-element__title--disabled",
        titleOnExpand: "sd-panel__title--expanded",
        titleOnError: "sd-panel__title--error",
        titleBar: "sd-action-title-bar",
        description: "sd-description sd-panel__description",
        container: "sd-element sd-element--complex sd-panel sd-row__panel",
        withFrame: "sd-element--with-frame",
        content: "sd-element__content sd-panel__content",
        icon: "sd-panel__icon",
        iconExpanded: "sd-panel__icon--expanded",
        footer: "sd-panel__footer",
        requiredMark: "sd-panel__required-text",
        header: "sd-panel__header sd-element__header sd-element__header--location-top",
        collapsed: "sd-element--collapsed",
        expanded: "sd-element--expanded",
        expandable: "sd-element--expandable",
        expandableAnimating: "sd-elemenet--expandable--animating",
        nested: "sd-element--nested sd-element--nested-with-borders",
        invisible: "sd-element--invisible",
        navigationButton: "",
        compact: "sd-element--with-frame sd-element--compact",
        errorsContainer: "sd-panel__errbox sd-element__erbox sd-element__erbox--above-element"
    },
    paneldynamic: {
        mainRoot: "sd-element  sd-question sd-question--paneldynamic sd-element--complex sd-question--complex sd-row__question",
        empty: "sd-question--empty",
        root: "sd-paneldynamic",
        iconRemove: "sd-hidden",
        navigation: "sd-paneldynamic__navigation",
        title: "sd-title sd-element__title sd-question__title",
        header: "sd-paneldynamic__header sd-element__header",
        headerTab: "sd-paneldynamic__header-tab",
        button: "sd-action sd-paneldynamic__btn",
        buttonRemove: "sd-action--negative sd-paneldynamic__remove-btn",
        buttonAdd: "sd-paneldynamic__add-btn",
        buttonPrev: "sd-paneldynamic__prev-btn sd-action--icon sd-action",
        buttonPrevDisabled: "sd-action--disabled",
        buttonNextDisabled: "sd-action--disabled",
        buttonNext: "sd-paneldynamic__next-btn sd-action--icon sd-action",
        progressContainer: "sd-paneldynamic__progress-container",
        progress: "sd-progress",
        progressBar: "sd-progress__bar",
        nested: "sd-element--nested sd-element--nested-with-borders",
        progressText: "sd-paneldynamic__progress-text",
        separator: "sd-paneldynamic__separator",
        panelWrapper: "sd-paneldynamic__panel-wrapper",
        footer: "sd-paneldynamic__footer",
        panelFooter: "sd-paneldynamic__panel-footer",
        footerButtonsContainer: "sd-paneldynamic__buttons-container",
        panelsContainer: "sd-paneldynamic__panels-container",
        panelWrapperInRow: "sd-paneldynamic__panel-wrapper--in-row",
        panelWrapperEnter: "sd-paneldynamic__panel-wrapper--enter",
        panelWrapperLeave: "sd-paneldynamic__panel-wrapper--leave",
        panelWrapperList: "sd-paneldynamic__panel-wrapper--list",
        progressBtnIcon: "icon-progressbuttonv2",
        noEntriesPlaceholder: "sd-paneldynamic__placeholder sd-question__placeholder",
        compact: "sd-element--with-frame sd-element--compact",
        tabsContainer: "sd-paneldynamic__tabs-container",
        tabsContainerWithHeader: "sd-paneldynamic__tabs-container--with-header",
        tabsRoot: "sd-tabs-toolbar",
        tabsLeft: "sd-tabs-toolbar--left",
        tabsRight: "sd-tabs-toolbar--right",
        tabsCenter: "sd-tabs-toolbar--center",
        tabs: {
            item: "sd-tab-item",
            itemPressed: "sd-tab-item--pressed",
            itemAsIcon: "sd-tab-item--icon",
            itemIcon: "sd-tab-item__icon",
            itemTitle: "sd-tab-item__title"
        }
    },
    progress: "sd-progress sd-body__progress",
    progressTop: "sd-body__progress--top",
    progressBottom: "sd-body__progress--bottom",
    progressBar: "sd-progress__bar",
    progressText: "sd-progress__text",
    progressButtonsRoot: "sd-progress-buttons",
    progressButtonsNumbered: "sd-progress-buttons--numbered",
    progressButtonsFitSurveyWidth: "sd-progress-buttons--fit-survey-width",
    progressButtonsContainerCenter: "sd-progress-buttons__container-center",
    progressButtonsContainer: "sd-progress-buttons__container",
    progressButtonsConnector: "sd-progress-buttons__connector",
    progressButtonsButton: "sd-progress-buttons__button",
    progressButtonsButtonBackground: "sd-progress-buttons__button-background",
    progressButtonsButtonContent: "sd-progress-buttons__button-content",
    progressButtonsHeader: "sd-progress-buttons__header",
    progressButtonsFooter: "sd-progress-buttons__footer",
    progressButtonsImageButtonLeft: "sd-progress-buttons__image-button-left",
    progressButtonsImageButtonRight: "sd-progress-buttons__image-button-right",
    progressButtonsImageButtonHidden: "sd-progress-buttons__image-button--hidden",
    progressButtonsListContainer: "sd-progress-buttons__list-container",
    progressButtonsList: "sd-progress-buttons__list",
    progressButtonsListElementPassed: "sd-progress-buttons__list-element--passed",
    progressButtonsListElementCurrent: "sd-progress-buttons__list-element--current",
    progressButtonsListElementNonClickable: "sd-progress-buttons__list-element--nonclickable",
    progressButtonsPageTitle: "sd-progress-buttons__page-title",
    progressButtonsPageDescription: "sd-progress-buttons__page-description",
    progressTextInBar: "sd-hidden",
    page: {
        root: "sd-page sd-body__page",
        emptyHeaderRoot: "sd-page__empty-header",
        title: "sd-title sd-page__title",
        description: "sd-description sd-page__description",
        number: "sd-page__num",
        errorsContainer: "sd-page__errbox"
    },
    pageTitle: "sd-title sd-page__title",
    pageDescription: "sd-description sd-page__description",
    row: "sd-row sd-clearfix",
    rowMultiple: "sd-row--multiple",
    rowCompact: "sd-row--compact",
    rowEnter: "sd-row--enter",
    rowDelayedEnter: "sd-row--delayed-enter",
    rowLeave: "sd-row--leave",
    rowReplace: "sd-row--replace",
    pageRow: "sd-page__row",
    question: {
        contentEnter: "sd-element__content--enter",
        contentLeave: "sd-element__content--leave",
        enter: "sd-element-wrapper--enter",
        leave: "sd-element-wrapper--leave",
        mobile: "sd-question--mobile",
        mainRoot: "sd-element sd-question sd-row__question",
        flowRoot: "sd-element sd-question sd-row__question sd-row__question--flow",
        withFrame: "sd-element--with-frame",
        asCell: "sd-table__cell",
        answered: "sd-question--answered",
        header: "sd-question__header sd-element__header",
        headerLeft: "sd-question__header--location--left",
        headerTop: "sd-question__header--location-top sd-element__header--location-top",
        headerBottom: "sd-question__header--location--bottom",
        content: "sd-element__content sd-question__content",
        contentSupportContainerQueries: "sd-question__content--support-container-queries",
        contentLeft: "sd-question__content--left",
        titleNumInline: "sd-element__title--num-inline",
        titleLeftRoot: "sd-question--left",
        titleTopRoot: "sd-question--title-top",
        descriptionUnderInputRoot: "sd-question--description-under-input",
        titleBottomRoot: "sd-question--title-bottom",
        titleOnAnswer: "sd-question__title--answer",
        titleEmpty: "sd-question__title--empty",
        titleOnError: "sd-question__title--error",
        title: "sd-title sd-element__title sd-question__title",
        titleExpandable: "sd-element__title--expandable",
        titleExpandableSvg: "sd-element__title-expandable-svg",
        titleExpanded: "sd-element__title--expanded",
        titleCollapsed: "sd-element__title--collapsed",
        titleDisabled: "sd-element__title--disabled",
        titleReadOnly: "sd-element__title--readonly",
        titleBar: "sd-action-title-bar",
        requiredMark: "sd-question__required-text",
        number: "sd-element__num",
        description: "sd-description sd-question__description",
        descriptionUnderInput: "sd-question__description--under-input",
        comment: "sd-input sd-comment",
        other: "sd-input sd-comment",
        required: "sd-question--required",
        titleRequired: "sd-question__title--required",
        indent: 20,
        footer: "sd-question__footer",
        commentArea: "sd-question__comment-area",
        formGroup: "sd-question__form-group",
        hasError: "sd-question--error",
        hasErrorTop: "sd-question--error-top",
        hasErrorBottom: "sd-question--error-bottom",
        collapsed: "sd-element--collapsed",
        expandable: "sd-element--expandable",
        expandableAnimating: "sd-elemenet--expandable--animating",
        expanded: "sd-element--expanded",
        nested: "sd-element--nested",
        invisible: "sd-element--invisible",
        composite: "sd-element--complex sd-composite",
        disabled: "sd-question--disabled",
        readOnly: "sd-question--readonly",
        preview: "sd-question--preview",
        noPointerEventsMode: "sd-question--no-pointer-events",
        errorsContainer: "sd-element__erbox sd-question__erbox",
        errorsContainerTop: "sd-element__erbox--above-element sd-question__erbox--above-question",
        errorsContainerBottom: "sd-question__erbox--below-question",
        confirmDialog: "sd-popup--confirm sv-popup--confirm",
        singleInputTitle: "sd-element__title--singleinput",
        singleInputWrapper: "sd-question__singleinput-wrapper",
        breadcrumbsRoot: "sd-breadcrumbs",
        breadcrumbsItem: "sd-breadcrumbs-item",
        breadcrumbsItemButton: "sd-breadcrumbs-item__button",
        breadcrumbsSeparator: "sd-breadcrumbs-separator",
        summary: "sd-summary",
        summaryRow: "sd-summary-row",
        summaryRowContent: "sd-summary-row__content",
        summaryRowActions: "sd-summary-row__actions",
        summaryRowAction: "sd-summary-row-action",
        summaryRowActionEdit: "sd-summary-row-action sd-summary-row-action--edit",
        summaryRowActionDelete: "sd-summary-row-action sd-summary-row-action--delete",
    },
    image: {
        mainRoot: "sd-element sd-question sd-question--image",
        root: "sd-image",
        image: "sd-image__image",
        adaptive: "sd-image__image--adaptive",
        noImage: "sd-image__no-image",
        noImageSvgIconId: "icon-no-image",
        withFrame: ""
    },
    html: {
        mainRoot: "sd-element sd-question sd-row__question sd-question--html",
        root: "sd-html",
        withFrame: "",
        nested: "sd-element--nested sd-html--nested"
    },
    error: {
        root: "sd-error",
        icon: "",
        item: "",
        locationTop: "",
        locationBottom: ""
    },
    checkbox: {
        root: "sd-selectbase",
        rootMobile: "sd-selectbase--mobile",
        rootRow: "sd-selectbase--row",
        rootMultiColumn: "sd-selectbase--multi-column",
        item: "sd-item sd-checkbox sd-selectbase__item",
        itemEnter: "sd-item--enter",
        itemLeave: "sd-item--leave",
        itemOnError: "sd-item--error",
        itemSelectAll: "sd-checkbox--selectall",
        itemNone: "sd-checkbox--none",
        itemDisabled: "sd-item--disabled sd-checkbox--disabled",
        itemReadOnly: "sd-item--readonly sd-checkbox--readonly",
        itemPreview: "sd-item--preview sd-checkbox--preview",
        itemPreviewSvgIconId: "#icon-check-16x16",
        itemChecked: "sd-item--checked sd-checkbox--checked",
        itemHover: "sd-item--allowhover sd-checkbox--allowhover",
        itemInline: "sd-selectbase__item--inline",
        label: "sd-selectbase__label",
        labelChecked: "",
        itemControl: "sd-visuallyhidden sd-item__control sd-checkbox__control",
        itemDecorator: "sd-item__svg sd-checkbox__svg",
        itemSvgIconId: "#icon-check-16x16",
        controlLabel: "sd-item__control-label",
        materialDecorator: "sd-item__decorator sd-checkbox__decorator",
        other: "sd-input sd-comment sd-selectbase__other",
        column: "sd-selectbase__column",
    },
    radiogroup: {
        root: "sd-selectbase",
        rootMobile: "sd-selectbase--mobile",
        rootRow: "sd-selectbase--row",
        rootMultiColumn: "sd-selectbase--multi-column",
        item: "sd-item sd-radio sd-selectbase__item",
        itemOnError: "sd-item--error",
        itemInline: "sd-selectbase__item--inline",
        label: "sd-selectbase__label",
        labelChecked: "",
        itemEnter: "sd-item--enter",
        itemLeave: "sd-item--leave",
        itemDisabled: "sd-item--disabled sd-radio--disabled",
        itemReadOnly: "sd-item--readonly sd-radio--readonly",
        itemPreview: "sd-item--preview sd-radio--preview",
        itemPreviewSvgIconId: "#icon-check-16x16",
        itemChecked: "sd-item--checked sd-radio--checked",
        itemHover: "sd-item--allowhover sd-radio--allowhover",
        itemControl: "sd-visuallyhidden sd-item__control sd-radio__control",
        itemDecorator: "sd-item__svg sd-radio__svg",
        controlLabel: "sd-item__control-label",
        materialDecorator: "sd-item__decorator sd-radio__decorator",
        other: "sd-input sd-comment sd-selectbase__other",
        clearButton: "",
        column: "sd-selectbase__column"
    },
    boolean: {
        mainRoot: "sd-element sd-question sd-row__question sd-question--boolean",
        root: "sv_qcbc sv_qbln sd-scrollable-container sd-boolean-root",
        rootRadio: "sv_qcbc sv_qbln sd-scrollable-container sd-scrollable-container--compact",
        item: "sd-boolean",
        itemOnError: "sd-boolean--error",
        control: "sd-boolean__control sd-visuallyhidden",
        itemChecked: "sd-boolean--checked",
        itemExchanged: "sd-boolean--exchanged",
        itemIndeterminate: "sd-boolean--indeterminate",
        itemDisabled: "sd-boolean--disabled",
        itemReadOnly: "sd-boolean--readonly",
        itemPreview: "sd-boolean--preview",
        itemHover: "sd-boolean--allowhover",
        label: "sd-boolean__label",
        labelTrue: "sd-boolean__label--true",
        labelFalse: "sd-boolean__label--false",
        switch: "sd-boolean__switch",
        disabledLabel: "sd-checkbox__label--disabled",
        labelReadOnly: "sd-checkbox__label--readonly",
        labelPreview: "sd-checkbox__label--preview",
        sliderText: "sd-boolean__thumb-text",
        slider: "sd-boolean__thumb",
        sliderGhost: "sd-boolean__thumb-ghost",
        //radio
        radioItem: "sd-item",
        radioItemChecked: "sd-item--checked sd-radio--checked",
        radioItemDisabled: "sd-item--disabled sd-radio--disabled",
        radioItemReadOnly: "sd-item--readonly sd-radio--readonly",
        radioItemPreview: "sd-item--preview sd-radio--preview",
        itemPreviewSvgIconId: "#icon-check-16x16",
        radioLabel: "sd-selectbase__label",
        radioControlLabel: "sd-item__control-label",
        radioFieldset: "sd-selectbase",
        itemRadioDecorator: "sd-item__svg sd-radio__svg",
        materialRadioDecorator: "sd-item__decorator sd-radio__decorator",
        itemRadioControl: "sd-visuallyhidden sd-item__control sd-radio__control",
        //end radio
        //checkbox
        rootCheckbox: "sd-selectbase",
        checkboxItem: "sd-item sd-selectbase__item sd-checkbox",
        checkboxLabel: "sd-selectbase__label",
        checkboxItemOnError: "sd-item--error",
        checkboxItemIndeterminate: "sd-checkbox--intermediate",
        checkboxItemChecked: "sd-item--checked sd-checkbox--checked",
        checkboxItemDecorator: "sd-item__svg sd-checkbox__svg",
        checkboxItemDisabled: "sd-item--disabled sd-checkbox--disabled",
        checkboxItemReadOnly: "sd-item--readonly sd-checkbox--readonly",
        checkboxItemPreview: "sd-item--preview sd-checkbox--preview",
        controlCheckbox: "sd-visuallyhidden sd-item__control sd-checkbox__control",
        checkboxMaterialDecorator: "sd-item__decorator sd-checkbox__decorator",
        checkboxControlLabel: "sd-item__control-label",
        svgIconCheckedId: "#icon-check-16x16",
    },
    text: {
        root: "sd-input sd-text",
        small: "sd-row__question--small",
        controlDisabled: "sd-input--disabled",
        controlReadOnly: "sd-input--readonly",
        controlPreview: "sd-input--preview",
        constrolWithCharacterCounter: "sd-text__character-counter",
        characterCounterBig: "sd-text__character-counter--big",
        content: "sd-text__content sd-question__content",
        remainingCharacterCounter: "sd-remaining-character-counter",
        onError: "sd-input--error"
    },
    multipletext: {
        root: "sd-multipletext",
        rootMobile: "sd-multipletext--mobile",
        itemLabel: "sd-multipletext__item-container sd-input",
        itemLabelReadOnly: "sd-input--readonly",
        itemLabelDisabled: "sd-input--disabled",
        itemLabelPreview: "sd-input--preview",
        itemLabelOnError: "sd-multipletext__item-container--error",
        itemLabelAllowFocus: "sd-multipletext__item-container--allow-focus",
        itemLabelAnswered: "sd-multipletext__item-container--answered",
        itemWithCharacterCounter: "sd-multipletext-item__character-counter",
        item: "sd-multipletext__item",
        itemTitle: "sd-multipletext__item-title",
        content: "sd-multipletext__content sd-question__content",
        row: "sd-multipletext__row",
        cell: "sd-multipletext__cell",
        cellError: "sd-multipletext__cell--error",
        cellErrorTop: "sd-multipletext__cell--error-top",
        cellErrorBottom: "sd-multipletext__cell--error-bottom"
    },
    dropdown: {
        root: "sd-selectbase",
        popup: "sv-dropdown-popup",
        small: "sd-row__question--small",
        selectWrapper: "sv-dropdown_select-wrapper",
        other: "sd-input sd-comment sd-selectbase__other",
        onError: "sd-input--error",
        label: "sd-selectbase__label",
        itemEnter: "sd-item--enter",
        itemLeave: "sd-item--leave",
        item: "sd-item sd-radio sd-selectbase__item",
        itemDisabled: "sd-item--disabled sd-radio--disabled",
        itemChecked: "sd-item--checked sd-radio--checked",
        itemHover: "sd-item--allowhover sd-radio--allowhover",
        itemControl: "sd-visuallyhidden sd-item__control sd-radio__control",
        itemDecorator: "sd-item__svg sd-radio__svg",
        cleanButtonIconId: "icon-cancel",
        chevronButton: "sd-dropdown_chevron-button",
        chevronButtonSvg: "sd-dropdown_chevron-button-svg",
        chevronButtonIconId: "icon-chevron",
        control: "sd-input sd-dropdown",
        controlInputFieldComponent: "sd-dropdown__input-field-component",
        controlValue: "sd-dropdown__value",
        controlDisabled: "sd-input--disabled",
        controlReadOnly: "sd-input--readonly",
        controlPreview: "sd-input--preview",
        controlEmpty: "sd-dropdown--empty",
        controlLabel: "sd-item__control-label",
        filterStringInput: "sd-dropdown__filter-string-input",
        materialDecorator: "sd-item__decorator sd-radio__decorator",
        hintPrefix: "sd-dropdown__hint-prefix",
        hintSuffix: "sd-dropdown__hint-suffix"
    },
    imagepicker: {
        mainRoot: "sd-element sd-question sd-row__question",
        root: "sd-selectbase sd-imagepicker",
        rootResponsive: "sd-imagepicker--responsive",
        rootStatic: "sd-imagepicker--static",
        rootColumn: "sd-imagepicker--column",
        item: "sd-imagepicker__item",
        itemOnError: "sd-imagepicker__item--error",
        itemInline: "sd-imagepicker__item--inline",
        itemChecked: "sd-imagepicker__item--checked",
        itemDisabled: "sd-imagepicker__item--disabled",
        itemReadOnly: "sd-imagepicker__item--readonly",
        itemPreview: "sd-imagepicker__item--preview",
        itemHover: "sd-imagepicker__item--allowhover",
        label: "sd-imagepicker__label",
        itemDecorator: "sd-imagepicker__item-decorator",
        imageContainer: "sd-imagepicker__image-container",
        itemControl: "sd-imagepicker__control sd-visuallyhidden",
        image: "sd-imagepicker__image",
        itemText: "sd-imagepicker__text",
        other: "sd-input sd-comment",
        itemNoImage: "sd-imagepicker__no-image",
        itemNoImageSvgIcon: "sd-imagepicker__no-image-svg",
        itemNoImageSvgIconId: "icon-no-image",
        column: "sd-selectbase__column sd-imagepicker__column",
        checkedItemDecorator: "sd-imagepicker__check-decorator",
        checkedItemSvgIcon: "sd-imagepicker__check-icon",
        checkedItemSvgIconId: "icon-check-24x24",
    },
    matrix: {
        mainRoot: "sd-element sd-question sd-row__question sd-element--complex sd-question--complex sd-question--table",
        tableWrapper: "sd-matrix sd-table-wrapper",
        root: "sd-table sd-matrix__table",
        columnsAutoWidth: "sd-table--columnsautowidth",
        noHeader: "sd-table--no-header",
        rootVerticalAlignTop: "sd-table--align-top",
        rootVerticalAlignMiddle: "sd-table--align-middle",
        rootAlternateRows: "sd-table--alternate-rows",
        rowError: "sd-matrix__row--error",
        cell: "sd-table__cell sd-matrix__cell",
        row: "sd-table__row",
        rowDisabled: "sd-table__row-disabled",
        rowReadOnly: "sd-table__row-readonly",
        headerCell: "sd-table__cell sd-table__cell--header",
        rowTextCell: "sd-table__cell sd-matrix__cell sd-table__cell--row-text",
        label: "sd-item sd-radio sd-matrix__label",
        itemOnError: "sd-item--error",
        itemValue: "sd-visuallyhidden sd-item__control sd-radio__control",
        itemChecked: "sd-item--checked sd-radio--checked",
        itemDisabled: "sd-item--disabled sd-radio--disabled",
        itemReadOnly: "sd-item--readonly sd-radio--readonly",
        itemPreview: "sd-item--preview sd-radio--preview",
        itemPreviewSvgIconId: "#icon-check-16x16",
        itemHover: "sd-radio--allowhover",
        materialDecorator: "sd-item__decorator sd-radio__decorator",
        itemDecorator: "sd-item__svg sd-radio__svg",
        cellText: "sd-matrix__text",
        cellTextSelected: "sd-matrix__text--checked",
        cellTextDisabled: "sd-matrix__text--disabled",
        cellResponsiveTitle: "sd-matrix__responsive-title",
        compact: "sd-element--with-frame sd-element--compact"
    },
    matrixdropdown: {
        mainRoot: "sd-element sd-question sd-row__question sd-element--complex sd-question--complex sd-question--table",
        rootScroll: "sd-question--scroll",
        root: "sd-table sd-matrixdropdown",
        columnsAutoWidth: "sd-table--columnsautowidth",
        noHeader: "sd-table--no-header",
        hasFooter: "sd-table--has-footer",
        rootVerticalAlignTop: "sd-table--align-top",
        rootVerticalAlignMiddle: "sd-table--align-middle",
        tableWrapper: "sd-table-wrapper",
        rootAlternateRows: "sd-table--alternate-rows",
        cell: "sd-table__cell",
        cellResponsiveTitle: "sd-table__responsive-title",
        errorsCell: "sd-table__cell--error",
        errorsCellTop: "sd-table__cell--error-top",
        errorsCellBottom: "sd-table__cell--error-bottom",
        itemCell: "sd-table__cell--item",
        row: "sd-table__row",
        rowDelayedEnter: "sd-table__row--delayed-enter",
        rowEnter: "sd-table__row--enter",
        rowLeave: "sd-table__row--leave",
        expandedRow: "sd-table__row--expanded",
        rowHasPanel: "sd-table__row--has-panel",
        rowHasEndActions: "sd-table__row--has-end-actions",
        headerCell: "sd-table__cell sd-table__cell--header",
        rowTextCell: "sd-table__cell sd-table__cell--row-text",
        footerCell: "sd-table__cell sd-table__cell--footer",
        footerTotalCell: "sd-table__cell sd-table__cell--footer-total",
        columnTitleCell: "sd-table__cell--column-title",
        cellRequiredMark: "sd-question__required-text",
        detailButton: "sd-table__cell--detail-button",
        detailButtonExpanded: "sd-table__cell--detail-button--expanded",
        detailIcon: "sd-detail-panel__icon",
        detailIconExpanded: "sd-detail-panel__icon--expanded",
        detailIconId: "icon-expanddetail",
        detailIconExpandedId: "icon-collapsedetail",
        detailPanelCell: "sd-table__cell--detail-panel",
        detailRowCell: "sd-table__cell--detail",
        actionsCellPrefix: "sd-table__cell-action",
        actionsCell: "sd-table__cell sd-table__cell--actions",
        actionsCellDrag: "sd-table__cell--drag",
        emptyCell: "sd-table__cell--empty",
        verticalCell: "sd-table__cell--vertical",
        cellQuestionWrapper: "sd-matrix__question-wrapper sd-table__question-wrapper",
        compact: "sd-element--with-frame sd-element--compact"
    },
    matrixdynamic: {
        mainRoot: "sd-element sd-question sd-row__question sd-element--complex sd-question--complex sd-question--table",
        rootScroll: "sd-question--scroll",
        empty: "sd-question--empty",
        root: "sd-table sd-matrixdynamic",
        columnsAutoWidth: "sd-table--columnsautowidth",
        noHeader: "sd-table--no-header",
        hasFooter: "sd-table--has-footer",
        tableWrapper: "sd-table-wrapper",
        rootAlternateRows: "sd-table--alternate-rows",
        content: "sd-matrixdynamic__content sd-question__content",
        cell: "sd-table__cell",
        cellResponsiveTitle: "sd-table__responsive-title",
        row: "sd-table__row",
        rowEmpty: "sd-table__row--empty",
        rowDelayedEnter: "sd-table__row--delayed-enter",
        rowEnter: "sd-table__row--enter",
        rowLeave: "sd-table__row--leave",
        rowHasPanel: "sd-table__row--has-panel",
        rowHasEndActions: "sd-table__row--has-end-actions",
        expandedRow: "sd-table__row--expanded",
        itemCell: "sd-table__cell--item",
        headerCell: "sd-table__cell sd-table__cell--header",
        rowTextCell: "sd-table__cell sd-table__cell--row-text",
        footerCell: "sd-table__cell sd-table__cell--footer",
        columnTitleCell: "sd-table__cell--column-title",
        cellRequiredMark: "sd-question__required-text",
        button: "sd-action sd-matrixdynamic__btn",
        detailRow: "sd-table__row sd-table__row--detail",
        detailButton: "sd-table__cell--detail-button",
        detailButtonExpanded: "sd-table__cell--detail-button--expanded",
        detailIcon: "sd-detail-panel__icon",
        detailIconExpanded: "sd-detail-panel__icon--expanded",
        detailIconId: "icon-expanddetail",
        detailIconExpandedId: "icon-collapsedetail",
        detailPanelCell: "sd-table__cell--detail-panel",
        detailRowCell: "sd-table__cell--detail",
        actionsCellPrefix: "sd-table__cell-action",
        actionsCell: "sd-table__cell sd-table__cell--actions",
        actionsCellDrag: "sd-table__cell--drag",
        buttonAdd: "sd-matrixdynamic__add-btn",
        buttonRemove: "sd-action--negative sd-matrixdynamic__remove-btn",
        iconAdd: "sd-hidden",
        iconRemove: "",
        dragElementDecorator: "sd-drag-element__svg",
        iconDragElement: "#icon-drag-24x24",
        footer: "sd-matrixdynamic__footer",
        footerTotalCell: "sd-table__cell sd-table__cell--footer-total",
        noRowsSection: "sd-matrixdynamic__placeholder sd-question__placeholder",
        iconDrag: "sv-matrixdynamic__drag-icon",
        ghostRow: "sv-matrix-row--drag-drop-ghost-mod",
        draggedRow: "sv-matrixdynamic-dragged-row",
        emptyCell: "sd-table__cell--empty",
        verticalCell: "sd-table__cell--vertical",
        cellQuestionWrapper: "sd-matrix__question-wrapper sd-table__question-wrapper",
        errorsCell: "sd-table__cell--error",
        errorsCellTop: "sd-table__cell--error-top",
        errorsCellBottom: "sd-table__cell--error-bottom",
        compact: "sd-element--with-frame sd-element--compact",
    },
    rating: {
        rootDropdown: "sd-scrollable-container sd-scrollable-container--compact sd-selectbase",
        root: "sd-scrollable-container sd-rating",
        rootWrappable: "sd-rating--wrappable",
        rootLabelsTop: "sd-rating--labels-top",
        rootLabelsBottom: "sd-rating--labels-bottom",
        rootLabelsDiagonal: "sd-rating--labels-diagonal",
        item: "sd-rating__item",
        itemOnError: "sd-rating__item--error",
        itemHover: "sd-rating__item--allowhover",
        selected: "sd-rating__item--selected",
        itemStar: "sd-rating__item-star",
        itemStarOnError: "sd-rating__item-star--error",
        itemStarHover: "sd-rating__item-star--allowhover",
        itemStarSelected: "sd-rating__item-star--selected",
        itemStarDisabled: "sd-rating__item-star--disabled",
        itemStarReadOnly: "sd-rating__item-star--readonly",
        itemStarPreview: "sd-rating__item-star--preview",
        itemStarHighlighted: "sd-rating__item-star--highlighted",
        itemStarUnhighlighted: "sd-rating__item-star--unhighlighted",
        itemStarSmall: "sd-rating__item-star--small",
        itemSmiley: "sd-rating__item-smiley",
        itemSmileyOnError: "sd-rating__item-smiley--error",
        itemSmileyHover: "sd-rating__item-smiley--allowhover",
        itemSmileySelected: "sd-rating__item-smiley--selected",
        itemSmileyDisabled: "sd-rating__item-smiley--disabled",
        itemSmileyReadOnly: "sd-rating__item-smiley--readonly",
        itemSmileyPreview: "sd-rating__item-smiley--preview",
        itemSmileyHighlighted: "sd-rating__item-star--highlighted",
        itemSmileyScaleColored: "sd-rating__item-smiley--scale-colored",
        itemSmileyRateColored: "sd-rating__item-smiley--rate-colored",
        itemSmileySmall: "sd-rating__item-smiley--small",
        minText: "sd-rating__item-text sd-rating__min-text",
        itemText: "sd-rating__item-text",
        maxText: "sd-rating__item-text sd-rating__max-text",
        itemDisabled: "sd-rating__item--disabled",
        itemReadOnly: "sd-rating__item--readonly",
        itemPreview: "sd-rating__item--preview",
        itemFixedSize: "sd-rating__item--fixed-size",
        control: "sd-input sd-dropdown",
        itemSmall: "sd-rating--small",
        selectWrapper: "sv-dropdown_select-wrapper",
        controlValue: "sd-dropdown__value",
        controlDisabled: "sd-input--disabled",
        controlReadOnly: "sd-input--readonly",
        controlPreview: "sd-input--preview",
        controlEmpty: "sd-dropdown--empty",
        filterStringInput: "sd-dropdown__filter-string-input",
        chevronButtonIconId: "icon-chevron",
        popup: "sv-dropdown-popup",
        onError: "sd-input--error",
    },
    slider: {
        root: "sd-slider",
        rootSingleMode: "sd-slider--single",
        rootNegativeScaleMode: "sd-slider--negative-scale",
        rootDesignMode: "sd-slider--design-mode",
        rootAnimatedThumbMode: "sd-slider--animated-thumb-mode",
        visualContainer: "sd-slider-container",
        visualContainerSlider: "sd-slider-container__slider",
        rangeTrack: "sd-slider__track sd-slider__range-track",
        inverseTrackLeft: "sd-slider__track sd-slider__inverse-track sd-slider__inverse-track--left",
        inverseTrackRight: "sd-slider__track sd-slider__inverse-track sd-slider__inverse-track--right",
        thumbContainer: "sd-slider__thumb-container",
        thumbContainerIndeterminateMode: "sd-slider__thumb-container--indeterminate",
        thumbContainerFocusedMode: "sd-slider__thumb-container--focused",
        thumb: "sd-slider__thumb",
        thumbDot: "sd-slider__thumb-dot",
        tooltip: "sd-slider__tooltip",
        tooltipPanel: "sd-slider__tooltip-panel",
        tooltipOnHoverMode: "sd-slider__tooltip--on-hover",
        tooltipValue: "sd-slider__tooltip-value",
        input: "sd-slider__input",
        labelsContainer: "sd-slider-labels-container",
        label: "sd-slider__label",
        labelLongMod: "sd-slider__label--long",
        labelTick: "sd-slider__label-tick",
        labelText: "sd-slider__label-text",
        clearButton: "",
    },
    comment: {
        root: "sd-input sd-comment",
        small: "sd-row__question--small",
        controlDisabled: "sd-input--disabled",
        controlReadOnly: "sd-input--readonly",
        controlPreview: "sd-input--preview",
        content: "sd-comment__content sd-question__content",
        remainingCharacterCounter: "sd-remaining-character-counter",
        onError: "sd-input--error"
    },
    expression: "sd-expression",
    file: {
        root: "sd-file",
        rootDragging: "sd-file--dragging",
        rootAnswered: "sd-file--answered",
        rootDisabled: "sd-file--disabled",
        rootReadOnly: "sd-file--readonly",
        rootPreview: "sd-file--preview",
        other: "sd-input sd-comment",
        placeholderInput: "sd-visuallyhidden",
        previewItem: "sd-file__preview-item",
        fileSign: "",
        fileList: "sd-file__list",
        fileSignBottom: "sd-file__sign",
        dragArea: "sd-file__drag-area",
        dragAreaActive: "sd-file__drag-area--active",
        fileDecorator: "sd-file__decorator",
        onError: "sd-file__decorator--error",
        fileDecoratorDrag: "sd-file__decorator--drag",
        fileInput: "sd-visuallyhidden",
        chooseFile: "sd-file__choose-btn",
        chooseFileAsText: "sd-action sd-file__choose-btn--text",
        chooseFileAsTextDisabled: "sd-action--disabled",
        chooseFileAsIcon: "sd-file__choose-btn--icon",
        chooseFileIconId: "icon-choosefile",
        disabled: "sd-file__choose-btn--disabled",
        controlDisabled: "sd-file__choose-file-btn--disabled",
        //todo: remove it in v2
        removeButton: "sd-context-btn--negative",
        removeButtonBottom: "",
        //
        removeButtonIconId: "icon-clear",
        removeFile: "sd-hidden",
        removeFileSvg: "",
        removeFileSvgIconId: "icon-close_16x16",
        wrapper: "sd-file__wrapper",
        defaultImage: "sd-file__default-image",
        defaultImageIconId: "icon-defaultfile",
        leftIconId: "icon-arrowleft",
        rightIconId: "icon-arrowright",
        removeFileButton: "sd-context-btn--small sd-context-btn--with-border sd-context-btn--colorful sd-context-btn--negative sd-file__remove-file-button",
        dragAreaPlaceholder: "sd-file__drag-area-placeholder",
        imageWrapper: "sd-file__image-wrapper",
        imageWrapperDefaultImage: "sd-file__image-wrapper--default-image",
        single: "sd-file--single",
        singleImage: "sd-file--single-image",
        mobile: "sd-file--mobile",
        videoContainer: "sd-file__video-container",
        contextButton: "sd-context-btn",
        video: "sd-file__video",
        actionsContainer: "sd-file__actions-container",
        closeCameraButton: "sd-file__close-camera-button",
        changeCameraButton: "sd-file__change-camera-button",
        takePictureButton: "sd-file__take-picture-button",
        loadingIndicator: "sd-file__loading-indicator",
        page: "sd-file__page"
    },
    signaturepad: {
        mainRoot: "sd-element sd-question sd-question--signature sd-row__question",
        root: "sd-signaturepad sjs_sp_container",
        small: "sd-row__question--small",
        controls: "sjs_sp_controls sd-signaturepad__controls",
        placeholder: "sjs_sp_placeholder",
        canvas: "sjs_sp_canvas sd-signaturepad__canvas",
        backgroundImage: "sjs_sp__background-image sd-signaturepad__background-image",
        clearButton: "sjs_sp_clear sd-context-btn sd-context-btn--negative sd-signaturepad__clear",
        clearButtonIconId: "icon-clear",
        loadingIndicator: "sd-signaturepad__loading-indicator"
    },
    saveData: {
        root: "sv-save-data_root",
        rootWithButtons: "sv-save-data_root--with-buttons",
        info: "sv-save-data_info",
        error: "sv-save-data_error",
        success: "sv-save-data_success",
        button: "sv-save-data_button",
        shown: "sv-save-data_root--shown"
    },
    window: {
        root: "sv_window",
        rootCollapsedMod: "sv_window--collapsed",
        rootFullScreenMode: "sv_window--full-screen",
        rootContent: "sv_window_root-content",
        body: "sv_window_content",
        header: {
            root: "sv_window_header",
            titleCollapsed: "sv_window_header_title_collapsed",
            buttonsContainer: "sv_window_buttons_container",
            button: "sv_window_button",
            buttonExpanded: "",
            buttonCollapsed: "",
            collapseButton: "sv_window_button sv_window_button_collapse",
            closeButton: "sv_window_button sv_window_button_close",
            fullScreenButton: "sv_window_button sv_window_button_full_screen"
        }
    },
    ranking: {
        root: "sv-ranking",
        rootMobileMod: "sv-ranking--mobile",
        rootDragMod: "sv-ranking--drag",
        rootDisabled: "sd-ranking--disabled",
        rootReadOnly: "sd-ranking--readonly",
        rootPreview: "sd-ranking--preview",
        rootDesignMode: "sv-ranking--design-mode",
        rootDragHandleAreaIcon: "sv-ranking--drag-handle-area-icon",
        rootSelectToRankMod: "sv-ranking--select-to-rank",
        rootSelectToRankEmptyValueMod: "sv-ranking--select-to-rank-empty-value",
        rootSelectToRankAlignVertical: "sv-ranking--select-to-rank-vertical",
        rootSelectToRankAlignHorizontal: "sv-ranking--select-to-rank-horizontal",
        rootSelectToRankSwapAreas: "sv-ranking--select-to-rank-swap-areas",
        item: "sv-ranking-item",
        itemContent: "sv-ranking-item__content sd-ranking-item__content",
        itemIndex: "sv-ranking-item__index sd-ranking-item__index",
        itemIndexEmptyMode: "sv-ranking-item__index--empty sd-ranking-item__index--empty",
        // itemText: "sv-ranking-item__text",
        itemDisabled: "sv-ranking-item--disabled",
        itemReadOnly: "sv-ranking-item--readonly",
        itemPreview: "sv-ranking-item--preview",
        controlLabel: "sv-ranking-item__text",
        itemGhostNode: "sv-ranking-item__ghost",
        itemIconContainer: "sv-ranking-item__icon-container",
        itemIcon: "sv-ranking-item__icon",
        itemIconHoverMod: "sv-ranking-item__icon--hover",
        itemIconFocusMod: "sv-ranking-item__icon--focus",
        itemGhostMod: "sv-ranking-item--ghost",
        itemDragMod: "sv-ranking--drag",
        itemOnError: "sv-ranking-item--error",
        container: "sv-ranking__container",
        containerEmptyMode: "sv-ranking__container--empty",
        containerFromMode: "sv-ranking__container--from",
        containerToMode: "sv-ranking__container--to",
        containerPlaceholder: "sv-ranking__container-placeholder",
        containersDivider: "sv-ranking__containers-divider",
    },
    buttongroup: {
        root: "sd-button-group-scrollable-container sv-button-group",
        item: "sv-button-group__item",
        itemIcon: "sv-button-group__item-icon",
        itemDecorator: "sv-button-group__item-decorator",
        itemCaption: "sv-button-group__item-caption",
        itemHover: "sv-button-group__item--hover",
        itemSelected: "sv-button-group__item--selected",
        itemDisabled: "sv-button-group__item--disabled",
        itemControl: "sv-visuallyhidden",
        rootDropdown: "sd-button-group-scrollable-container sd-scrollable-container--compact sd-selectbase",
        selectWrapper: "sv-dropdown_select-wrapper",
        control: "sd-input sd-dropdown",
        controlEmpty: "sd-dropdown--empty",
        controlValue: "sd-dropdown__value",
        controlDisabled: "sd-input--disabled",
        controlReadOnly: "sd-input--readonly",
        controlPreview: "sd-input--preview",
        controlLabel: "sd-item__control-label",
        filterStringInput: "sd-dropdown__filter-string-input",
        chevronButtonIconId: "icon-chevron",
        popup: "sv-dropdown-popup",
        cleanButtonIconId: "icon-cancel",
        hintPrefix: "sd-dropdown__hint-prefix",
        hintSuffix: "sd-dropdown__hint-suffix"
    },
    list: {
        root: "sv-list__container sd-list",
        item: "sv-list__item sd-list__item",
        itemBody: "sv-list__item-body sd-list__item-body",
        itemSelected: "sv-list__item--selected sd-list__item--selected",
        itemFocused: "sv-list__item--focused sd-list__item--focused",
        itemHovered: "sv-list__item--hovered sd-list__item--hovered",
    },
    actionBar: {
        root: "sd-action-bar",
        item: "sd-action",
        defaultSizeMode: "",
        smallSizeMode: "",
        itemPressed: "sd-action--pressed",
        itemAsIcon: "sd-action--icon",
        itemIcon: "sd-action__icon",
        itemTitle: "sd-action__title",
    },
    variables: {
        mobileWidth: "--sd-mobile-width",
        themeMark: "--sv-defaultV2-mark"
    },
    tagbox: {
        root: "sd-selectbase",
        popup: "sv-dropdown-popup",
        small: "sd-row__question--small",
        selectWrapper: "sv-dropdown_select-wrapper",
        other: "sd-input sd-comment sd-selectbase__other",
        onError: "sd-input--error",
        label: "sd-selectbase__label",
        itemSvgIconId: "#icon-check-16x16",
        item: "sd-item sd-checkbox sd-selectbase__item",
        itemDisabled: "sd-item--disabled sd-checkbox--disabled",
        itemChecked: "sd-item--checked sd-checkbox--checked",
        itemHover: "sd-item--allowhover sd-checkbox--allowhover",
        itemControl: "sd-visuallyhidden sd-item__control sd-checkbox__control",
        itemDecorator: "sd-item__svg sd-checkbox__svg",
        itemEnter: "sd-item--enter",
        itemLeave: "sd-item--leave",
        // cleanButton: "sd-tagbox_clean-button sd-editor-clean-button",
        cleanButtonIconId: "icon-cancel-24x24",
        cleanItemButton: "sd-tagbox-item_clean-button",
        cleanItemButtonSvg: "sd-tagbox-item_clean-button-svg",
        cleanItemButtonIconId: "icon-clear_16x16",
        chevronButtonIconId: "icon-chevron",
        control: "sd-input sd-tagbox sd-dropdown",
        controlValue: "sd-tagbox__value sd-dropdown__value",
        controlValueItems: "sd-tagbox__value-items",
        placeholderInput: "sd-tagbox__placeholder",
        controlEditable: "sd-input--editable",
        controlDisabled: "sd-input--disabled",
        controlReadOnly: "sd-input--readonly",
        controlPreview: "sd-input--preview",
        controlEmpty: "sd-dropdown--empty sd-tagbox--empty",
        controlLabel: "sd-item__control-label",
        filterStringInput: "sd-tagbox__filter-string-input sd-dropdown__filter-string-input",
        materialDecorator: "sd-item__decorator sd-checkbox__decorator",
        hint: "sd-tagbox__hint",
        hintPrefix: "sd-dropdown__hint-prefix sd-tagbox__hint-prefix",
        hintSuffix: "sd-dropdown__hint-suffix sd-tagbox__hint-suffix",
        hintSuffixWrapper: "sd-tagbox__hint-suffix-wrapper"
    },
};
const defaultThemeName = "default";
surveyCss[defaultThemeName] = defaultCss;

var surveyTimerFunctions = {
    setTimeout: (func) => {
        return surveyTimerFunctions.safeTimeOut(func, 1000);
    },
    clearTimeout: (timerId) => {
        clearTimeout(timerId);
    },
    safeTimeOut: (func, delay) => {
        if (delay <= 0) {
            func();
            return 0;
        }
        else {
            return setTimeout(func, delay);
        }
    },
    now() { return Date.now(); }
};
class SurveyTimer {
    constructor() {
        this.listenerCounter = 0;
        this.timerId = -1;
        this.onTimerTick = new EventBase();
        this.onTimer = this.onTimerTick;
    }
    static get instance() {
        if (!SurveyTimer.instanceValue) {
            SurveyTimer.instanceValue = new SurveyTimer();
        }
        return SurveyTimer.instanceValue;
    }
    start(func = null) {
        if (func) {
            this.onTimerTick.add(func);
        }
        this.prevTimeInMs = surveyTimerFunctions.now();
        if (this.timerId < 0) {
            this.timerId = surveyTimerFunctions.setTimeout(() => {
                this.doTimer();
            });
        }
        this.listenerCounter++;
    }
    stop(func = null) {
        if (func) {
            this.onTimerTick.remove(func);
        }
        this.listenerCounter--;
        if (this.listenerCounter == 0 && this.timerId > -1) {
            surveyTimerFunctions.clearTimeout(this.timerId);
            this.timerId = -1;
        }
    }
    doTimer() {
        if (this.onTimerTick.isEmpty || this.listenerCounter == 0) {
            this.timerId = -1;
        }
        if (this.timerId < 0)
            return;
        const newTimer = surveyTimerFunctions.now();
        let seconds = Math.floor((newTimer - this.prevTimeInMs) / 1000);
        this.prevTimeInMs = newTimer;
        if (seconds < 0) {
            seconds = 1;
        }
        const prevItem = this.timerId;
        this.onTimerTick.fire(this, { seconds: seconds });
        //We have to check that we have the same timerId
        //It could be changed during events execution and it will lead to double timer events
        if (prevItem !== this.timerId)
            return;
        this.timerId = surveyTimerFunctions.setTimeout(() => {
            this.doTimer();
        });
    }
}
SurveyTimer.instanceValue = null;

class SurveyTimerModel extends Base {
    constructor(survey) {
        super();
        this.timerFunc = null;
        this.surveyValue = survey;
        this.onCreating();
    }
    get survey() { return this.surveyValue; }
    onCreating() { }
    start() {
        if (!this.survey)
            return;
        if (this.isRunning || this.isDesignMode)
            return;
        this.survey.onCurrentPageChanged.add(() => {
            this.update();
        });
        this.timerFunc = (sender, options) => { this.doTimer(options.seconds); };
        this.setIsRunning(true);
        this.update();
        SurveyTimer.instance.start(this.timerFunc);
    }
    stop() {
        if (!this.isRunning)
            return;
        this.setIsRunning(false);
        SurveyTimer.instance.stop(this.timerFunc);
    }
    get isRunning() {
        return this.getPropertyValue("isRunning", false);
    }
    setIsRunning(val) {
        this.setPropertyValue("isRunning", val);
    }
    update() {
        this.updateText();
        this.updateProgress();
    }
    doTimer(seconds) {
        var page = this.survey.currentPage;
        if (page) {
            const pageMaxTime = page.getMaxTimeToFinish();
            if (pageMaxTime > 0 && pageMaxTime < page.timeSpent + seconds) {
                seconds = pageMaxTime - page.timeSpent;
            }
            page.timeSpent = page.timeSpent + seconds;
        }
        this.spent = this.spent + seconds;
        this.update();
        if (this.onTimerTick) {
            this.onTimerTick(page);
        }
    }
    updateProgress() {
        let { spent, limit } = this.survey.timerInfo;
        if (!limit) {
            this.progress = undefined;
        }
        else {
            if (spent == 0) {
                this.progress = 0;
                setTimeout(() => {
                    this.progress = Math.floor((spent + 1) / limit * 100) / 100;
                }, 0);
            }
            else if (spent <= limit) {
                this.progress = Math.floor((spent + 1) / limit * 100) / 100;
            }
            if (this.progress > 1) {
                this.progress = undefined;
            }
        }
    }
    updateText() {
        let timerClock = this.survey.timerClock;
        this.clockMajorText = timerClock.majorText;
        this.clockMinorText = timerClock.minorText;
        this.text = this.survey.timerInfoText;
    }
    get showProgress() {
        return this.progress !== undefined;
    }
    get showTimerAsClock() {
        return !!this.survey.getCss().clockTimerRoot;
    }
    get rootCss() {
        return new CssClassBuilder()
            .append(this.survey.getCss().clockTimerRoot)
            .append(this.survey.getCss().clockTimerRootTop, this.survey.isTimerPanelShowingOnTop)
            .append(this.survey.getCss().clockTimerRootBottom, this.survey.isTimerPanelShowingOnBottom)
            .toString();
    }
    getProgressCss() {
        return new CssClassBuilder()
            .append(this.survey.getCss().clockTimerProgress)
            .append(this.survey.getCss().clockTimerProgressAnimation, this.progress > 0)
            .toString();
    }
    get textContainerCss() {
        return this.survey.getCss().clockTimerTextContainer;
    }
    get minorTextCss() {
        return this.survey.getCss().clockTimerMinorText;
    }
    get majorTextCss() {
        return this.survey.getCss().clockTimerMajorText;
    }
}
__decorate([
    property()
], SurveyTimerModel.prototype, "text", void 0);
__decorate([
    property()
], SurveyTimerModel.prototype, "progress", void 0);
__decorate([
    property()
], SurveyTimerModel.prototype, "clockMajorText", void 0);
__decorate([
    property()
], SurveyTimerModel.prototype, "clockMinorText", void 0);
__decorate([
    property({ defaultValue: 0 })
], SurveyTimerModel.prototype, "spent", void 0);

class Notifier extends Base {
    constructor(cssClasses) {
        super();
        this.cssClasses = cssClasses;
        this.timeout = settings.notifications.lifetime;
        this.timer = undefined;
        this.actionsVisibility = {};
        this.showActions = true;
        this.actionBar = new ActionContainer();
        this.actionBar.updateCallback = (isResetInitialized) => {
            this.actionBar.actions.forEach(action => action.cssClasses = {});
        };
        this.css = this.cssClasses.root;
    }
    getCssClass(type) {
        return new CssClassBuilder()
            .append(this.cssClasses.root)
            .append(this.cssClasses.rootWithButtons, this.actionBar.visibleActions.length > 0)
            .append(this.cssClasses.info, type !== "error" && type !== "success")
            .append(this.cssClasses.error, type === "error")
            .append(this.cssClasses.success, type === "success")
            .append(this.cssClasses.shown, this.active)
            .toString();
    }
    updateActionsVisibility(type) {
        this.actionBar.actions.forEach(action => action.visible = this.showActions && (this.actionsVisibility[action.id] === type));
    }
    notify(message, type = "info", waitUserAction = false) {
        this.isDisplayed = true;
        setTimeout(() => {
            this.updateActionsVisibility(type);
            this.message = message;
            this.active = true;
            this.css = this.getCssClass(type);
            if (!!this.timer) {
                clearTimeout(this.timer);
                this.timer = undefined;
            }
            if (!waitUserAction) {
                this.timer = setTimeout(() => {
                    this.timer = undefined;
                    this.active = false;
                    this.css = this.getCssClass(type);
                }, this.timeout);
            }
        }, 1);
    }
    addAction(action, notificationType) {
        action.visible = false;
        action.innerCss = this.cssClasses.button;
        const res = this.actionBar.addAction(action);
        this.actionsVisibility[res.id] = notificationType;
    }
}
__decorate([
    property({ defaultValue: false })
], Notifier.prototype, "active", void 0);
__decorate([
    property({ defaultValue: false })
], Notifier.prototype, "isDisplayed", void 0);
__decorate([
    property()
], Notifier.prototype, "message", void 0);
__decorate([
    property()
], Notifier.prototype, "css", void 0);

class CoverCell {
    calcRow(positionY) {
        return positionY === "top" ? 1 : (positionY === "middle" ? 2 : 3);
    }
    calcColumn(positionX) {
        return positionX === "left" ? 1 : (positionX === "center" ? 2 : 3);
    }
    calcAlignItems(positionX) {
        return positionX === "left" ? "flex-start" : (positionX === "center" ? "center" : "flex-end");
    }
    calcAlignText(positionX) {
        return positionX === "left" ? "start" : (positionX === "center" ? "center" : "end");
    }
    calcJustifyContent(positionY) {
        return positionY === "top" ? "flex-start" : (positionY === "middle" ? "center" : "flex-end");
    }
    calcGridRow() {
        const rowNumber = this.calcRow(this.positionY);
        if (!!this.cover.renderedHeight)
            return rowNumber;
        const visibleRows = this.cover.getVisibleRows();
        const visibleRowIndex = visibleRows.indexOf(rowNumber);
        if (visibleRowIndex === -1)
            return 0;
        const visibleRowsCount = visibleRows.length;
        if (visibleRowsCount === 3)
            return rowNumber;
        if (visibleRowsCount === 1)
            return 1;
        return visibleRowIndex + 1;
    }
    constructor(cover, positionX, positionY) {
        this.cover = cover;
        this.positionX = positionX;
        this.positionY = positionY;
    }
    get survey() {
        return this.cover.survey;
    }
    get css() {
        const result = new CssClassBuilder()
            .append(CoverCell.CLASSNAME)
            .append(`${CoverCell.CLASSNAME}--${this.positionX}`)
            .append(`${CoverCell.CLASSNAME}--${this.positionY}`)
            .append(CoverCell.CLASSNAME + "--empty", this.isEmpty)
            .toString();
        return result;
    }
    get style() {
        const gridRow = this.calcGridRow();
        const result = {};
        result["gridRow"] = gridRow;
        result["gridColumn"] = gridRow !== 0 ? this.calcColumn(this.positionX) : 0;
        result["width"] = !!this.width ? this.width + "px" : undefined;
        if (gridRow === 0) {
            result["display"] = "none";
        }
        return result;
    }
    get contentStyle() {
        const result = {};
        result["textAlign"] = this.calcAlignText(this.positionX);
        result["alignItems"] = this.calcAlignItems(this.positionX);
        result["justifyContent"] = this.calcJustifyContent(this.positionY);
        result["maxWidth"] = this.contentMaxWidth;
        return result;
    }
    get showLogo() {
        return this.survey.hasLogo && this.positionX === this.cover.logoPositionX && this.positionY === this.cover.logoPositionY;
    }
    get showTitle() {
        return this.survey.hasTitle && this.positionX === this.cover.titlePositionX && this.positionY === this.cover.titlePositionY;
    }
    get showDescription() {
        return this.survey.renderedHasDescription && this.positionX === this.cover.descriptionPositionX && this.positionY === this.cover.descriptionPositionY;
    }
    get isEmpty() {
        return !this.showLogo && !this.showTitle && !this.showDescription;
    }
    get textAreaWidth() {
        return this.cover.renderedTextAreaWidth;
    }
    get width() {
        if (this.cover.width) {
            return Math.ceil(this.cover.width / 3);
        }
        return undefined;
    }
    get contentMaxWidth() {
        return this.cover.getContentMaxWidth(this);
    }
}
CoverCell.CLASSNAME = "sv-header__cell";
class Cover extends Base {
    calcBackgroundSize(backgroundImageFit) {
        if (backgroundImageFit === "fill") {
            return "100% 100%";
        }
        if (backgroundImageFit === "tile") {
            return "auto";
        }
        return backgroundImageFit;
    }
    updateHeaderClasses() {
        const backgroundColorNone = !this.backgroundColor || this.backgroundColor === "transparent";
        const backgroundColorAccent = this.backgroundColor === "var(--sjs-primary-backcolor)";
        const backgroundColorCustom = !backgroundColorNone && !backgroundColorAccent;
        this.headerClasses = new CssClassBuilder()
            .append("sv-header")
            .append("sv-header--height-auto", !this.renderedHeight)
            .append("sv-header__without-background", backgroundColorNone && !this.backgroundImage)
            .append("sv-header__background-color--none", backgroundColorNone && !this.titleColor && !this.descriptionColor)
            .append("sv-header__background-color--accent", backgroundColorAccent && !this.titleColor && !this.descriptionColor)
            .append("sv-header__background-color--custom", backgroundColorCustom && !this.titleColor && !this.descriptionColor)
            .append("sv-header__overlap", this.overlapEnabled)
            .toString();
    }
    updateContentClasses() {
        const surveyWidthMode = !!this.survey && this.survey.calculateWidthMode();
        this.maxWidth = this.inheritWidthFrom === "survey" && !!surveyWidthMode && surveyWidthMode === "static" && this.survey.width;
        if (!!this.maxWidth) {
            const maxWidthString = this.maxWidth.toString();
            if (maxWidthString.indexOf("px") === -1 && maxWidthString.indexOf("%") === -1) {
                this.maxWidth = parseFloat(maxWidthString) + "px";
            }
        }
        this.contentClasses = new CssClassBuilder()
            .append("sv-header__content")
            .append("sv-header__content--static", this.inheritWidthFrom === "survey" && !!surveyWidthMode && surveyWidthMode === "static")
            .append("sv-header__content--responsive", this.inheritWidthFrom === "container" || (!!surveyWidthMode && surveyWidthMode === "responsive"))
            .toString();
    }
    updateBackgroundImageClasses() {
        this.backgroundImageClasses = new CssClassBuilder()
            .append("sv-header__background-image")
            .append("sv-header__background-image--contain", this.backgroundImageFit === "contain")
            .append("sv-header__background-image--tile", this.backgroundImageFit === "tile")
            .toString();
    }
    fromTheme(theme) {
        super.fromJSON(theme.header || {});
        if (!!theme.cssVariables) {
            this.backgroundColor = theme.cssVariables["--sjs-header-backcolor"];
            this.titleColor = theme.cssVariables["--sjs-font-headertitle-color"];
            this.descriptionColor = theme.cssVariables["--sjs-font-headerdescription-color"];
        }
        this.init();
    }
    init() {
        this.renderBackgroundImage = wrapUrlForBackgroundImage(this.backgroundImage);
        this.updateHeaderClasses();
        this.updateContentClasses();
        this.updateBackgroundImageClasses();
    }
    constructor() {
        super();
        this.cells = [];
        ["top", "middle", "bottom"].forEach((positionY) => ["left", "center", "right"].forEach((positionX) => this.cells.push(new CoverCell(this, positionX, positionY))));
        this.init();
    }
    getType() {
        return "cover";
    }
    get renderedHeight() {
        if (this.survey && !this.survey.isMobile || !this.survey) {
            return this.height ? this.height + "px" : undefined;
        }
        if (this.survey && this.survey.isMobile) {
            return this.mobileHeight ? this.mobileHeight + "px" : undefined;
        }
        return undefined;
    }
    get renderedTextAreaWidth() {
        return this.textAreaWidth ? this.textAreaWidth + "px" : undefined;
    }
    get isEmpty() {
        return !this.survey.hasLogo && !this.survey.hasTitle && !this.survey.renderedHasDescription;
    }
    get survey() {
        return this._survey;
    }
    set survey(newValue) {
        if (this._survey === newValue)
            return;
        this._survey = newValue;
        if (!!newValue) {
            this.updateContentClasses();
            this._survey.onPropertyChanged.add((sender, options) => {
                if (options.name == "widthMode" || options.name == "width") {
                    this.updateContentClasses();
                }
            });
        }
    }
    get backgroundImageStyle() {
        if (!this.backgroundImage)
            return null;
        return {
            opacity: this.backgroundImageOpacity,
            backgroundImage: this.renderBackgroundImage,
            backgroundSize: this.calcBackgroundSize(this.backgroundImageFit),
        };
    }
    propertyValueChanged(name, oldValue, newValue, arrayChanges, target) {
        super.propertyValueChanged(name, oldValue, newValue);
        if (name === "height" || name === "backgroundColor" || name === "backgroundImage" || name === "overlapEnabled") {
            this.updateHeaderClasses();
        }
        if (name === "inheritWidthFrom") {
            this.updateContentClasses();
        }
        if (name === "backgroundImageFit") {
            this.updateBackgroundImageClasses();
        }
    }
    getVisibleRows() {
        const result = [];
        for (let rowIndex = 0; rowIndex < 3; rowIndex++) {
            const startCellIndex = rowIndex * 3;
            if (!this.cells[startCellIndex].isEmpty || !this.cells[startCellIndex + 1].isEmpty || !this.cells[startCellIndex + 2].isEmpty) {
                result.push(rowIndex + 1);
            }
        }
        return result.length !== 0 ? result : [1, 2, 3];
    }
    // public calculateActualHeight(logoHeight: number, titleHeight: number, descriptionHeight: number): number {
    //   const positionsY = ["top", "middle", "bottom"];
    //   const logoIndex = positionsY.indexOf(this.logoPositionY);
    //   const titleIndex = positionsY.indexOf(this.titlePositionY);
    //   const descriptionIndex = positionsY.indexOf(this.descriptionPositionY);
    //   const positionsX = ["left", "center", "right"];
    //   const logoIndexX = positionsX.indexOf(this.logoPositionX);
    //   const titleIndexX = positionsX.indexOf(this.titlePositionX);
    //   const descriptionIndexX = positionsX.indexOf(this.descriptionPositionX);
    //   const heights = [
    //     [0, 0, 0],
    //     [0, 0, 0],
    //     [0, 0, 0]
    //   ];
    //   heights[logoIndex][logoIndexX] = logoHeight;
    //   heights[titleIndex][titleIndexX] += titleHeight;
    //   heights[descriptionIndex][descriptionIndexX] += descriptionHeight;
    //   return heights.reduce((total, rowArr) => total + Math.max(...rowArr), 0);
    // }
    getContentMaxWidth(cell) {
        if (cell.isEmpty || cell.showLogo) {
            return undefined;
        }
        const cellIndex = this.cells.indexOf(cell);
        const rowIndex = Math.floor(cellIndex / 3);
        const colIndex = cellIndex % 3;
        if (colIndex == 1) {
            if (!this.cells[rowIndex * 3].isEmpty || !this.cells[rowIndex * 3 + 2].isEmpty) {
                return "100%";
            }
        }
        else if (colIndex == 0) {
            let rightFreeCells = 0;
            let index = colIndex + 1;
            while (index < 3 && this.cells[rowIndex * 3 + index].isEmpty) {
                if (this.cells[rowIndex * 3 + index].isEmpty) {
                    rightFreeCells++;
                }
                index++;
            }
            return (100 * (rightFreeCells + 1)) + "%";
        }
        else if (colIndex == 2) {
            let leftFreeCells = 0;
            let index = colIndex - 1;
            while (index > 0 && this.cells[rowIndex * 3 + index].isEmpty) {
                if (this.cells[rowIndex * 3 + index].isEmpty) {
                    leftFreeCells++;
                }
                index--;
            }
            return (100 * (leftFreeCells + 1)) + "%";
        }
        return undefined;
    }
    processResponsiveness() {
        if (this.survey && this.survey.rootElement) {
            if (!this.survey.isMobile) {
                const headerEl = this.survey.rootElement.querySelectorAll(".sv-header__content")[0];
                if (!headerEl)
                    return;
                let elWidth = headerEl.getBoundingClientRect().width;
                const headerComputedStyle = DomDocumentHelper.getComputedStyle(headerEl);
                const paddingLeft = (parseFloat(headerComputedStyle.paddingLeft) || 0);
                const paddingRight = (parseFloat(headerComputedStyle.paddingRight) || 0);
                const columnGap = (parseFloat(headerComputedStyle.columnGap) || 0);
                this.width = elWidth - paddingLeft - paddingRight - 2 * columnGap;
            }
        }
    }
    get hasBackground() {
        return !!this.backgroundImage || this.backgroundColor !== "transparent";
    }
}
__decorate([
    property()
], Cover.prototype, "height", void 0);
__decorate([
    property()
], Cover.prototype, "mobileHeight", void 0);
__decorate([
    property()
], Cover.prototype, "inheritWidthFrom", void 0);
__decorate([
    property()
], Cover.prototype, "textAreaWidth", void 0);
__decorate([
    property()
], Cover.prototype, "textGlowEnabled", void 0);
__decorate([
    property()
], Cover.prototype, "overlapEnabled", void 0);
__decorate([
    property({ defaultValue: "transparent" })
], Cover.prototype, "backgroundColor", void 0);
__decorate([
    property()
], Cover.prototype, "titleColor", void 0);
__decorate([
    property()
], Cover.prototype, "descriptionColor", void 0);
__decorate([
    property({
        onSet: (newVal, target) => {
            target.renderBackgroundImage = wrapUrlForBackgroundImage(newVal);
        }
    })
], Cover.prototype, "backgroundImage", void 0);
__decorate([
    property()
], Cover.prototype, "renderBackgroundImage", void 0);
__decorate([
    property()
], Cover.prototype, "backgroundImageFit", void 0);
__decorate([
    property()
], Cover.prototype, "backgroundImageOpacity", void 0);
__decorate([
    property()
], Cover.prototype, "logoPositionX", void 0);
__decorate([
    property()
], Cover.prototype, "logoPositionY", void 0);
__decorate([
    property()
], Cover.prototype, "titlePositionX", void 0);
__decorate([
    property()
], Cover.prototype, "titlePositionY", void 0);
__decorate([
    property()
], Cover.prototype, "descriptionPositionX", void 0);
__decorate([
    property()
], Cover.prototype, "descriptionPositionY", void 0);
__decorate([
    property()
], Cover.prototype, "logoStyle", void 0);
__decorate([
    property()
], Cover.prototype, "titleStyle", void 0);
__decorate([
    property()
], Cover.prototype, "descriptionStyle", void 0);
__decorate([
    property()
], Cover.prototype, "headerClasses", void 0);
__decorate([
    property()
], Cover.prototype, "contentClasses", void 0);
__decorate([
    property()
], Cover.prototype, "width", void 0);
__decorate([
    property()
], Cover.prototype, "maxWidth", void 0);
__decorate([
    property()
], Cover.prototype, "backgroundImageClasses", void 0);
Serializer.addClass("cover", [
    { name: "height:number", minValue: 0, default: 0 },
    { name: "mobileHeight:number", minValue: 0, default: 0 },
    { name: "inheritWidthFrom", default: "survey" },
    { name: "textAreaWidth:number", minValue: 0, default: 0 },
    { name: "textGlowEnabled:boolean" },
    { name: "overlapEnabled:boolean" },
    { name: "backgroundImage:file" },
    { name: "backgroundImageOpacity:number", minValue: 0, maxValue: 1, default: 1 },
    { name: "backgroundImageFit", default: "cover", choices: ["cover", "fill", "contain"] },
    { name: "logoPositionX", default: "left" },
    { name: "logoPositionY", default: "top" },
    { name: "titlePositionX", default: "left" },
    { name: "titlePositionY", default: "bottom" },
    { name: "descriptionPositionX", default: "left" },
    { name: "descriptionPositionY", default: "bottom" }
], function () {
    return new Cover();
});

class SurveyTaskModel {
    constructor(type) {
        this.type = type;
        this.timestamp = new Date();
    }
}
class SurveyTaskManagerModel extends Base {
    constructor() {
        super();
        this.taskList = [];
        this.onAllTasksCompleted = this.addEvent();
    }
    runTask(type, func) {
        const task = new SurveyTaskModel(type);
        this.taskList.push(task);
        this.hasActiveTasks = true;
        func(() => this.taskFinished(task));
        return task;
    }
    waitAndExecute(action) {
        if (!this.hasActiveTasks) {
            action();
            return;
        }
        this.onAllTasksCompleted.add(() => { action(); });
    }
    taskFinished(task) {
        const index = this.taskList.indexOf(task);
        if (index > -1) {
            this.taskList.splice(index, 1);
        }
        if (this.hasActiveTasks && this.taskList.length == 0) {
            this.hasActiveTasks = false;
            this.onAllTasksCompleted.fire(this, {});
        }
    }
}
__decorate([
    property({ defaultValue: false })
], SurveyTaskManagerModel.prototype, "hasActiveTasks", void 0);

class PanelLayoutColumnModel extends Base {
    constructor(width, questionTitleWidth) {
        super();
        this.effectiveWidth = width;
        this.questionTitleWidth = questionTitleWidth;
    }
    getType() {
        return "panellayoutcolumn";
    }
    isEmpty() {
        return !this.width && !this.questionTitleWidth;
    }
}
__decorate([
    property()
], PanelLayoutColumnModel.prototype, "width", void 0);
__decorate([
    property({
        onSet: (newValue, target, prevVal) => {
            if (newValue !== prevVal) {
                target.width = newValue;
            }
        }
    })
], PanelLayoutColumnModel.prototype, "effectiveWidth", void 0);
__decorate([
    property()
], PanelLayoutColumnModel.prototype, "questionTitleWidth", void 0);
Serializer.addClass("panellayoutcolumn", [
    { name: "effectiveWidth:number", isSerializable: false, minValue: 0 },
    { name: "width:number", visible: false },
    "questionTitleWidth",
], (value) => new PanelLayoutColumnModel());

class QuestionRowModel extends Base {
    static getRowId() {
        return "pr_" + QuestionRowModel.rowCounter++;
    }
    get allowRendering() {
        return !this.panel || !this.panel.survey || !this.panel.survey["isLazyRenderingSuspended"];
    }
    startLazyRendering(rowContainerDiv, findScrollableContainer = findScrollableParent) {
        if (!DomDocumentHelper.isAvailable())
            return;
        this._scrollableParent = findScrollableContainer(rowContainerDiv);
        // if  this._scrollableParent is html the scroll event isn't fired, so we should use window
        if (this._scrollableParent === DomDocumentHelper.getDocumentElement()) {
            this._scrollableParent = DomWindowHelper.getWindow();
        }
        const hasScroll = this._scrollableParent.scrollHeight > this._scrollableParent.clientHeight;
        this.isNeedRender = !hasScroll;
        if (hasScroll) {
            this._updateVisibility = () => {
                if (!this.allowRendering) {
                    return;
                }
                var isRowContainerDivVisible = isElementVisible(rowContainerDiv, 50);
                if (!this.isNeedRender && isRowContainerDivVisible) {
                    this.isNeedRender = true;
                    this.stopLazyRendering();
                }
            };
            this.lazyRenderingTimeout = setTimeout(() => {
                if (!!this._scrollableParent &&
                    !!this._scrollableParent.addEventListener) {
                    this._scrollableParent.addEventListener("scroll", this._updateVisibility);
                }
                this.ensureVisibility();
            }, 10);
        }
    }
    ensureVisibility() {
        if (!!this._updateVisibility) {
            this._updateVisibility();
        }
    }
    stopLazyRendering() {
        if (!!this._scrollableParent &&
            !!this._updateVisibility &&
            !!this._scrollableParent.removeEventListener) {
            this._scrollableParent.removeEventListener("scroll", this._updateVisibility);
        }
        clearTimeout(this.lazyRenderingTimeout);
        this._scrollableParent = undefined;
        this._updateVisibility = undefined;
    }
    constructor(panel) {
        super();
        this.panel = panel;
        this._scrollableParent = undefined;
        this._updateVisibility = undefined;
        this.visibleElementsAnimation = new AnimationGroup(this.getVisibleElementsAnimationOptions(), (value) => {
            this.setWidth(value);
            this.setPropertyValue("visibleElements", value);
        }, () => this.visibleElements);
        this.idValue = QuestionRowModel.getRowId();
        this.visible = panel.areInvisibleElementsShowing;
        this.createNewArray("elements");
        this.createNewArray("visibleElements");
    }
    setIsLazyRendering(val) {
        this.isLazyRenderingValue = val;
        this.isNeedRender = !val;
    }
    isLazyRendering() {
        return this.isLazyRenderingValue === true;
    }
    get id() {
        return this.idValue;
    }
    equalsCore(obj) {
        return this == obj;
    }
    get elements() {
        return this.getPropertyValue("elements");
    }
    getIsAnimationAllowed() {
        var _a;
        return super.getIsAnimationAllowed() && this.visible && ((_a = this.panel) === null || _a === void 0 ? void 0 : _a.animationAllowed);
    }
    getVisibleElementsAnimationOptions() {
        const beforeRunAnimation = (el) => {
            prepareElementForVerticalAnimation(el);
            setPropertiesOnElementForAnimation(el, { width: getElementWidth(el) + "px" });
        };
        return {
            getRerenderEvent: () => this.onElementRerendered,
            isAnimationEnabled: () => this.animationAllowed,
            allowSyncRemovalAddition: false,
            getAnimatedElement: (element) => element.getWrapperElement(),
            getLeaveOptions: (element) => {
                const surveyElement = element;
                const cssClasses = element.isPanel ? surveyElement.cssClasses.panel : surveyElement.cssClasses;
                return {
                    cssClass: cssClasses.leave,
                    onBeforeRunAnimation: beforeRunAnimation,
                    onAfterRunAnimation: cleanHtmlElementAfterAnimation
                };
            },
            getEnterOptions: (element) => {
                const surveyElement = element;
                const cssClasses = element.isPanel ? surveyElement.cssClasses.panel : surveyElement.cssClasses;
                return {
                    cssClass: cssClasses.enter,
                    onBeforeRunAnimation: beforeRunAnimation,
                    onAfterRunAnimation: cleanHtmlElementAfterAnimation
                };
            }
        };
    }
    set visibleElements(val) {
        if (!val.length) {
            this.visible = false;
            this.visibleElementsAnimation.cancel();
            return;
        }
        else {
            this.visible = true;
        }
        this.visibleElementsAnimation.sync(val);
    }
    get visibleElements() {
        return this.getPropertyValue("visibleElements");
    }
    get visible() {
        return this.getPropertyValue("visible", true);
    }
    set visible(val) {
        this.setPropertyValue("visible", val);
        this.onVisibleChangedCallback && this.onVisibleChangedCallback();
    }
    get isNeedRender() {
        return this.getPropertyValue("isneedrender", true);
    }
    set isNeedRender(val) {
        this.setPropertyValue("isneedrender", val);
    }
    updateVisible() {
        var visElements = [];
        for (var i = 0; i < this.elements.length; i++) {
            if (this.elements[i].isVisible) {
                visElements.push(this.elements[i]);
            }
            if (this.elements[i].isPanel || this.elements[i].getType() === "paneldynamic") {
                this.setIsLazyRendering(false);
                this.stopLazyRendering();
            }
        }
        this.visibleElements = visElements;
        return;
    }
    addElement(q) {
        this.elements.push(q);
        this.updateVisible();
    }
    get index() {
        return this.panel.rows.indexOf(this);
    }
    setWidth(visibleElement) {
        var visCount = visibleElement.length;
        if (visCount == 0)
            return;
        const isSingleInRow = visibleElement.length === 1;
        var preSetWidthElements = [];
        for (var i = 0; i < this.elements.length; i++) {
            var el = this.elements[i];
            if (el.isVisible) {
                el.isSingleInRow = isSingleInRow;
                var width = this.getElementWidth(el);
                if (!!width) {
                    el.renderWidth = this.getRenderedWidthFromWidth(width);
                    preSetWidthElements.push(el);
                }
                el.rightIndent = 0;
            }
            else {
                el.renderWidth = "";
            }
        }
        for (var i = 0; i < this.elements.length; i++) {
            var el = this.elements[i];
            if (!el.isVisible || preSetWidthElements.indexOf(el) > -1)
                continue;
            if (preSetWidthElements.length == 0) {
                el.renderWidth = `${Number.parseFloat((100 / visCount).toFixed(6))}%`;
            }
            else {
                el.renderWidth = this.getRenderedCalcWidth(el, preSetWidthElements, visCount);
            }
        }
    }
    getRenderedCalcWidth(el, preSetWidthElements, visCount) {
        var expression = "100%";
        for (var i = 0; i < preSetWidthElements.length; i++) {
            expression += " - " + preSetWidthElements[i].renderWidth;
        }
        var calcWidthEl = visCount - preSetWidthElements.length;
        if (calcWidthEl > 1) {
            expression = "(" + expression + ")/" + calcWidthEl.toString();
        }
        return "calc(" + expression + ")";
    }
    getElementWidth(el) {
        var width = el.width;
        if (!width || typeof width !== "string")
            return "";
        return width.trim();
    }
    getRenderedWidthFromWidth(width) {
        return Helpers.isNumber(width) ? width + "px" : width;
    }
    dispose() {
        super.dispose();
        this.stopLazyRendering();
    }
    getRowCss() {
        return new CssClassBuilder()
            .append(this.panel.cssClasses.row)
            .append(this.panel.cssClasses.rowCompact, this.panel["isCompact"])
            .append(this.panel.cssClasses.pageRow, this.panel.isPage || this.panel.showPanelAsPage)
            .append(this.panel.cssClasses.rowMultiple, this.visibleElements.length > 1)
            .toString();
    }
    setRootElement(element) {
        this.rootElement = element;
    }
    getRootElement() {
        return this.rootElement;
    }
}
QuestionRowModel.rowCounter = 100;
/**
 * A base class for the [`PanelModel`](https://surveyjs.io/form-library/documentation/panelmodel) and [`PageModel`](https://surveyjs.io/form-library/documentation/pagemodel) classes.
 */
class PanelModelBase extends SurveyElement {
    static getPanelId() {
        return "sp_" + PanelModelBase.panelCounter++;
    }
    /**
     * An array of columns used to arrange survey elements within this page or panel. Applies only if you set the `SurveyModel`'s [`gridLayoutEnabled`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#gridLayoutEnabled) property to `true`.
     *
     * Each object in this array configures a single layout column and has the following properties:
     *
     * - `width`: `number`\
     * Column width, in percentage.
     *
     * - `questionTitleWidth`: `string`\
     * The width of question titles, in pixels.
     *
     * The `gridLayoutColumns` array is generated automatically based on the maximum number of questions and panels in the same row. To arrange the survey elements in one or several rows, disable the [`startWithNewLine`](https://surveyjs.io/form-library/documentation/api-reference/question#startWithNewLine) property for those elements that should occupy the same row as the previous question or panel. You can also set the [`colSpan`](https://surveyjs.io/form-library/documentation/api-reference/question#colSpan) property for individual questions and panels to specify how many layout columns they span.
     */
    get gridLayoutColumns() {
        let res = this.getPropertyValue("gridLayoutColumns");
        if (!this._columns) {
            this.generateColumns([].concat(res));
            res = this._columns;
            this.gridLayoutColumns = res;
        }
        return res;
    }
    set gridLayoutColumns(val) {
        this.setPropertyValue("gridLayoutColumns", val);
    }
    onAddRow(row) {
        this.onRowVisibleChanged();
        row.onVisibleChangedCallback = () => this.onRowVisibleChanged();
    }
    getRowsAnimationOptions() {
        return {
            getRerenderEvent: () => this.onElementRerendered,
            isAnimationEnabled: () => this.animationAllowed,
            getAnimatedElement: (row) => row.getRootElement(),
            getLeaveOptions: (row, info) => {
                return {
                    cssClass: this.cssClasses.rowLeave,
                    onBeforeRunAnimation: prepareElementForVerticalAnimation,
                    onAfterRunAnimation: cleanHtmlElementAfterAnimation,
                };
            },
            getEnterOptions: (_, animationInfo) => {
                const cssClasses = this.cssClasses;
                return {
                    cssClass: new CssClassBuilder().append(cssClasses.rowEnter).append(cssClasses.rowDelayedEnter, animationInfo.isDeletingRunning).toString(),
                    onBeforeRunAnimation: prepareElementForVerticalAnimation,
                    onAfterRunAnimation: cleanHtmlElementAfterAnimation
                };
            }
        };
    }
    get visibleRows() {
        return this.getPropertyValue("visibleRows");
    }
    set visibleRows(val) {
        this.rowsAnimation.sync(val);
    }
    onRemoveRow(row) {
        row.visibleElementsAnimation.cancel();
        this.visibleRows = this.rows.filter(row => row.visible);
        row.onVisibleChangedCallback = undefined;
    }
    onRowVisibleChanged() {
        this.visibleRows = this.rows.filter(row => row.visible);
    }
    constructor(name = "") {
        super(name);
        this.isQuestionsReady = false;
        this.questionsValue = new Array();
        this._columns = undefined;
        this._columnsReady = false;
        this.rowsAnimation = new AnimationGroup(this.getRowsAnimationOptions(), (value) => {
            this.setPropertyValue("visibleRows", value);
        }, () => this.visibleRows);
        this.isRandomizing = false;
        this.onColumnPropertyValueChangedCallback = (name, oldValue, newValue, sender, arrayChanges) => {
            if (this._columnsReady) {
                this.updateColumnWidth(this.gridLayoutColumns);
                this.updateRootStyle();
            }
        };
        this.locCountRowUpdates = 0;
        this.createNewArray("rows", (el, index) => { this.onAddRow(el); }, (el) => { this.onRemoveRow(el); });
        this.createNewArray("visibleRows");
        this.createNewArray("gridLayoutColumns", (col) => {
            col.onPropertyValueChangedCallback = this.onColumnPropertyValueChangedCallback;
        });
        this.elementsValue = this.createNewArray("elements", this.onAddElement.bind(this), this.onRemoveElement.bind(this));
        this.setPropertyValueDirectly("id", PanelModelBase.getPanelId());
        this.addExpressionProperty("visibleIf", (obj, res) => { this.visible = res === true; }, (obj) => { return !this.areInvisibleElementsShowing; });
        this.addExpressionProperty("enableIf", (obj, res) => { this.readOnly = res === false; });
        this.addExpressionProperty("requiredIf", (obj, res) => { this.isRequired = res === true; });
        this.createLocalizableString("requiredErrorText", this);
        this.createLocalizableString("navigationTitle", this, true).onGetTextCallback = (text) => {
            return text || this.title || this.name;
        };
        this.registerPropertyChangedHandlers(["questionTitleLocation"], () => {
            this.onVisibleChanged.bind(this);
            this.updateElementCss(true);
        });
        this.registerPropertyChangedHandlers(["questionStartIndex", "showQuestionNumbers"], () => {
            this.updateVisibleIndexes();
        });
        this.registerPropertyChangedHandlers(["title"], () => {
            this.resetHasTextInTitle();
        });
    }
    getType() {
        return "panelbase";
    }
    setSurveyImpl(value, isLight) {
        //if(this.surveyImpl === value) return; TODO refactor
        this.blockAnimations();
        super.setSurveyImpl(value, isLight);
        if (this.isDesignMode)
            this.onVisibleChanged();
        for (var i = 0; i < this.elements.length; i++) {
            this.elements[i].setSurveyImpl(value, isLight);
        }
        this.releaseAnimations();
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        this.markQuestionListDirty();
        this.onRowsChanged();
    }
    get hasTextInTitle() {
        return this.getPropertyValue("hasTextInTitle", undefined, () => !!this.title);
    }
    resetHasTextInTitle() {
        this.resetPropertyValue("hasTextInTitle");
    }
    get hasTitle() {
        return ((this.canShowTitle(this.survey) && (this.hasTextInTitle || this.locTitle.textOrHtml.length > 0)) ||
            (this.isDesignMode && !this.isPanel && this.showTitle && settings.designMode.showEmptyTitles));
    }
    delete(doDispose = true) {
        this.deletePanel();
        this.removeFromParent();
        if (doDispose) {
            this.dispose();
        }
    }
    deletePanel() {
        const els = this.elements;
        for (let i = 0; i < els.length; i++) {
            const el = els[i];
            if (el.isPanel) {
                el.deletePanel();
            }
            this.onRemoveElementNotifySurvey(el);
        }
    }
    removeFromParent() { }
    canShowTitle(survey) { return true; }
    getDefaultTitleTagName() {
        return settings.titleTags.panel;
    }
    get _showDescription() {
        if (!this.hasTitle && this.isDesignMode)
            return false;
        return this.survey && this.survey.showPageTitles && this.hasDescription ||
            (this.showDescription && this.isDesignMode &&
                settings.designMode.showEmptyDescriptions);
    }
    localeChanged() {
        super.localeChanged();
        for (var i = 0; i < this.elements.length; i++) {
            this.elements[i].localeChanged();
        }
    }
    locStrsChanged() {
        super.locStrsChanged();
        for (var i = 0; i < this.elements.length; i++) {
            this.elements[i].locStrsChanged();
        }
    }
    getMarkdownHtml(text, name, item) {
        if (name === "navigationTitle" && this.locNavigationTitle.isEmpty) {
            return this.locTitle.renderedHtml || this.name;
        }
        return super.getMarkdownHtml(text, name, item);
    }
    get locNavigationTitle() {
        return this.getLocalizableString("navigationTitle");
    }
    get renderedNavigationTitle() {
        return this.locNavigationTitle.renderedHtml;
    }
    /**
     * Returns a character or text string that indicates a required panel/page.
     * @see SurveyModel.requiredMark
     * @see isRequired
     */
    get requiredMark() {
        return !!this.survey && this.isRequired
            ? this.survey.requiredMark
            : "";
    }
    /**
     * @deprecated Use the [`requiredMark`](https://surveyjs.io/form-library/documentation/api-reference/panel-model#requiredMark) property instead.
     */
    get requiredText() {
        return this.requiredMark;
    }
    get titlePattern() {
        return !!this.survey ? this.survey.questionTitlePattern : "numTitleRequire";
    }
    get isRequireTextOnStart() {
        return this.isRequired && this.titlePattern == "requireNumTitle";
    }
    get isRequireTextBeforeTitle() {
        return this.isRequired && this.titlePattern == "numRequireTitle";
    }
    get isRequireTextAfterTitle() {
        return this.isRequired && this.titlePattern == "numTitleRequire";
    }
    /**
     * Specifies a custom error message for a required panel/page.
     * @see isRequired
     * @see requiredIf
     */
    get requiredErrorText() {
        return this.getLocalizableStringText("requiredErrorText");
    }
    set requiredErrorText(val) {
        this.setLocalizableStringText("requiredErrorText", val);
    }
    get locRequiredErrorText() {
        return this.getLocalizableString("requiredErrorText");
    }
    /**
     * Specifies the sort order of questions in the panel/page.
     *
     * Possible values:
     *
     * - `"initial"` - Preserves the original order of questions.
     * - `"random"` - Displays questions in random order.
     * - `"default"` (default) - Inherits the setting from the `SurveyModel`'s [`questionOrder`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionOrder) property.
     * @see areQuestionsRandomized
     */
    get questionOrder() {
        return this.getPropertyValue("questionOrder");
    }
    set questionOrder(val) {
        this.setPropertyValue("questionOrder", val);
    }
    /**
     * @deprecated Use the [`questionOrder`](https://surveyjs.io/form-library/documentation/api-reference/panel-model#questionOrder) property instead.
     */
    get questionsOrder() {
        return this.questionOrder;
    }
    set questionsOrder(val) {
        this.questionOrder = val;
    }
    addNoFromChild(no) { return no; }
    canRandomize(isRandom) {
        return isRandom && (this.questionOrder !== "initial") || this.questionOrder === "random";
    }
    randomizeElements(isRandom) {
        if (!this.canRandomize(isRandom) || this.isRandomizing)
            return false;
        this.isRandomizing = true;
        var oldElements = [];
        var elements = this.elements;
        for (var i = 0; i < elements.length; i++) {
            oldElements.push(elements[i]);
        }
        const newElements = Helpers.randomizeArray(oldElements);
        this.setArrayPropertyDirectly("elements", newElements, false);
        this.updateRows();
        this.updateVisibleIndexes();
        this.isRandomizing = false;
        return true;
    }
    /**
     * Returns `true` if elements in this panel/page are arranged in random order.
     * @see questionOrder
     */
    get areQuestionsRandomized() {
        var order = this.questionOrder == "default" && this.survey
            ? this.survey.questionOrder
            : this.questionOrder;
        return order == "random";
    }
    /**
     * Returns a survey element (panel or page) that contains this panel and allows you to move the panel to a different survey element.
     *
     * For `PageModel` objects, the `parent` property is `null`, except in the following cases:
     *
     * - `SurveyModel`'s [`questionsOnPageMode`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionsOnPageMode) is set to `"singlePage"`.
     * - The page is included in a [preview of given answers](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#preview-page).
     *
     * In those cases, the survey creates an internal `PageModel` object to show all questions on one page, and the `parent` property contains this object.
     */
    get parent() {
        return this.getPropertyValue("parent", null);
    }
    set parent(val) {
        this.setPropertyValue("parent", val);
    }
    get depth() {
        if (this.parent == null)
            return 0;
        return this.parent.depth + 1;
    }
    /**
     * A Boolean expression. If it evaluates to `false`, this panel/page becomes hidden.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see visible
     * @see isVisible
     */
    get visibleIf() {
        return this.getPropertyValue("visibleIf", "");
    }
    set visibleIf(val) {
        this.setPropertyValue("visibleIf", val);
    }
    calcCssClasses(css) {
        var classes = { panel: {}, error: {}, row: "", rowEnter: "", rowLeave: "", rowDelayedEnter: "", rowMultiple: "", pageRow: "", rowCompact: "" };
        this.copyCssClasses(classes.panel, css.panel);
        this.copyCssClasses(classes.error, css.error);
        if (!!css.pageRow) {
            classes.pageRow = css.pageRow;
        }
        if (!!css.rowCompact) {
            classes.rowCompact = css.rowCompact;
        }
        if (!!css.row) {
            classes.row = css.row;
        }
        if (!!css.rowEnter) {
            classes.rowEnter = css.rowEnter;
        }
        if (!!css.rowLeave) {
            classes.rowLeave = css.rowLeave;
        }
        if (!!css.rowDelayedEnter) {
            classes.rowDelayedEnter = css.rowDelayedEnter;
        }
        if (!!css.rowMultiple) {
            classes.rowMultiple = css.rowMultiple;
        }
        if (this.survey) {
            this.survey.updatePanelCssClasses(this, classes);
        }
        return classes;
    }
    /**
     * An auto-generated unique element identifier.
     */
    get id() {
        return this.getPropertyValue("id");
    }
    set id(val) {
        this.setPropertyValue("id", val);
    }
    get isPanel() {
        return false;
    }
    getPanel() {
        return this;
    }
    getLayoutType() {
        return "row";
    }
    isLayoutTypeSupported(layoutType) {
        return layoutType !== "flow";
    }
    /**
     * An array of all questions within this panel/page. Includes questions within nested panels.
     * @see elements
     */
    get questions() {
        if (!this.isQuestionsReady) {
            this.questionsValue = [];
            for (var i = 0; i < this.elements.length; i++) {
                var el = this.elements[i];
                if (el.isPanel) {
                    var qs = el.questions;
                    for (var j = 0; j < qs.length; j++) {
                        this.questionsValue.push(qs[j]);
                    }
                }
                else {
                    this.questionsValue.push(el);
                }
            }
            this.isQuestionsReady = true;
        }
        return this.questionsValue;
    }
    get visibleQuestions() {
        const res = new Array();
        this.questions.forEach(q => {
            if (q.isVisible)
                res.push(q);
        });
        return res;
    }
    getQuestions(includeNested) {
        const res = this.questions;
        if (!includeNested)
            return res;
        const res2 = [];
        res.forEach(q => {
            res2.push(q);
            q.getNestedQuestions().forEach(nQ => res2.push(nQ));
        });
        return res2;
    }
    getValidName(name) {
        if (!!name)
            return name.trim();
        return name;
    }
    /**
     * Returns a question with a specified `name`. This method does not find questions within nested panels.
     * @param name A question name.
     */
    getQuestionByName(name) {
        var questions = this.questions;
        for (var i = 0; i < questions.length; i++) {
            if (questions[i].name == name)
                return questions[i];
        }
        return null;
    }
    /**
     * Returns a survey element with a specified `name`. This method can find survey elements within nested panels.
     * @param name An element name.
     */
    getElementByName(name) {
        var elements = this.elements;
        for (var i = 0; i < elements.length; i++) {
            var el = elements[i];
            if (el.name == name)
                return el;
            var pnl = el.getPanel();
            if (!!pnl) {
                var res = pnl.getElementByName(name);
                if (!!res)
                    return res;
            }
        }
        return null;
    }
    getQuestionByValueName(valueName) {
        const res = this.getQuestionsByValueName(valueName);
        return res.length > 0 ? res[0] : null;
    }
    getQuestionsByValueName(valueName) {
        const res = [];
        var questions = this.questions;
        for (var i = 0; i < questions.length; i++) {
            if (questions[i].getValueName() == valueName)
                res.push(questions[i]);
        }
        return res;
    }
    /**
     * Returns a JSON object with question values nested in the panel/page.
     * @see getDisplayValue
     */
    getValue() {
        var data = {};
        this.collectValues(data, 0);
        return Helpers.getUnbindValue(data);
    }
    hasValueAnyQuestion(visibleOnly) {
        const questions = visibleOnly ? this.visibleQuestions : this.questions;
        for (let i = 0; i < questions.length; i++) {
            if (!questions[i].isEmpty())
                return true;
        }
        return false;
    }
    collectValues(data, level) {
        let elements = this.elements;
        if (level === 0) {
            elements = this.questions;
        }
        for (var i = 0; i < elements.length; i++) {
            const el = elements[i];
            if (el.isPanel || el.isPage) {
                const panelData = {};
                if (el.collectValues(panelData, level - 1)) {
                    data[el.name] = panelData;
                }
            }
            else {
                const q = el;
                if (!q.isEmpty()) {
                    var valueName = q.getValueName();
                    data[valueName] = q.value;
                    if (!!this.data) {
                        var comment = this.data.getComment(valueName);
                        if (!!comment) {
                            data[valueName + Base.commentSuffix] = comment;
                        }
                    }
                }
            }
        }
        return true;
    }
    /**
     * Returns a JSON object with display texts that correspond to question values nested in the panel/page.
     * @param keysAsText Pass `true` if not only values in the object should be display texts, but also keys. Default value: `false`.
     * @see getValue
     */
    getDisplayValue(keysAsText) {
        var data = {};
        var questions = this.questions;
        for (var i = 0; i < questions.length; i++) {
            var q = questions[i];
            if (q.isEmpty())
                continue;
            var valueName = keysAsText ? q.title : q.getValueName();
            data[valueName] = q.getDisplayValue(keysAsText);
        }
        return data;
    }
    /**
     * Returns a JSON object with comments left to questions within this panel/page. Question names are used as keys.
     */
    getComments() {
        var comments = {};
        if (!this.data)
            return comments;
        var questions = this.questions;
        for (var i = 0; i < questions.length; i++) {
            var q = questions[i];
            var comment = this.data.getComment(q.getValueName());
            if (!!comment) {
                comments[q.getValueName()] = comment;
            }
        }
        return comments;
    }
    /**
     * Removes values that cannot be assigned to nested questions, for example, choices unlisted in the `choices` array.
     *
     * Call this method after you assign new question values in code to ensure that they are acceptable.
     *
     * > This method does not remove values for invisible questions and values that fail validation. Call the `validate()` method to validate newly assigned values.
     *
     * @see validate
     */
    clearIncorrectValues() {
        for (var i = 0; i < this.elements.length; i++) {
            this.elements[i].clearIncorrectValues();
        }
    }
    /**
     * Empties the `errors` array for this panel/page and all its child elements (panels and questions).
     * @see errors
     */
    clearErrors() {
        for (var i = 0; i < this.elements.length; i++) {
            this.elements[i].clearErrors();
        }
        this.errors = [];
    }
    markQuestionListDirty() {
        this.isQuestionsReady = false;
        if (this.parent)
            this.parent.markQuestionListDirty();
    }
    /**
     * An array of all survey elements (questions or panels) within this panel/page. Does not include questions within nested panels.
     * @see questions
     */
    get elements() {
        Base.collectDependency(this, "elements");
        return this.elementsValue;
    }
    getElementsInDesign(includeHidden = false) {
        return this.elements;
    }
    /**
     * Checks whether a given element belongs to this panel/page or nested panels.
     * @param element A survey element to check.
     */
    containsElement(element) {
        for (var i = 0; i < this.elements.length; i++) {
            var el = this.elements[i];
            if (el == element)
                return true;
            var pnl = el.getPanel();
            if (!!pnl) {
                if (pnl.containsElement(element))
                    return true;
            }
        }
        return false;
    }
    /**
     * Makes the panel/page require an answer at least in one nested question. If a respondent leaves the panel/page without any answers, the survey displays a validation error.
     * @see requiredIf
     * @see [Data Validation](https://surveyjs.io/form-library/documentation/data-validation)
     */
    get isRequired() {
        return this.getPropertyValue("isRequired");
    }
    set isRequired(val) {
        this.setPropertyValue("isRequired", val);
    }
    /**
     * A Boolean expression. If it evaluates to `true`, this panel/page becomes required (at least one question in the panel/page should have an answer).
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see isRequired
     */
    get requiredIf() {
        return this.getPropertyValue("requiredIf", "");
    }
    set requiredIf(val) {
        this.setPropertyValue("requiredIf", val);
    }
    searchText(text, founded) {
        super.searchText(text, founded);
        for (var i = 0; i < this.elements.length; i++) {
            this.elements[i].searchText(text, founded);
        }
    }
    hasErrors(fireCallback = true, focusOnFirstError = false, rec = null) {
        return !this.validate(fireCallback, focusOnFirstError, rec);
    }
    /**
     * Validates questions within this panel or page and returns `false` if the validation fails.
     * @param fireCallback *(Optional)* Pass `false` if you do not want to show validation errors in the UI.
     * @param focusFirstError *(Optional)* Pass `true` if you want to focus the first question with a validation error.
     * @see [Data Validation](https://surveyjs.io/form-library/documentation/data-validation)
     */
    validate(fireCallback = true, focusFirstError = false, rec = null) {
        rec = rec || {
            fireCallback: fireCallback,
            focusOnFirstError: focusFirstError,
            firstErrorQuestion: null,
            result: false,
        };
        if (rec.result !== true)
            rec.result = false;
        this.hasErrorsCore(rec);
        return !rec.result;
    }
    validateContainerOnly() {
        this.hasErrorsInPanels({ fireCallback: true });
        if (!!this.parent) {
            this.parent.validateContainerOnly();
        }
    }
    onQuestionValueChanged(el) {
        const index = this.questions.indexOf(el);
        if (index < 0)
            return;
        const dif = 5;
        const max = this.questions.length - 1;
        const start = index - dif > 0 ? index - dif : 0;
        const end = index + dif < max ? index + dif : max;
        for (let i = start; i <= end; i++) {
            if (i === index)
                continue;
            const q = this.questions[i];
            if (q.errors.length > 0 && q.validate(false)) {
                q.validate(true);
            }
        }
    }
    hasErrorsInPanels(rec) {
        var errors = [];
        this.hasRequiredError(rec, errors);
        if (this.survey) {
            this.survey.validatePanel(this, errors, rec.fireCallback);
            if (errors.length > 0) {
                rec.result = true;
            }
        }
        if (!!rec.fireCallback) {
            this.errors = errors;
        }
    }
    //ISurveyErrorOwner
    getErrorCustomText(text, error) {
        if (!!this.survey)
            return this.survey.getSurveyErrorCustomText(this, text, error);
        return text;
    }
    hasRequiredError(rec, errors) {
        if (!this.isRequired)
            return;
        var visQuestions = [];
        this.addQuestionsToList(visQuestions, true);
        if (visQuestions.length == 0)
            return;
        for (var i = 0; i < visQuestions.length; i++) {
            if (!visQuestions[i].isEmpty())
                return;
        }
        rec.result = true;
        errors.push(new OneAnswerRequiredError(this.requiredErrorText, this));
        if (rec.focusOnFirstError && !rec.firstErrorQuestion) {
            rec.firstErrorQuestion = visQuestions[0];
        }
    }
    hasErrorsCore(rec) {
        var _a;
        let singleQ = (_a = this.survey) === null || _a === void 0 ? void 0 : _a.currentSingleQuestion;
        if (singleQ && this.questions.indexOf(singleQ) < 0) {
            singleQ = undefined;
        }
        const elements = singleQ ? [singleQ] : this.elements;
        let element = null;
        let firstErroredEl = null;
        for (var i = 0; i < elements.length; i++) {
            element = elements[i];
            if (!element.isVisible)
                continue;
            if (element.isPanel) {
                element.hasErrorsCore(rec);
            }
            else {
                var question = element;
                if (!question.validate(rec.fireCallback, rec)) {
                    if (!firstErroredEl) {
                        firstErroredEl = question;
                    }
                    if (!rec.firstErrorQuestion) {
                        rec.firstErrorQuestion = question;
                    }
                    rec.result = true;
                }
            }
        }
        if (!singleQ) {
            this.hasErrorsInPanels(rec);
            this.updateContainsErrors();
        }
        if (!firstErroredEl && this.errors.length > 0) {
            firstErroredEl = this.getFirstQuestionToFocus(false, true);
            if (!rec.firstErrorQuestion) {
                rec.firstErrorQuestion = firstErroredEl;
            }
        }
        if (rec.fireCallback && firstErroredEl) {
            const selQ = singleQ ? (rec.firstErrorQuestion || firstErroredEl) : firstErroredEl;
            if (rec.focusOnFirstError) {
                selQ.focus(true);
            }
            else {
                selQ.expandAllParents();
            }
        }
    }
    getContainsErrors() {
        var res = super.getContainsErrors();
        if (res)
            return res;
        var elements = this.elements;
        for (var i = 0; i < elements.length; i++) {
            if (elements[i].containsErrors)
                return true;
        }
        return false;
    }
    updateElementVisibility() {
        for (let i = 0; i < this.elements.length; i++) {
            this.elements[i].updateElementVisibility();
        }
        super.updateElementVisibility();
    }
    getFirstQuestionToFocus(withError = false, ignoreCollapseState = false) {
        if (!withError && !ignoreCollapseState && this.isCollapsed)
            return null;
        var elements = this.elements;
        for (var i = 0; i < elements.length; i++) {
            var el = elements[i];
            if (!el.isVisible || !ignoreCollapseState && el.isCollapsed)
                continue;
            if (el.isPanel) {
                var res = el.getFirstQuestionToFocus(withError, ignoreCollapseState);
                if (!!res)
                    return res;
            }
            else {
                const q = el.getFirstQuestionToFocus(withError);
                if (!!q)
                    return q;
            }
        }
        return null;
    }
    getFirstVisibleQuestion() {
        const qs = this.questions;
        for (let i = 0; i < qs.length; i++) {
            if (qs[i].isVisible)
                return qs[i];
        }
        return null;
    }
    getFirstVisibleElement() {
        const els = this.elements;
        for (let i = 0; i < els.length; i++) {
            if (els[i].isVisible)
                return els[i];
        }
        return null;
    }
    /**
     * Focuses the first question in this panel/page.
     * @see focusFirstErrorQuestion
     */
    focusFirstQuestion() {
        const q = this.getFirstQuestionToFocus();
        if (!!q) {
            q.focus();
        }
    }
    /**
     * Focuses the first question with a validation error in this panel/page.
     * @see validate
     * @see focusFirstQuestion
     */
    focusFirstErrorQuestion() {
        var q = this.getFirstQuestionToFocus(true);
        if (!!q) {
            q.focus();
        }
    }
    addQuestionsToList(list, visibleOnly = false, includingDesignTime = false) {
        this.addElementsToList(list, visibleOnly, includingDesignTime, false);
    }
    addPanelsIntoList(list, visibleOnly = false, includingDesignTime = false) {
        this.addElementsToList(list, visibleOnly, includingDesignTime, true);
    }
    addElementsToList(list, visibleOnly, includingDesignTime, isPanel) {
        if (visibleOnly && !this.visible)
            return;
        this.addElementsToListCore(list, this.elements, visibleOnly, includingDesignTime, isPanel);
    }
    addElementsToListCore(list, elements, visibleOnly, includingDesignTime, isPanel) {
        for (var i = 0; i < elements.length; i++) {
            var el = elements[i];
            if (visibleOnly && !el.visible)
                continue;
            if ((isPanel && el.isPanel) || (!isPanel && !el.isPanel)) {
                list.push(el);
            }
            if (el.isPanel) {
                el.addElementsToListCore(list, el.elements, visibleOnly, includingDesignTime, isPanel);
            }
            else {
                if (includingDesignTime) {
                    this.addElementsToListCore(list, el.getElementsInDesign(false), visibleOnly, includingDesignTime, isPanel);
                }
            }
        }
    }
    calcMaxRowColSpan() {
        let maxRowColSpan = 0;
        this.rows.forEach(row => {
            let curRowSpan = 0;
            let userDefinedRow = false;
            row.elements.forEach(el => {
                if (!!el.width) {
                    userDefinedRow = true;
                }
                curRowSpan += (el.colSpan || 1);
            });
            if (!userDefinedRow && curRowSpan > maxRowColSpan)
                maxRowColSpan = curRowSpan;
        });
        return maxRowColSpan;
    }
    updateColumnWidth(columns) {
        let remainingSpace = 0, remainingColCount = 0;
        columns.forEach(col => {
            if (!col.width) {
                remainingColCount++;
            }
            else {
                remainingSpace += col.width;
                col.setPropertyValue("effectiveWidth", col.width);
            }
        });
        if (!!remainingColCount) {
            const oneColumnWidth = floorTo2Decimals((100 - remainingSpace) / remainingColCount);
            for (let index = 0; index < columns.length; index++) {
                if (!columns[index].width) {
                    columns[index].setPropertyValue("effectiveWidth", oneColumnWidth);
                }
            }
        }
    }
    updateColumns() {
        this._columns = undefined;
        this.updateRootStyle();
    }
    updateRootStyle() {
        var _a;
        super.updateRootStyle();
        (_a = this.elements) === null || _a === void 0 ? void 0 : _a.forEach(el => el.updateRootStyle());
    }
    updateCustomWidgets() {
        for (var i = 0; i < this.elements.length; i++) {
            this.elements[i].updateCustomWidgets();
        }
    }
    /**
     * Sets a title location relative to the input field for questions that belong to this panel/page.
     *
     * Use this property to override the [`questionTitleLocation`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionTitleLocation) property specified for the survey or parent page. You can also set the [`titleLocation`](https://surveyjs.io/form-library/documentation/api-reference/question#titleLocation) property for individual questions.
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the `questionTitleLocation` property specified for the survey or parent page.
     * - `"top"` - Displays the title above the input field.
     * - `"bottom"` - Displays the title below the input field.
     * - `"left"` - Displays the title to the left of the input field.
     * - `"hidden"` - Hides the question title.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/vertically-align-input-fields/ (linkStyle))
     *
     * > Certain question types (Matrix, Multiple Text) do not support the `"left"` value. For them, the `"top"` value is used.
     */
    get questionTitleLocation() {
        return this.getPropertyValue("questionTitleLocation");
    }
    set questionTitleLocation(value) {
        this.setPropertyValue("questionTitleLocation", value.toLowerCase());
    }
    getQuestionTitleLocation() {
        if (this.onGetQuestionTitleLocation)
            return this.onGetQuestionTitleLocation();
        if (this.questionTitleLocation != "default")
            return this.questionTitleLocation;
        if (this.parent)
            return this.parent.getQuestionTitleLocation();
        return this.survey ? this.survey.questionTitleLocation : "top";
    }
    availableQuestionTitleWidth() {
        return this.getQuestionTitleLocation() === "left" || this.hasElementWithTitleLocationLeft();
    }
    hasElementWithTitleLocationLeft() {
        const result = this.elements.some(el => {
            if (el instanceof PanelModelBase) {
                return el.hasElementWithTitleLocationLeft();
            }
            else if (el instanceof Question) {
                return el.getTitleLocation() === "left";
            }
        });
        return result;
    }
    getQuestionTitleWidth() {
        const width = this.onGetQuestionTitleWidth ? this.onGetQuestionTitleWidth() : this.questionTitleWidth;
        return width || this.parent && this.parent.getQuestionTitleWidth();
    }
    get columns() {
        if (!this._columns) {
            this.generateColumns(this.gridLayoutColumns);
            this.gridLayoutColumns = this._columns;
        }
        return this._columns || [];
    }
    generateColumns(gridColumns) {
        var _a;
        const isEnabled = (_a = this.survey) === null || _a === void 0 ? void 0 : _a.gridLayoutEnabled;
        let columns = [].concat(gridColumns);
        if (isEnabled) {
            let maxRowColSpan = this.calcMaxRowColSpan();
            if (maxRowColSpan <= gridColumns.length) {
                columns = gridColumns.slice(0, maxRowColSpan);
            }
            else {
                for (let index = gridColumns.length; index < maxRowColSpan; index++) {
                    const newCol = new PanelLayoutColumnModel();
                    columns.push(newCol);
                }
            }
        }
        this._columns = columns;
        try {
            this._columnsReady = false;
            this.updateColumnWidth(columns);
        }
        finally {
            this._columnsReady = true;
        }
    }
    createGridLayoutColumns() {
        this.generateColumns([]);
        return this._columns;
    }
    updateGridColumns() {
        this.updateColumns();
        this.elements.forEach(el => {
            el.isPanel && el.updateGridColumns();
        });
    }
    getColumsForElement(el) {
        const row = this.findRowByElement(el);
        if (!row || !this.survey || !this.survey.gridLayoutEnabled)
            return [];
        let lastExpandableElementIndex = row.elements.length - 1;
        while (lastExpandableElementIndex >= 0) {
            if (!row.elements[lastExpandableElementIndex].getPropertyValueWithoutDefault("colSpan")) {
                break;
            }
            lastExpandableElementIndex--;
        }
        const elementIndex = row.elements.indexOf(el);
        let startIndex = 0;
        for (let index = 0; index < elementIndex; index++) {
            startIndex += row.elements[index].colSpan;
        }
        let currentColSpan = el.getPropertyValueWithoutDefault("colSpan");
        if (!currentColSpan && elementIndex === lastExpandableElementIndex) {
            let usedSpans = 0;
            for (let index = 0; index < row.elements.length; index++) {
                if (index !== lastExpandableElementIndex) {
                    usedSpans += row.elements[index].colSpan;
                }
            }
            currentColSpan = this.columns.length - usedSpans;
        }
        const result = this.columns.slice(startIndex, startIndex + (currentColSpan || 1));
        el.setPropertyValueDirectly("effectiveColSpan", result.length);
        return result;
    }
    getStartIndex() {
        if (!!this.parent)
            return this.parent.getQuestionStartIndex();
        if (!!this.survey)
            return this.survey.questionStartIndex;
        return "";
    }
    getQuestionStartIndex() {
        return this.getStartIndex();
    }
    getChildrenLayoutType() {
        return "row";
    }
    getProgressInfo() {
        return SurveyElement.getProgressInfoByElements(this.elements, this.isRequired);
    }
    get root() {
        var res = this;
        while (res.parent)
            res = res.parent;
        return res;
    }
    childVisibilityChanged() {
        var newIsVisibleValue = this.getIsPageVisible(null);
        var oldIsVisibleValue = this.getPropertyValue("isVisible", true);
        if (newIsVisibleValue !== oldIsVisibleValue) {
            this.onVisibleChanged();
        }
    }
    canRenderFirstRows() {
        return this.isPage;
    }
    isLazyRenderInRow(rowIndex) {
        if (!this.survey || !this.survey.isLazyRendering)
            return false;
        return (rowIndex >= this.survey.lazyRenderFirstBatchSize ||
            !this.canRenderFirstRows());
    }
    createRowAndSetLazy(index) {
        const row = this.createRow();
        row.setIsLazyRendering(this.isLazyRenderInRow(index));
        return row;
    }
    createRow() {
        return new QuestionRowModel(this);
    }
    onSurveyLoad() {
        this.blockAnimations();
        super.onSurveyLoad();
        for (var i = 0; i < this.elements.length; i++) {
            this.elements[i].onSurveyLoad();
        }
        this.onElementVisibilityChanged(this);
        this.releaseAnimations();
    }
    onFirstRenderingCore() {
        super.onFirstRenderingCore();
        this.onRowsChanged();
        this.elements.forEach(el => el.onFirstRendering());
    }
    updateRows() {
        if (this.isLoadingFromJson)
            return;
        this.getElementsForRows().forEach(el => {
            if (el.isPanel) {
                el.updateRows();
            }
        });
        this.onRowsChanged();
    }
    get rows() {
        return this.getPropertyValue("rows");
    }
    ensureRowsVisibility() {
        this.rows.forEach((row) => {
            row.ensureVisibility();
        });
    }
    onRowsChanged() {
        if (this.isLoadingFromJson)
            return;
        this.blockAnimations();
        this.setArrayPropertyDirectly("rows", this.buildRows());
        this.updateColumns();
        this.releaseAnimations();
    }
    blockRowsUpdates() {
        this.locCountRowUpdates++;
    }
    releaseRowsUpdates() {
        this.locCountRowUpdates--;
    }
    updateRowsBeforeElementRemoved(element) {
        const elementRow = this.findRowByElement(element);
        const elementRowIndex = this.rows.indexOf(elementRow);
        const elementIndexInRow = elementRow.elements.indexOf(element);
        elementRow.elements.splice(elementIndexInRow, 1);
        if (elementRow.elements.length == 0) {
            this.rows.splice(elementRowIndex, 1);
        }
        else if (!elementRow.elements[0].startWithNewLine && this.rows[elementRowIndex - 1]) {
            elementRow.elements.forEach(el => this.rows[elementRowIndex - 1].addElement(el));
            this.rows.splice(elementRowIndex, 1);
        }
        else {
            elementRow.updateVisible();
        }
    }
    updateRowsOnElementAdded(element) {
        const index = this.elements.indexOf(element);
        const targetElement = this.elements[index + 1];
        const createRowAtIndex = (index) => {
            const row = this.createRowAndSetLazy(index);
            if (this.isDesignMode) {
                row.setIsLazyRendering(false);
            }
            this.rows.splice(index, 0, row);
            return row;
        };
        const updateRow = (row, start, deleteCount, ...elements) => {
            const removedElements = row.elements.splice(start, deleteCount, ...elements);
            row.updateVisible();
            return removedElements;
        };
        if (!targetElement) {
            if (index == 0 || element.startWithNewLine) {
                updateRow(createRowAtIndex(this.rows.length), 0, 0, element);
            }
            else {
                this.rows[this.rows.length - 1].addElement(element);
            }
            return;
        }
        const targetRow = this.findRowByElement(targetElement);
        if (!targetRow)
            return;
        const targetRowIndex = this.rows.indexOf(targetRow);
        const targetElementIndexInRow = targetRow.elements.indexOf(targetElement);
        if (targetElementIndexInRow == 0) {
            if (!targetElement.startWithNewLine) {
                updateRow(targetRow, 0, 0, element);
            }
            else if (element.startWithNewLine || targetRowIndex < 1) {
                createRowAtIndex(targetRowIndex).addElement(element);
            }
            else {
                this.rows[targetRowIndex - 1].addElement(element);
            }
        }
        else {
            if (element.startWithNewLine) {
                updateRow(createRowAtIndex(targetRowIndex + 1), 0, 0, ...[element].concat(updateRow(targetRow, targetElementIndexInRow, targetRow.elements.length)));
            }
            else {
                updateRow(targetRow, targetElementIndexInRow, 0, element);
            }
        }
    }
    canFireAddRemoveNotifications(element) {
        return !!this.survey && element.prevSurvey !== this.survey;
    }
    onAddElement(element, index) {
        const survey = this.survey;
        const fireNotification = this.canFireAddRemoveNotifications(element);
        if (!!this.surveyImpl) {
            element.setSurveyImpl(this.surveyImpl);
        }
        element.parent = this;
        this.markQuestionListDirty();
        if (this.canBuildRows()) {
            this.updateRowsOnElementAdded(element);
        }
        if (fireNotification) {
            if (element.isPanel) {
                survey.panelAdded(element, index, this, this.root);
            }
            else {
                survey.questionAdded(element, index, this, this.root);
            }
        }
        if (!!this.addElementCallback)
            this.addElementCallback(element);
        element.registerPropertyChangedHandlers(["visible", "isVisible"], () => {
            this.onElementVisibilityChanged(element);
        }, this.id);
        element.registerPropertyChangedHandlers(["startWithNewLine"], () => {
            this.onElementStartWithNewLineChanged(element);
        }, this.id);
        this.onElementVisibilityChanged(this);
    }
    onRemoveElement(element) {
        element.parent = null;
        this.unregisterElementPropertiesChanged(element);
        this.markQuestionListDirty();
        this.updateRowsOnElementRemoved(element);
        if (this.isRandomizing)
            return;
        this.onRemoveElementNotifySurvey(element);
        if (!!this.removeElementCallback)
            this.removeElementCallback(element);
        this.onElementVisibilityChanged(this);
    }
    unregisterElementPropertiesChanged(element) {
        element.unregisterPropertyChangedHandlers(["visible", "isVisible", "startWithNewLine"], this.id);
    }
    onRemoveElementNotifySurvey(element) {
        if (!this.canFireAddRemoveNotifications(element))
            return;
        if (!element.isPanel) {
            this.survey.questionRemoved(element);
        }
        else {
            this.survey.panelRemoved(element);
        }
    }
    onElementVisibilityChanged(element) {
        if (this.isLoadingFromJson || this.isRandomizing)
            return;
        this.updateRowsVisibility(element);
        this.childVisibilityChanged();
        if (!!this.parent) {
            this.parent.onElementVisibilityChanged(this);
        }
    }
    onElementStartWithNewLineChanged(element) {
        if (this.locCountRowUpdates > 0)
            return;
        this.blockAnimations();
        this.updateRowsBeforeElementRemoved(element);
        this.updateRowsOnElementAdded(element);
        this.releaseAnimations();
    }
    updateRowsVisibility(element) {
        var rows = this.rows;
        for (var i = 0; i < rows.length; i++) {
            var row = rows[i];
            if (row.elements.indexOf(element) > -1) {
                row.updateVisible();
                if (row.visible && !row.isNeedRender) {
                    row.isNeedRender = true;
                }
                break;
            }
        }
    }
    canBuildRows() {
        return !this.isLoadingFromJson && this.getChildrenLayoutType() == "row";
    }
    buildRows() {
        if (!this.canBuildRows())
            return [];
        const res = new Array();
        const els = this.getElementsForRows();
        for (let i = 0; i < els.length; i++) {
            const el = els[i];
            const isNewRow = i == 0 || el.startWithNewLine;
            const row = isNewRow ? this.createRowAndSetLazy(res.length) : res[res.length - 1];
            if (isNewRow)
                res.push(row);
            row.addElement(el);
        }
        res.forEach(row => row.updateVisible());
        return res;
    }
    getElementsForRows() {
        return this.elements;
    }
    getDragDropInfo() {
        const page = this.getPage(this.parent);
        return !!page ? page.getDragDropInfo() : undefined;
    }
    updateRowsOnElementRemoved(element) {
        if (!this.canBuildRows())
            return;
        this.updateRowsRemoveElementFromRow(element, this.findRowByElement(element));
        this.updateColumns();
    }
    updateRowsRemoveElementFromRow(element, row) {
        if (!row || !row.panel)
            return;
        var elIndex = row.elements.indexOf(element);
        if (elIndex < 0)
            return;
        row.elements.splice(elIndex, 1);
        if (row.elements.length > 0) {
            this.blockRowsUpdates();
            row.elements[0].startWithNewLine = true;
            this.releaseRowsUpdates();
            row.updateVisible();
        }
        else {
            if (row.index >= 0) {
                row.panel.rows.splice(row.index, 1);
            }
        }
    }
    getAllRows() {
        const allRows = [];
        this.rows.forEach(row => {
            const nestedRows = [];
            row.elements.forEach(element => {
                if (element.isPanel) {
                    nestedRows.push(...element.getAllRows());
                }
                else if (element.getType() == "paneldynamic") {
                    if (this.isDesignMode) {
                        nestedRows.push(...element.template.getAllRows());
                    }
                    else {
                        element.panels.forEach((panel) => nestedRows.push(...panel.getAllRows()));
                    }
                }
            });
            allRows.push(row);
            allRows.push(...nestedRows);
        });
        return allRows;
    }
    findRowAndIndexByElement(el, rows) {
        if (!el) {
            return { row: undefined, index: this.rows.length - 1 };
        }
        rows = rows || this.rows;
        for (var i = 0; i < rows.length; i++) {
            if (rows[i].elements.indexOf(el) > -1)
                return { row: rows[i], index: i };
        }
        return { row: null, index: -1 };
    }
    forceRenderRow(row) {
        if (!!row && !row.isNeedRender) {
            row.isNeedRender = true;
            row.stopLazyRendering();
        }
    }
    forceRenderElement(el, elementsRendered = () => { }, gap = 0) {
        const allRows = this.getAllRows();
        const { row, index } = this.findRowAndIndexByElement(el, allRows);
        if (index >= 0 && index < allRows.length) {
            const rowsToRender = [];
            rowsToRender.push(row);
            for (let i = index - 1; i >= index - gap && i >= 0; i--) {
                rowsToRender.push(allRows[i]);
            }
            this.forceRenderRows(rowsToRender, elementsRendered);
        }
    }
    forceRenderRows(rows, elementsRendered = () => { }) {
        const rowRenderedHandler = (rowsCount => () => {
            rowsCount--;
            if (rowsCount <= 0) {
                elementsRendered();
            }
        })(rows.length);
        rows.forEach(row => new RenderingCompletedAwaiter(row.visibleElements, rowRenderedHandler));
        rows.forEach(row => this.forceRenderRow(row));
    }
    findRowByElement(el) {
        return this.findRowAndIndexByElement(el).row;
    }
    elementWidthChanged(el) {
        if (this.isLoadingFromJson)
            return;
        var row = this.findRowByElement(el);
        if (!!row) {
            row.updateVisible();
        }
    }
    get ariaTitleId() {
        return this.id + "_ariaTitle";
    }
    get ariaLabelledBy() {
        return this.hasTitle ? this.ariaTitleId : null;
    }
    get ariaLabel() {
        return this.hasTitle ? null : (this.title || this.name || null);
    }
    get ariaRole() {
        return "group";
    }
    get processedTitle() {
        return this.getRenderedTitle(this.locTitle.textOrHtml);
    }
    getRenderedTitle(str) {
        return this.textProcessor != null
            ? this.textProcessor.processText(str, true)
            : str;
    }
    /**
     * Gets or sets panel/page visibility.
     *
     * If you want to display or hide a survey element based on a condition, specify the `visibleIf` property. Refer to the following help topic for information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see visibleIf
     * @see isVisible
     */
    get visible() {
        return this.getPropertyValue("visible", true);
    }
    set visible(value) {
        if (value === this.visible)
            return;
        this.setPropertyValue("visible", value);
        this.setPropertyValue("isVisible", this.isVisible);
        if (!this.isLoadingFromJson)
            this.onVisibleChanged();
    }
    onHidingContent() {
        this.questions.forEach(q => q.onHidingContent());
    }
    onVisibleChanged() {
        if (this.isRandomizing)
            return;
        this.setPropertyValue("isVisible", this.isVisible);
        if (!this.isLoadingFromJson) {
            const questions = this.questions;
            const isVisible = this.isVisible;
            for (var i = 0; i < questions.length; i++) {
                const q = questions[i];
                if (!isVisible) {
                    q.clearValueIfInvisible("onHiddenContainer");
                    q.onHidingContent();
                }
                else {
                    q.updateValueWithDefaults();
                }
            }
        }
    }
    notifyStateChanged(prevState) {
        super.notifyStateChanged(prevState);
        if (this.isCollapsed) {
            this.questions.forEach(q => q.onHidingContent());
        }
    }
    /**
     * Returns `true` if the panel/page is visible or the survey is currently in design mode.
     *
     * If you want to display or hide a question based on a condition, specify the `visibleIf` property. Refer to the following help topic for information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see visibleIf
     * @see visible
     */
    get isVisible() {
        return this.areInvisibleElementsShowing || this.getIsPageVisible(null);
    }
    getIsContentVisible(exceptionQuestion) {
        if (this.areInvisibleElementsShowing)
            return true;
        for (var i = 0; i < this.elements.length; i++) {
            if (this.elements[i] == exceptionQuestion)
                continue;
            if (this.elements[i].isVisible)
                return true;
        }
        return false;
    }
    getIsPageVisible(exceptionQuestion) {
        const isContentVisible = this.getIsContentVisible(exceptionQuestion);
        return this.visible && isContentVisible;
    }
    setVisibleIndex(index) {
        if (!this.isVisible || index < 0) {
            this.resetVisibleIndexes();
            return 0;
        }
        this.lastVisibleIndex = index;
        var startIndex = index;
        index += this.beforeSetVisibleIndex(index);
        var panelStartIndex = this.getPanelStartIndex(index);
        var panelIndex = panelStartIndex;
        const elements = this.elements;
        for (var i = 0; i < elements.length; i++) {
            panelIndex += elements[i].setVisibleIndex(panelIndex);
        }
        if (this.isContinueNumbering()) {
            index += panelIndex - panelStartIndex;
        }
        return index - startIndex;
    }
    updateVisibleIndexes() {
        if (this.lastVisibleIndex === undefined)
            return;
        this.resetVisibleIndexes();
        this.setVisibleIndex(this.lastVisibleIndex);
    }
    resetVisibleIndexes() {
        const elements = this.elements;
        for (var i = 0; i < elements.length; i++) {
            elements[i].setVisibleIndex(-1);
        }
    }
    beforeSetVisibleIndex(index) {
        return 0;
    }
    getPanelStartIndex(index) {
        return index;
    }
    isContinueNumbering() { return true; }
    get isReadOnly() {
        var isParentReadOnly = !!this.parent && this.parent.isReadOnly;
        var isSurveyReadOnly = !!this.survey && this.survey.isDisplayMode;
        return this.readOnly || isParentReadOnly || isSurveyReadOnly;
    }
    onReadOnlyChanged() {
        for (var i = 0; i < this.elements.length; i++) {
            var el = this.elements[i];
            el.setPropertyValue("isReadOnly", el.isReadOnly);
        }
        super.onReadOnlyChanged();
    }
    updateElementCss(reNew) {
        super.updateElementCss(reNew);
        for (let i = 0; i < this.elements.length; i++) {
            const el = this.elements[i];
            el.updateElementCss(reNew);
        }
    }
    /**
     * A Boolean expression. If it evaluates to `false`, this panel/page becomes read-only.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see readOnly
     * @see isReadOnly
     */
    get enableIf() {
        return this.getPropertyValue("enableIf", "");
    }
    set enableIf(val) {
        this.setPropertyValue("enableIf", val);
    }
    /**
     * Adds a survey element (question or panel) to this panel/page. Returns `true` if the element was added successfully; `false` otherwise.
     * @param element A survey element to add.
     * @param index A desired index of this element in the `elements` array.
     * @see addNewQuestion
     * @see addNewPanel
     */
    addElement(element, index = -1) {
        if (!this.canAddElement(element))
            return false;
        if (index < 0 || index >= this.elements.length) {
            this.elements.push(element);
        }
        else {
            this.elements.splice(index, 0, element);
        }
        if (this.wasRendered) {
            element.onFirstRendering();
        }
        this.updateColumns();
        return true;
    }
    insertElement(element, dest, location = "bottom") {
        if (!dest) {
            this.addElement(element);
            return;
        }
        this.blockRowsUpdates();
        let index = this.elements.indexOf(dest);
        const destRow = this.findRowByElement(dest);
        if (location == "left" || location == "right") {
            if (location == "right") {
                element.startWithNewLine = false;
                index++;
            }
            else {
                if (destRow.elements.indexOf(dest) == 0) {
                    dest.startWithNewLine = false;
                    element.startWithNewLine = true;
                }
                else {
                    element.startWithNewLine = false;
                }
            }
        }
        else {
            element.startWithNewLine = true;
            if (location == "top") {
                index = this.elements.indexOf(destRow.elements[0]);
            }
            else {
                index = this.elements.indexOf(destRow.elements[destRow.elements.length - 1]) + 1;
            }
        }
        this.releaseRowsUpdates();
        this.addElement(element, index);
    }
    insertElementAfter(element, after) {
        const index = this.elements.indexOf(after);
        if (index >= 0)
            this.addElement(element, index + 1);
    }
    insertElementBefore(element, before) {
        const index = this.elements.indexOf(before);
        if (index >= 0)
            this.addElement(element, index);
    }
    canAddElement(element) {
        return (!!element && element.isLayoutTypeSupported(this.getChildrenLayoutType()));
    }
    addQuestion(question, index = -1) {
        return this.addElement(question, index);
    }
    addPanel(panel, index = -1) {
        return this.addElement(panel, index);
    }
    /**
     * Creates a new question of a given type and adds it to the `elements` array at a specified index.
     *
     * This method returns `null` if the question cannot be created or added to this panel/page; otherwise, the method returns the created question.
     *
     * @param questionType A [question type](https://surveyjs.io/form-library/documentation/question#getType).
     * @param name A question name.
     * @param index A desired index of the new question in the `elements` array.
     * @see elements
     * @see addElement
     */
    addNewQuestion(questionType, name = null, index = -1) {
        var question = QuestionFactory.Instance.createQuestion(questionType, name);
        if (!this.addQuestion(question, index))
            return null;
        return question;
    }
    /**
     * Creates a new panel and adds it to the end of the `elements` array.
     *
     * This method returns `null` if the panel cannot be created or added to this panel/page; otherwise, the method returns the created panel.
     * @param name A panel name.
     * @see elementsup
     * @see addElement
     */
    addNewPanel(name = null) {
        var panel = this.createNewPanel(name);
        if (!this.addPanel(panel))
            return null;
        return panel;
    }
    indexOf(element) {
        return this.elements.indexOf(element);
    }
    createNewPanel(name) {
        var res = Serializer.createClass("panel");
        res.name = name;
        return res;
    }
    /**
     * Deletes a survey element (question or panel) from this panel/page. Returns `true` if the element was deleted successfully; `false` otherwise.
     * @param element A survey element to delete.
     * @see elements
     */
    removeElement(element) {
        var index = this.elements.indexOf(element);
        if (index < 0) {
            for (var i = 0; i < this.elements.length; i++) {
                if (this.elements[i].removeElement(element))
                    return true;
            }
            return false;
        }
        this.elements.splice(index, 1);
        this.updateColumns();
        return true;
    }
    removeQuestion(question) {
        this.removeElement(question);
    }
    runCondition(values, properties) {
        if (this.isDesignMode || this.isLoadingFromJson)
            return;
        var elements = this.elements.slice();
        for (var i = 0; i < elements.length; i++) {
            elements[i].runCondition(values, properties);
        }
        this.runConditionCore(values, properties);
    }
    onAnyValueChanged(name, questionName) {
        var els = this.elements;
        for (var i = 0; i < els.length; i++) {
            els[i].onAnyValueChanged(name, questionName);
        }
    }
    checkBindings(valueName, value) {
        var els = this.elements;
        for (var i = 0; i < els.length; i++) {
            els[i].checkBindings(valueName, value);
        }
    }
    needResponsiveWidth() {
        let result = false;
        this.elements.forEach((e) => {
            if (e.needResponsiveWidth())
                result = true;
        });
        this.rows.forEach((r) => {
            if (r.elements.length > 1)
                result = true;
        });
        return result;
    }
    get hasDescriptionUnderTitle() {
        return this.hasDescription;
    }
    get cssHeader() {
        return this.cssClasses.panel.header;
    }
    get cssDescription() {
        return this.cssClasses.panel.description;
    }
    /**
     * Specifies the error message position for questions that belong to this page/panel.
     *
     * Use this property to override the [`questionErrorLocation`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionErrorLocation) property specified for the survey. You can also set the [`errorLocation`](https://surveyjs.io/form-library/documentation/question#errorLocation) property for individual questions.
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the `questionErrorLocation` property specified for the survey.
     * - `"top"` - Displays error messages above questions.
     * - `"bottom"` - Displays error messages below questions.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/set-properties-on-multiple-questions-using-panel/ (linkStyle))
     */
    get questionErrorLocation() {
        return this.getPropertyValue("questionErrorLocation");
    }
    set questionErrorLocation(val) {
        this.setPropertyValue("questionErrorLocation", val);
    }
    getQuestionErrorLocation() {
        if (this.questionErrorLocation !== "default")
            return this.questionErrorLocation;
        if (this.parent)
            return this.parent.getQuestionErrorLocation();
        return this.survey ? this.survey.questionErrorLocation : "top";
    }
    //ITitleOwner
    getTitleOwner() { return this; }
    get no() { return ""; }
    get cssTitleNumber() {
        return this.cssClasses.panel.number;
    }
    get cssRequiredMark() {
        return this.cssClasses.panel.requiredMark;
    }
    get cssError() {
        return this.getCssError(this.cssClasses);
    }
    getCssError(cssClasses) {
        return new CssClassBuilder().append(cssClasses.error.root).toString();
    }
    getSerializableColumnsValue() {
        let tailIndex = -1;
        for (let index = this.gridLayoutColumns.length - 1; index >= 0; index--) {
            if (!this.gridLayoutColumns[index].isEmpty()) {
                tailIndex = index;
                break;
            }
        }
        return this.gridLayoutColumns.slice(0, tailIndex + 1);
    }
    afterRender(el) {
        this.afterRenderCore(el);
    }
    dispose() {
        super.dispose();
        if (this.rows) {
            for (let i = 0; i < this.rows.length; i++) {
                this.rows[i].dispose();
            }
            this.rows.splice(0, this.rows.length);
        }
        this.disposeElements();
        this.elements.splice(0, this.elements.length);
    }
    disposeElements() {
        for (let i = 0; i < this.elements.length; i++) {
            this.elements[i].dispose();
        }
    }
}
PanelModelBase.panelCounter = 100;
__decorate([
    property({ defaultValue: true })
], PanelModelBase.prototype, "showTitle", void 0);
__decorate([
    property({ defaultValue: true })
], PanelModelBase.prototype, "showDescription", void 0);
__decorate([
    property()
], PanelModelBase.prototype, "questionTitleWidth", void 0);
/**
 * A class that describes the Panel container element.
 *
 * A panel can contain questions and other panels. Refer to the following help topic for an illustration: [Survey Structure](https://surveyjs.io/form-library/documentation/design-survey-create-a-simple-survey#survey-structure).
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-panel/ (linkStyle))
 */
class PanelModel extends PanelModelBase {
    constructor(name = "") {
        super(name);
        this.forcusFirstQuestionOnExpand = true;
        this.createNewArray("footerActions");
        this.registerPropertyChangedHandlers(["width"], () => {
            if (!!this.parent) {
                this.parent.elementWidthChanged(this);
            }
        });
        this.registerPropertyChangedHandlers(["indent", "innerIndent", "rightIndent"], () => { this.resetIndents(); });
        this.registerPropertyChangedHandlers(["colSpan"], () => { var _a; (_a = this.parent) === null || _a === void 0 ? void 0 : _a.updateColumns(); });
    }
    getType() {
        return "panel";
    }
    get contentId() {
        return this.id + "_content";
    }
    getSurvey(live = false) {
        if (live && this.isPanel) {
            return !!this.parent ? this.parent.getSurvey(live) : null;
        }
        return super.getSurvey(live);
    }
    get isPanel() {
        return true;
    }
    /**
     * Returns a page to which the panel belongs and allows you to move this panel to a different page.
     * @see PanelModelBase.parent
     */
    get page() {
        return this.getPage(this.parent);
    }
    set page(val) {
        this.setPage(this.parent, val);
    }
    removeFromParent() {
        if (!!this.parent) {
            this.removeSelfFromList(this.parent.elements);
        }
    }
    moveTo(container, insertBefore = null) {
        return this.moveToBase(this.parent, container, insertBefore);
    }
    /**
     * Returns the visible index of the panel in the survey. Commonly it is -1 and it doesn't show.
     * You have to set showNumber to true to show index/numbering for the Panel
     * @see showNumber
     */
    get visibleIndex() {
        return this.getPropertyValue("visibleIndex", -1);
    }
    /**
     * Specifies whether to show the panel number in the title.
     *
     * Default value: `false`
     * @see SurveyModel.showQuestionNumbers
     * @see SurveyModel.questionTitlePattern
     */
    get showNumber() {
        return this.getPropertyValue("showNumber");
    }
    set showNumber(val) {
        this.setPropertyValue("showNumber", val);
        this.notifySurveyOnVisibilityChanged();
    }
    addNoFromChild(no) {
        if (this.isQuestionIndexRecursive)
            return this.calcNo() + no;
        return super.addNoFromChild(no);
    }
    /**
     * Specifies whether to display survey element numbers within this page/panel and how to calculate them.
     *
     * Possible values:
     *
     * - `"default"` - Inherits the setting from the parent panel, page, or survey.
     * - `"recursive"` - Applies recursive numbering to elements nested within this page/panel (for example, 1 -> 1.1 -> 1.1.1, etc.).
     * - `"onpanel"` - Starts numbering within this page/panel from scratch.
     * - `false` or `"off"` - Hides question numbers within this page/panel.
     * @see [SurveyModel.showQuestionNumbers](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showQuestionNumbers)
     * @see showNumber
     */
    get showQuestionNumbers() {
        return this.getPropertyValue("showQuestionNumbers");
    }
    set showQuestionNumbers(value) {
        this.setPropertyValue("showQuestionNumbers", value);
        this.notifySurveyOnVisibilityChanged();
    }
    /**
     * Specifies a number or letter used to start numbering of elements inside the panel.
     *
     * You can include desired prefixes and postfixes alongside the number or letter:
     *
     * ```js
     * "questionStartIndex": "a.", // a., b., c., ...
     * "questionStartIndex": "#3", // #3, #4, #5, ...
     * "questionStartIndex": "(B)." // (B)., (C)., (D)., ...
     * ```
     * Default value: `"1."` (inherited from `SurveyModel`'s `questionStartIndex` property)
     * @see SurveyModel.questionStartIndex
     * @see showQuestionNumbers
     */
    get questionStartIndex() {
        return this.getPropertyValue("questionStartIndex", "");
    }
    set questionStartIndex(val) {
        this.setPropertyValue("questionStartIndex", val);
    }
    getQuestionStartIndex() {
        if (!!this.questionStartIndex)
            return this.questionStartIndex;
        return super.getQuestionStartIndex();
    }
    /**
     * A question number or letter (depends on the `questionStartIndex` property).
     *
     * When the question number, title, or the entire question is invisible, this property returns an empty string.
     * @see questionStartIndex
     * @see showNumber
     * @see visibleIf
     */
    get no() {
        return this.getPropertyValue("no", undefined, () => this.calcNo());
    }
    calcNo() {
        let no = Helpers.getNumberByIndex(this.visibleIndex, this.getStartIndex());
        if (!!this.parent) {
            no = this.parent.addNoFromChild(no);
        }
        if (this.survey) {
            no = this.survey.getUpdatedPanelNo(this, no);
        }
        return no || "";
    }
    notifyStateChanged(prevState) {
        if (!this.isLoadingFromJson) {
            this.locTitle.strChanged();
        }
        super.notifyStateChanged(prevState);
    }
    createLocTitleProperty() {
        const locTitleValue = super.createLocTitleProperty();
        locTitleValue.onGetTextCallback = (text) => {
            if (!text && (this.state !== "default")) {
                text = this.name;
            }
            return text;
        };
        return locTitleValue;
    }
    beforeSetVisibleIndex(index) {
        if (this.isPage)
            return super.beforeSetVisibleIndex(index);
        let visibleIndex = -1;
        if ((this.showNumber || this.isQuestionIndexRecursive) && (this.isDesignMode || !this.locTitle.isEmpty || this.hasParentInQuestionIndex())) {
            visibleIndex = index;
        }
        this.setPropertyValue("visibleIndex", visibleIndex);
        this.resetPropertyValue("no");
        return visibleIndex < 0 ? 0 : 1;
    }
    getPanelStartIndex(index) {
        if (this.showQuestionNumbers === "off")
            return -1;
        if (this.isQuestionIndexOnPanel)
            return 0;
        return index;
    }
    get isQuestionIndexOnPanel() {
        return this.showQuestionNumbers === "onpanel" || this.isQuestionIndexRecursive;
    }
    get isQuestionIndexRecursive() {
        if (this.isPage)
            return false;
        const val = this.showQuestionNumbers;
        if (val !== "default")
            return val === "recursive";
        return !!this.survey && this.survey.showQuestionNumbers === "recursive";
    }
    hasParentInQuestionIndex() {
        if (!this.isQuestionIndexOnPanel)
            return false;
        const str = this.questionStartIndex;
        const index = str.indexOf(".");
        return index > -1 && index < str.length - 1;
    }
    isContinueNumbering() {
        return this.showQuestionNumbers !== "off" && !this.isQuestionIndexOnPanel;
    }
    notifySurveyOnVisibilityChanged() {
        if (this.survey != null && !this.isLoadingFromJson) {
            this.survey.panelVisibilityChanged(this, this.isVisible);
        }
    }
    getRenderedTitle(str) {
        if (this.isPanel && !str) {
            if (this.isCollapsed || this.isExpanded)
                return this.name;
            if (this.isDesignMode)
                return "[" + this.name + "]";
        }
        return super.getRenderedTitle(str);
    }
    /**
     * Increases or decreases an indent of panel content from the left edge. Accepts positive integer values and 0.
     */
    get innerIndent() {
        return this.getPropertyValue("innerIndent");
    }
    set innerIndent(val) {
        this.setPropertyValue("innerIndent", val);
    }
    /**
     * Disable this property if you want to render the current panel on the same line or row with the previous question or panel.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/arrange-multiple-questions-in-single-line/ (linkStyle))
     */
    get startWithNewLine() {
        return this.getPropertyValue("startWithNewLine");
    }
    set startWithNewLine(value) {
        this.setPropertyValue("startWithNewLine", value);
    }
    get allowAdaptiveActions() {
        return this.getPropertyValue("allowAdaptiveActions");
    }
    set allowAdaptiveActions(val) {
        this.setPropertyValue("allowAdaptiveActions", val);
    }
    get innerPaddingLeft() {
        const func = () => {
            return this.getIndentSize(this.innerIndent);
        };
        return this.getPropertyValue("innerPaddingLeft", undefined, func);
    }
    set innerPaddingLeft(val) {
        this.setPropertyValue("innerPaddingLeft", val);
    }
    calcPaddingLeft() {
        return this.getIndentSize(this.indent);
    }
    calcPaddingRight() {
        return this.getIndentSize(this.rightIndent);
    }
    resetIndents() {
        this.resetPropertyValue("innerPaddingLeft");
        super.resetIndents();
    }
    getIndentSize(indent) {
        if (!this.survey)
            return undefined;
        if (indent < 1)
            return "";
        var css = this.survey["css"];
        if (!css || !css.question || !css.question.indent)
            return "";
        return indent * css.question.indent + "px";
    }
    clearOnDeletingContainer() {
        this.elements.forEach((element) => {
            if (element instanceof Question || element instanceof PanelModel) {
                element.clearOnDeletingContainer();
            }
        });
    }
    get footerActions() {
        return this.getPropertyValue("footerActions");
    }
    getFooterToolbar() {
        var _a, _b;
        if (!this.footerToolbarValue) {
            var actions = this.footerActions;
            if (this.hasEditButton) {
                actions.push({
                    id: "cancel-preview",
                    locTitle: this.survey.locEditText,
                    innerCss: this.survey.cssNavigationEdit,
                    component: "sv-nav-btn",
                    action: () => { this.cancelPreview(); }
                });
            }
            if (!!this.onGetFooterActionsCallback) {
                actions = this.onGetFooterActionsCallback();
            }
            else {
                actions = (_a = this.survey) === null || _a === void 0 ? void 0 : _a.getUpdatedPanelFooterActions(this, actions);
            }
            this.footerToolbarValue = this.createActionContainer(this.allowAdaptiveActions);
            let footerCss = this.onGetFooterToolbarCssCallback ? this.onGetFooterToolbarCssCallback() : "";
            if (!footerCss) {
                footerCss = (_b = this.cssClasses.panel) === null || _b === void 0 ? void 0 : _b.footer;
            }
            if (footerCss) {
                this.footerToolbarValue.containerCss = footerCss;
            }
            this.footerToolbarValue.setItems(actions);
        }
        return this.footerToolbarValue;
    }
    get hasEditButton() { return false; }
    cancelPreview() {
        if (!this.hasEditButton)
            return;
        this.survey.cancelPreviewByPage(this);
    }
    get cssTitle() {
        return this.getCssPanelTitle();
    }
    getCssPanelTitle() {
        return this.getCssTitle(this.cssClasses.panel);
    }
    getCssTitleExpandableSvg() {
        if (this.state === "default")
            return null;
        return this.cssClasses.panel.titleExpandableSvg;
    }
    get showErrorsAbovePanel() {
        return !this.showPanelAsPage;
    }
    getCssError(cssClasses) {
        if (this.isPage)
            return super.getCssError(cssClasses);
        const builder = new CssClassBuilder()
            .append(super.getCssError(cssClasses))
            .append(cssClasses.panel.errorsContainer);
        return builder.append("panel-error-root", builder.isEmpty()).toString();
    }
    onVisibleChanged() {
        super.onVisibleChanged();
        this.notifySurveyOnVisibilityChanged();
    }
    needResponsiveWidth() {
        if (!this.startWithNewLine) {
            return true;
        }
        else {
            return super.needResponsiveWidth();
        }
    }
    focusIn() {
        if (!this.survey)
            return;
        this.survey.whenPanelFocusIn(this);
    }
    getHasFrameV2() {
        return super.getHasFrameV2() && !this.showPanelAsPage;
    }
    getIsNested() {
        return super.getIsNested() && this.parent !== undefined;
    }
    get showPanelAsPage() {
        return false;
    }
    /**
     * Expands the panel.
     * @param focusFirstQuestion Specifies whether to focus the first question within the expanded panel. Default value: `true`.
     * @hidefor PageModel
     * @see state
     * @see toggleState
     * @see collapse
     * @see isCollapsed
     * @see isExpanded
     */
    expand(focusFirstQuestion = true) {
        this.forcusFirstQuestionOnExpand = focusFirstQuestion;
        super.expand();
    }
    onElementExpanded(elementIsRendered) {
        if (!this.forcusFirstQuestionOnExpand) {
            return;
        }
        if (this.survey != null && !this.isLoadingFromJson) {
            const q = this.getFirstQuestionToFocus(false);
            if (!!q) {
                setTimeout(() => {
                    if (!this.isDisposed && !!this.survey) {
                        this.survey.scrollElementToTop(q, q, null, q.inputId, false, { behavior: "smooth" });
                    }
                }, elementIsRendered ? 0 : 15);
            }
        }
    }
    getCssRoot(cssClasses) {
        return new CssClassBuilder()
            .append(super.getCssRoot(cssClasses))
            .append(cssClasses.container)
            .append(cssClasses.asPage, this.showPanelAsPage)
            .append(cssClasses.invisible, !this.isDesignMode && this.areInvisibleElementsShowing && !this.visible)
            .toString();
    }
    getContainerCss() {
        return this.getCssRoot(this.cssClasses.panel);
    }
    afterRenderCore(element) {
        var _a;
        super.afterRenderCore(element);
        if (this.isPanel) {
            (_a = this.survey) === null || _a === void 0 ? void 0 : _a.afterRenderPanel(this, element);
        }
    }
}
Serializer.addClass("panelbase", [
    "name",
    {
        name: "elements",
        alternativeName: "questions",
        baseClassName: "question",
        visible: false,
        isLightSerializable: false,
    },
    { name: "visible:switch", default: true, overridingProperty: "visibleIf" },
    { name: "readOnly:boolean", overridingProperty: "enableIf" },
    "visibleIf:condition",
    "enableIf:condition",
    "requiredIf:condition",
    {
        name: "questionTitleWidth",
        visibleIf: function (obj) {
            return !!obj && obj["availableQuestionTitleWidth"]();
        }
    },
    {
        name: "questionTitleLocation",
        default: "default",
        choices: ["default", "top", "bottom", "left", "hidden"],
    },
    {
        name: "gridLayoutColumns:panellayoutcolumns",
        className: "panellayoutcolumn", isArray: true,
        onSerializeValue: (obj) => { return obj.getSerializableColumnsValue(); },
        visibleIf: function (obj) { return !!obj && !!obj.survey && obj.survey.gridLayoutEnabled; }
    },
    { name: "title:text", serializationProperty: "locTitle" },
    { name: "description:text", serializationProperty: "locDescription" },
    {
        name: "questionOrder", alternativeName: "questionsOrder",
        default: "default",
        choices: ["default", "initial", "random"],
    },
    { name: "questionErrorLocation", default: "default", choices: ["default", "top", "bottom"] }
], function () {
    return new PanelModelBase();
});
Serializer.addClass("panel", [
    { name: "state", default: "default", choices: ["default", "collapsed", "expanded"] },
    { name: "isRequired:switch", overridingProperty: "requiredIf" },
    { name: "requiredErrorText:text", serializationProperty: "locRequiredErrorText" },
    { name: "startWithNewLine:boolean", default: true },
    { name: "width" },
    { name: "minWidth", defaultFunc: () => "auto" },
    { name: "maxWidth", defaultFunc: () => settings.maxWidth },
    { name: "colSpan:number", visible: false, onSerializeValue: (obj) => { return obj.getPropertyValue("colSpan"); } },
    {
        name: "effectiveColSpan:number", minValue: 1, isSerializable: false,
        visibleIf: function (obj) { return !!obj.survey && obj.survey.gridLayoutEnabled; }
    },
    { name: "innerIndent:number", default: 0, choices: [0, 1, 2, 3] },
    { name: "indent:number", default: 0, choices: [0, 1, 2, 3], visible: false },
    {
        name: "page",
        isSerializable: false,
        visibleIf: function (obj) {
            var survey = obj ? obj.survey : null;
            return !survey || !survey.pages || survey.pages.length > 1;
        },
        choices: function (obj) {
            var survey = obj ? obj.survey : null;
            return survey
                ? survey.pages.map((p) => {
                    return { value: p.name, text: p.title };
                })
                : [];
        },
    },
    { name: "showNumber:boolean" },
    { name: "showQuestionNumbers", default: "default", choices: ["default", "onpanel", "recursive", "off"] },
    { name: "questionStartIndex", visibleIf: (obj) => obj.isPanel },
    { name: "allowAdaptiveActions:boolean", default: true, visible: false },
], function () {
    return new PanelModel();
}, "panelbase");
ElementFactory.Instance.registerElement("panel", (name) => {
    return new PanelModel(name);
});

/**
 * The `PageModel` object describes a survey page and contains properties and methods that allow you to control the page and access its elements (panels and questions).
 *
 * [View Demo](https://surveyjs.io/form-library/examples/nps-question/ (linkStyle))
 */
class PageModel extends PanelModel {
    constructor(name = "") {
        super(name);
        /**
         * A time period that a respondent has spent on this page so far; measured in seconds. Applies only to [quiz surveys](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz).
         * @see timeLimit
         */
        this.timeSpent = 0;
        this._isReadyForClean = true;
        this.createLocalizableString("navigationDescription", this, true);
    }
    getType() {
        return "page";
    }
    toString() {
        return this.name;
    }
    get isPage() {
        return !this.isPanel;
    }
    get isPanel() {
        return !!this.parent;
    }
    get showPanelAsPage() {
        return true;
    }
    get hasEditButton() {
        return this.isPanel && this.survey && this.survey.state === "preview"
            && !!this.parent && !this.parent.isPanel;
    }
    getElementsForRows() {
        var _a;
        if (!this.isStartPage) {
            const q = (_a = this.survey) === null || _a === void 0 ? void 0 : _a.currentSingleElement;
            if (!!q) {
                if (q.page === this)
                    return [q];
                return [];
            }
        }
        return super.getElementsForRows();
    }
    disposeElements() {
        if (!this.isPageContainer) {
            super.disposeElements();
        }
    }
    onRemoveElement(element) {
        if (this.isPageContainer) {
            element.parent = null;
            this.unregisterElementPropertiesChanged(element);
        }
        else {
            super.onRemoveElement(element);
        }
    }
    getTemplate() {
        return this.isPanel ? "panel" : super.getTemplate();
    }
    get no() {
        if (!this.canShowPageNumber() || !this.survey)
            return "";
        let no = this.isStartPage ? "" : this.num + ". ";
        return this.survey.getUpdatedPageNo(this, no);
    }
    get cssTitleNumber() {
        return this.isPanel ? this.cssClasses.panel.number : this.cssClasses.page.number;
    }
    getCssTitleExpandableSvg() {
        return null;
    }
    get cssRequiredMark() {
        return "";
    }
    canShowPageNumber() {
        return this.survey && this.survey.showPageNumbers;
    }
    canShowTitle(survey) {
        return !survey || survey.showPageTitles;
    }
    setTitleValue(val) {
        super.setTitleValue(val);
        this.navigationLocStrChanged();
    }
    getDefaultTitleTagName() {
        return settings.titleTags.page;
    }
    /**
     * A caption displayed on a navigation button in the TOC or progress bar. Applies when [`showTOC`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showTOC) is `true` or when the [progress bar is visible](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showProgressBar), [`progressBarType`](https://surveyjs.io/form-library/documentation/surveymodel#progressBarType) is set to `"pages"`, and [`progressBarShowPageTitles`](https://surveyjs.io/form-library/documentation/surveymodel#progressBarShowPageTitles) is `true`.
     *
     * [Table of Contents Demo](https://surveyjs.io/form-library/examples/table-of-contents/ (linkStyle))
     *
     * [Progress Bar Demo](https://surveyjs.io/form-library/examples/configure-form-navigation-with-progress-indicators/ (linkStyle))
     *
     * > If navigation titles are unspecified, the navigation buttons display page [titles](https://surveyjs.io/form-library/documentation/api-reference/page-model#title) or [names](https://surveyjs.io/form-library/documentation/pagemodel#name).
     */
    get navigationTitle() {
        return this.getLocalizableStringText("navigationTitle");
    }
    set navigationTitle(val) {
        this.setLocalizableStringText("navigationTitle", val);
    }
    get navigationDescription() {
        return this.getLocalizableStringText("navigationDescription");
    }
    set navigationDescription(val) {
        this.setLocalizableStringText("navigationDescription", val);
    }
    get locNavigationDescription() {
        return this.getLocalizableString("navigationDescription");
    }
    navigationLocStrChanged() {
        if (this.locNavigationTitle.isEmpty) {
            this.locTitle.strChanged();
        }
        this.locNavigationTitle.strChanged();
        this.locNavigationDescription.strChanged();
    }
    getMarkdownHtml(text, name, item) {
        const result = super.getMarkdownHtml(text, name, item);
        if (name === "navigationTitle" && this.canShowPageNumber() && result) {
            return this.num + ". " + result;
        }
        return result;
    }
    get passed() {
        return this.getPropertyValue("passed", false);
    }
    set passed(val) {
        this.setPropertyValue("passed", val);
    }
    removeFromParent() {
        if (!!this.survey) {
            this.removeSelfFromList(this.survey.pages);
        }
    }
    /**
     * The visible index of the page. It has values from 0 to visible page count - 1.
     * @see SurveyModel.visiblePages
     * @see SurveyModel.pages
     */
    get visibleIndex() {
        return this.getPropertyValue("visibleIndex", -1);
    }
    set visibleIndex(val) {
        this.setPropertyValue("visibleIndex", val);
    }
    canRenderFirstRows() {
        return !this.isDesignMode || this.visibleIndex == 0;
    }
    /**
     * Returns `true` if this page is a start page.
     *
     * Refer to the following help topic for more information on how to configure a start page: [Start Page](https://surveyjs.io/form-library/documentation/design-survey-create-a-multi-page-survey#start-page).
     */
    get isStartPage() {
        return this.survey && this.survey.isPageStarted(this);
    }
    get isStarted() { return this.isStartPage; }
    calcCssClasses(css) {
        if (this.isPanel)
            return super.calcCssClasses(css);
        const classes = { page: {}, error: {}, pageTitle: "", pageDescription: "", row: "", rowMultiple: "", pageRow: "", rowCompact: "", rowEnter: "", rowLeave: "", rowDelayedEnter: "", rowReplace: "" };
        this.copyCssClasses(classes.page, css.page);
        this.copyCssClasses(classes.error, css.error);
        if (!!css.pageTitle) {
            classes.pageTitle = css.pageTitle;
        }
        if (!!css.pageDescription) {
            classes.pageDescription = css.pageDescription;
        }
        if (!!css.row) {
            classes.row = css.row;
        }
        if (!!css.pageRow) {
            classes.pageRow = css.pageRow;
        }
        if (!!css.rowMultiple) {
            classes.rowMultiple = css.rowMultiple;
        }
        if (!!css.rowCompact) {
            classes.rowCompact = css.rowCompact;
        }
        if (!!css.rowEnter) {
            classes.rowEnter = css.rowEnter;
        }
        if (!!css.rowDelayedEnter) {
            classes.rowDelayedEnter = css.rowDelayedEnter;
        }
        if (!!css.rowLeave) {
            classes.rowLeave = css.rowLeave;
        }
        if (!!css.rowReplace) {
            classes.rowReplace = css.rowReplace;
        }
        if (this.survey) {
            this.survey.updatePageCssClasses(this, classes);
        }
        return classes;
    }
    getCssPanelTitle() {
        if (this.isPanel)
            return super.getCssPanelTitle();
        if (!this.cssClasses.page)
            return "";
        return new CssClassBuilder()
            .append(this.cssClasses.page.title)
            .toString();
    }
    get cssRoot() {
        if (this.isPanel || !this.cssClasses.page || !this.survey)
            return "";
        return new CssClassBuilder()
            .append(this.cssClasses.page.root)
            .append(this.cssClasses.page.emptyHeaderRoot, !this.survey.renderedHasHeader &&
            !(this.survey.isShowProgressBarOnTop && !this.survey.isStaring))
            .toString();
    }
    getCssError(cssClasses) {
        if (this.isPanel)
            return super.getCssError(cssClasses);
        return new CssClassBuilder()
            .append(super.getCssError(cssClasses))
            .append(cssClasses.page.errorsContainer).toString();
    }
    /**
     * @deprecated Use the [`showNavigationButtons`](https://surveyjs.io/form-library/documentation/api-reference/page-model#showNavigationButtons) property instead.
     */
    get navigationButtonsVisibility() {
        const result = this.showNavigationButtons;
        if (result === undefined || result === null) {
            return "inherit";
        }
        return result ? "show" : "hide";
    }
    set navigationButtonsVisibility(val) {
        if (typeof val == "string") {
            val = val.toLowerCase();
        }
        this.showNavigationButtons = val;
    }
    /**
     * Gets or sets the visibility of the Start, Next, Previous, and Complete navigation buttons on this page. Overrides the [`showNavigationButtons`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showNavigationButtons) property specified on the survey-level.
     *
     * Default value: `undefined` (the visibility depends on the survey-level setting)
     */
    get showNavigationButtons() {
        return this.getPropertyValue("showNavigationButtons", undefined);
    }
    set showNavigationButtons(val) {
        this.setShowNavigationButtonsProperty(val);
    }
    setShowNavigationButtonsProperty(val) {
        if (val === true || val === false) {
            this.setPropertyValue("showNavigationButtons", val);
        }
        else if (val === "show") {
            this.setPropertyValue("showNavigationButtons", true);
        }
        else if (val === "hide") {
            this.setPropertyValue("showNavigationButtons", false);
        }
        else {
            this.setPropertyValue("showNavigationButtons", undefined);
        }
    }
    /**
     * Returns `true` if this is the current page.
     * @see SurveyModel.currentPage
     */
    get isActive() {
        return !!this.survey && this.survey.currentPage === this;
    }
    /**
     * Returns `true` if the respondent has already seen this page during the current session.
     */
    get wasShown() {
        return this.wasRendered;
    }
    get hasShown() {
        return this.wasRendered;
    }
    setWasShown(val) {
        if (!val) {
            this.resetWasRendered();
        }
    }
    onFirstRenderingCore() {
        var _a;
        super.onFirstRenderingCore();
        if (this.isDesignMode)
            return;
        var els = this.elements;
        for (var i = 0; i < els.length; i++) {
            if (els[i].isPanel) {
                els[i].randomizeElements(this.areQuestionsRandomized);
            }
        }
        if (this.randomizeElements(this.areQuestionsRandomized)) {
            const singleQuestion = (_a = this.survey) === null || _a === void 0 ? void 0 : _a.currentSingleElement;
            if ((singleQuestion === null || singleQuestion === void 0 ? void 0 : singleQuestion.page) === this) {
                this.survey.currentSingleElement = this.getFirstVisibleElement();
            }
        }
    }
    /**
     * Scrolls this page to the top.
     */
    scrollToTop() {
        if (!!this.survey) {
            this.survey.scrollElementToTop(this, null, this, this.id, false, { block: "start" });
        }
    }
    /**
     * Returns a list of all panels on this page.
     * @param visibleOnly A Boolean value that specifies whether to include only visible panels.
     * @param includingDesignTime For internal use.
     */
    getAllPanels(visibleOnly = false, includingDesignTime = false) {
        var result = new Array();
        this.addPanelsIntoList(result, visibleOnly, includingDesignTime);
        return result;
    }
    getPanels(visibleOnly = false, includingDesignTime = false) {
        return this.getAllPanels(visibleOnly, includingDesignTime);
    }
    /**
     * A time period that a respondent has to complete this page; measured in seconds. Applies only to [quiz surveys](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz).
     *
     * Default value: 0 (time is unlimited)
     *
     * Alternatively, you can use the `SurveyModel`'s [`timeLimitPerPage`](https://surveyjs.io/form-library/documentation/surveymodel#timeLimitPerPage) property to specify identical time periods for all survey pages.
     * @see timeSpent
     */
    get timeLimit() {
        return this.getPropertyValue("timeLimit", 0);
    }
    set timeLimit(val) {
        this.setPropertyValue("timeLimit", val);
    }
    /**
     * @deprecated Use the [`timeLimit`](https://surveyjs.io/form-library/documentation/api-reference/page-model#timeLimit) property instead.
     */
    get maxTimeToFinish() {
        return this.timeLimit;
    }
    set maxTimeToFinish(val) {
        this.timeLimit = val;
    }
    getMaxTimeToFinish() {
        if (this.timeLimit !== 0)
            return this.timeLimit;
        const res = !!this.survey ? this.survey.timeLimitPerPage : 0;
        return res > 0 ? res : 0;
    }
    onNumChanged(value) { }
    onVisibleChanged() {
        if (this.isRandomizing)
            return;
        super.onVisibleChanged();
        if (this.survey != null) {
            this.survey.pageVisibilityChanged(this, this.isVisible);
        }
    }
    ensureRowsVisibility() {
        super.ensureRowsVisibility();
        this.getPanels().forEach((panel) => panel.ensureRowsVisibility());
    }
    get isReadyForClean() {
        return this._isReadyForClean;
    }
    set isReadyForClean(val) {
        const oldValue = this._isReadyForClean;
        this._isReadyForClean = val;
        if (this._isReadyForClean !== oldValue) {
            this.isReadyForCleanChangedCallback && this.isReadyForCleanChangedCallback();
        }
    }
    enableOnElementRerenderedEvent() {
        super.enableOnElementRerenderedEvent();
        this.isReadyForClean = false;
    }
    disableOnElementRerenderedEvent() {
        super.disableOnElementRerenderedEvent();
        this.isReadyForClean = true;
    }
}
__decorate([
    property({ defaultValue: -1, onSet: (val, target) => target.onNumChanged(val) })
], PageModel.prototype, "num", void 0);
Serializer.addClass("page", [
    {
        name: "showNavigationButtons:boolean",
        defaultFunc: () => undefined,
        onSetValue: function (obj, value) {
            obj && obj.setShowNavigationButtonsProperty(value);
        },
        alternativeName: "navigationButtonsVisibility"
    },
    {
        name: "timeLimit:number",
        alternativeName: "maxTimeToFinish",
        default: 0,
        minValue: 0,
        visibleIf: (obj) => {
            return !!obj.survey && obj.survey.showTimer;
        }
    },
    {
        name: "navigationTitle",
        serializationProperty: "locNavigationTitle",
    },
    {
        name: "navigationDescription",
        visibleIf: function (obj) {
            return !!obj.survey && obj.survey.progressBarType === "buttons";
        },
        serializationProperty: "locNavigationDescription",
    },
    { name: "title:text", serializationProperty: "locTitle" },
    { name: "description:text", serializationProperty: "locDescription" },
    { name: "state", visible: false },
    { name: "isRequired", visible: false },
    { name: "startWithNewLine", visible: false },
    { name: "width", visible: false },
    { name: "minWidth", visible: false },
    { name: "maxWidth", visible: false },
    { name: "colSpan", visible: false, isSerializable: false },
    { name: "effectiveColSpan:number", visible: false, isSerializable: false },
    { name: "innerIndent", visible: false },
    { name: "indent", visible: false },
    { name: "page", visible: false, isSerializable: false },
    { name: "showNumber", visible: false },
    { name: "showQuestionNumbers", visible: false },
    { name: "questionStartIndex", visible: false },
    { name: "allowAdaptiveActions", visible: false },
    { name: "requiredErrorText:text", serializationProperty: "locRequiredErrorText", visible: false },
], function () {
    return new PageModel();
}, "panel");

class ProgressButtons extends Base {
    constructor(survey) {
        super();
        this.survey = survey;
        this.onResize = this.addEvent();
    }
    isListElementClickable(index) {
        if (!this.survey.onServerValidateQuestions ||
            this.survey.onServerValidateQuestions.isEmpty ||
            this.survey.checkErrorsMode === "onComplete") {
            return true;
        }
        return index <= this.survey.currentPageNo + 1;
    }
    getRootCss(container = "center") {
        let result = this.survey.css.progressButtonsContainerCenter;
        if (this.survey.css.progressButtonsRoot) {
            result += " " + this.survey.css.progressButtonsRoot + " " + this.survey.css.progressButtonsRoot + "--" + (["footer", "contentBottom"].indexOf(container) !== -1 ? "bottom" : "top");
            result += " " + this.survey.css.progressButtonsRoot + "--" + (this.showItemTitles ? "with-titles" : "no-titles");
        }
        if (this.showItemNumbers && this.survey.css.progressButtonsNumbered) {
            result += " " + this.survey.css.progressButtonsNumbered;
        }
        if (this.isFitToSurveyWidth) {
            result += " " + this.survey.css.progressButtonsFitSurveyWidth;
        }
        return result;
    }
    getListElementCss(index) {
        if (index >= this.survey.visiblePages.length)
            return;
        return new CssClassBuilder()
            .append(this.survey.css.progressButtonsListElementPassed, this.survey.visiblePages[index].passed)
            .append(this.survey.css.progressButtonsListElementCurrent, this.survey.currentPageNo === index)
            .append(this.survey.css.progressButtonsListElementNonClickable, !this.isListElementClickable(index))
            .toString();
    }
    getScrollButtonCss(hasScroller, isLeftScroll) {
        return new CssClassBuilder()
            .append(this.survey.css.progressButtonsImageButtonLeft, isLeftScroll)
            .append(this.survey.css.progressButtonsImageButtonRight, !isLeftScroll)
            .append(this.survey.css.progressButtonsImageButtonHidden, !hasScroller)
            .toString();
    }
    clickListElement(element) {
        if (!(element instanceof PageModel)) {
            element = this.survey.visiblePages[element];
        }
        this.survey.tryNavigateToPage(element);
    }
    isListContainerHasScroller(element) {
        const listContainerElement = element.querySelector("." + this.survey.css.progressButtonsListContainer);
        if (!!listContainerElement) {
            return listContainerElement.scrollWidth > listContainerElement.offsetWidth;
        }
        return false;
    }
    isCanShowItemTitles(element) {
        const listContainerElement = element.querySelector("ul");
        if (!listContainerElement || listContainerElement.children.length < 2)
            return true;
        if (listContainerElement.clientWidth > listContainerElement.parentElement.clientWidth) {
            return false;
        }
        const expectedElementWidth = listContainerElement.children[0].clientWidth;
        for (let i = 0; i < listContainerElement.children.length; i++) {
            if (Math.abs(listContainerElement.children[i].clientWidth - expectedElementWidth) > 5) {
                return false;
            }
        }
        return true;
    }
    clearConnectorsWidth(element) {
        const listContainerElements = element.querySelectorAll(".sd-progress-buttons__connector");
        for (let i = 0; i < listContainerElements.length; i++) {
            listContainerElements[i].style.width = "";
        }
    }
    adjustConnectors(element) {
        const listContainerElement = element.querySelector("ul");
        if (!listContainerElement)
            return;
        const listContainerElements = element.querySelectorAll(".sd-progress-buttons__connector");
        const circleWidth = this.showItemNumbers ? 36 : 20;
        // const sideCorrection = this.survey.isMobile ? circleWidth : listContainerElement.children[0].clientWidth;
        // const connectorWidth = (listContainerElement.clientWidth - sideCorrection) / (listContainerElement.children.length - 1) - circleWidth;
        const connectorWidth = (listContainerElement.clientWidth - circleWidth) / (listContainerElement.children.length - 1) - circleWidth;
        for (let i = 0; i < listContainerElements.length; i++) {
            listContainerElements[i].style.width = connectorWidth + "px";
        }
    }
    get isFitToSurveyWidth() {
        if (surveyCss.currentType !== "default") {
            return false;
        }
        return this.survey.progressBarInheritWidthFrom === "survey" && this.survey.widthMode == "static";
    }
    get progressWidth() {
        if (this.isFitToSurveyWidth) {
            return this.survey.renderedWidth;
        }
        return "";
    }
    get showItemNumbers() {
        if (surveyCss.currentType !== "default") {
            return false;
        }
        return this.survey.progressBarShowPageNumbers;
    }
    get showItemTitles() {
        if (surveyCss.currentType !== "default") {
            return true;
        }
        return this.survey.progressBarShowPageTitles;
    }
    getItemNumber(page) {
        let result = "";
        if (this.showItemNumbers) {
            result += this.survey.visiblePages.indexOf(page) + 1;
        }
        return result;
    }
    get headerText() {
        return this.survey.currentPage ? this.survey.currentPage.renderedNavigationTitle : "";
    }
    get footerText() {
        return this.progressText;
    }
    get progressText() {
        return this.getPropertyValue("progressText", undefined, () => this.survey.getProgressText());
    }
    get progressBarAriaLabel() {
        return getLocaleString("progressbar", this.survey.getLocale());
    }
    resetProgressText() {
        this.resetPropertyValue("progressText");
    }
    processResponsiveness(width) {
        this.onResize.fire(this, { width });
    }
}
class ProgressButtonsResponsivityManager {
    constructor(model, element, viewModel) {
        this.model = model;
        this.element = element;
        this.viewModel = viewModel;
        this.criticalProperties = ["progressBarType", "progressBarShowPageTitles"];
        this.canShowItemTitles = true;
        this.processResponsiveness = (model, options) => {
            this.viewModel.onUpdateScroller(model.isListContainerHasScroller(this.element));
            this.model.clearConnectorsWidth(this.element);
            if (!model.showItemTitles) {
                this.model.adjustConnectors(this.element);
                return;
            }
            if (model.survey.isMobile) {
                this.prevWidth = options.width;
                this.canShowItemTitles = false;
                this.model.adjustConnectors(this.element);
                this.viewModel.onResize(this.canShowItemTitles);
                return;
            }
            if (this.timer !== undefined) {
                clearTimeout(this.timer);
            }
            this.timer = setTimeout(() => {
                if (this.prevWidth === undefined || this.prevWidth < options.width && !this.canShowItemTitles || this.prevWidth > options.width && this.canShowItemTitles) {
                    this.prevWidth = options.width;
                    this.canShowItemTitles = model.isCanShowItemTitles(this.element);
                    this.viewModel.onResize(this.canShowItemTitles);
                    this.timer = undefined;
                }
            }, 10);
        };
        this.model.survey.registerFunctionOnPropertiesValueChanged(this.criticalProperties, () => this.forceUpdate(), "ProgressButtonsResponsivityManager" + this.viewModel.container);
        this.model.onResize.add(this.processResponsiveness);
        this.forceUpdate();
    }
    forceUpdate() {
        this.viewModel.onUpdateSettings();
        this.processResponsiveness(this.model, {});
    }
    dispose() {
        clearTimeout(this.timer);
        this.model.onResize.remove(this.processResponsiveness);
        this.model.survey.unRegisterFunctionOnPropertiesValueChanged(this.criticalProperties, "ProgressButtonsResponsivityManager" + this.viewModel.container);
        this.element = undefined;
        this.model = undefined;
    }
}

function tryFocusPage(survey, panel) {
    if (survey.isDesignMode)
        return true;
    panel.focusFirstQuestion();
    return true;
}
function getPage(question) {
    if (!!question.parentQuestion) {
        return getPage(question.parentQuestion);
    }
    let parent = question.parent;
    while (parent && parent.getType() !== "page" && parent.parent) {
        parent = parent.parent;
    }
    if (parent && parent.getType() === "page") {
        return parent;
    }
    return null;
}
function createTOCListModel(survey, onAction) {
    var items = getTOCItems(survey, onAction);
    const listOptions = {
        items: items,
        searchEnabled: false,
        locOwner: survey,
        listRole: "menu",
        listItemRole: "menuitemradio",
        listAriaLabel: getLocaleString("toc", survey.getLocale())
    };
    var listModel = new ListModel(listOptions);
    listModel.allowSelection = false;
    const updateSelectedItem = (currentPage, defaultSelection) => {
        listModel.selectedItem = !!currentPage && listModel.actions.filter(i => i.id === currentPage.name)[0] || defaultSelection;
    };
    updateSelectedItem(survey.currentPage, items[0]);
    survey.onCurrentPageChanged.add((s, o) => {
        updateSelectedItem(survey.currentPage);
    });
    survey.onFocusInQuestion.add((s, o) => {
        updateSelectedItem(getPage(o.question));
    });
    const updatePagesFunc = () => {
        listModel.setItems(getTOCItems(survey, onAction));
    };
    survey.registerFunctionOnPropertyValueChanged("pages", updatePagesFunc, "toc");
    survey.onEndLoadingFromJson.add(updatePagesFunc);
    return listModel;
}
function getTOCItems(survey, onAction) {
    const pagesSource = survey.pages;
    var items = (pagesSource || []).map(page => {
        return new Action({
            id: page.name,
            locTitle: page.locNavigationTitle,
            action: () => {
                DomDocumentHelper.activeElementBlur();
                !!onAction && onAction();
                if (page.isPage) {
                    return survey.tryNavigateToPage(page);
                }
                else if (page.isPanel) {
                    return tryFocusPage(survey, page);
                }
            },
            visible: new ComputedUpdater(() => {
                return page.isVisible && !(page["isStartPage"]);
            })
        });
    });
    return items;
}
function getTocRootCss(survey, isMobile = false) {
    let rootCss = TOCModel.RootStyle;
    if (isMobile) {
        return rootCss + " " + TOCModel.RootStyle + "--mobile";
    }
    rootCss += (" " + TOCModel.RootStyle + "--" + (survey.tocLocation || "").toLowerCase());
    if (TOCModel.StickyPosition) {
        rootCss += " " + TOCModel.RootStyle + "--sticky";
    }
    return rootCss;
}
class TOCModel {
    constructor(survey) {
        this.survey = survey;
        this.icon = "icon-navmenu_24x24";
        this.togglePopup = () => {
            this.popupModel.toggleVisibility();
        };
        this.listModel = createTOCListModel(survey, () => { this.popupModel.isVisible = false; });
        this.popupModel = new PopupModel("sv-list", { model: this.listModel });
        this.popupModel.overlayDisplayMode = "tablet-dropdown-overlay";
        this.popupModel.displayMode = new ComputedUpdater(() => this.isMobile ? "overlay" : "popup");
        if (TOCModel.StickyPosition) {
            survey.onAfterRenderSurvey.add((s, o) => this.initStickyTOCSubscriptions(o.htmlElement));
            this.initStickyTOCSubscriptions(survey.rootElement);
        }
    }
    initStickyTOCSubscriptions(rootElement) {
        if (TOCModel.StickyPosition && !!rootElement) {
            rootElement.addEventListener("scroll", (event) => {
                this.updateStickyTOCSize(rootElement);
            });
            this.updateStickyTOCSize(rootElement);
        }
    }
    updateStickyTOCSize(rootElement) {
        if (!rootElement) {
            return;
        }
        const tocRootElement = rootElement.querySelector("." + TOCModel.RootStyle);
        if (!!tocRootElement) {
            tocRootElement.style.height = "";
            if (!this.isMobile && TOCModel.StickyPosition && !!rootElement) {
                const rootHeight = rootElement.getBoundingClientRect().height;
                const headerLayoutElement = this.survey.findLayoutElement("advanced-header");
                const advHeader = headerLayoutElement && headerLayoutElement.data;
                let isBelowHeader = !advHeader || advHeader.hasBackground;
                const titleSelector = this.survey.headerView === "advanced" ? ".sv-header" : ".sv_custom_header+div div." + (this.survey.css.title || "sd-title");
                const titleElement = rootElement.querySelector(titleSelector);
                const titleElementHeight = titleElement && isBelowHeader ? titleElement.getBoundingClientRect().height : 0;
                const scrollElement = rootElement.querySelector(".sv-scroll__scroller") || rootElement;
                const scrollCompensationHeight = scrollElement.scrollTop > titleElementHeight ? 0 : titleElementHeight - scrollElement.scrollTop;
                tocRootElement.style.height = (rootHeight - scrollCompensationHeight - 1) + "px";
            }
        }
    }
    get isMobile() {
        return this.survey.isMobile;
    }
    get containerCss() {
        return getTocRootCss(this.survey, this.isMobile);
    }
    dispose() {
        const [handler] = this.survey.unRegisterFunctionOnPropertyValueChanged("pages", "toc");
        this.survey.onEndLoadingFromJson.remove(handler);
        this.survey.onPageAdded.remove(handler);
        this.popupModel.dispose();
        this.listModel.dispose();
    }
}
TOCModel.RootStyle = "sv_progress-toc";
TOCModel.StickyPosition = true;

/**
 * The `SurveyModel` object contains properties and methods that allow you to control the survey and access its elements.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/nps-question/ (linkStyle))
 */
class SurveyModel extends SurveyElementCore {
    get platformName() {
        return SurveyModel.platform;
    }
    /**
     * A suffix added to the name of the property that stores comments.
     *
     * Default value: "-Comment"
     *
     * Many question types allow respondents to leave comments. To enable this functionality, set a question's [`showCommentArea`](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model#showCommentArea) property to `true`. Comment values are saved in a separate property. The property name is composed of the question `name` and `commentSuffix`.
     *
     * Respondents can also leave comments when they select "Other" in choice-based questions, such as Dropdown or Checkboxes. The property name for the comment value is composed according to the same rules. However, you can use the question `name` as a key to store the comment value instead. Disable the [`storeOthersAsComment`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#storeOthersAsComment) property in this case.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/create-checkboxes-question-in-javascript/ (linkStyle))
     */
    get commentSuffix() {
        return settings.commentSuffix;
    }
    set commentSuffix(val) {
        settings.commentSuffix = val;
    }
    get commentPrefix() {
        return this.commentSuffix;
    }
    set commentPrefix(val) {
        this.commentSuffix = val;
    }
    //#endregion
    constructor(jsonObj = null, renderedElement = null) {
        super();
        this.valuesHash = {};
        this.variablesHash = {};
        //#region Event declarations
        this.onEndLoadingFromJson = this.addEvent();
        /**
         * An event that is raised after a [trigger](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#triggers) is executed.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [Conditional Survey Logic (Triggers)](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-survey-logic-triggers (linkStyle))
         * @see triggers
         * @see runTriggers
         */
        this.onTriggerExecuted = this.addEvent();
        /**
         * An event that is raised before the survey is completed. Use this event to prevent survey completion.
         * @see onComplete
         * @see doComplete
         * @see autoAdvanceAllowComplete
         */
        this.onCompleting = this.addEvent();
        /**
         * An event that is raised after the survey is completed. Use this event to send survey results to the server.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * For an example of how to use the methods described above, refer to the following help topic: [Store Survey Results in Your Own Database](https://surveyjs.io/form-library/documentation/handle-survey-results-store#store-survey-results-in-your-own-database).
         *
         * > Do not disable the [`showCompletePage`](https://surveyjs.io/form-library/documentation/surveymodel#showCompletePage) property if you call one of the `options.showSave...` methods. This is required because the UI that indicates data saving progress is integrated into the complete page. If you hide the complete page, the UI also becomes invisible.
         * @see onPartialSend
         * @see doComplete
         * @see autoAdvanceAllowComplete
         */
        this.onComplete = this.addEvent();
        /**
         * An event that is raised before the survey displays a [preview of given answers](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#preview-page). Use this event to cancel the preview.
         * @see showPreviewBeforeComplete
         * @see previewMode
         * @see showPreview
         * @see cancelPreview
         */
        this.onShowingPreview = this.addEvent();
        /**
         * An event that is raised before the survey navigates to a specified URL. Use this event to change the URL or cancel the navigation.
         * @see navigateToUrl
         * @see navigateToUrlOnCondition
         */
        this.onNavigateToUrl = this.addEvent();
        /**
         * An event that is raised when the survey [`state`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#state) changes to `"running"`.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/automatically-move-to-next-page-if-answer-selected/ (linkStyle))
         * @see firstPageIsStartPage
         */
        this.onStarted = this.addEvent();
        /**
         * An event that is raised to save incomplete survey results. Enable the [`partialSendEnabled`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#partialSendEnabled) property for this event to occur.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * Alternatively, you can handle the [`onCurrentPageChanged`](#onCurrentPageChanged) and [`onValueChanged`](#onValueChanged) events, as shown in the following demo: [Continue an Incomplete Survey](https://surveyjs.io/form-library/examples/survey-editprevious/).
         */
        this.onPartialSend = this.addEvent();
        /**
         * An event that is raised before the current page is switched.
         *
         * @see currentPageNo
         * @see nextPage
         * @see prevPage
         **/
        this.onCurrentPageChanging = this.addEvent();
        /**
         * An event that is raised after the current page is switched.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/save-and-restore-user-responses-to-complete-survey/ (linkStyle))
         * @see currentPageNo
         * @see nextPage
         * @see prevPage
         */
        this.onCurrentPageChanged = this.addEvent();
        /**
         * An event that is raised before a question value is changed.
         * @see setValue
         */
        this.onValueChanging = this.addEvent();
        /**
         * An event that is raised after a question value is changed.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/save-and-restore-user-responses-to-complete-survey/ (linkStyle))
         *
         * To handle value changes in matrix cells or panels within a [Dynamic Panel](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model), use the [`onMatrixCellValueChanged`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onMatrixCellValueChanged) or [`onDynamicPanelValueChanged`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onDynamicPanelValueChanged) event.
         * @see setValue
         */
        this.onValueChanged = this.addEvent();
        /**
         * An event that is raised after a [variable](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#variables) or [calculated value](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#calculated-values) is changed.
         *
         * @see setVariable
         * @see calculatedValues
         */
        this.onVariableChanged = this.addEvent();
        /**
         * An event that is raised after question visibility is changed.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * Refer to the following help topic for information on how to implement conditional visibility: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-visibility).
         */
        this.onQuestionVisibleChanged = this.addEvent();
        this.onVisibleChanged = this.onQuestionVisibleChanged;
        /**
         * An event that is raised after page visibility is changed.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * Refer to the following help topic for information on how to implement conditional visibility: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-visibility).
         */
        this.onPageVisibleChanged = this.addEvent();
        /**
         * An event that is raised after panel visibility is changed.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * Refer to the following help topic for information on how to implement conditional visibility: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-visibility).
         */
        this.onPanelVisibleChanged = this.addEvent();
        /**
         * An event that is raised when the survey creates any new object derived from [`Question`](https://surveyjs.io/form-library/documentation/api-reference/question).
         *
         * In a survey, complex elements ([Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/), [Multiple Text](https://surveyjs.io/form-library/examples/questiontype-multipletext/), and [Dynamic Panel](https://surveyjs.io/form-library/examples/questiontype-paneldynamic/)) are composed of questions. Use this event to customize any question regardless of which survey element it belongs to.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * To use this event for questions loaded from JSON, create an empty survey model, add an event handler, and only then populate the model from the JSON object:
         *
         * ```js
         * import { Model } from "survey-core";
         *
         * const surveyJson = {
         *    // ...
         * };
         * // Create an empty model
         * const survey = new Model();
         * // Add an event handler
         * survey.onQuestionCreated.add((sender, options) => {
         *   //...
         * });
         * // Load the survey JSON schema
         * survey.fromJSON(surveyJson);
         * ```
         * @see onQuestionAdded
         */
        this.onQuestionCreated = this.addEvent();
        /**
         * An event that is raised when a new question is added to a panel or page.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * To use this event for questions loaded from JSON, create an empty survey model, add an event handler, and only then populate the model from the JSON object:
         *
         * ```js
         * import { Model } from "survey-core";
         *
         * const surveyJson = {
         *    // ...
         * };
         * // Create an empty model
         * const survey = new Model();
         * // Add an event handler
         * survey.onQuestionAdded.add((sender, options) => {
         *   //...
         * });
         * // Load the survey JSON schema
         * survey.fromJSON(surveyJson);
         * ```
         * @see onQuestionCreated
         */
        this.onQuestionAdded = this.addEvent();
        /**
         * An event that is raised after a question is deleted from the survey.
         */
        this.onQuestionRemoved = this.addEvent();
        /**
         * An event that is raised when a new panel is added to a page.
         */
        this.onPanelAdded = this.addEvent();
        /**
         * An event that is raised after a panel is deleted from the survey.
         */
        this.onPanelRemoved = this.addEvent();
        /**
         * An event that is raised when a new page is added to the survey.
         * @see PanelModel
         */
        this.onPageAdded = this.addEvent();
        /**
         * An event that is raised when a question value is being validated. Use this event to add/remove/modify errors or specify a custom error message.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/add-custom-input-validation/ (linkStyle))
         * @see onServerValidateQuestions
         * @see onValidatePanel
         * @see onMatrixCellValidate
         */
        this.onValidateQuestion = this.addEvent();
        /**
         * @deprecated Use the [`onValidateQuestion`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onValidateQuestion) property instead.
         */
        this.onSettingQuestionErrors = this.addEvent();
        /**
         * Use this event to validate data on your server.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/javascript-server-side-form-validation/ (linkStyle))
         * @see onValidateQuestion
         * @see onValidatePanel
         * @see isValidatingOnServer
         */
        this.onServerValidateQuestions = this.addEvent();
        /**
         * An event that is raised when a panel is being validated. Use this event to add/remove/modify errors or specify a custom error message.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/add-custom-input-validation/ (linkStyle))
         * @see onValidateQuestion
         * @see onServerValidateQuestions
         */
        this.onValidatePanel = this.addEvent();
        /**
         * @deprecated Use the [`onValidateQuestion`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onValidateQuestion), [`onValidatePanel`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onValidatePanel), and [`onValidatePage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onValidatePage) events instead.
         */
        this.onErrorCustomText = this.addEvent();
        /**
         * An event that is raised when a survey page is being validated. Use this event to add/remove/modify errors.
         */
        this.onValidatePage = this.addEvent();
        /**
         * @deprecated Use the [`onValidatePage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onValidatePage) event instead.
         */
        this.onValidatedErrorsOnCurrentPage = this.onValidatePage;
        /**
         * An event that is raised when the survey processes HTML content. Handle this event to modify HTML content before displaying.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/add-html-form-field/ (linkStyle))
         * @see completedHtml
         * @see loadingHtml
         * @see [QuestionHtmlModel.html](https://surveyjs.io/form-library/documentation/api-reference/add-custom-html-to-survey#html)
         */
        this.onProcessHtml = this.addEvent();
        /**
         * Use this event to change a question's display text.
         */
        this.onGetQuestionDisplayValue = this.addEvent();
        /**
         * An event that is raised before the survey displays a question title. Handle this event to modify question titles.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * If you want to modify question numbers, handle the [`onGetQuestionNumber`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onGetQuestionNumber) event.
         * @see requiredMark
         */
        this.onGetQuestionTitle = this.addEvent();
        /**
         * An event that is raised when the survey applies HTML tags to a survey, page, panel, and question title. Handle this event to change the HTML tag of individual titles.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * If you want to specify HTML tags for all titles, use the [`titleTags`](https://surveyjs.io/form-library/documentation/api-reference/settings#titleTags) object in [global settings](https://surveyjs.io/form-library/documentation/api-reference/settings).
         *
         * [View Demo](https://surveyjs.io/form-library/examples/survey-titletagnames/ (linkStyle))
         * @see onGetQuestionTitle
         * @see onGetQuestionNumber
         */
        this.onGetTitleTagName = this.addEvent();
        /**
         * An event that is raised before the survey calculates a question number. Handle this event to modify question numbers.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * If you want to hide question numbers, disable the [`showQuestionNumbers`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showQuestionNumbers) property.
         * @see onGetQuestionTitle
         * @see questionStartIndex
         */
        this.onGetQuestionNumber = this.addEvent();
        /**
         * @deprecated Use the [`onGetQuestionNumber`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onGetQuestionNumber) event instead.
         */
        this.onGetQuestionNo = this.onGetQuestionNumber;
        /**
         * An event that is raised before the survey calculates a panel number. Handle this event to modify panel numbers.
         *
         * This event is raised only for the panels with a [specified title](https://surveyjs.io/form-library/documentation/api-reference/panel-model#title) and [visible number](https://surveyjs.io/form-library/documentation/api-reference/panel-model#showNumber).
         */
        this.onGetPanelNumber = this.addEvent();
        /**
         * An event that is raised before the survey calculates a page number. Handle this event to modify page numbers.
         *
         * This event is raised only if the [`showPageNumbers`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showPageNumbers) property is enabled.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         * @see onGetQuestionTitle
         * @see questionStartIndex
         */
        this.onGetPageNumber = this.addEvent();
        /**
         * An event that is raised before the survey displays progress text. Handle this event to change the progress text in code.
         * @see showProgressBar
         * @see progressBarLocation
         * @see progressBarType
         */
        this.onGetProgressText = this.addEvent();
        /**
         * @deprecated Use the [`onGetProgressText`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onGetProgressText) event instead.
         */
        this.onProgressText = this.onGetProgressText;
        /**
         * An event that is raised to convert Markdown content to HTML.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/edit-survey-questions-markdown/ (linkStyle))
         */
        this.onTextMarkdown = this.addEvent();
        this.onTextRenderAs = this.addEvent();
        /**
         * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
         */
        this.onSendResult = this.addEvent();
        /**
         * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
         */
        this.onGetResult = this.addEvent();
        /**
         * An event that is raised when a respondent opens a dialog window to select files.
         * @see chooseFiles
         */
        this.onOpenFileChooser = this.addEvent();
        /**
         * An event that is raised when a File Upload or Signature Pad question starts to upload a file. Applies only if [`storeDataAsText`](https://surveyjs.io/form-library/documentation/api-reference/file-model#storeDataAsText) is `false`. Use this event to upload files to your server.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [File Upload Demo](https://surveyjs.io/form-library/examples/file-upload/ (linkStyle))
         *
         * [Signature Pad Demo](https://surveyjs.io/form-library/examples/upload-signature-pad-data-to-server/ (linkStyle))
         * @see uploadFiles
         * @see onDownloadFile
         * @see onClearFiles
         */
        this.onUploadFiles = this.addEvent();
        /**
         * An event that is raised when a File Upload question starts to download a file. Use this event to implement file preview when your server stores only file names.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/store-file-names-in-survey-results/ (linkStyle))
         * @see downloadFile
         * @see onClearFiles
         * @see onUploadFiles
         */
        this.onDownloadFile = this.addEvent();
        /**
         * An event that is raised when users clear files in a [File Upload](https://surveyjs.io/form-library/documentation/api-reference/file-model) question or clear signature in a [Signature Pad](https://surveyjs.io/form-library/documentation/api-reference/signature-pad-model) question. Use this event to delete files from your server.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [File Upload Demo](https://surveyjs.io/form-library/examples/file-upload/ (linkStyle))
         *
         * [Signature Pad Demo](https://surveyjs.io/form-library/examples/upload-signature-pad-data-to-server/ (linkStyle))
         * @see clearFiles
         * @see onDownloadFile
         * @see onUploadFiles
         */
        this.onClearFiles = this.addEvent();
        /**
         * An event that is raised after choices are loaded from a server but before they are assigned to a choice-based question, such as [Dropdown](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model) or [Checkboxes](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model). Handle this event if you need to modify the loaded choices.
         */
        this.onChoicesLoaded = this.addEvent();
        /**
         * @deprecated Use the [`onChoicesLoaded`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onChoicesLoaded) event instead.
         */
        this.onLoadChoicesFromServer = this.onChoicesLoaded;
        /**
         * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
         */
        this.onLoadedSurveyFromService = this.addEvent();
        /**
         * An event that is raised when the survey processes [dynamic texts](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#dynamic-texts) and any text in curly brackets. Use this event, for instance, to substitute parameters in a RESTful URL with real values when you [load choices by URL](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model#choicesByUrl).
         */
        this.onProcessDynamicText = this.addEvent();
        /**
         * @deprecated Use the [`onProcessDynamicText`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onProcessDynamicText) event instead.
         */
        this.onProcessTextValue = this.onProcessDynamicText;
        /**
         * An event that is raised before rendering a question. Use it to override default question CSS classes.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/customize-survey-with-css/ (linkStyle))
         * @see css
         */
        this.onUpdateQuestionCssClasses = this.addEvent();
        /**
         * An event that is raised before rendering a standalone panel and panels within [Dynamic Panel](https://surveyjs.io/form-library/examples/duplicate-group-of-fields-in-form/). Use it to override default panel CSS classes.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/customize-survey-with-css/ (linkStyle))
         * @see css
         */
        this.onUpdatePanelCssClasses = this.addEvent();
        /**
         * An event that is raised before rendering a page. Use it to override default page CSS classes.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/customize-survey-with-css/ (linkStyle))
         * @see css
         */
        this.onUpdatePageCssClasses = this.addEvent();
        /**
         * An event that is raised before rendering a choice item in Radio Button Group, Checkboxes and Rating Scale questions. Use it to override default CSS classes applied to choice items.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/customize-survey-with-css/ (linkStyle))
         * @see css
         */
        this.onUpdateChoiceItemCss = this.addEvent();
        /**
         * An event that is raised after the survey is rendered to the DOM. Use this event to modify survey markup.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/survey-animation/ (linkStyle))
         */
        this.onAfterRenderSurvey = this.addEvent();
        this.onAfterRenderHeader = this.addEvent();
        /**
         * An event that is raised after a page is rendered to the DOM. Use it to modify page markup.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/survey-afterrender/ (linkStyle))
         */
        this.onAfterRenderPage = this.addEvent();
        /**
         * An event that is raised after a question is rendered to the DOM. Use it to modify question markup.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/survey-afterrender/ (linkStyle))
         */
        this.onAfterRenderQuestion = this.addEvent();
        /**
         * An event that is raised after a question with a single input field is rendered to the DOM. Use it to modify question markup.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * > This event is not raised for questions without input fields ([HTML](https://surveyjs.io/form-library/documentation/questionhtmlmodel), [Image](https://surveyjs.io/form-library/documentation/questionimagemodel)) or questions with multiple input fields ([Matrix](https://surveyjs.io/form-library/documentation/questionmatrixmodel), [Multiple Text](https://surveyjs.io/form-library/documentation/questionmultipletextmodel)).
         */
        this.onAfterRenderQuestionInput = this.addEvent();
        /**
         * An event that is raised after a panel is rendered to the DOM. Use it to modify panel markup.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * > This event is raised for static [Panels](https://surveyjs.io/form-library/examples/set-properties-on-multiple-questions-using-panel/) as well as panels within a [Dynamic Panel](https://surveyjs.io/form-library/examples/duplicate-group-of-fields-in-form/).
         */
        this.onAfterRenderPanel = this.addEvent();
        /**
         * An event that is raised when an element (input field, checkbox, radio button) within a question gets focus.
         * @see onFocusInPanel
         * @see autoFocusFirstQuestion
         * @see focusQuestion
         */
        this.onFocusInQuestion = this.addEvent();
        /**
         * An event that is raised when an element within a panel gets focus.
         * @see onFocusInQuestion
         * @see autoFocusFirstQuestion
         * @see focusQuestion
         */
        this.onFocusInPanel = this.addEvent();
        /**
         * An event that is raised before a [choice item](https://surveyjs.io/form-library/documentation/api-reference/questionselectbase#choices) is displayed. Use this event to change the visibility of individual choice items in [Checkboxes](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model), [Dropdown](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model), [Radio Button Group](https://surveyjs.io/form-library/documentation/api-reference/radio-button-question-model), and other similar question types.
         */
        this.onShowingChoiceItem = this.addEvent();
        /**
         * Use this event to load choice items in [Dropdown](https://surveyjs.io/form-library/documentation/questiondropdownmodel) and [Tag Box](https://surveyjs.io/form-library/documentation/questiontagboxmodel) questions on demand.
         *
         * This event is raised only for those questions that have the [`choicesLazyLoadEnabled`](https://surveyjs.io/form-library/documentation/questiondropdownmodel#choicesLazyLoadEnabled) property set to `true`.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/lazy-loading-dropdown/ (linkStyle))
         */
        this.onChoicesLazyLoad = this.addEvent();
        /**
         * An event that is raised each time a search string in a [Dropdown](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model) or [Tag Box](https://surveyjs.io/form-library/documentation/api-reference/dropdown-tag-box-model) question changes. Use this event to implement custom filtering of choice options.
         * @see [QuestionDropdownModel.searchEnabled](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model#searchEnabled)
         * @see [QuestionDropdownModel.searchMode](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model#searchMode)
         */
        this.onChoicesSearch = this.addEvent();
        /**
         * Use this event to load a display text for the [default choice item](https://surveyjs.io/form-library/documentation/questiondropdownmodel#defaultValue) in [Dropdown](https://surveyjs.io/form-library/documentation/questiondropdownmodel) and [Tag Box](https://surveyjs.io/form-library/documentation/questiontagboxmodel) questions.
         *
         * If you load choices from a server (use [`choicesByUrl`](https://surveyjs.io/form-library/documentation/questiondropdownmodel#choicesByUrl) or [`onChoicesLazyLoad`](https://surveyjs.io/form-library/documentation/surveymodel#onChoicesLazyLoad)), display texts become available only when data is loaded, which does not happen until a user opens the drop-down menu. However, a display text for a default choice item is required before that. In this case, you can load data individually for the default item within the `onGetChoiceDisplayValue` event handler.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/lazy-loading-dropdown/ (linkStyle))
         */
        this.onGetChoiceDisplayValue = this.addEvent();
        /**
         * An event that is raised after a new row is added to a [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/).
         */
        this.onMatrixRowAdded = this.addEvent();
        /**
         * An event that is raised before a new row is added to a [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/).
         */
        this.onMatrixRowAdding = this.addEvent();
        /**
         * @deprecated Use the [`onMatrixRowAdding`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onMatrixRowAdding) event instead.
         */
        this.onMatrixBeforeRowAdded = this.onMatrixRowAdding;
        /**
         * An event that is raised before a row is deleted from a [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/). You can cancel row deletion and clear row data instead.
         * @see onMatrixRenderRemoveButton
         */
        this.onMatrixRowRemoving = this.addEvent();
        /**
         * An event that is raised after a row is deleted from a [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/).
         * @see onMatrixRenderRemoveButton
         */
        this.onMatrixRowRemoved = this.addEvent();
        /**
         * An event that is raised before rendering the Remove button in a row of a [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/). Use this event to hide the Remove button for individual matrix rows.
         * @see onMatrixRowRemoving
         * @see onMatrixRowRemoved
         */
        this.onMatrixRenderRemoveButton = this.addEvent();
        /**
         * @deprecated Use the [`onMatrixRenderRemoveButton`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onMatrixRenderRemoveButton) event instead.
         */
        this.onMatrixAllowRemoveRow = this.onMatrixRenderRemoveButton;
        /**
         * An event that is raised after the visibility of an [expandable detail section](https://surveyjs.io/form-library/examples/add-expandable-details-section-under-matrix-rows/) is changed. This event can be raised for [Multi-Select](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list) and [Dynamic Matrix](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model) questions.
         */
        this.onMatrixDetailPanelVisibleChanged = this.addEvent();
        /**
         * An event that is raised before a cell in a [Multi-Select Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdropdown/) or [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/) is created. Use this event to change the type of individual matrix cells.
         * @see onAfterRenderMatrixCell
         */
        this.onMatrixCellCreating = this.addEvent();
        /**
          * An event that is raised after a cell in a [Multi-Select Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdropdown/) or [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/) is created.
          * @see onAfterRenderMatrixCell
          */
        this.onMatrixCellCreated = this.addEvent();
        /**
         * An event that is raised after a cell in a [Multi-Select Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdropdown/) or [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/) is rendered to the DOM.
         * @see onMatrixCellCreated
         */
        this.onAfterRenderMatrixCell = this.addEvent();
        /**
         * @deprecated Use the [`onAfterRenderMatrixCell`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onAfterRenderMatrixCell) event instead.
         */
        this.onMatrixAfterCellRender = this.onAfterRenderMatrixCell;
        /**
         * An event that is raised after a cell value is changed in a [Multi-Select Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdropdown/) or [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/).
         * @see onMatrixRowAdding
         */
        this.onMatrixCellValueChanged = this.addEvent();
        /**
         * An event that is raised before a cell value is changed in a [Multi-Select Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdropdown/) or [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/). Use this event to change the cell value.
         * @see onMatrixRowAdding
         */
        this.onMatrixCellValueChanging = this.addEvent();
        /**
         * An event that is raised for [Multi-Select Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdropdown/) and [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/) questions when they validate a cell value. Use this event to display a custom error message based on a condition.
         * @see onMatrixRowAdding
         */
        this.onMatrixCellValidate = this.addEvent();
        /**
         * An event that is raised after a new column is added to a [Multi-Select Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdropdown/) or [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/).
         */
        this.onMatrixColumnAdded = this.addEvent();
        /**
         * An event that is raised on adding a new item in Multiple Text question.
         */
        this.onMultipleTextItemAdded = this.addEvent();
        /**
         * An event that is raised after a new panel is added to a [Dynamic Panel](https://surveyjs.io/form-library/examples/questiontype-paneldynamic/) question.
         */
        this.onDynamicPanelAdded = this.addEvent();
        /**
         * An event that is raised after a panel is deleted from a [Dynamic Panel](https://surveyjs.io/form-library/examples/questiontype-paneldynamic/) question.
         */
        this.onDynamicPanelRemoved = this.addEvent();
        /**
         * An event that is raised before a panel is deleted from a [Dynamic Panel](https://surveyjs.io/form-library/examples/questiontype-paneldynamic/) question. Use this event to cancel the deletion.
         */
        this.onDynamicPanelRemoving = this.addEvent();
        /**
        * An event that is raised every second while the timer is running.
        *
        * Use the [`timeSpent`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#timeSpent) property to find out how many seconds have elapsed.
        * @see timeLimit
        * @see timeLimitPerPage
        * @see showTimer
        * @see timerLocation
        * @see startTimer
        */
        this.onTimerTick = this.addEvent();
        /**
         * @deprecated Use the [`onTimerTick`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onTimerTick) event instead.
         */
        this.onTimer = this.onTimerTick;
        this.onTimerPanelInfoText = this.addEvent();
        /**
         * An event that is raised after a value is changed in a panel within a [Dynamic Panel](https://surveyjs.io/form-library/examples/questiontype-paneldynamic/) question.
         */
        this.onDynamicPanelValueChanged = this.addEvent();
        /**
         * @deprecated Use the [`onDynamicPanelValueChanged`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onDynamicPanelValueChanged) event instead.
         */
        this.onDynamicPanelItemValueChanged = this.onDynamicPanelValueChanged;
        /**
         * An event that is raised before a value is changed in a panel within a [Dynamic Panel](https://surveyjs.io/form-library/examples/questiontype-paneldynamic/) question.
         */
        this.onDynamicPanelValueChanging = this.addEvent();
        /**
         * An event that is raised before a [Dynamic Panel](https://surveyjs.io/form-library/examples/questiontype-paneldynamic/) renders [tab titles](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#templateTabTitle). Use this event to change individual tab titles.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/tabbed-interface-for-duplicate-group-option/ (linkStyle))
         */
        this.onGetDynamicPanelTabTitle = this.addEvent();
        /**
         * An event that is raised after the current panel is changed in a [Dynamic Panel](https://surveyjs.io/form-library/examples/questiontype-paneldynamic/) question.
         */
        this.onDynamicPanelCurrentIndexChanged = this.addEvent();
        /**
         * An event that is raised to define whether a question answer is correct. Applies only to [quiz surveys](https://surveyjs.io/form-library/documentation/design-survey/create-a-quiz).
         */
        this.onCheckAnswerCorrect = this.addEvent();
        /**
         * @deprecated Use the [`onCheckAnswerCorrect`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onCheckAnswerCorrect) event instead.
         */
        this.onIsAnswerCorrect = this.onCheckAnswerCorrect;
        /**
         * An event that is raised when users drag and drop survey elements while designing the survey in [Survey Creator](https://surveyjs.io/survey-creator/documentation/overview). Use this event to control drag and drop operations.
         * @see isDesignMode
         */
        this.onDragDropAllow = this.addEvent();
        this.onMatrixRowDragOver = this.addEvent();
        /**
         * An event this is raised before a survey element (usually page) is scrolled to the top. Use this event to cancel the scroll operation.
         */
        this.onScrollToTop = this.addEvent();
        /**
         * @deprecated Use the [`onScrollToTop`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onScrollToTop) event instead.
         */
        this.onScrollingElementToTop = this.onScrollToTop;
        this.onLocaleChangedEvent = this.addEvent();
        /**
         * An event that allows you to add, delete, or modify actions in a question title.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/survey-titleactions/ (linkStyle))
         * @see [IAction](https://surveyjs.io/form-library/documentation/api-reference/iaction)
        */
        this.onGetQuestionTitleActions = this.addEvent();
        /**
         * An event that allows you to add, delete, or modify actions in a panel title.
         * @see [IAction](https://surveyjs.io/form-library/documentation/api-reference/iaction)
         */
        this.onGetPanelTitleActions = this.addEvent();
        /**
         * An event that allows you to add, delete, or modify actions in a page title.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/modify-titles-of-survey-elements/ (linkStyle))
         * @see [IAction](https://surveyjs.io/form-library/documentation/api-reference/iaction)
         */
        this.onGetPageTitleActions = this.addEvent();
        /**
         * An event that allows you to add, delete, or modify actions in the footer of a [Panel](https://surveyjs.io/form-library/documentation/panelmodel). This panel may belong to a [Dynamic Panel](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model) or be a standalone survey element.
         * @see [IAction](https://surveyjs.io/form-library/documentation/api-reference/iaction)
         */
        this.onGetPanelFooterActions = this.addEvent();
        /**
         * An event that allows you to add, delete, or modify actions in rows of a [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/).
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/employee-information-form/ (linkStyle))
         * @see [IAction](https://surveyjs.io/form-library/documentation/api-reference/iaction)
         */
        this.onGetMatrixRowActions = this.addEvent();
        this.onElementContentVisibilityChanged = this.addEvent();
        /**
         * An event that is raised before an [Expression](https://surveyjs.io/form-library/documentation/api-reference/expression-model) question displays a value. Use this event to override the display value.
         */
        this.onGetExpressionDisplayValue = this.addEvent();
        this.onCheckSingleInputPerPageMode = this.addEvent();
        /**
         * An event that is raised after the visibility of a popup is changed.
         *
         * This event can be raised for [Single-](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model) and [Multi-Select Dropdown](https://surveyjs.io/form-library/documentation/api-reference/dropdown-tag-box-model) questions and [Rating Scale](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model) questions [rendered as drop-down menus](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model#displayMode), and [Multi-Select Matrix](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list) questions that contain columns of the `"dropdown"` or `"tagbox"` [`cellType`](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list#cellType).
         */
        this.onPopupVisibleChanged = this.addEvent();
        /**
         * An event that is raised when users open a drop-down menu.
         *
         * This event can be raised for [Single-](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model) and [Multi-Select Dropdown](https://surveyjs.io/form-library/documentation/api-reference/dropdown-tag-box-model) questions, [Rating Scale](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model) questions [rendered as drop-down menus](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model#displayMode), and [Multi-Select Matrix](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list) questions that contain columns of the `"dropdown"` or `"tagbox"` [`cellType`](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list#cellType). Handle this event to change the drop-down menu type for specific questions or device types.
         */
        this.onOpenDropdownMenu = this.addEvent();
        this.onElementWrapperComponentName = this.addEvent();
        this.onElementWrapperComponentData = this.addEvent();
        /**
         * An event that is raised when users add a custom choice option to a [Single-](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model) or [Multi-Select Dropdown](https://surveyjs.io/form-library/documentation/api-reference/dropdown-tag-box-model) question. Handle this event to save the choice option in a data storage.
         *
         * For information on event handler parameters, refer to descriptions within the interface.
         *
         * To let users add their own choice options, enable the [`allowCustomChoices`](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model#allowCustomChoices) property for individual dropdown questions.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/dropdown-custom-choice-options/ (linkStyle))
         */
        this.onCreateCustomChoiceItem = this.addEvent();
        /**
         * A list of errors in a survey JSON schema.
         * @see ensureUniqueNames
         */
        this.jsonErrors = null;
        this.cssValue = null;
        /**
         * Specifies whether the [Complete page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#complete-page) should display the [survey header](https://surveyjs.io/form-library/examples/brand-your-survey-header/).
         *
         * Possible values:
         *
         * - `true` - Displays the survey header on the Complete page.
         * - `false` - Hides the header when users reach the Complete page.
         * - `"auto"` (default) - Displays a header with the basic view, but hides a header with the advanced view (see the [`headerView`](https://surveyjs.io/form-library/documentation/api-reference/itheme#headerView) property description).
         *
         * > This property cannot be specified in the survey JSON schema. Use dot notation to specify it.
         */
        this.showHeaderOnCompletePage = "auto";
        this._isLazyRenderingSuspended = false;
        /**
         * Specifies whether to hide validation errors thrown by the Required validation in the UI.
         *
         * [Built-In Client-Side Validators](https://surveyjs.io/form-library/documentation/data-validation#built-in-client-side-validators (linkStyle))
         * @see validationEnabled
         * @see validationAllowSwitchPages
         */
        this.hideRequiredErrors = false;
        //#endregion
        this.cssVariables = {};
        this._isMobile = false;
        this._isCompact = false;
        this.setValueOnExpressionCounter = 0;
        this._isDesignMode = false;
        /**
         * Specifies whether respondents can switch the current page even if it contains validation errors.
         *
         * Default value: `false`
         * @see checkErrorsMode
         */
        this.validationAllowSwitchPages = false;
        /**
         * Specifies whether respondents can end a survey with validation errors.
         *
         * Default value: `false`
         * @see checkErrorsMode
         */
        this.validationAllowComplete = false;
        this.isNavigationButtonPressed = false;
        this.mouseDownPage = null;
        this.isSmoothScrollEnabled = false;
        /**
         * An event that is raised when the survey's width or height is changed.
         */
        this.onResize = new EventBase();
        this.isCurrentPageRendering = true;
        this.isCurrentPageRendered = undefined;
        this.skeletonHeight = undefined;
        this.isTriggerIsRunning = false;
        this.triggerValues = null;
        this.triggerKeys = null;
        this.conditionValues = null;
        this.isValueChangedOnRunningCondition = false;
        this.conditionRunnerCounter = 0;
        this.conditionUpdateVisibleIndexes = false;
        this.conditionNotifyElementsOnAnyValueOrVariableChanged = false;
        this.isEndLoadingFromJson = null;
        this.questionHashes = {
            names: {},
            namesInsensitive: {},
            valueNames: {},
            valueNamesInsensitive: {},
        };
        this.setValueFromTriggerCounter = 0;
        this.isMovingPage = false;
        this.needRenderIcons = true;
        this.skippedPages = [];
        this.skeletonComponentName = "sv-skeleton";
        this.taskManager = new SurveyTaskManagerModel();
        this.questionErrorComponent = "sv-question-error";
        this.onBeforeRunConstructor();
        // if (DomDocumentHelper.isAvailable()) {
        //   SurveyModel.stylesManager = new StylesManager();
        // }
        this.createHtmlLocString("completedHtml", "completingSurvey");
        this.createHtmlLocString("completedBeforeHtml", "completingSurveyBefore", "completed-before");
        this.createHtmlLocString("loadingHtml", "loadingSurvey", "loading");
        this.createLocalizableString("emptySurveyText", this, true, "emptySurvey");
        this.createLocalizableString("logo", this, false);
        this.createLocalizableString("startSurveyText", this, false, true);
        this.createLocalizableString("pagePrevText", this, false, true);
        this.createLocalizableString("pageNextText", this, false, true);
        this.createLocalizableString("completeText", this, false, true);
        this.createLocalizableString("previewText", this, false, true);
        this.createLocalizableString("editText", this, false, true);
        this.createLocalizableString("questionTitleTemplate", this, true);
        this.timerModelValue = new SurveyTimerModel(this);
        this.timerModelValue.onTimerTick = (page) => {
            this.doTimer(page);
        };
        this.createNewArray("pages", (value) => {
            if (value.isReadyForCleanChangedCallback) {
                value.isReadyForCleanChangedCallback();
            }
            this.doOnPageAdded(value);
        }, (value) => {
            if (!value.isReadyForClean) {
                value.isReadyForCleanChangedCallback = () => {
                    this.doOnPageRemoved(value);
                    value.isReadyForCleanChangedCallback = undefined;
                };
            }
            else {
                this.doOnPageRemoved(value);
            }
        });
        this.createNewArray("triggers", (value) => {
            value.setOwner(this);
        });
        this.createNewArray("calculatedValues", (value) => {
            value.setOwner(this);
        });
        this.createNewArray("completedHtmlOnCondition", (value) => {
            value.locOwner = this;
        });
        this.createNewArray("navigateToUrlOnCondition", (value) => {
            value.locOwner = this;
        });
        this.registerPropertyChangedHandlers(["locale"], () => {
            this.onSurveyLocaleChanged();
        });
        this.registerPropertyChangedHandlers(["firstPageIsStartPage"], () => {
            this.onFirstPageIsStartedChanged();
        });
        this.registerPropertyChangedHandlers(["readOnly"], () => {
            this.onReadOnlyChanged();
        });
        this.registerPropertyChangedHandlers(["progressBarType"], () => {
            this.updateProgressText();
        });
        this.registerPropertyChangedHandlers(["questionStartIndex", "requiredMark", "questionTitlePattern"], () => {
            this.resetVisibleIndexes();
        });
        this.registerPropertyChangedHandlers(["isLoading", "isCompleted", "isCompletedBefore", "readOnly", "isStartedState", "currentPage", "isShowingPreview"], () => { this.updateState(); });
        this.registerPropertyChangedHandlers(["state", "currentPage", "showPreviewBeforeComplete"], () => { this.onStateAndCurrentPageChanged(); });
        this.registerPropertyChangedHandlers(["logo", "logoPosition"], () => { this.resetHasLogo(); });
        this.registerPropertyChangedHandlers(["backgroundImage"], () => { this.resetPropertyValue("renderBackgroundImage"); });
        this.registerPropertyChangedHandlers(["backgroundImage", "backgroundOpacity", "backgroundImageFit", "fitToContainer", "backgroundImageAttachment"], () => {
            this.resetPropertyValue("backgroundImageStyle");
        });
        this.registerPropertyChangedHandlers(["showPrevButton", "showCompleteButton"], () => { this.updateButtonsVisibility(); });
        this.onGetQuestionNumber.onCallbacksChanged = () => {
            this.resetVisibleIndexes();
        };
        this.onGetPanelNumber.onCallbacksChanged = () => {
            this.resetVisibleIndexes();
        };
        this.onGetProgressText.onCallbacksChanged = () => {
            this.updateProgressText();
        };
        this.onTextMarkdown.onCallbacksChanged = () => {
            this.locStrsChanged();
        };
        this.onProcessHtml.onCallbacksChanged = () => {
            this.locStrsChanged();
        };
        this.onGetQuestionTitle.onCallbacksChanged = () => {
            this.locStrsChanged();
        };
        this.onUpdatePageCssClasses.onCallbacksChanged = () => {
            this.currentPage && this.currentPage.updateElementCss();
        };
        this.onUpdatePanelCssClasses.onCallbacksChanged = () => {
            this.currentPage && this.currentPage.updateElementCss();
        };
        this.onUpdateQuestionCssClasses.onCallbacksChanged = () => {
            this.currentPage && this.currentPage.updateElementCss();
        };
        this.onShowingChoiceItem.onCallbacksChanged = () => {
            this.rebuildQuestionChoices();
        };
        this.locTitle.onStringChanged.add(() => this.resetPropertyValue("titleIsEmpty"));
        this.onBeforeCreating();
        if (jsonObj) {
            if (typeof jsonObj === "string" || jsonObj instanceof String) {
                jsonObj = JSON.parse(jsonObj);
            }
            if (jsonObj && jsonObj.clientId) {
                this.clientId = jsonObj.clientId;
            }
            this.fromJSON(jsonObj);
            if (this.surveyId) {
                this.loadSurveyFromService(this.surveyId, this.clientId);
            }
        }
        this.onCreating();
        if (!!renderedElement) {
            this.render(renderedElement);
        }
        this.updateCss();
        this.setCalculatedWidthModeUpdater();
        this.notifier = new Notifier(this.css.saveData);
        this.notifier.addAction(this.createTryAgainAction(), "error");
        this.onPopupVisibleChanged.add((_, opt) => {
            if (opt.visible) {
                this.onScrollCallback = () => {
                    opt.popup.hide();
                };
            }
            else {
                this.onScrollCallback = undefined;
            }
        });
        this.layoutElements.push({
            id: "timerpanel",
            template: "survey-timerpanel",
            component: "sv-timerpanel",
            data: this.timerModel
        });
        this.layoutElements.push({
            id: "progress-buttons",
            component: "sv-progress-buttons",
            getData: () => this.progressBar,
            processResponsiveness: width => this.progressBar.processResponsiveness && this.progressBar.processResponsiveness(width)
        });
        this.layoutElements.push({
            id: "progress-questions",
            component: "sv-progress-questions",
            data: this
        });
        this.layoutElements.push({
            id: "progress-pages",
            component: "sv-progress-pages",
            data: this
        });
        this.layoutElements.push({
            id: "progress-correctquestions",
            component: "sv-progress-correctquestions",
            data: this
        });
        this.layoutElements.push({
            id: "progress-requiredquestions",
            component: "sv-progress-requiredquestions",
            data: this
        });
        this.addLayoutElement({
            id: "toc-navigation",
            component: "sv-navigation-toc",
            getData: () => this.tocModel,
            processResponsiveness: width => this.tocModel.updateStickyTOCSize(this.rootElement)
        });
        this.layoutElements.push({
            id: "buttons-navigation",
            component: "sv-action-bar",
            getData: () => this.navigationBar
        });
    }
    get tocModel() {
        if (!this.tocModelValue) {
            this.tocModelValue = new TOCModel(this);
        }
        return this.tocModelValue;
    }
    get sjsVersion() {
        return this.getPropertyValue("sjsVersion");
    }
    set sjsVersion(val) {
        this.setPropertyValue("sjsVersion", val);
    }
    processClosedPopup(question, popupModel) {
        throw new Error("Method not implemented.");
    }
    createTryAgainAction() {
        return {
            id: "save-again",
            title: this.getLocalizationString("saveAgainButton"),
            action: () => {
                if (this.isCompleted) {
                    this.saveDataOnComplete();
                }
                else {
                    this.doComplete();
                }
            }
        };
    }
    createHtmlLocString(name, locName, reason) {
        const res = this.createLocalizableString(name, this, false, locName);
        if (reason) {
            res.onGetTextCallback = (str) => { return this.processHtml(str, reason); };
        }
    }
    getType() {
        return "survey";
    }
    onPropertyValueChanged(name, oldValue, newValue) {
        if (name === "questionsOnPageMode") {
            this.onQuestionsOnPageModeChanged(oldValue);
        }
    }
    /**
     * Returns an array of all pages in the survey.
     *
     * To get an array of only visible pages, use the [`visiblePages`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#visiblePages) array.
     * @see PageModel
     */
    get pages() {
        return this.getPropertyValue("pages");
    }
    render(element = null) {
        if (this.renderCallback) {
            this.renderCallback();
        }
    }
    updateSurvey(newProps, oldProps) {
        for (var key in newProps) {
            if (key == "model" || key == "children")
                continue;
            if (key.indexOf("on") == 0 && this[key] && this[key].add) {
                let funcBody = newProps[key];
                let func = function (sender, options) {
                    funcBody(sender, options);
                };
                this[key].add(func);
            }
            else {
                this[key] = newProps[key];
            }
        }
        if (newProps && newProps.data)
            this.onValueChanged.add((sender, options) => {
                newProps.data[options.name] = options.value;
            });
    }
    getCss() {
        return this.css;
    }
    updateCompletedPageCss() {
        this.containerCss = this.css.container;
        this.completedCss = new CssClassBuilder().append(this.css.body)
            .append(this.css.completedPage).toString(); // for completed page
        this.completedBeforeCss = new CssClassBuilder()
            .append(this.css.body)
            .append(this.css.completedBeforePage)
            .toString();
        this.loadingBodyCss = new CssClassBuilder()
            .append(this.css.body)
            .append(this.css.bodyLoading)
            .toString();
    }
    updateCss() {
        this.rootCss = this.getRootCss();
        this.updateNavigationCss();
        this.updateCompletedPageCss();
        this.updateWrapperFormCss();
    }
    /**
     * Gets or sets an object in which keys are UI elements and values are CSS classes applied to them.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/customize-survey-with-css/ (linkStyle))
     */
    get css() {
        if (!this.cssValue) {
            this.cssValue = {};
            this.copyCssClasses(this.cssValue, surveyCss.getCss());
        }
        return this.cssValue;
    }
    set css(value) {
        this.setCss(value);
    }
    setCss(value, needMerge = true) {
        if (needMerge) {
            this.mergeValues(value, this.css);
        }
        else {
            this.cssValue = value;
        }
        this.updateElementCss(false);
    }
    get cssTitle() {
        return this.css.title;
    }
    get cssNavigationComplete() {
        return this.getNavigationCss(this.cssSurveyNavigationButton, this.css.navigation.complete);
    }
    get cssNavigationPreview() {
        return this.getNavigationCss(this.cssSurveyNavigationButton, this.css.navigation.preview);
    }
    get cssNavigationEdit() {
        return this.getNavigationCss(this.css.navigationButton, this.css.navigation.edit);
    }
    get cssNavigationPrev() {
        return this.getNavigationCss(this.cssSurveyNavigationButton, this.css.navigation.prev);
    }
    get cssNavigationStart() {
        return this.getNavigationCss(this.cssSurveyNavigationButton, this.css.navigation.start);
    }
    get cssNavigationNext() {
        return this.getNavigationCss(this.cssSurveyNavigationButton, this.css.navigation.next);
    }
    get cssSurveyNavigationButton() {
        return new CssClassBuilder().append(this.css.navigationButton).append(this.css.bodyNavigationButton).toString();
    }
    get bodyCss() {
        return new CssClassBuilder().append(this.css.body)
            .append(this.css.bodyWithTimer, this.showTimer && this.state === "running")
            .append(this.css.body + "--" + this.calculatedWidthMode).toString();
    }
    get bodyContainerCss() {
        return this.css.bodyContainer;
    }
    insertAdvancedHeader(advHeader) {
        advHeader.survey = this;
        this.layoutElements.push({
            id: "advanced-header",
            container: "header",
            component: "sv-header",
            index: -100,
            data: advHeader,
            processResponsiveness: width => advHeader.processResponsiveness()
        });
    }
    getNavigationCss(main, btn) {
        return new CssClassBuilder().append(main)
            .append(btn).toString();
    }
    /**
     * Specifies whether to enable lazy rendering.
     *
     * In default mode, a survey renders the entire current page. With lazy rendering, the survey renders the page gradually as a user scrolls it. This helps reduce survey startup time and optimizes large surveys for low-end devices.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-lazy/ (linkStyle))
     * @see [settings.lazyRender](https://surveyjs.io/form-library/documentation/api-reference/settings#lazyRender)
     */
    get lazyRenderEnabled() {
        return this.lazyRenderEnabledValue === true;
    }
    set lazyRenderEnabled(val) {
        if (this.lazyRenderEnabled === val)
            return;
        this.lazyRenderEnabledValue = val;
        const page = this.currentPage;
        if (!!page) {
            page.updateRows();
        }
    }
    /**
     * @deprecated Use the [`lazyRenderEnabled`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#lazyRenderEnabled) property instead.
     */
    get lazyRendering() {
        return this.lazyRenderEnabled;
    }
    set lazyRendering(val) {
        this.lazyRenderEnabled = val;
    }
    get isLazyRendering() {
        return this.lazyRenderEnabled || settings.lazyRender.enabled;
    }
    get lazyRenderFirstBatchSize() {
        return this.lazyRenderFirstBatchSizeValue || settings.lazyRender.firstBatchSize;
    }
    set lazyRenderFirstBatchSize(val) {
        this.lazyRenderFirstBatchSizeValue = val;
    }
    get isLazyRenderingSuspended() {
        return this._isLazyRenderingSuspended;
    }
    suspendLazyRendering() {
        if (!this.isLazyRendering)
            return;
        this._isLazyRenderingSuspended = true;
    }
    releaseLazyRendering() {
        if (!this.isLazyRendering)
            return;
        this._isLazyRenderingSuspended = false;
    }
    updateLazyRenderingRowsOnRemovingElements() {
        var _a, _b;
        if (!this.isLazyRendering)
            return;
        var page = this.currentPage;
        if (!!page) {
            const htmlElement = (_b = (this.rootElement || ((_a = this.creator) === null || _a === void 0 ? void 0 : _a.rootElement))) === null || _b === void 0 ? void 0 : _b.querySelector(`#${page.id}`);
            activateLazyRenderingChecks(htmlElement);
        }
    }
    /**
     * A list of triggers in the survey.
     *
     * [Conditional Survey Logic (Triggers)](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-survey-logic-triggers (linkStyle))
     * @see runTriggers
     * @see onTriggerExecuted
     */
    get triggers() {
        return this.getPropertyValue("triggers");
    }
    set triggers(val) {
        this.setPropertyValue("triggers", val);
    }
    /**
     * An array of [calculated values](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#calculated-values).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/custom-variables-for-background-form-calculations/ (linkStyle))
     */
    get calculatedValues() {
        return this.getPropertyValue("calculatedValues");
    }
    set calculatedValues(val) {
        this.setPropertyValue("calculatedValues", val);
    }
    /**
     * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
     */
    get surveyId() {
        return this.getPropertyValue("surveyId", "");
    }
    set surveyId(val) {
        this.setPropertyValue("surveyId", val);
    }
    /**
     * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
     */
    get surveyPostId() {
        return this.getPropertyValue("surveyPostId", "");
    }
    set surveyPostId(val) {
        this.setPropertyValue("surveyPostId", val);
    }
    /**
     * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
     */
    get clientId() {
        return this.getPropertyValue("clientId", "");
    }
    set clientId(val) {
        this.setPropertyValue("clientId", val);
    }
    /**
     * A cookie name used to save information about survey completion.
     *
     * When this property has a value, the survey creates a cookie with the specified name on completion. This cookie helps ensure that users do not pass the same survey twice. On the second run, they will see the [Completed Before page](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#completedBeforeHtml).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/how-to-prevent-duplicate-form-submissions/ (linkStyle))
     * @see clientId
     */
    get cookieName() {
        return this.getPropertyValue("cookieName", "");
    }
    set cookieName(val) {
        this.setPropertyValue("cookieName", val);
    }
    /**
     * Specifies whether to save survey results when respondents switch between pages. Handle the [`onPartialSend`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onPartialSend) event to implement the save operation.
     *
     * Alternatively, you can handle the [`onCurrentPageChanged`](#onCurrentPageChanged) and [`onValueChanged`](#onValueChanged) events, as shown in the following demo: [Continue an Incomplete Survey](https://surveyjs.io/form-library/examples/survey-editprevious/).
     */
    get partialSendEnabled() {
        return this.getPropertyValue("partialSendEnabled");
    }
    set partialSendEnabled(val) {
        this.setPropertyValue("partialSendEnabled", val);
    }
    /**
     * @deprecated Use the [`partialSendEnabled`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#partialSendEnabled) property instead.
     */
    get sendResultOnPageNext() {
        return this.partialSendEnabled;
    }
    set sendResultOnPageNext(val) {
        this.partialSendEnabled = val;
    }
    /**
     * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
     */
    get surveyShowDataSaving() {
        return this.getPropertyValue("surveyShowDataSaving");
    }
    set surveyShowDataSaving(val) {
        this.setPropertyValue("surveyShowDataSaving", val);
    }
    /**
     * Specifies whether to focus the first question on the page on survey startup or when users switch between pages.
     *
     * Default value: `false` in v1.9.114 and later, `true` in earlier versions
     * @see autoFocusFirstError
     * @see focusFirstQuestion
     * @see focusQuestion
     */
    get autoFocusFirstQuestion() {
        return this.getPropertyValue("autoFocusFirstQuestion");
    }
    set autoFocusFirstQuestion(val) {
        this.setPropertyValue("autoFocusFirstQuestion", val);
    }
    /**
     * @deprecated Use the [`autoFocusFirstQuestion`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#autoFocusFirstQuestion) property instead.
     */
    get focusFirstQuestionAutomatic() {
        return this.autoFocusFirstQuestion;
    }
    set focusFirstQuestionAutomatic(val) {
        this.autoFocusFirstQuestion = val;
    }
    /**
     * Specifies whether to focus the first question with a validation error on the current page.
     *
     * Default value: `true`
     * @see validate
     * @see autoFocusFirstQuestion
     */
    get autoFocusFirstError() {
        return this.getPropertyValue("autoFocusFirstError");
    }
    set autoFocusFirstError(val) {
        this.setPropertyValue("autoFocusFirstError", val);
    }
    /**
     * @deprecated Use the [`autoFocusFirstError`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#autoFocusFirstError) property instead.
     */
    get focusOnFirstError() {
        return this.autoFocusFirstError;
    }
    set focusOnFirstError(val) {
        this.autoFocusFirstError = val;
    }
    /**
     * Gets or sets the visibility of the Start, Next, Previous, and Complete navigation buttons.
     *
     * Possible values:
     *
     * - `true` (default) - Displays the navigation buttons.
     * - `false` - Hides the navigation buttons. This setting may be useful if you [implement custom external navigation](https://surveyjs.io/form-library/examples/external-form-navigation-system/).
     * @see navigationButtonsLocation
     * @see autoAdvanceEnabled
     * @see showPrevButton
     * @see showCompleteButton
     */
    get showNavigationButtons() {
        return this.getPropertyValue("showNavigationButtons");
    }
    set showNavigationButtons(val) {
        if (val === true || val === false) {
            this.setPropertyValue("showNavigationButtons", val);
        }
        else if (val === "none") {
            this.setPropertyValue("showNavigationButtons", false);
        }
        else if (["top", "bottom", "both", "topBottom"].indexOf(val) > -1) {
            this.setPropertyValue("showNavigationButtons", true);
            this.navigationButtonsLocation = val;
        }
    }
    /**
     * Gets or sets the position of the Start, Next, Previous, and Complete navigation buttons. Applies only if the [`showNavigationButtons`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showNavigationButtons) property is `true`.
     *
     * Possible values:
     *
     * - `"bottom"` (default) - Displays the navigation buttons below survey content.
     * - `"top"` - Displays the navigation buttons above survey content.
     * - `"topBottom"` - Displays the navigation buttons above and below survey content.
     * @see autoAdvanceEnabled
     * @see showPrevButton
     * @see showCompleteButton
     */
    get navigationButtonsLocation() {
        return this.getPropertyValue("navigationButtonsLocation");
    }
    set navigationButtonsLocation(val) {
        this.setPropertyValue("navigationButtonsLocation", val);
    }
    /**
     * Specifies whether to display the Previous button. Set this property to `false` if respondents should not move backward along the survey.
     * @see showNavigationButtons
     * @see showCompleteButton
     */
    get showPrevButton() {
        return this.getPropertyValue("showPrevButton");
    }
    set showPrevButton(val) {
        this.setPropertyValue("showPrevButton", val);
    }
    /**
     * Specifies whether to display the Complete button. Set this property to `false` if respondents should not complete the survey.
     * @see showNavigationButtons
     * @see showPrevButton
     */
    get showCompleteButton() {
        return this.getPropertyValue("showCompleteButton", true);
    }
    set showCompleteButton(val) {
        this.setPropertyValue("showCompleteButton", val);
    }
    /**
     * Gets or sets the visibility of the table of contents.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/toc-feature/ (linkStyle))
     * @see tocLocation
     */
    get showTOC() {
        return this.getPropertyValue("showTOC");
    }
    set showTOC(val) {
        this.setPropertyValue("showTOC", val);
    }
    /**
     * Gets or sets the position of the table of contents. Applies only when the table of contents is visible.
     *
     * Possible values:
     *
     * - `"left"` (default)
     * - `"right"`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/toc-feature/ (linkStyle))
     * @see showTOC
     */
    get tocLocation() {
        return this.getPropertyValue("tocLocation");
    }
    set tocLocation(val) {
        this.setPropertyValue("tocLocation", val);
    }
    /**
     * Specifies whether to display the [survey title](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#title).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/brand-your-survey-header/ (linkStyle))
     * @see title
     */
    get showTitle() {
        return this.getPropertyValue("showTitle");
    }
    set showTitle(val) {
        this.setPropertyValue("showTitle", val);
    }
    /**
     * Specifies whether to display [page titles](https://surveyjs.io/form-library/documentation/api-reference/page-model#title).
     */
    get showPageTitles() {
        return this.getPropertyValue("showPageTitles");
    }
    set showPageTitles(val) {
        this.setPropertyValue("showPageTitles", val);
    }
    /**
     * Specifies whether to show the [complete page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#complete-page).
     * @see onComplete
     * @see navigateToUrl
     */
    get showCompletePage() {
        return this.getPropertyValue("showCompletePage");
    }
    set showCompletePage(val) {
        this.setPropertyValue("showCompletePage", val);
    }
    /**
     * @deprecated Use the [`showCompletePage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showCompletePage) property instead.
     */
    get showCompletedPage() { return this.showCompletePage; }
    set showCompletedPage(val) { this.showCompletePage = val; }
    /**
     * A URL to which respondents should be navigated after survey completion.
     * @see onNavigateToUrl
     * @see navigateToUrlOnCondition
     */
    get navigateToUrl() {
        return this.getPropertyValue("navigateToUrl");
    }
    set navigateToUrl(val) {
        this.setPropertyValue("navigateToUrl", val);
    }
    /**
     * An array of objects that allows you to navigate respondents to different URLs after survey completion.
     *
     * Each object should include the [`expression`](https://surveyjs.io/form-library/documentation/api-reference/urlconditionitem#url) and [`url`](https://surveyjs.io/form-library/documentation/api-reference/urlconditionitem#expression) properties. When `expression` evaluates to `true`, the survey navigates to the corresponding `url`. Refer to the following help topic for more information about expressions: [Expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions).
     * @see onNavigateToUrl
     * @see navigateToUrl
     */
    get navigateToUrlOnCondition() {
        return this.getPropertyValue("navigateToUrlOnCondition");
    }
    set navigateToUrlOnCondition(val) {
        this.setPropertyValue("navigateToUrlOnCondition", val);
    }
    getNavigateToUrl() {
        var item = this.getExpressionItemOnRunCondition(this.navigateToUrlOnCondition);
        var url = !!item ? item.url : this.navigateToUrl;
        if (!!url) {
            url = this.processText(url, false);
        }
        return url;
    }
    navigateTo() {
        var url = this.getNavigateToUrl();
        var options = { url: url, allow: true };
        this.onNavigateToUrl.fire(this, options);
        if (!options.url || !options.allow)
            return;
        navigateToUrl(options.url);
    }
    /**
     * Specifies one or multiple characters that designate required questions.
     *
     * Default value: `*`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/modify-question-title/ (linkStyle))
     */
    get requiredMark() {
        return this.getPropertyValue("requiredMark");
    }
    set requiredMark(val) {
        this.setPropertyValue("requiredMark", val);
    }
    /**
     * @deprecated Use the [`requiredMark`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#requiredMark) property instead.
     */
    get requiredText() {
        return this.requiredMark;
    }
    set requiredText(val) {
        this.requiredMark = val;
    }
    beforeSettingQuestionErrors(question, errors) {
        this.makeRequiredErrorsInvisible(errors);
        this.onSettingQuestionErrors.fire(this, {
            question: question,
            errors: errors,
        });
    }
    makeRequiredErrorsInvisible(errors) {
        if (!this.hideRequiredErrors)
            return;
        for (var i = 0; i < errors.length; i++) {
            var erType = errors[i].getErrorType();
            if (erType == "required" || erType == "requireoneanswer") {
                errors[i].visible = false;
            }
        }
    }
    /**
     * Specifies the initial number or letter from which to start question numbering.
     *
     * [Question Numbers](https://surveyjs.io/form-library/documentation/design-survey/configure-question-titles#question-numbers (linkStyle))
     */
    get questionStartIndex() {
        return this.getPropertyValue("questionStartIndex", "");
    }
    set questionStartIndex(val) {
        this.setPropertyValue("questionStartIndex", val);
    }
    /**
     * Specifies whether to store the "Other" option response in a separate property.
     *
     * Default value: `true`
     *
     * Respondents can leave comments when they select "Other" in choice-based questions, such as Dropdown or Checkboxes. Comment values are saved in a separate property. The property name is composed of the question `name` and [`commentSuffix`](#commentSuffix). However, you can use the question `name` as a key to store the comment value instead. Disable the `storeOthersAsComment` property in this case.
     * @see maxCommentLength
     */
    get storeOthersAsComment() {
        return this.getPropertyValue("storeOthersAsComment");
    }
    set storeOthersAsComment(val) {
        this.setPropertyValue("storeOthersAsComment", val);
    }
    /**
     * Specifies the maximum text length in textual questions ([Single-Line Input](https://surveyjs.io/form-library/examples/text-entry-question/), [Long Text](https://surveyjs.io/form-library/examples/add-open-ended-question-to-a-form/), [Multiple Textboxes](https://surveyjs.io/form-library/examples/multiple-text-box-question/)), measured in characters.
     *
     * Default value: 0 (unlimited)
     *
     * You can override this setting for individual questions if you specify their [`maxLength`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#maxLength) property.
     * @see maxCommentLength
     */
    get maxTextLength() {
        return this.getPropertyValue("maxTextLength");
    }
    set maxTextLength(val) {
        this.setPropertyValue("maxTextLength", val);
    }
    /**
     * Specifies the maximum text length for question comments. Applies to questions with the [`showCommentArea`](https://surveyjs.io/form-library/documentation/api-reference/question#showCommentArea) or [`showOtherItem`](https://surveyjs.io/form-library/documentation/api-reference/question#showOtherItem) property set to `true`.
     *
     * Default value: 0 (unlimited)
     * @see maxTextLength
     */
    get maxCommentLength() {
        return this.getPropertyValue("maxCommentLength");
    }
    set maxCommentLength(val) {
        this.setPropertyValue("maxCommentLength", val);
    }
    /**
     * @deprecated Use the [`maxCommentLength`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#maxCommentLength) property instead.
     */
    get maxOthersLength() {
        return this.maxCommentLength;
    }
    set maxOthersLength(val) {
        this.maxCommentLength = val;
    }
    /**
     * Specifies whether the survey switches to the next page automatically after a user answers all questions on the current page.
     *
     * Default value: `false`
     *
     * If you enable this property, the survey is also completed automatically. Set the [`autoAdvanceAllowComplete`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#autoAdvanceAllowComplete) property to `false` if you want to disable this behavior.
     *
     * > If any of the following questions is answered last, the survey does not switch to the next page: Checkboxes, Yes/No (Boolean) (rendered as Checkbox), Long Text, Signature, Image Picker (with Multi Select), File Upload, Single-Select Matrix (not all rows are answered), Dynamic Matrix, Dynamic Panel.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/automatically-move-to-next-page-if-answer-selected/ (linkStyle))
     * @see [`settings.autoAdvanceDelay`](https://surveyjs.io/form-library/documentation/api-reference/settings#autoAdvanceDelay)
     */
    get autoAdvanceEnabled() {
        return this.getPropertyValue("autoAdvanceEnabled");
    }
    set autoAdvanceEnabled(val) {
        this.setPropertyValue("autoAdvanceEnabled", val);
    }
    /**
     * @deprecated Use the [`autoAdvanceEnabled`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#autoAdvanceEnabled) property instead.
     */
    get goNextPageAutomatic() {
        return this.autoAdvanceEnabled;
    }
    set goNextPageAutomatic(val) {
        this.autoAdvanceEnabled = val;
    }
    /**
     * Specifies whether to complete the survey automatically after a user answers all questions on the last page. Applies only if the [`autoAdvanceEnabled`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#autoAdvanceEnabled) property is `true`.
     *
     * Default value: `true`
     * @see [`settings.autoAdvanceDelay`](https://surveyjs.io/form-library/documentation/api-reference/settings#autoAdvanceDelay)
     */
    get autoAdvanceAllowComplete() {
        return this.getPropertyValue("autoAdvanceAllowComplete");
    }
    set autoAdvanceAllowComplete(val) {
        this.setPropertyValue("autoAdvanceAllowComplete", val);
    }
    /**
     * @deprecated Use the [`autoAdvanceAllowComplete`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#autoAdvanceAllowComplete) property instead.
     */
    get allowCompleteSurveyAutomatic() {
        return this.autoAdvanceAllowComplete;
    }
    set allowCompleteSurveyAutomatic(val) {
        this.autoAdvanceAllowComplete = val;
    }
    /**
     * Specifies when the survey validates answers.
     *
     * Possible values:
     *
     * - `"onNextPage"` (default) - Triggers validation before the survey is switched to the next page or completed.
     * - `"onValueChanged"` - Triggers validation each time a question value is changed. [View Demo](https://surveyjs.io/form-library/examples/javascript-form-validation/)
     * - `"onComplete"` - Triggers validation when a user clicks the Complete button. If previous pages contain errors, the survey switches to the page with the first error.
     *
     * > In SurveyJS Form Library v1.12.5 and earlier, the `"onValueChanged"` mode doesn't work with date input fields because of the way browsers process date values. In most browsers, the value is considered changed as soon as a user starts entering the date in a text input field. This means that a user may only enter the day without having the chance to enter the month and year before validation is triggered. For this reason, date input fields are validated before the survey is switched to the next page or completed. Starting with v1.12.6, `"onValueChanged"` works for date input fields as well as for input fields of other types.
     *
     * Refer to the following help topic for more information: [Data Validation](https://surveyjs.io/form-library/documentation/data-validation).
     * @see validationEnabled
     * @see validationAllowSwitchPages
     * @see validationAllowComplete
     * @see validate
     */
    get checkErrorsMode() {
        return this.getPropertyValue("checkErrorsMode");
    }
    set checkErrorsMode(val) {
        this.setPropertyValue("checkErrorsMode", val);
    }
    /**
     * Specifies whether to trigger validation when a user focuses on an empty input field and then leaves it without making any changes. Applies only if [`checkErrorsMode`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#checkErrorsMode) is set to `"onValueChanged"`.
     *
     * Default value: `false`
     *
     * This property changes validation behavior for the following question types:
     *
     * - [Single-Line Input](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model)
     * - [Long Text](https://surveyjs.io/form-library/documentation/api-reference/comment-field-model)
     * - [Dropdown](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model)
     * @see validationEnabled
     * @see validationAllowSwitchPages
     * @see validationAllowComplete
     * @see validate
     */
    get validateVisitedEmptyFields() {
        return this.getPropertyValue("validateVisitedEmptyFields");
    }
    set validateVisitedEmptyFields(val) {
        this.setPropertyValue("validateVisitedEmptyFields", val);
    }
    getValidateVisitedEmptyFields() { return this.validateVisitedEmptyFields && this.isValidateOnValueChange; }
    /**
     * Specifies whether to increase the height of [Long Text](https://surveyjs.io/form-library/examples/add-open-ended-question-to-a-form/) questions and other text areas to accommodate multi-line text content.
     *
     * Default value: `false`
     *
     * You can override this property for individual Long Text questions: [`autoGrow`](https://surveyjs.io/form-library/documentation/api-reference/comment-field-model#autoGrow).
     * @see allowResizeComment
     * @see commentAreaRows
     */
    get autoGrowComment() {
        return this.getPropertyValue("autoGrowComment");
    }
    set autoGrowComment(val) {
        this.setPropertyValue("autoGrowComment", val);
    }
    /**
     * Specifies whether to display a resize handle for [Long Text](https://surveyjs.io/form-library/examples/add-open-ended-question-to-a-form/) questions and other text areas intended for multi-line text content.
     *
     * Default value: `true`
     *
     * You can override this property for individual Long Text questions: [`allowResize`](https://surveyjs.io/form-library/documentation/api-reference/comment-field-model#allowResize).
     * @see autoGrowComment
     * @see commentAreaRows
     */
    get allowResizeComment() {
        return this.getPropertyValue("allowResizeComment");
    }
    set allowResizeComment(val) {
        this.setPropertyValue("allowResizeComment", val);
    }
    /**
     * Specifies the visible height of comment areas, measured in lines. Applies to the questions with the [`showCommentArea`](https://surveyjs.io/form-library/documentation/api-reference/question#showCommentArea) or [`showOtherItem`](https://surveyjs.io/form-library/documentation/api-reference/question#showOtherItem) property enabled.
     *
     * Default value: 2
     *
     * The value of this property is passed on to the `rows` attribute of the underlying `<textarea>` element.
     * @see autoGrowComment
     * @see allowResizeComment
     */
    get commentAreaRows() {
        return this.getPropertyValue("commentAreaRows");
    }
    set commentAreaRows(val) {
        this.setPropertyValue("commentAreaRows", val);
    }
    /**
     * Specifies when to update the question value in questions with a text input field.
     *
     * Possible values:
     *
     * - `"onBlur"` (default) - Updates the value after the input field loses focus.
     * - `"onTyping"` - Updates the value on every key press.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/set-question-value-dynamically/ (linkStyle))
     *
     * > Do not use the `"onTyping"` mode if your survey contains many expressions. Expressions are re-evaluated each time a question value is changed. In `"onTyping"` mode, the question value changes frequently. This may cause performance degradation.
     *
     * You can override this setting for individual questions: [`textUpdateMode`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#textUpdateMode).
     */
    get textUpdateMode() {
        return this.getPropertyValue("textUpdateMode");
    }
    set textUpdateMode(val) {
        this.setPropertyValue("textUpdateMode", val);
    }
    /**
     * Specifies when to remove values of invisible questions from [survey results](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#data).
     *
     * Possible values:
     *
     * - `"onComplete"` (default) - Clears invisible question values when the survey is complete.
     * - `"onHidden"` - Clears a question value when the question becomes invisible. If the question is invisible initially, its value is removed on survey completion.
     * - `"onHiddenContainer"` - Clears a question value when the question or its containter (page or panel) becomes invisible. If the question is invisible initially, its value is removed on survey completion.
     * - `"none"` - Keeps invisible values in survey results.
     * - `true` - Equivalent to `"onComplete"`.
     * - `false` - Equivalent to `"none"`.
     * @see [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-visibility)
     * @see onComplete
     */
    get clearInvisibleValues() {
        return this.getPropertyValue("clearInvisibleValues");
    }
    set clearInvisibleValues(val) {
        if (val === true)
            val = "onComplete";
        if (val === false)
            val = "none";
        this.setPropertyValue("clearInvisibleValues", val);
    }
    /**
     * Removes values that cannot be assigned to a question, for example, choices unlisted in the `choices` array.
     *
     * Call this method after you assign new question values in code to ensure that they are acceptable.
     *
     * > This method does not remove values that fail validation. Call the [`validate()`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#validate) method to validate newly assigned values.
     * @param removeNonExistingRootKeys Pass `true` to remove values that do not correspond to any question or [calculated value](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#calculated-values).
     */
    clearIncorrectValues(removeNonExistingRootKeys = false) {
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].clearIncorrectValues();
        }
        if (!removeNonExistingRootKeys)
            return;
        var data = this.data;
        var hasChanges = false;
        for (var key in data) {
            if (!!this.getQuestionByValueName(key))
                continue;
            if (this.iscorrectValueWithPostPrefix(key, settings.commentSuffix) ||
                this.iscorrectValueWithPostPrefix(key, settings.matrix.totalsSuffix))
                continue;
            var calcValue = this.getCalculatedValueByName(key);
            if (!!calcValue && calcValue.includeIntoResult)
                continue;
            hasChanges = true;
            delete data[key];
        }
        if (hasChanges) {
            this.data = data;
        }
    }
    iscorrectValueWithPostPrefix(key, postPrefix) {
        if (key.indexOf(postPrefix) !== key.length - postPrefix.length)
            return false;
        return !!this.getQuestionByValueName(key.substring(0, key.indexOf(postPrefix)));
    }
    /**
     * Specifies whether to keep values that cannot be assigned to questions, for example, choices unlisted in the `choices` array.
     *
     * > This property cannot be specified in the survey JSON schema. Use dot notation to specify it.
     * @see clearIncorrectValues
     */
    get keepIncorrectValues() {
        return this.getPropertyValue("keepIncorrectValues");
    }
    set keepIncorrectValues(val) {
        this.setPropertyValue("keepIncorrectValues", val);
    }
    /**
     * Specifies the survey's locale.
     *
     * Default value: `""` (a default locale is used)
     *
     * [Localization & Globalization help topic](https://surveyjs.io/form-library/documentation/survey-localization (linkStyle))
     *
     * [Survey Localization demo](https://surveyjs.io/form-library/examples/survey-localization/ (linkStyle))
     */
    get locale() {
        return this.getPropertyValueWithoutDefault("locale") || surveyLocalization.currentLocale;
    }
    set locale(value) {
        if (value === surveyLocalization.defaultLocale && !surveyLocalization.currentLocale) {
            value = "";
        }
        this.setPropertyValue("locale", value);
    }
    onSurveyLocaleChanged() {
        this.notifyElementsOnAnyValueOrVariableChanged("locale");
        this.localeChanged();
        this.onLocaleChangedEvent.fire(this, this.locale);
    }
    get localeDir() {
        return surveyLocalization.localeDirections[this.locale];
    }
    /**
     * Returns an array of locales whose translations are used in the survey.
     *
     * [Localization & Globalization help topic](https://surveyjs.io/form-library/documentation/survey-localization (linkStyle))
     *
     * [Survey Localization demo](https://surveyjs.io/form-library/examples/survey-localization/ (linkStyle))
     */
    getUsedLocales() {
        var locs = new Array();
        this.addUsedLocales(locs);
        //Replace the default locale with the real one
        var index = locs.indexOf("default");
        if (index > -1) {
            var defaultLoc = surveyLocalization.defaultLocale;
            //Remove the defaultLoc
            var defIndex = locs.indexOf(defaultLoc);
            if (defIndex > -1) {
                locs.splice(defIndex, 1);
            }
            index = locs.indexOf("default");
            locs[index] = defaultLoc;
        }
        return locs;
    }
    localeChanged() {
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].localeChanged();
        }
    }
    //ILocalizableOwner
    getLocale() {
        return this.locale;
    }
    locStrsChanged() {
        if (this.isClearingUnsedValues)
            return;
        super.locStrsChanged();
        if (!this.currentPage)
            return;
        if (this.isDesignMode) {
            this.pages.forEach(page => page.locStrsChanged());
        }
        else {
            var page = this.activePage;
            if (!!page) {
                page.locStrsChanged();
            }
            const visPages = this.visiblePages;
            for (var i = 0; i < visPages.length; i++) {
                visPages[i].navigationLocStrChanged();
            }
        }
        if (!this.isStartPageActive) {
            this.updateProgressText();
        }
        if (!!this.navigationBarValue) {
            this.navigationBar.locStrsChanged();
        }
    }
    getMarkdownHtml(text, name, item) {
        return this.getSurveyMarkdownHtml(this, text, name, item);
    }
    getRenderer(name) {
        return this.getRendererForString(this, name);
    }
    getRendererContext(locStr) {
        return this.getRendererContextForString(this, locStr);
    }
    getRendererForString(element, name) {
        let renderAs = this.getBuiltInRendererForString(element, name);
        renderAs = this.elementWrapperComponentNameCore(renderAs, element, "string", name);
        const options = { element: element, name: name, renderAs: renderAs };
        this.onTextRenderAs.fire(this, options);
        return options.renderAs;
    }
    getRendererContextForString(element, locStr) {
        return this.elementWrapperDataCore(locStr, element, "string");
    }
    getExpressionDisplayValue(question, value, displayValue) {
        const options = {
            question: question,
            value: value,
            displayValue: displayValue,
        };
        this.onGetExpressionDisplayValue.fire(this, options);
        return options.displayValue;
    }
    getBuiltInRendererForString(element, name) {
        if (this.isDesignMode)
            return LocalizableString.editableRenderer;
        return undefined;
    }
    getProcessedText(text) {
        return this.processText(text, true);
    }
    getLocString(str) {
        return this.getLocalizationString(str);
    }
    //ISurveyErrorOwner
    getErrorCustomText(text, error) {
        return this.getSurveyErrorCustomText(this, text, error);
    }
    getSurveyErrorCustomText(obj, text, error) {
        const options = {
            text: text,
            name: error.getErrorType(),
            obj: obj,
            error: error
        };
        this.onErrorCustomText.fire(this, options);
        return options.text;
    }
    getQuestionDisplayValue(question, displayValue) {
        const options = { question: question, displayValue: displayValue };
        this.onGetQuestionDisplayValue.fire(this, options);
        return options.displayValue;
    }
    /**
     * A message that is displayed when a survey does not contain visible pages or questions.
     * @see [Localization & Globalization](https://surveyjs.io/form-library/documentation/survey-localization)
     */
    get emptySurveyText() {
        return this.getLocalizableStringText("emptySurveyText");
    }
    set emptySurveyText(val) {
        this.setLocalizableStringText("emptySurveyText", val);
    }
    //#region Title/Header options
    /**
     * An image URL or a Base64-encoded image to use as a survey logo.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-logo/ (linkStyle))
     * @see logoPosition
     * @see logoFit
     */
    get logo() {
        return this.getLocalizableStringText("logo");
    }
    set logo(value) {
        this.setLocalizableStringText("logo", value);
    }
    get locLogo() {
        return this.getLocalizableString("logo");
    }
    /**
     * A logo width in CSS-accepted values.
     *
     * Default value: `auto` (the width is calculated automatically based on the [`logoHeight`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#logoHeight) value to keep the original aspect ratio)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-logo/ (linkStyle))
     * @see logo
     * @see logoPosition
     * @see logoFit
     */
    get logoWidth() {
        return this.getPropertyValue("logoWidth");
    }
    set logoWidth(value) {
        this.setPropertyValue("logoWidth", value);
    }
    get renderedLogoWidth() {
        return this.logoWidth ? getRenderedSize(this.logoWidth) : undefined;
    }
    get renderedStyleLogoWidth() {
        return this.logoWidth ? getRenderedStyleSize(this.logoWidth) : undefined;
    }
    /**
     * A logo height in CSS-accepted values.
     *
     * Default value: `40px`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-logo/ (linkStyle))
     * @see logoWidth
     * @see logo
     * @see logoPosition
     * @see logoFit
     */
    get logoHeight() {
        return this.getPropertyValue("logoHeight");
    }
    set logoHeight(value) {
        this.setPropertyValue("logoHeight", value);
    }
    get renderedLogoHeight() {
        return this.logoHeight ? getRenderedSize(this.logoHeight) : undefined;
    }
    get renderedStyleLogoHeight() {
        return this.logoHeight ? getRenderedStyleSize(this.logoHeight) : undefined;
    }
    /**
     * A logo position relative to the [survey title](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#title).
     *
     * Possible values:
     *
     * - `"left"` (default) - Places the logo to the left of the survey title.
     * - `"right"` - Places the logo to the right of the survey title.
     * - `"none"` - Hides the logo.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-logo/ (linkStyle))
     * @see logo
     * @see logoFit
     */
    get logoPosition() {
        return this.getPropertyValue("logoPosition");
    }
    set logoPosition(value) {
        this.setPropertyValue("logoPosition", value);
    }
    get hasLogo() {
        return this.getPropertyValue("hasLogo", undefined, () => !!this.logo && this.logoPosition !== "none");
    }
    resetHasLogo() {
        this.resetPropertyValue("hasLogo");
    }
    get isLogoBefore() {
        if (this.isDesignMode)
            return false;
        return (this.renderedHasLogo &&
            (this.logoPosition === "left" || this.logoPosition === "top"));
    }
    get isLogoAfter() {
        if (this.isDesignMode)
            return this.renderedHasLogo;
        return (this.renderedHasLogo &&
            (this.logoPosition === "right" || this.logoPosition === "bottom"));
    }
    get logoClassNames() {
        const logoClasses = {
            left: "sv-logo--left",
            right: "sv-logo--right",
            top: "sv-logo--top",
            bottom: "sv-logo--bottom",
        };
        return new CssClassBuilder().append(this.css.logo)
            .append(logoClasses[this.logoPosition]).toString();
    }
    get titleIsEmpty() {
        return this.getPropertyValue("titleIsEmpty", undefined, () => this.locTitle.isEmpty);
    }
    get renderedHasTitle() {
        if (this.isDesignMode)
            return this.isPropertyVisible("title");
        return !this.titleIsEmpty && this.showTitle;
    }
    get renderedHasDescription() {
        if (this.isDesignMode)
            return this.isPropertyVisible("description");
        return !!this.hasDescription && this.showTitle;
    }
    get hasTitle() {
        return this.renderedHasTitle;
    }
    get renderedHasLogo() {
        if (this.isDesignMode)
            return this.isPropertyVisible("logo");
        return this.hasLogo;
    }
    get renderedHasHeader() {
        return this.renderedHasTitle || this.renderedHasLogo;
    }
    /**
     * Specifies how to resize a logo to fit it into its container.
     *
     * Possible values:
     *
     * - `"contain"` (default)
     * - `"cover"`
     * - `"fill"`
     * - `"none"`
     *
     * Refer to the [`object-fit`](https://developer.mozilla.org/en-US/docs/Web/CSS/object-fit) CSS property description for information on the possible values.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-logo/ (linkStyle))
     * @see logo
     * @see logoPosition
     */
    get logoFit() {
        return this.getPropertyValue("logoFit");
    }
    set logoFit(val) {
        this.setPropertyValue("logoFit", val);
    }
    get themeVariables() {
        return Object.assign({}, this.cssVariables);
    }
    setIsMobile(newVal = true) {
        if (this._isMobile !== newVal) {
            this._isMobile = newVal;
            this.updateCss();
            this.getAllQuestions().forEach(q => q.setIsMobile(newVal));
        }
    }
    get isMobile() {
        return this._isMobile && !this.isDesignMode;
    }
    set isCompact(newVal) {
        if (newVal !== this._isCompact) {
            this._isCompact = newVal;
            this.updateElementCss();
            this.triggerResponsiveness(true);
        }
    }
    get isCompact() {
        return this._isCompact;
    }
    isLogoImageChoosen() {
        return this.locLogo.renderedHtml;
    }
    get titleMaxWidth() {
        return "";
    }
    get renderBackgroundImage() {
        return this.getPropertyValue("renderBackgroundImage", undefined, () => wrapUrlForBackgroundImage(this.backgroundImage));
    }
    /**
     * A value from 0 to 1 that specifies how transparent the [background image](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#backgroundImage) should be: 0 makes the image completely transparent, and 1 makes it opaque.
     */
    get backgroundOpacity() {
        return this.getPropertyValue("backgroundOpacity");
    }
    set backgroundOpacity(val) {
        this.setPropertyValue("backgroundOpacity", val);
    }
    get backgroundImageStyle() {
        return this.getPropertyValue("backgroundImageStyle", undefined, () => this.calcBackgroundImageStyle());
    }
    calcBackgroundImageStyle() {
        return {
            opacity: this.backgroundOpacity,
            backgroundImage: this.renderBackgroundImage,
            backgroundSize: this.backgroundImageFit,
            backgroundAttachment: !this.fitToContainer ? this.backgroundImageAttachment : undefined
        };
    }
    updateWrapperFormCss() {
        this.wrapperFormCss = new CssClassBuilder()
            .append(this.css.rootWrapper)
            .append(this.css.rootWrapperHasImage, !!this.backgroundImage)
            .append(this.css.rootWrapperFixed, !this.formScrollDisabled)
            .toString();
    }
    /**
     * HTML content displayed on the [complete page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#complete-page).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/modify-survey-navigation-settings/ (linkStyle))
     * @see showCompletePage
     * @see completedHtmlOnCondition
     */
    get completedHtml() {
        return this.getLocalizableStringText("completedHtml");
    }
    set completedHtml(value) {
        this.setLocalizableStringText("completedHtml", value);
    }
    get locCompletedHtml() {
        return this.getLocalizableString("completedHtml");
    }
    /**
     * An array of objects that allows you to specify different HTML content for the [complete page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#complete-page).
     *
     * Each object should include the [`expression`](https://surveyjs.io/form-library/documentation/api-reference/htmlconditionitem#expression) and [`html`](https://surveyjs.io/form-library/documentation/api-reference/htmlconditionitem#html) properties. When `expression` evaluates to `true`, the survey uses the corresponding HTML markup instead of [`completedHtml`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#completedHtml). Refer to the following help topic for more information about expressions: [Expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/nps-question/ (linkStyle))
     */
    get completedHtmlOnCondition() {
        return this.getPropertyValue("completedHtmlOnCondition");
    }
    set completedHtmlOnCondition(val) {
        this.setPropertyValue("completedHtmlOnCondition", val);
    }
    /**
     * Calculates a given [expression](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions) and returns a result value.
     * @param expression An expression to calculate.
     * @param callback A callback function that you can use to access the calculation result if the expression uses asynchronous functions.
     */
    runExpression(expression, callback) {
        if (!expression)
            return null;
        var values = this.getFilteredValues();
        var properties = this.getFilteredProperties();
        const exp = new ExpressionRunner(expression);
        let onCompleteRes = undefined;
        exp.onRunComplete = (res) => {
            onCompleteRes = res;
            callback && callback(res);
        };
        return exp.run(values, properties) || onCompleteRes;
    }
    get isSettingValueOnExpression() { return this.setValueOnExpressionCounter > 0; }
    startSetValueOnExpression() {
        this.setValueOnExpressionCounter++;
    }
    finishSetValueOnExpression() {
        this.setValueOnExpressionCounter--;
    }
    /**
     * Calculates a given [expression](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions) and returns `true` or `false`.
     * @param expression An expression to calculate.
     */
    runCondition(expression) {
        if (!expression)
            return false;
        var values = this.getFilteredValues();
        var properties = this.getFilteredProperties();
        return new ConditionRunner(expression).run(values, properties);
    }
    /**
     * Executes [all triggers](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#triggers), except ["complete"](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#complete).
     *
     * [Conditional Survey Logic (Triggers)](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-survey-logic-triggers (linkStyle))
     * @see onTriggerExecuted
     */
    runTriggers() {
        this.checkTriggers(this.getFilteredValues(), false);
    }
    get renderedCompletedHtml() {
        var item = this.getExpressionItemOnRunCondition(this.completedHtmlOnCondition);
        return !!item ? item.html : this.completedHtml;
    }
    getExpressionItemOnRunCondition(items) {
        if (items.length == 0)
            return null;
        var values = this.getFilteredValues();
        var properties = this.getFilteredProperties();
        for (var i = 0; i < items.length; i++) {
            if (items[i].runCondition(values, properties)) {
                return items[i];
            }
        }
        return null;
    }
    /**
     * HTML content displayed to a user who has completed the survey before. To identify such users, the survey uses a [cookie name](#cookieName).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/how-to-prevent-duplicate-form-submissions/ (linkStyle))
     * @see processedCompletedBeforeHtml
     */
    get completedBeforeHtml() {
        return this.getLocalizableStringText("completedBeforeHtml");
    }
    set completedBeforeHtml(value) {
        this.setLocalizableStringText("completedBeforeHtml", value);
    }
    get locCompletedBeforeHtml() {
        return this.getLocalizableString("completedBeforeHtml");
    }
    /**
     * HTML content displayed while a survey JSON schema is [being loaded](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#beginLoading).
     * @see processedLoadingHtml
     */
    get loadingHtml() {
        return this.getLocalizableStringText("loadingHtml");
    }
    set loadingHtml(value) {
        this.setLocalizableStringText("loadingHtml", value);
    }
    get locLoadingHtml() {
        return this.getLocalizableString("loadingHtml");
    }
    get navigationBar() {
        if (!this.navigationBarValue) {
            this.navigationBarValue = this.createNavigationBar();
            this.updateNavigationCss();
        }
        return this.navigationBarValue;
    }
    /**
     * Adds a custom navigation item similar to the Previous Page, Next Page, and Complete buttons. Accepts an object described in the [IAction](https://surveyjs.io/Documentation/Library?id=IAction) help section.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-changenavigation/ (linkStyle))
    */
    addNavigationItem(val) {
        if (!val.component) {
            val.component = "sv-nav-btn";
        }
        if (!val.innerCss) {
            val.innerCss = this.cssSurveyNavigationButton;
        }
        return this.navigationBar.addAction(val);
    }
    removeNavigationItem(id) {
        const action = this.navigationBar.getActionById(id);
        if (action) {
            const actions = this.navigationBar.actions;
            actions.splice(actions.indexOf(action), 1);
        }
    }
    /**
     * Gets or sets a caption for the Start button.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/make-quiz-javascript/ (linkStyle))
     * @see firstPageIsStartPage
     * @see [Localization & Globalization](https://surveyjs.io/form-library/documentation/survey-localization)
     */
    get startSurveyText() {
        return this.getLocalizableStringText("startSurveyText");
    }
    set startSurveyText(newValue) {
        this.setLocalizableStringText("startSurveyText", newValue);
    }
    get locStartSurveyText() {
        return this.getLocalizableString("startSurveyText");
    }
    /**
     * Gets or sets a caption for the Previous button.
     * @see [Localization & Globalization](https://surveyjs.io/form-library/documentation/survey-localization)
     */
    get pagePrevText() {
        return this.getLocalizableStringText("pagePrevText");
    }
    set pagePrevText(newValue) {
        this.setLocalizableStringText("pagePrevText", newValue);
    }
    get locPagePrevText() {
        return this.getLocalizableString("pagePrevText");
    }
    /**
     * Gets or sets a caption for the Next button.
     * @see [Localization & Globalization](https://surveyjs.io/form-library/documentation/survey-localization)
     */
    get pageNextText() {
        return this.getLocalizableStringText("pageNextText");
    }
    set pageNextText(newValue) {
        this.setLocalizableStringText("pageNextText", newValue);
    }
    get locPageNextText() {
        return this.getLocalizableString("pageNextText");
    }
    /**
     * Gets or sets a caption for the Complete button.
     * @see [Localization & Globalization](https://surveyjs.io/form-library/documentation/survey-localization)
     */
    get completeText() {
        return this.getLocalizableStringText("completeText");
    }
    set completeText(newValue) {
        this.setLocalizableStringText("completeText", newValue);
    }
    get locCompleteText() {
        return this.getLocalizableString("completeText");
    }
    /**
     * Gets or sets a caption for the Preview button.
     * @see showPreviewBeforeComplete
     * @see showPreview
     * @see editText
     */
    get previewText() {
        return this.getLocalizableStringText("previewText");
    }
    set previewText(newValue) {
        this.setLocalizableStringText("previewText", newValue);
    }
    get locPreviewText() {
        return this.getLocalizableString("previewText");
    }
    /**
     * Gets or sets a caption for the Edit button displayed when the survey shows a [preview of given answers](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#preview-page).
     * @see showPreviewBeforeComplete
     * @see cancelPreview
     * @see previewText
     */
    get editText() {
        return this.getLocalizableStringText("editText");
    }
    set editText(newValue) {
        this.setLocalizableStringText("editText", newValue);
    }
    get locEditText() {
        return this.getLocalizableString("editText");
    }
    getElementTitleTagName(element, tagName) {
        if (this.onGetTitleTagName.isEmpty)
            return tagName;
        const options = { element: element, tagName: tagName };
        this.onGetTitleTagName.fire(this, options);
        return options.tagName;
    }
    /**
     * Specifies a pattern for question titles.
     *
     * Refer to the following help topic for more information: [Title Pattern](https://surveyjs.io/form-library/documentation/design-survey/configure-question-titles#title-pattern).
     */
    get questionTitlePattern() {
        return this.getPropertyValue("questionTitlePattern", "numTitleRequire");
    }
    set questionTitlePattern(val) {
        if (val !== "numRequireTitle" &&
            val !== "requireNumTitle" &&
            val != "numTitle") {
            val = "numTitleRequire";
        }
        this.setPropertyValue("questionTitlePattern", val);
    }
    getQuestionTitlePatternOptions() {
        const res = new Array();
        const title = this.getLocalizationString("questionTitlePatternText");
        const num = !!this.questionStartIndex ? this.questionStartIndex : "1.";
        res.push({
            value: "numTitleRequire",
            text: num + " " + title + " " + this.requiredMark
        });
        res.push({
            value: "numRequireTitle",
            text: num + " " + this.requiredMark + " " + title
        });
        // res.push({
        //   value: "requireNumTitle",
        //   text: this.requiredMark + " " + num + " " + title
        // });
        res.push({
            value: "numTitle",
            text: num + " " + title
        });
        return res;
    }
    get questionTitleTemplate() {
        return this.getLocalizableStringText("questionTitleTemplate");
    }
    set questionTitleTemplate(value) {
        this.setLocalizableStringText("questionTitleTemplate", value);
        this.questionTitlePattern = this.getNewTitlePattern(value);
        this.questionStartIndex = this.getNewQuestionTitleElement(value, "no", this.questionStartIndex, "1");
        this.requiredMark = this.getNewQuestionTitleElement(value, "require", this.requiredMark, "*");
    }
    getNewTitlePattern(template) {
        if (!!template) {
            var strs = [];
            while (template.indexOf("{") > -1) {
                template = template.substring(template.indexOf("{") + 1);
                var ind = template.indexOf("}");
                if (ind < 0)
                    break;
                strs.push(template.substring(0, ind));
                template = template.substring(ind + 1);
            }
            if (strs.length > 1) {
                if (strs[0] == "require")
                    return "requireNumTitle";
                if (strs[1] == "require" && strs.length == 3)
                    return "numRequireTitle";
                if (strs.indexOf("require") < 0)
                    return "numTitle";
            }
            if (strs.length == 1 && strs[0] == "title") {
                return "numTitle";
            }
        }
        return "numTitleRequire";
    }
    getNewQuestionTitleElement(template, name, currentValue, defaultValue) {
        name = "{" + name + "}";
        if (!template || template.indexOf(name) < 0)
            return currentValue;
        var ind = template.indexOf(name);
        var prefix = "";
        var postfix = "";
        var i = ind - 1;
        for (; i >= 0; i--) {
            if (template[i] == "}")
                break;
        }
        if (i < ind - 1) {
            prefix = template.substring(i + 1, ind);
        }
        ind += name.length;
        i = ind;
        for (; i < template.length; i++) {
            if (template[i] == "{")
                break;
        }
        if (i > ind) {
            postfix = template.substring(ind, i);
        }
        i = 0;
        while (i < prefix.length && prefix.charCodeAt(i) < 33)
            i++;
        prefix = prefix.substring(i);
        i = postfix.length - 1;
        while (i >= 0 && postfix.charCodeAt(i) < 33)
            i--;
        postfix = postfix.substring(0, i + 1);
        if (!prefix && !postfix)
            return currentValue;
        var value = !!currentValue ? currentValue : defaultValue;
        return prefix + value + postfix;
    }
    get locQuestionTitleTemplate() {
        return this.getLocalizableString("questionTitleTemplate");
    }
    getUpdatedQuestionTitle(question, title) {
        if (this.onGetQuestionTitle.isEmpty)
            return title;
        const options = { question: question, title: title };
        this.onGetQuestionTitle.fire(this, options);
        return options.title;
    }
    getUpdatedQuestionNo(question, no) {
        if (this.onGetQuestionNumber.isEmpty)
            return no;
        const options = { question: question, number: no, no: no };
        this.onGetQuestionNumber.fire(this, options);
        return options.no === no ? options.number : options.no;
    }
    getUpdatedPanelNo(panel, no) {
        if (this.onGetPanelNumber.isEmpty)
            return no;
        const options = { panel: panel, number: no };
        this.onGetPanelNumber.fire(this, options);
        return options.number;
    }
    getUpdatedPageNo(page, no) {
        if (this.onGetPageNumber.isEmpty)
            return no;
        const options = { page: page, number: no };
        this.onGetPageNumber.fire(this, options);
        return options.number;
    }
    /**
     * Specifies whether page titles contain page numbers.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/how-to-number-pages-and-questions/ (linkStyle))
     * @see onGetPageNumber
     */
    get showPageNumbers() {
        return this.getPropertyValue("showPageNumbers");
    }
    set showPageNumbers(value) {
        if (value === this.showPageNumbers)
            return;
        this.setPropertyValue("showPageNumbers", value);
        this.updateVisibleIndexes();
    }
    /**
     * Specifies whether to display survey element numbers and how to calculate them.
     *
     * Possible values:
     *
     * - `true` or `"on"` - Numbers survey elements in order, regardless of their nesting level.
     * - `"recursive"` - Applies recursive numbering to elements nested in panels (for example, 1 -> 1.1 -> 1.1.1, etc.).
     * - `"onpage"` - Starts numbering on each page from scratch.
     * - `false` or `"off"` - Hides question numbers.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/how-to-number-pages-and-questions/ (linkStyle))
     *
     * If you want to hide the number of an individual question, disable its [`showNumber`](https://surveyjs.io/form-library/documentation/api-reference/question#showNumber) property.
     * @see onGetQuestionNumber
     */
    get showQuestionNumbers() {
        return this.getPropertyValue("showQuestionNumbers");
    }
    set showQuestionNumbers(value) {
        if (value === true) {
            value = "on";
        }
        if (value === false) {
            value = "off";
        }
        value = value.toLowerCase();
        value = value === "onpage" ? "onPage" : value;
        if (value === this.showQuestionNumbers)
            return;
        this.setPropertyValue("showQuestionNumbers", value);
        this.updateVisibleIndexes();
    }
    get progressBar() {
        if (!this.progressBarValue) {
            this.progressBarValue = new ProgressButtons(this);
        }
        return this.progressBarValue;
    }
    /**
     * Specifies the visibility of the progress bar.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/navigation-default/ (linkStyle))
     * @see progressBarLocation
     * @see progressBarType
     * @see progressValue
     */
    get showProgressBar() {
        return this.getPropertyValue("showProgressBar");
    }
    set showProgressBar(newValue) {
        this.setShowProgressBar(newValue);
    }
    setShowProgressBar(newValue) {
        if (newValue === "off") {
            newValue = false;
        }
        if (newValue === true || newValue === false) {
            this.setPropertyValue("showProgressBar", newValue);
        }
        else {
            this.setPropertyValue("showProgressBar", true);
            this.progressBarLocation = newValue;
        }
    }
    /**
     * Specifies the alignment of the progress bar. Applies only if the [`showProgressBar`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showProgressBar) property is `true`.
     *
     * Possible values:
     *
     * - `"aboveHeader"` - Displays the progress bar above the survey header.
     * - `"belowHeader"` - Displays the progress bar below the survey header.
     * - `"bottom"` - Displays the progress bar below survey content.
     * - `"topBottom"` - Displays the progress bar above and below survey content.
     * - `"auto"` (default) - Displays the progress bar below the survey header if the header has a [background image](https://surveyjs.io/form-library/documentation/api-reference/iheader#backgroundImage) or color. Otherwise, the progress bar is displayed above the header.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/navigation-default/ (linkStyle))
     * @see showProgressBar
     * @see progressBarType
     * @see progressValue
     */
    get progressBarLocation() {
        return this.getPropertyValue("progressBarLocation");
    }
    set progressBarLocation(newValue) {
        this.setPropertyValue("progressBarLocation", newValue.toLowerCase());
    }
    /**
     * Specifies the type of information displayed by the progress bar. Applies only when [`showProgressBar`](#showProgressBar) is `true`.
     *
     * Possible values:
     *
     * - `"pages"` (default) - The number of completed pages.
     * - `"questions"` - The number of answered questions.
     * - `"requiredQuestions"` - The number of answered [required questions](https://surveyjs.io/form-library/documentation/api-reference/question#isRequired).
     * - `"correctQuestions"` - The number of correct questions in a [quiz](https://surveyjs.io/form-library/documentation/design-survey/create-a-quiz).
     * - `"buttons"` - *(Obsolete)* Use the `"pages"` property value with the [`progressBarShowPageTitles`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#progressBarShowPageTitles) property set to `true` instead.
     *
     * > When `progressBarType` is set to `"pages"`, you can also enable the [`progressBarShowPageNumbers`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#progressBarShowPageNumbers) and [`progressBarShowPageTitles`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#progressBarShowPageTitles) properties if you want to display page numbers and titles in the progress bar.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/navigation-buttons/ (linkStyle))
     * @see progressValue
     */
    get progressBarType() {
        return this.getPropertyValue("progressBarType");
    }
    set progressBarType(newValue) {
        if (newValue === "correctquestion")
            newValue = "correctQuestion";
        if (newValue === "requiredquestion")
            newValue = "requiredQuestion";
        // if (newValue === "buttons") {
        //   newValue = "pages";
        //   this.progressBarShowPageTitles = true;
        // }
        this.setPropertyValue("progressBarType", newValue);
    }
    get progressBarComponentName() {
        let actualProgressBarType = this.progressBarType;
        if (!settings.legacyProgressBarView && surveyCss.currentType === "default") {
            if (isStrCiEqual(actualProgressBarType, "pages")) {
                actualProgressBarType = "buttons";
            }
        }
        return "progress-" + actualProgressBarType;
    }
    get isShowProgressBarOnTop() {
        if (!this.canShowProgressBar())
            return false;
        if (!this.showProgressBar)
            return false;
        return ["auto", "aboveheader", "belowheader", "topbottom", "top", "both"].indexOf(this.progressBarLocation) !== -1;
    }
    get isShowProgressBarOnBottom() {
        if (!this.canShowProgressBar())
            return false;
        if (!this.showProgressBar)
            return false;
        return this.progressBarLocation === "bottom" || this.progressBarLocation === "both" || this.progressBarLocation === "topbottom";
    }
    getProgressTypeComponent() {
        return "sv-progress-" + this.progressBarType.toLowerCase();
    }
    getProgressCssClasses(container = "") {
        return new CssClassBuilder()
            .append(this.css.progress)
            .append(this.css.progressTop, this.isShowProgressBarOnTop && (!container || container == "header"))
            .append(this.css.progressBottom, this.isShowProgressBarOnBottom && (!container || container == "footer"))
            .toString();
    }
    canShowProgressBar() {
        return (!this.isShowingPreview ||
            !this.showPreviewBeforeComplete || this.previewMode != "allQuestions");
    }
    get processedTitle() {
        return this.locTitle.renderedHtml;
    }
    /**
     * Gets or sets question title location relative to the input field: `"top"`, `"bottom"`, or `"left"`.
     *
     * > Certain question types (Matrix, Multiple Text) do not support the `"left"` value. For them, the `"top"` value is used.
     *
     * You can override this setting if you specify the `questionTitleLocation` property for an [individual page](https://surveyjs.io/form-library/documentation/pagemodel#questionTitleLocation) or [panel](https://surveyjs.io/form-library/documentation/panelmodel#questionTitleLocation) or set the `titleLocation` property for a [specific question](https://surveyjs.io/form-library/documentation/question#titleLocation).
     */
    get questionTitleLocation() {
        return this.getPropertyValue("questionTitleLocation");
    }
    set questionTitleLocation(value) {
        this.setPropertyValue("questionTitleLocation", value.toLowerCase());
        if (!this.isLoadingFromJson) {
            this.updateElementCss(true);
        }
    }
    updateElementCss(reNew) {
        if (!!this.startPage) {
            this.startPage.updateElementCss(reNew);
        }
        var pages = this.visiblePages;
        for (var i = 0; i < pages.length; i++) {
            pages[i].updateElementCss(reNew);
        }
        this.updateCss();
    }
    /**
     * Specifies the error message position.
     *
     * Possible values:
     *
     * - `"top"` (default) - Displays error messages above questions.
     * - `"bottom"` - Displays error messages below questions.
     *
     * You can override this setting if you specify the `questionErrorLocation` property for an [individual page](https://surveyjs.io/form-library/documentation/pagemodel#questionErrorLocation) or [panel](https://surveyjs.io/form-library/documentation/panelmodel#questionErrorLocation) or set the `errorLocation` property for a [specific question](https://surveyjs.io/form-library/documentation/question#errorLocation).
     */
    get questionErrorLocation() {
        return this.getPropertyValue("questionErrorLocation");
    }
    set questionErrorLocation(value) {
        this.setPropertyValue("questionErrorLocation", value.toLowerCase());
    }
    /**
     * Specifies where to display question descriptions.
     *
     * Possible values:
     *
     * - `"underTitle"` (default) - Displays descriptions under question titles.
     * - `"underInput"` - Displays descriptions under the interactive area.
     *
     * You can override this setting for individual questions if you specify their [`descriptionLocation`](https://surveyjs.io/form-library/documentation/api-reference/question#descriptionLocation) property.
     *
     */
    get questionDescriptionLocation() {
        return this.getPropertyValue("questionDescriptionLocation");
    }
    set questionDescriptionLocation(value) {
        this.setPropertyValue("questionDescriptionLocation", value);
    }
    /**
     * @deprecated Use the [`readOnly`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#readOnly) property.
     */
    get mode() {
        return this.readOnly ? "display" : "edit";
    }
    set mode(value) {
        value = value.toLowerCase();
        if (value == this.mode)
            return;
        if (value != "edit" && value != "display")
            return;
        this.readOnly = value == "display";
    }
    /**
     * Enables the read-only mode. If you set this property to `true`, users cannot take the survey.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/prevent-form-editing-with-read-only-mode/ (linkStyle))
     */
    get readOnly() {
        return this.getPropertyValue("readOnly");
    }
    set readOnly(val) {
        this.setPropertyValue("readOnly", val);
    }
    onReadOnlyChanged() {
        for (var i = 0; i < this.pages.length; i++) {
            var page = this.pages[i];
            page.setPropertyValue("isReadOnly", page.isReadOnly);
        }
        this.updateButtonsVisibility();
        this.updateCss();
    }
    /**
     * Gets or sets an object with survey results. You can set this property with an object of the following structure:
     *
     * ```js
     * {
     *   question1Name: question1Value,
     *   question2Name: question2Value,
     *   // ...
     * }
     * ```
     *
     * [View Demo](https://surveyjs.io/form-library/examples/auto-populate-form-fields/ (linkStyle))
     *
     * When you set the `data` property in code, the new object overrides the old object that may contain default question values and entered data. If you want to *merge* the new and old objects, call the [`mergeData(newDataObj)`](https://surveyjs.io/form-library/documentation/surveymodel#mergeData) method.
     *
     * If you assign a new object while a respondent takes the survey, set the [`currentPageNo`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#currentPageNo) property to 0 to start the survey from the beginning. This will also cause the survey to re-evaluate the [`visibleIf`](https://surveyjs.io/form-library/documentation/api-reference/question#visibleIf), [`enableIf`](https://surveyjs.io/form-library/documentation/api-reference/question#enableIf), and other [expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions).
     * @see setValue
     * @see getValue
     */
    get data() {
        var result = {};
        var keys = this.getValuesKeys();
        for (var i = 0; i < keys.length; i++) {
            var key = keys[i];
            var dataValue = this.getDataValueCore(this.valuesHash, key);
            if (dataValue !== undefined) {
                result[key] = dataValue;
            }
        }
        this.setCalculatedValuesIntoResult(result);
        return result;
    }
    set data(data) {
        this.valuesHash = {};
        this.setDataCore(data, !data);
    }
    /**
     * Merges a specified data object with the object from the [`data`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#data) property.
     *
     * Refer to the following help topic for more information: [Populate Form Fields | Multiple Question Values](https://surveyjs.io/form-library/documentation/design-survey/pre-populate-form-fields#multiple-question-values).
     *
     * @param data A data object to merge. It should have the following structure: `{ questionName: questionValue, ... }`
     * @see setValue
     */
    mergeData(data) {
        if (!data)
            return;
        const newData = this.data;
        this.mergeValues(data, newData);
        this.setDataCore(newData);
    }
    setDataCore(data, clearData = false) {
        if (clearData) {
            this.valuesHash = {};
        }
        if (data) {
            for (var key in data) {
                const dataKey = typeof key === "string" ? key.trim() : key;
                this.setDataValueCore(this.valuesHash, dataKey, data[key]);
            }
        }
        this.updateAllQuestionsValue(clearData);
        this.notifyAllQuestionsOnValueChanged();
        this.notifyElementsOnAnyValueOrVariableChanged("");
        this.runConditions();
        this.updateAllQuestionsValue(clearData);
    }
    get isSurvey() { return true; }
    /**
     * Returns an object with survey results.
     *
     * If you want to get a survey results object that mirrors the survey structure, call the `getData()` method with an object that has the `includePages` and `includePanels` properties enabled. Without this object, the `getData()` method returns the [`data`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#data) property value.
     *
     * ```js
     * import { Model } from "survey-core";
     *
     * const surveyJson = { ... };
     * const survey = new Model(surveyJson);
     * survey.getData({ includePages: true, includePanels: true });
     * ```
     */
    getData(options) {
        const opt = options || { includePages: false, includePanels: false };
        if (!opt.includePages && !opt.includePanels)
            return this.data;
        return this.getStructuredData(!!opt.includePages, !opt.includePanels ? (opt.includePages ? 1 : 0) : -1);
    }
    getStructuredData(includePages = true, level = -1) {
        if (level === 0)
            return this.data;
        const data = {};
        this.pages.forEach(p => {
            if (includePages) {
                const pageValues = {};
                if (p.collectValues(pageValues, level - 1)) {
                    data[p.name] = pageValues;
                }
            }
            else {
                p.collectValues(data, level);
            }
        });
        return data;
    }
    setStructuredData(data, doMerge = false) {
        if (!data)
            return;
        const res = {};
        for (let key in data) {
            const q = this.getQuestionByValueName(key);
            if (q) {
                res[key] = data[key];
            }
            else {
                let panel = this.getPageByName(key);
                if (!panel) {
                    panel = this.getPanelByName(key);
                }
                if (panel) {
                    this.collectDataFromPanel(panel, res, data[key]);
                }
            }
        }
        if (doMerge) {
            this.mergeData(res);
        }
        else {
            this.data = res;
        }
    }
    collectDataFromPanel(panel, output, data) {
        for (let key in data) {
            let el = panel.getElementByName(key);
            if (!el)
                continue;
            if (el.isPanel) {
                this.collectDataFromPanel(el, output, data[key]);
            }
            else {
                output[key] = data[key];
            }
        }
    }
    get editingObj() {
        return this.editingObjValue;
    }
    set editingObj(val) {
        if (this.editingObj == val)
            return;
        this.unConnectEditingObj();
        this.editingObjValue = val;
        if (this.isDisposed)
            return;
        if (!val) {
            var questions = this.getAllQuestions();
            for (var i = 0; i < questions.length; i++) {
                questions[i].unbindValue();
            }
        }
        if (!!this.editingObj) {
            this.setDataCore({});
            this.onEditingObjPropertyChanged = (sender, options) => {
                if (!Serializer.hasOriginalProperty(this.editingObj, options.name))
                    return;
                if (options.name === "locale") {
                    this.setDataCore({});
                }
                this.updateOnSetValue(options.name, this.editingObj[options.name], options.oldValue);
            };
            this.editingObj.onPropertyChanged.add(this.onEditingObjPropertyChanged);
        }
    }
    unConnectEditingObj() {
        if (!!this.editingObj && !this.editingObj.isDisposed) {
            this.editingObj.onPropertyChanged.remove(this.onEditingObjPropertyChanged);
        }
    }
    get isEditingSurveyElement() {
        return !!this.editingObj;
    }
    setCalculatedValuesIntoResult(result) {
        for (var i = 0; i < this.calculatedValues.length; i++) {
            var calValue = this.calculatedValues[i];
            if (calValue.includeIntoResult &&
                !!calValue.name &&
                this.getVariable(calValue.name) !== undefined) {
                result[calValue.name] = this.getVariable(calValue.name);
            }
        }
    }
    getAllValues() {
        return this.data;
    }
    /**
     * Returns survey results as an array of objects in which the question name, title, value, and other parameters are stored as individual properties.
     *
     * If a question can have more than one value (Matrix, Multiple Text), its object enables the `isNode` flag and stores information about these values in the `data` property. Refer to the following help topic for more information: [Access Full Survey Results](https://surveyjs.io/form-library/documentation/handle-survey-results-access#access-full-survey-results).
     *
     * If you want to skip empty answers, pass an object with the `includeEmpty` property set to `false`.
     */
    getPlainData(options) {
        if (!options) {
            options = { includeEmpty: true, includeQuestionTypes: false, includeValues: false };
        }
        const result = [];
        const questionValueNames = [];
        this.getAllQuestions().forEach((question) => {
            var resultItem = question.getPlainData(options);
            if (!!resultItem) {
                result.push(resultItem);
                questionValueNames.push(question.valueName || question.name);
            }
        });
        if (!!options.includeValues) {
            const keys = this.getValuesKeys();
            for (var i = 0; i < keys.length; i++) {
                var key = keys[i];
                if (questionValueNames.indexOf(key) == -1) {
                    var dataValue = this.getDataValueCore(this.valuesHash, key);
                    if (!!dataValue) {
                        result.push({
                            name: key,
                            title: key,
                            value: dataValue,
                            displayValue: dataValue,
                            isNode: false,
                            getString: (val) => typeof val === "object" ? JSON.stringify(val) : val,
                        });
                    }
                }
            }
        }
        return result;
    }
    getFilteredValues() {
        const values = {};
        for (var key in this.variablesHash)
            values[key] = this.variablesHash[key];
        this.addCalculatedValuesIntoFilteredValues(values);
        if (!this.isDesignMode) {
            const keys = this.getValuesKeys();
            for (var i = 0; i < keys.length; i++) {
                var key = keys[i];
                values[key] = this.getDataValueCore(this.valuesHash, key);
            }
            this.getAllQuestions().forEach(q => {
                if (q.hasFilteredValue) {
                    values[q.getFilteredName()] = q.getFilteredValue();
                }
            });
        }
        return values;
    }
    addCalculatedValuesIntoFilteredValues(values) {
        var caclValues = this.calculatedValues;
        for (var i = 0; i < caclValues.length; i++)
            values[caclValues[i].name] = caclValues[i].value;
    }
    getFilteredProperties() {
        return { survey: this };
    }
    getValuesKeys() {
        if (!this.editingObj)
            return Object.keys(this.valuesHash);
        var props = Serializer.getPropertiesByObj(this.editingObj);
        var res = [];
        for (var i = 0; i < props.length; i++) {
            res.push(props[i].name);
        }
        return res;
    }
    getDataValueCore(valuesHash, key) {
        if (!!this.editingObj)
            return Serializer.getObjPropertyValue(this.editingObj, key);
        return this.getDataFromValueHash(valuesHash, key);
    }
    setDataValueCore(valuesHash, key, value) {
        if (!!this.editingObj) {
            Serializer.setObjPropertyValue(this.editingObj, key, value);
        }
        else {
            this.setDataToValueHash(valuesHash, key, value);
        }
    }
    deleteDataValueCore(valuesHash, key) {
        if (!!this.editingObj) {
            this.editingObj[key] = null;
        }
        else {
            this.deleteDataFromValueHash(valuesHash, key);
        }
    }
    getDataFromValueHash(valuesHash, key) {
        if (!!this.valueHashGetDataCallback)
            return this.valueHashGetDataCallback(valuesHash, key);
        return valuesHash[key];
    }
    setDataToValueHash(valuesHash, key, value) {
        if (!!this.valueHashSetDataCallback) {
            this.valueHashSetDataCallback(valuesHash, key, value);
        }
        else {
            valuesHash[key] = value;
        }
    }
    deleteDataFromValueHash(valuesHash, key) {
        if (!!this.valueHashDeleteDataCallback) {
            this.valueHashDeleteDataCallback(valuesHash, key);
        }
        else {
            delete valuesHash[key];
        }
    }
    /**
     * An object with all comment values.
     * @see Question.showCommentArea
     * @see storeOthersAsComment
     */
    get comments() {
        var result = {};
        var keys = this.getValuesKeys();
        for (var i = 0; i < keys.length; i++) {
            var key = keys[i];
            if (key.indexOf(this.commentSuffix) > 0) {
                result[key] = this.getDataValueCore(this.valuesHash, key);
            }
        }
        return result;
    }
    /**
     * Returns an array of visible pages without the start page.
     *
     * To get an array of all pages, use the [`pages`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#pages) property. If all pages are visible, the `pages` and `visiblePages` arrays are identical.
     * @see [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-visibility)
     */
    get visiblePages() {
        if (this.isDesignMode)
            return this.pages;
        if (!!this.pageContainerValue && (this.isShowingPreview || this.isSinglePage))
            return [this.pageContainerValue];
        var result = new Array();
        for (var i = 0; i < this.pages.length; i++) {
            if (this.isPageInVisibleList(this.pages[i])) {
                result.push(this.pages[i]);
            }
        }
        return result;
    }
    isPageInVisibleList(page) {
        return this.isDesignMode || page.isVisible && !page.isStartPage;
    }
    /**
     * Returns `true` if the survey contains zero pages.
     * @see emptySurveyText
     */
    get isEmpty() {
        return this.pages.length == 0;
    }
    get PageCount() {
        return this.pageCount;
    }
    /**
     * Returns a total number of survey pages.
     *
     * To get the number of visible pages, use the [`visiblePageCount`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#visiblePageCount) property.
     * @see pages
     */
    get pageCount() {
        return this.pages.length;
    }
    /**
     * Returns the number of visible survey pages.
     *
     * To get a total number of survey pages, use the [`pageCount`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#pageCount) property.
     * @see visiblePages
     * @see [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-visibility)
     */
    get visiblePageCount() {
        return this.visiblePages.length;
    }
    /**
     * Returns the start page. Applies only if the [`firstPageIsStartPage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#firstPageIsStartPage) property is set to `true`.
     *
     * Refer to the following help topic for more information: [Start Page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#start-page).
     * @see firstPageIsStartPage
     * @see activePage
     */
    get startPage() {
        var page = this.firstPageIsStartPage && this.pages.length > 1 ? this.pages[0] : null;
        if (!!page) {
            page.onFirstRendering();
        }
        return page;
    }
    /**
     * @deprecated Use the [`startPage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#startPage) property instead.
     */
    get startedPage() { return this.startPage; }
    /**
     * Gets or sets the current page.
     *
     * If you want to change the current page, set this property to a `PageModel` object. You can get this object in different ways. For example, you can call the [`getPageByName()`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#getPageByName) method to obtain a `PageModel` object with a specific name:
     *
     * ```js
     * survey.currentPage = survey.getPageByName("my-page-name");
     * ```
     *
     * Alternative ways to change the current page are listed below:
     *
     * - Set the [`currentPageNo`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#currentPageNo) property to the index of the required page.
     * - Assign a required page name to the [`currentElementName`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#currentElementName) property.
     * - Assign a required page to the [`currentElement`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#currentElement) property.
     *
     * The `currentPage` property does not return the start page even if it is current. Use the [`activePage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#activePage) property instead if your survey contains a start page.
     */
    get currentPage() {
        return this.getPropertyValue("currentPage", null);
    }
    set currentPage(value) {
        if (this.isLoadingFromJson)
            return;
        var newPage = this.getPageByObject(value);
        if (!!value && !newPage)
            return;
        if (!newPage && this.isCurrentPageAvailable)
            return;
        var vPages = this.visiblePages;
        if (newPage != null && vPages.indexOf(newPage) < 0)
            return;
        if (newPage == this.currentPage)
            return;
        const curEl = this.currentSingleElement;
        if (!this.isShowingPreview && !!curEl && newPage !== curEl.page) {
            this.currentSingleElement = newPage.getFirstVisibleElement();
            return;
        }
        var oldValue = this.currentPage;
        if (!this.isShowingPreview && !curEl && !this.currentPageChanging(newPage, oldValue))
            return;
        this.setPropertyValue("currentPage", newPage);
        if (!!newPage) {
            newPage.onFirstRendering();
            newPage.updateCustomWidgets();
        }
        this.locStrsChanged();
        if (!this.isShowingPreview) {
            this.currentPageChanged(newPage, oldValue);
        }
    }
    /**
     * Specifies the current page, panel, or question (depends on the [`questionsOnPageMode`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionsOnPageMode) value) using its [`name`](https://surveyjs.io/form-library/documentation/api-reference/question#name).
     *
     * The following table illustrates the dependency between `questionsOnPageMode` values and the types of survey elements that the `currentElementName` property can specify:
     *
     * | `questionsOnPageMode` | Survey element |
     * | --------------------- | -------------- |
     * | `"standard"` or `"singlePage"` | Page |
     * | `"questionPerPage"` | Question or Panel |
     * | `"inputPerPage"` | Question |
     * @see currentElement
     */
    get currentElementName() {
        var _a;
        return ((_a = this.currentElement) === null || _a === void 0 ? void 0 : _a.name) || "";
    }
    set currentElementName(val) {
        if (!!val) {
            this.currentElement = this.getElementByName(val);
        }
    }
    /**
     * Gets or sets the current page, panel, or question (depends on the [`questionsOnPageMode`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#questionsOnPageMode) value).
     *
     * The following table illustrates the dependency between `questionsOnPageMode` values and the types of survey elements that the `currentElement` property can contain:
     *
     * | `questionsOnPageMode` | Survey element |
     * | --------------------- | -------------- |
     * | `"standard"` or `"singlePage"` | Page |
     * | `"questionPerPage"` | Question or Panel |
     * | `"inputPerPage"` | Question |
     */
    get currentElement() {
        return this.currentSingleElement || this.currentPage;
    }
    set currentElement(val) {
        if (val) {
            if (val.isPage) {
                this.currentPage = val;
            }
            else {
                const page = val.page;
                if (!!page && !this.isSingleVisibleQuestion) {
                    this.currentPage = page;
                }
                else {
                    this.currentSingleElement = val;
                }
            }
        }
    }
    /**
     * Returns a page, panel, or question with a specified [`name`](https://surveyjs.io/form-library/documentation/api-reference/question#name).
     * @param name A survey element name.
     * @returns A survey element with the specified name.
     * @see currentElementName
     */
    getElementByName(name) {
        if (!name)
            return null;
        return this.getPageByName(name) || this.getPanelByName(name) || this.getQuestionByName(name);
    }
    tryNavigateToPage(page /*, serverValidationRes?: (res: boolean)=> void*/) {
        if (!this.performValidationOnPageChanging(page))
            return false;
        const index = this.visiblePages.indexOf(page);
        const res = index < this.currentPageNo || !this.doServerValidation(false, false, page);
        if (res) {
            this.currentPage = page;
        }
        return res;
    }
    performValidationOnPageChanging(page) {
        if (this.isDesignMode)
            return false;
        if (this.canGoTroughValidation())
            return true;
        const index = this.visiblePages.indexOf(page);
        if (index < 0 || index >= this.visiblePageCount)
            return false;
        if (index === this.currentPageNo)
            return false;
        if (index < this.currentPageNo || this.checkErrorsMode === "onComplete" || this.validationAllowSwitchPages)
            return true;
        if (!this.validateCurrentPage())
            return false;
        for (let i = this.currentPageNo + 1; i < index; i++) {
            const page = this.visiblePages[i];
            if (!page.validate(true, true))
                return false;
            page.passed = true;
        }
        return true;
    }
    updateCurrentPage() {
        if (this.isCurrentPageAvailable)
            return;
        this.currentPage = this.firstVisiblePage;
    }
    get isCurrentPageAvailable() {
        const page = this.currentPage;
        return !!page && this.isPageInVisibleList(page) && this.isPageExistsInSurvey(page);
    }
    isPageExistsInSurvey(page) {
        if (this.pages.indexOf(page) > -1)
            return true;
        return !!this.onContainsPageCallback && this.onContainsPageCallback(page);
    }
    /**
     * Returns [`startPage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#startPage) if the survey currently displays a start page; otherwise, returns [`currentPage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#currentPage).
     * @see startPage
     * @see currentPage
     * @see firstPageIsStartPage
     */
    get activePage() {
        return this.getPropertyValue("activePage");
    }
    /**
     * A Boolean value that indicates whether the [start page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#start-page) is currently displayed.
     */
    get isStartPageActive() {
        return this.state === "starting";
    }
    /**
     * @deprecated Use the [`isStartPageActive`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#isStartPageActive) property instead.
     */
    get isShowStartingPage() {
        return this.isStartPageActive;
    }
    /**
     * Specifies which part of a matrix row responds to a drag gesture in [Dynamic Matrix](https://surveyjs.io/form-library/examples/questiontype-matrixdynamic/) questions.
     *
     * Possible values:
     *
     * - `"entireItem"` (default) - Users can use the entire matrix row as a drag handle.
     * - `"icon"` - Users can only use a drag icon as a drag handle.
     */
    get matrixDragHandleArea() {
        return this.getPropertyValue("matrixDragHandleArea", "entireItem");
    }
    set matrixDragHandleArea(val) {
        this.setPropertyValue("matrixDragHandleArea", val);
    }
    get isShowingPage() {
        return this.state == "running" || this.state == "preview" || this.isStartPageActive;
    }
    updateActivePage() {
        const newPage = this.isStartPageActive ? this.startPage : this.currentPage;
        if (newPage !== this.activePage) {
            this.setPropertyValue("activePage", newPage);
        }
    }
    onStateAndCurrentPageChanged() {
        this.updateActivePage();
        this.updateButtonsVisibility();
    }
    getPageByObject(value) {
        if (!value)
            return null;
        if (value.getType && value.getType() == "page")
            return value;
        if (typeof value === "string" || value instanceof String)
            return this.getPageByName(String(value));
        if (!isNaN(value)) {
            var index = Number(value);
            var vPages = this.visiblePages;
            if (value < 0 || value >= vPages.length)
                return null;
            return vPages[index];
        }
        return value;
    }
    /**
     * A zero-based index of the current page in the [`visiblePages`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#visiblePages) array.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-editprevious/ (linkStyle))
     * @see visiblePages
     */
    get currentPageNo() {
        return this.visiblePages.indexOf(this.currentPage);
    }
    set currentPageNo(value) {
        var vPages = this.visiblePages;
        if (value < 0 || value >= vPages.length)
            return;
        this.currentPage = vPages[value];
    }
    /**
     * Specifies the sort order of questions in the survey.
     *
     * Possible values:
     *
     * - `"initial"` (default) - Preserves the original order of questions.
     * - `"random"` - Displays questions in random order.
     *
     * You can override this property for individual pages and panels.
     * @see PageModel.questionOrder
     * @see PanelModel.questionOrder
     */
    get questionOrder() {
        return this.getPropertyValue("questionOrder");
    }
    set questionOrder(val) {
        this.setPropertyValue("questionOrder", val);
    }
    /**
     * @deprecated Use the [`questionOrder`](#questionOrder) property instead.
     */
    get questionsOrder() { return this.questionOrder; }
    set questionsOrder(val) { this.questionOrder = val; }
    /**
     * Focuses the first question on the current page.
     * @see focusQuestion
     * @see autoFocusFirstQuestion
     */
    focusFirstQuestion() {
        if (this.focusingQuestionInfo)
            return;
        var page = this.activePage;
        if (page) {
            page.scrollToTop();
            page.focusFirstQuestion();
        }
    }
    scrollToTopOnPageChange(doScroll = true) {
        var page = this.activePage;
        if (!page)
            return;
        if (doScroll) {
            page.scrollToTop();
        }
        if (this.isCurrentPageRendering && this.autoFocusFirstQuestion && !this.focusingQuestionInfo) {
            page.focusFirstQuestion();
            this.isCurrentPageRendering = false;
        }
    }
    /**
     * Returns the current survey state.
     *
     * Possible values:
     *
     * - `"loading"` - The survey is being loaded from a JSON schema.
     * - `"empty"` - The survey has no elements to display.
     * - `"starting"` - The survey displays a [start page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#start-page).
     * - `"running"` - A respondent is taking the survey.
     * - `"preview"` - A respondent is [previewing](https://surveyjs.io/form-library/examples/survey-showpreview/) answers before submitting them.
     * - `"completed"` - A respondent has completed the survey and submitted the results.
     */
    get state() {
        return this.getPropertyValue("state", "empty");
    }
    updateState() {
        this.setPropertyValue("state", this.calcState());
    }
    calcState() {
        if (this.isLoading)
            return "loading";
        if (this.isCompleted)
            return "completed";
        if (this.isCompletedBefore)
            return "completedbefore";
        if (!this.isDesignMode &&
            this.isEditMode &&
            this.isStartedState &&
            this.startPage)
            return "starting";
        if (this.isShowingPreview)
            return this.currentPage ? "preview" : "empty";
        return this.currentPage ? "running" : "empty";
    }
    get isCompleted() {
        return this.getPropertyValue("isCompleted", false);
    }
    set isCompleted(val) {
        this.setPropertyValue("isCompleted", val);
    }
    get isShowingPreview() {
        return this.getPropertyValue("isShowingPreview", false);
    }
    set isShowingPreview(val) {
        if (this.isShowingPreview == val)
            return;
        this.setPropertyValue("isShowingPreview", val);
        this.onShowingPreviewChanged();
    }
    get isStartedState() {
        return this.getPropertyValue("isStartedState", false);
    }
    set isStartedState(val) {
        this.setPropertyValue("isStartedState", val);
    }
    get isCompletedBefore() {
        return this.getPropertyValue("isCompletedBefore", false);
    }
    set isCompletedBefore(val) {
        this.setPropertyValue("isCompletedBefore", val);
    }
    get isLoading() {
        return this.getPropertyValue("isLoading", false);
    }
    set isLoading(val) {
        this.setPropertyValue("isLoading", val);
    }
    /**
     * Displays the [Loading page](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#loadingHtml).
     * @see endLoading
     */
    beginLoading() {
        this.isLoading = true;
    }
    /**
     * Stops displaying the [Loading page](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#loadingHtml).
     * @see beginLoading
     */
    endLoading() {
        this.isLoading = false;
    }
    get completedState() {
        return this.getPropertyValue("completedState", "");
    }
    get completedStateText() {
        return this.getPropertyValue("completedStateText", "");
    }
    setCompletedState(value, text) {
        this.setPropertyValue("completedState", value);
        if (!text) {
            if (value == "saving")
                text = this.getLocalizationString("savingData");
            if (value == "error")
                text = this.getLocalizationString("savingDataError");
            if (value == "success")
                text = this.getLocalizationString("savingDataSuccess");
        }
        this.setPropertyValue("completedStateText", text);
        if (this.state === "completed" && this.showCompletePage && !!this.completedState) {
            this.notify(this.completedStateText, this.completedState, value === "error");
        }
    }
    /**
     * Displays a toast notification with a specified message.
     *
     * Depending on the `type` argument, a survey can display the following notification types:
     *
     * ![Toast notification types in SurveyJS Form Library](https://surveyjs.io//Content/Images/docs/notification-types.png)
     * @param message A message to display.
     * @param type A notification type: `"info"` (default), `"success"`, or `"error"`.
     * @param showActions For internal use.
     */
    notify(message, type, showActions = false) {
        this.notifier.showActions = showActions;
        this.notifier.notify(message, type, showActions);
    }
    /**
     * Resets the survey [`state`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#state) and, optionally, [`data`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#data). If `state` is `"completed"`, it becomes `"running"`.
     * @param clearData *(Optional)* Specifies whether to clear survey data. Default value: `true`.
     * @param goToFirstPage *(Optional)* Specifies whether to switch the survey to the first page. Default value: `true`.
     */
    clear(clearData = true, goToFirstPage = true) {
        this.isCompleted = false;
        this.isCompletedBefore = false;
        this.isLoading = false;
        this.completedByTriggers = undefined;
        this.skippedPages = [];
        if (clearData) {
            this.setDataCore(null, true);
        }
        this.timerModel.spent = 0;
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].timeSpent = 0;
            this.pages[i].setWasShown(false);
            this.pages[i].passed = false;
        }
        this.onFirstPageIsStartedChanged();
        if (goToFirstPage) {
            this.currentPage = this.firstVisiblePage;
            if (this.currentSingleElement) {
                const questions = this.getSingleElements();
                this.currentSingleElement = questions.length > 0 ? questions[0] : undefined;
            }
        }
        if (clearData) {
            this.updateValuesWithDefaults();
        }
    }
    mergeValues(src, dest) {
        mergeValues(src, dest);
    }
    updateValuesWithDefaults() {
        if (this.isDesignMode || this.isLoading)
            return;
        for (var i = 0; i < this.pages.length; i++) {
            var questions = this.pages[i].questions;
            for (var j = 0; j < questions.length; j++) {
                questions[j].updateValueWithDefaults();
            }
        }
    }
    updateCustomWidgets(page) {
        if (!page)
            return;
        page.updateCustomWidgets();
    }
    currentPageChanging(newValue, oldValue, newQuestion, oldQuestion) {
        const options = this.createPageChangeEventOptions(newValue, oldValue, newQuestion, oldQuestion);
        return this.currentPageChangingFromOptions(options);
    }
    currentPageChangingFromOptions(options) {
        options.allow = true;
        options.allowChanging = true;
        this.onCurrentPageChanging.fire(this, options);
        const allow = options.allowChanging && options.allow;
        if (allow && options.newCurrentPage !== options.oldCurrentPage) {
            this.isCurrentPageRendering = true;
        }
        return allow;
    }
    currentPageChanged(newValue, oldValue) {
        this.notifyQuestionsOnHidingContent(oldValue);
        if (oldValue && !oldValue.isDisposed && !oldValue.passed) {
            if (oldValue.validate(false)) {
                oldValue.passed = true;
            }
        }
        if (this.isCurrentPageRendered === true) {
            this.isCurrentPageRendered = false;
        }
        if (!this.currentSingleElement) {
            const options = this.createPageChangeEventOptions(newValue, oldValue);
            this.onCurrentPageChanged.fire(this, options);
        }
    }
    notifyQuestionsOnHidingContent(page) {
        if (page && !page.isDisposed) {
            page.questions.forEach(q => q.onHidingContent());
        }
    }
    createPageChangeEventOptions(newValue, oldValue, newQuestion, oldQuestion) {
        const diff = !!newValue && !!oldValue ? newValue.visibleIndex - oldValue.visibleIndex : 0;
        let qDiff = diff;
        if (qDiff === 0 && !!oldQuestion && !!newQuestion) {
            qDiff = newValue.elements.indexOf(newQuestion) - newValue.elements.indexOf(oldQuestion);
        }
        return {
            oldCurrentQuestion: oldQuestion,
            newCurrentQuestion: newQuestion,
            oldCurrentPage: oldValue,
            newCurrentPage: newValue,
            isNextPage: diff === 1,
            isPrevPage: diff === -1,
            isGoingForward: qDiff > 0,
            isGoingBackward: qDiff < 0,
            isAfterPreview: this.changeCurrentPageFromPreview === true
        };
    }
    getProgress() {
        if (this.currentPage == null)
            return 0;
        if (this.progressBarType !== "pages") {
            var info = this.getProgressInfo();
            if (this.progressBarType === "requiredQuestions") {
                return info.requiredQuestionCount >= 1
                    ? Math.ceil((info.requiredAnsweredQuestionCount * 100) /
                        info.requiredQuestionCount)
                    : 100;
            }
            return info.questionCount >= 1
                ? Math.ceil((info.answeredQuestionCount * 100) / info.questionCount)
                : 100;
        }
        const visPages = this.visiblePages;
        var index = visPages.indexOf(this.currentPage);
        return Math.ceil((index * 100) / visPages.length);
    }
    get isNavigationButtonsShowing() {
        if (this.isDesignMode)
            return "none";
        var page = this.activePage;
        if (!page)
            return "none";
        if (page.navigationButtonsVisibility === "hide") {
            return "none";
        }
        if (page.navigationButtonsVisibility === "show") {
            return !this.showNavigationButtons ? "bottom" : this.navigationButtonsLocation;
        }
        return !this.showNavigationButtons ? "none" : this.navigationButtonsLocation;
    }
    get isNavigationButtonsShowingOnTop() {
        return this.getIsNavigationButtonsShowingOn("top");
    }
    get isNavigationButtonsShowingOnBottom() {
        return this.getIsNavigationButtonsShowingOn("bottom");
    }
    getIsNavigationButtonsShowingOn(buttonPosition) {
        var res = this.isNavigationButtonsShowing;
        return res == "both" || res == "topBottom" || res == buttonPosition;
    }
    get isEditMode() {
        return !this.readOnly;
    }
    get isDisplayMode() {
        return this.readOnly && !this.isDesignMode || this.state == "preview";
    }
    get isUpdateValueTextOnTyping() {
        return this.textUpdateMode == "onTyping";
    }
    /**
     * Indicates whether the survey is being designed in [Survey Creator](https://surveyjs.io/survey-creator/documentation/overview).
     */
    get isDesignMode() {
        return this._isDesignMode;
    }
    setDesignMode(value) {
        if (!!this._isDesignMode != !!value) {
            this._isDesignMode = !!value;
            this.onQuestionsOnPageModeChanged("standard");
        }
    }
    /**
     * Specifies whether to show all survey elements, regardless of their visibility.
     *
     * Default value: `false`
     */
    get showInvisibleElements() {
        return this.getPropertyValue("showInvisibleElements", false);
    }
    set showInvisibleElements(val) {
        var visPages = this.visiblePages;
        this.setPropertyValue("showInvisibleElements", val);
        if (this.isLoadingFromJson)
            return;
        this.runConditions();
        this.updateAllElementsVisibility(visPages);
    }
    updateAllElementsVisibility(visPages) {
        for (var i = 0; i < this.pages.length; i++) {
            var page = this.pages[i];
            page.updateElementVisibility();
            if (visPages.indexOf(page) > -1 != page.isVisible) {
                this.onPageVisibleChanged.fire(this, {
                    page: page,
                    visible: page.isVisible,
                });
            }
        }
    }
    get areInvisibleElementsShowing() {
        return this.isDesignMode || this.showInvisibleElements;
    }
    get areEmptyElementsHidden() {
        return (this.isShowingPreview &&
            this.showPreviewBeforeComplete && this.previewMode == "answeredQuestions" && this.isAnyQuestionAnswered);
    }
    get isAnyQuestionAnswered() {
        const questions = this.getAllQuestions(true);
        for (let i = 0; i < questions.length; i++) {
            if (!questions[i].isEmpty())
                return true;
        }
        return false;
    }
    /**
     * Indicates whether the browser has a cookie with a specified [`cookieName`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#cookieName). If this property's value is `true`, the respondent has passed the survey previously.
     * @see setCookie
     * @see deleteCookie
     */
    get hasCookie() {
        if (!this.cookieName)
            return false;
        var cookies = DomDocumentHelper.getCookie();
        return cookies && cookies.indexOf(this.cookieName + "=true") > -1;
    }
    /**
     * Sets a cookie with a specified [`cookieName`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#cookieName) in the browser. If the `cookieName` property value is defined, this method is automatically called on survey completion.
     * @see hasCookie
     * @see deleteCookie
     */
    setCookie() {
        if (!this.cookieName)
            return;
        DomDocumentHelper.setCookie(this.cookieName + "=true; expires=Fri, 31 Dec 9999 0:0:0 GMT");
    }
    /**
     * Deletes a cookie with a specified [`cookieName`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#cookieName) from the browser.
     * @see hasCookie
     * @see setCookie
     */
    deleteCookie() {
        if (!this.cookieName)
            return;
        DomDocumentHelper.setCookie(this.cookieName + "=;");
    }
    /**
     * @deprecated Use the [`validationEnabled`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#validationEnabled) property instead.
     */
    get ignoreValidation() { return !this.validationEnabled; }
    set ignoreValidation(val) { this.validationEnabled = !val; }
    /**
     * Switches the survey to the next page.
     *
     * This method returns a Boolean value that indicates whether the page was successfully switched. `false` is returned if the current page is the last page or if it contains validation errors.
     * @returns `true` if the page was successfully switched; `false` otherwise.
     * @see isLastPage
     * @see prevPage
     * @see completeLastPage
     */
    nextPage() {
        if (this.currentSingleElement)
            return this.performNext();
        if (this.isLastPage)
            return false;
        return this.doCurrentPageComplete(false);
    }
    performNext() {
        const q = this.currentSingleElement;
        if (!q)
            return this.nextPage();
        this.resetNavigationButton();
        if (this.isSingleVisibleInput) {
            if (!q.validateSingleInput())
                return false;
            if (q.nextSingleInput()) {
                this.updateButtonsVisibility();
                return true;
            }
        }
        if (this.validationEnabled && !q.validate(true))
            return false;
        this.sendPartialResult();
        const questions = this.getSingleElements();
        const index = questions.indexOf(q);
        if (index < 0 || index === questions.length - 1)
            return false;
        let keys = {};
        if (q.isQuestion) {
            keys[q.name] = q.value;
        }
        else {
            if (q.isPanel) {
                keys = q.getValue();
            }
        }
        this.checkTriggers(keys, true, false, true, q.name);
        if (q === this.currentSingleElement) {
            this.currentSingleElement = questions[index + 1];
        }
        return true;
    }
    performPrevious() {
        return this.prevPage();
    }
    hasErrorsOnNavigate(doComplete) {
        if (this.canGoTroughValidation())
            return false;
        const skipValidation = doComplete && this.validationAllowComplete || !doComplete && this.validationAllowSwitchPages;
        const func = (hasErrors) => {
            if (!hasErrors || skipValidation) {
                this.doCurrentPageCompleteCore(doComplete);
            }
        };
        if (this.isValidateOnComplete) {
            if (!this.isLastPage)
                return false;
            return this.validate(true, this.autoFocusFirstError, func, true) !== true && !skipValidation;
        }
        return this.validateCurrentPage(func) !== true && !skipValidation;
    }
    canGoTroughValidation() { return !this.isEditMode || !this.validationEnabled; }
    checkForAsyncQuestionValidation(questions, func) {
        this.clearAsyncValidationQuesitons();
        for (var i = 0; i < questions.length; i++) {
            if (questions[i].isRunningValidators) {
                let q = questions[i];
                q.onCompletedAsyncValidators = (hasErrors) => {
                    this.onCompletedAsyncQuestionValidators(q, func, hasErrors);
                };
                this.asyncValidationQuesitons.push(questions[i]);
            }
        }
        return this.asyncValidationQuesitons.length > 0;
    }
    clearAsyncValidationQuesitons() {
        if (!!this.asyncValidationQuesitons) {
            var asynQuestions = this.asyncValidationQuesitons;
            for (var i = 0; i < asynQuestions.length; i++) {
                asynQuestions[i].onCompletedAsyncValidators = null;
            }
        }
        this.asyncValidationQuesitons = [];
    }
    onCompletedAsyncQuestionValidators(question, func, hasErrors) {
        if (hasErrors) {
            this.clearAsyncValidationQuesitons();
            func(true);
            if (this.autoFocusFirstError && !!question && !!question.page && question.page === this.currentPage) {
                const questions = this.currentPage.questions;
                for (let i = 0; i < questions.length; i++) {
                    if (questions[i] !== question && questions[i].errors.length > 0)
                        return;
                }
                question.focus(true);
            }
            return;
        }
        var asynQuestions = this.asyncValidationQuesitons;
        for (var i = 0; i < asynQuestions.length; i++) {
            if (asynQuestions[i].isRunningValidators)
                return;
        }
        func(false);
    }
    get isCurrentPageHasErrors() {
        return this.checkIsCurrentPageHasErrors();
    }
    /**
     * Returns `true` if the current page does not contain errors.
     * @see currentPage
     */
    get isCurrentPageValid() {
        return !this.checkIsCurrentPageHasErrors();
    }
    hasCurrentPageErrors(onAsyncValidation) {
        return this.hasPageErrors(undefined, onAsyncValidation);
    }
    /**
     * Validates all questions on the current page and returns `false` if the validation fails.
     *
     * If you use validation expressions and at least one of them calls an async function, the `validateCurrentPage` method returns `undefined`. In this case, you should pass a callback function as the `onAsyncValidation` parameter. The function's `hasErrors` Boolean parameter will contain the validation result.
     * @param onAsyncValidation *(Optional)* Pass a callback function. It accepts a Boolean `hasErrors` parameter that equals `true` if the validation fails or `false` otherwise.
     * @see currentPage
     * @see validate
     * @see validateCurrentPage
     */
    validateCurrentPage(onAsyncValidation) {
        return this.validatePage(undefined, onAsyncValidation);
    }
    hasPageErrors(page, onAsyncValidation) {
        const res = this.validatePage(page, onAsyncValidation);
        if (res === undefined)
            return res;
        return !res;
    }
    /**
     * Validates all questions on a specified page and returns `false` if the validation fails.
     *
     * If you use validation expressions and at least one of them calls an async function, the `validatePage` method returns `undefined`. In this case, you should pass a callback function as the `onAsyncValidation` parameter. The function's `hasErrors` Boolean parameter will contain the validation result.
     * @param page Pass the `PageModel` that you want to validate. You can pass `undefined` to validate the [`activePage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#activePage).
     * @param onAsyncValidation *(Optional)* Pass a callback function. It accepts a Boolean `hasErrors` parameter that equals `true` if the validation fails or `false` otherwise.
     * @see validate
     * @see validateCurrentPage
     */
    validatePage(page, onAsyncValidation) {
        if (!page) {
            page = this.activePage;
        }
        if (!page)
            return true;
        if (this.checkIsPageHasErrors(page))
            return false;
        if (!onAsyncValidation)
            return true;
        return this.checkForAsyncQuestionValidation(page.questions, (hasErrors) => onAsyncValidation(hasErrors))
            ? undefined
            : true;
    }
    hasErrors(fireCallback = true, focusOnFirstError = false, onAsyncValidation) {
        const res = this.validate(fireCallback, focusOnFirstError, onAsyncValidation);
        if (res === undefined)
            return res;
        return !res;
    }
    /**
     * Validates all questions and returns `false` if the validation fails.
     *
     * If you use validation expressions and at least one of them calls an async function, the `validate` method returns `undefined`. In this case, you should pass a callback function as the `onAsyncValidation` parameter. The function's `hasErrors` Boolean parameter will contain the validation result.
     * @param fireCallback *(Optional)* Pass `false` if you do not want to show validation errors in the UI.
     * @param focusFirstError *(Optional)* Pass `true` if you want to focus the first question with a validation error. The survey will be switched to the page that contains this question if required.
     * @param onAsyncValidation *(Optional)* Pass a callback function. It accepts a Boolean `hasErrors` parameter that equals `true` if the validation fails or `false` otherwise.
     * @see validateCurrentPage
     * @see validatePage
     */
    validate(fireCallback = true, focusFirstError = false, onAsyncValidation, changeCurrentPage) {
        if (!!onAsyncValidation) {
            fireCallback = true;
        }
        var visPages = this.visiblePages;
        var res = true;
        const rec = { fireCallback: fireCallback, focusOnFirstError: focusFirstError, firstErrorQuestion: null, result: false };
        for (var i = 0; i < visPages.length; i++) {
            if (!visPages[i].validate(fireCallback, focusFirstError, rec)) {
                res = false;
            }
        }
        if (!!rec.firstErrorQuestion && (focusFirstError || changeCurrentPage)) {
            if (focusFirstError) {
                rec.firstErrorQuestion.focus(true);
            }
            else {
                this.currentPage = rec.firstErrorQuestion.page;
            }
        }
        if (!res || !onAsyncValidation)
            return res;
        return this.checkForAsyncQuestionValidation(this.getAllQuestions(), (hasErrors) => onAsyncValidation(hasErrors))
            ? undefined
            : true;
    }
    ensureUniqueNames(element = null) {
        if (element == null) {
            for (var i = 0; i < this.pages.length; i++) {
                this.ensureUniqueName(this.pages[i]);
            }
        }
        else {
            this.ensureUniqueName(element);
        }
    }
    ensureUniqueName(element) {
        if (element.isPage) {
            this.ensureUniquePageName(element);
        }
        if (element.isPanel) {
            this.ensureUniquePanelName(element);
        }
        if (element.isPage || element.isPanel) {
            var elements = element.elements;
            for (var i = 0; i < elements.length; i++) {
                this.ensureUniqueNames(elements[i]);
            }
        }
        else {
            this.ensureUniqueQuestionName(element);
        }
    }
    ensureUniquePageName(element) {
        return this.ensureUniqueElementName(element, (name) => {
            return this.getPageByName(name);
        });
    }
    ensureUniquePanelName(element) {
        return this.ensureUniqueElementName(element, (name) => {
            return this.getPanelByName(name);
        });
    }
    ensureUniqueQuestionName(element) {
        return this.ensureUniqueElementName(element, (name) => {
            return this.getQuestionByName(name);
        });
    }
    ensureUniqueElementName(element, getElementByName) {
        var existingElement = getElementByName(element.name);
        if (!existingElement || existingElement == element)
            return;
        var newName = this.getNewName(element.name);
        while (!!getElementByName(newName)) {
            var newName = this.getNewName(element.name);
        }
        element.name = newName;
    }
    getNewName(name) {
        var pos = name.length;
        while (pos > 0 && name[pos - 1] >= "0" && name[pos - 1] <= "9") {
            pos--;
        }
        var base = name.substring(0, pos);
        var num = 0;
        if (pos < name.length) {
            num = parseInt(name.substring(pos));
        }
        num++;
        return base + num;
    }
    checkIsCurrentPageHasErrors(isFocuseOnFirstError = undefined) {
        return this.checkIsPageHasErrors(this.activePage, isFocuseOnFirstError);
    }
    checkIsPageHasErrors(page, isFocuseOnFirstError = undefined) {
        if (isFocuseOnFirstError === undefined) {
            isFocuseOnFirstError = this.focusOnFirstError;
        }
        if (!page)
            return true;
        const res = !page.validate(true, isFocuseOnFirstError);
        this.fireValidatedErrorsOnPage(page);
        return res;
    }
    fireValidatedErrorsOnPage(page) {
        if (this.onValidatePage.isEmpty || !page)
            return;
        const questionsOnPage = this.getNestedQuestionsByQuestionArray(page.questions, true);
        var questions = new Array();
        var errors = new Array();
        for (var i = 0; i < questionsOnPage.length; i++) {
            var q = questionsOnPage[i];
            if (q.errors.length > 0) {
                questions.push(q);
                for (var j = 0; j < q.errors.length; j++) {
                    errors.push(q.errors[j]);
                }
            }
        }
        this.onValidatePage.fire(this, {
            questions: questions,
            errors: errors,
            page: page,
        });
    }
    /**
     * Switches the survey to the previous page.
     *
     * This method returns a Boolean value that indicates whether the page was successfully switched. `false` is returned if the current page is the first page.
     * @returns `true` if the page was successfully switched; `false` otherwise.
     * @see isFirstPage
     * @see nextPage
     */
    prevPage() {
        if (this.isFirstPage || this.state === "starting")
            return false;
        this.resetNavigationButton();
        const curElement = this.currentSingleElement;
        if (this.doSkipOnPrevPage(curElement))
            return true;
        if (curElement)
            return this.prevPageSingleElement(curElement);
        const vPages = this.visiblePages;
        const index = vPages.indexOf(this.currentPage);
        this.currentPage = vPages[index - 1];
        return true;
    }
    doSkipOnPrevPage(curElement) {
        const toEl = curElement || this.currentPage;
        const skipped = this.skippedPages.find(sp => sp.to === toEl);
        let elTo = undefined;
        if (!!skipped) {
            this.skippedPages.splice(this.skippedPages.indexOf(skipped), 1);
            const el = skipped.from;
            if (!el.isDisposed && el.isVisible) {
                elTo = el;
            }
        }
        if (!!elTo) {
            if (!!curElement) {
                this.currentSingleElement = elTo;
            }
            else {
                this.currentPage = elTo;
            }
        }
        return !!elTo;
    }
    prevPageSingleElement(curElement) {
        if (this.isSingleVisibleInput) {
            if (curElement.prevSingleInput()) {
                this.updateButtonsVisibility();
                return true;
            }
        }
        const questions = this.getSingleElements();
        const index = questions.indexOf(curElement);
        if (index === 0)
            return false;
        this.currentSingleElement = questions[index - 1];
        return true;
    }
    /**
     * Completes the survey if it currently displays the last page and the page contains no validation errors. If both these conditions are met, this method returns `true`; otherwise, `false`.
     *
     * If you want to complete the survey regardless of the current page and validation errors, use the [`doComplete()`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#completeLastPage) event.
     * @see isCurrentPageValid
     * @see nextPage
     */
    tryComplete() {
        if (this.isValidateOnComplete) {
            this.cancelPreview();
        }
        let res = this.doCurrentPageComplete(true);
        if (res) {
            this.cancelPreview();
        }
        return res;
    }
    /**
     * @deprecated Use the [`tryComplete`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#tryComplete) method instead.
     */
    completeLastPage() {
        return this.tryComplete();
    }
    navigationMouseDown() {
        this.isNavigationButtonPressed = true;
        return true;
    }
    resetNavigationButton() {
        this.isNavigationButtonPressed = false;
    }
    nextPageUIClick() {
        if (!!this.mouseDownPage && this.mouseDownPage !== this.activePage)
            return false;
        this.mouseDownPage = null;
        return this.performNext();
    }
    nextPageMouseDown() {
        this.mouseDownPage = this.activePage;
        return this.navigationMouseDown();
    }
    /**
     * Displays a [preview of given answers](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#preview-page). Returns `false` if the preview cannot be displayed because of validation errors.
     * @see cancelPreview
     * @see showPreviewBeforeComplete
     * @see onShowingPreview
     * @see state
     */
    showPreview() {
        this.resetNavigationButton();
        if (!this.isValidateOnComplete) {
            if (this.hasErrorsOnNavigate(true))
                return false;
            if (this.doServerValidation(true, true))
                return false;
        }
        this.showPreviewCore();
        return this.isShowingPreview;
    }
    showPreviewCore() {
        var options = { allowShowPreview: true, allow: true };
        this.onShowingPreview.fire(this, options);
        this.isShowingPreview = options.allowShowPreview && options.allow;
    }
    /**
     * Cancels a [preview of given answers](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#preview-page) and switches the survey to the page specified by the `currentPage` parameter.
     * @param currentPage A new current page. If you do not specify this parameter, the survey displays the last page.
     * @see showPreview
     * @see showPreviewBeforeComplete
     * @see state
     */
    cancelPreview(currentPage = null) {
        var _a;
        if (!this.isShowingPreview)
            return;
        this.gotoPageFromPreview = currentPage;
        this.isShowingPreview = false;
        const page = (_a = this.currentSingleElement) === null || _a === void 0 ? void 0 : _a.page;
        if (!!page) {
            page.updateRows();
            this.currentPage = page;
        }
    }
    cancelPreviewByPage(panel) {
        this.cancelPreview(panel);
    }
    doCurrentPageComplete(doComplete) {
        if (this.isValidatingOnServer)
            return false;
        this.resetNavigationButton();
        if (this.hasErrorsOnNavigate(doComplete))
            return false;
        return this.doCurrentPageCompleteCore(doComplete);
    }
    doCurrentPageCompleteCore(doComplete) {
        if (this.doServerValidation(doComplete))
            return false;
        if (doComplete) {
            this.currentPage.passed = true;
            return this.doComplete(this.canBeCompletedByTrigger, this.completedTrigger);
        }
        this.doNextPage();
        return true;
    }
    get isSinglePage() {
        return this.questionsOnPageMode == "singlePage";
    }
    set isSinglePage(val) {
        this.questionsOnPageMode = val ? "singlePage" : "standard";
    }
    get isSingleVisibleQuestion() {
        return !this.isDesignMode && (this.isSingleVisibleQuestionVal(this.questionsOnPageMode) || this.isSingleVisibleInput);
    }
    get isSingleVisibleInput() {
        return !this.isDesignMode && this.questionsOnPageMode == "inputPerPage";
    }
    isSingleVisibleQuestionVal(val) {
        return val === "questionPerPage" || val === "questionOnPage";
    }
    /**
     * Specifies how to distribute survey elements between pages.
     *
     * Possible values:
     *
     * - `"singlePage"` - Combines all survey pages into a single page.
     * - `"questionPerPage"` - Displays each question on a separate page.
     * - `"inputPerPage"` - Displays each input field on a separate page. Complex questions&mdash;such as [Single-Select Matrix](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-question-model), [Multi-Select Matrix](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-with-dropdown-list), [Dynamic Matrix](https://surveyjs.io/form-library/documentation/api-reference/dynamic-matrix-table-question-model), [Dynamic Panel](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model), and [Multiple Textboxes](https://surveyjs.io/form-library/documentation/api-reference/multiple-text-entry-question-model)&mdash;are split so that each input field appears on its own page. [View Demo](https://surveyjs.io/form-library/examples/loop-and-merge/)
     * - `"standard"` (default) - Retains the original structure specified in the JSON schema.
     */
    get questionsOnPageMode() {
        return this.getPropertyValue("questionsOnPageMode");
    }
    set questionsOnPageMode(val) {
        this.setPropertyValue("questionsOnPageMode", val);
    }
    /**
     * Gets or sets a Boolean value that specifies whether the first page is a start page.
     *
     * Refer to the following help topic for more information: [Start Page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#start-page).
     * @see startPage
     * @see activePage
     */
    get firstPageIsStartPage() {
        return this.getPropertyValue("firstPageIsStartPage");
    }
    set firstPageIsStartPage(val) {
        this.setPropertyValue("firstPageIsStartPage", val);
    }
    /**
     * @deprecated Use the [`firstPageIsStartPage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#firstPageIsStartPage) property instead.
     */
    get firstPageIsStarted() {
        return this.firstPageIsStartPage;
    }
    set firstPageIsStarted(val) {
        this.firstPageIsStartPage = val;
    }
    isPageStarted(page) {
        return (this.firstPageIsStartPage && this.pages.length > 1 && this.pages[0] === page);
    }
    /**
     * Specifies whether to show a preview of given answers before they are submitted.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-preview/ (linkStyle))
     * @see previewMode
     * @see showPreview
     * @see cancelPreview
     */
    get showPreviewBeforeComplete() {
        return this.getPropertyValue("showPreviewBeforeComplete");
    }
    set showPreviewBeforeComplete(val) {
        this.setShowPreviewBeforeComplete(val);
    }
    setShowPreviewBeforeComplete(val) {
        if (val === undefined || val === "noPreview" || val === false) {
            this.setPropertyValue("showPreviewBeforeComplete", false);
        }
        else {
            this.setPropertyValue("showPreviewBeforeComplete", true);
            if (val === "showAllQuestions")
                this.previewMode = "allQuestions";
            if (val === "showAnsweredQuestions")
                this.previewMode = "answeredQuestions";
        }
    }
    /**
     * Specifies whether the [preview of given answers](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#preview-page) includes all or only answered questions.
     *
     * Possible values:
     *
     * - `"allQuestions"` (default)
     * - `"answeredQuestions"`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/survey-preview/ (linkStyle))
     */
    get previewMode() {
        return this.getPropertyValue("previewMode");
    }
    set previewMode(val) {
        this.setPropertyValue("previewMode", val);
    }
    onFirstPageIsStartedChanged() {
        this.isStartedState = this.firstPageIsStartPage && this.pages.length > 1;
        this.pageVisibilityChanged(this.pages[0], !this.isStartedState);
    }
    onShowingPreviewChanged() {
        this.updatePagesContainer();
    }
    createRootPage(name, pages) {
        const container = Serializer.createClass("page");
        container.name = name;
        container.isPageContainer = true;
        pages.forEach(page => {
            if (!page.isStartPage) {
                container.addElement(page);
            }
        });
        return container;
    }
    disposeContainerPage() {
        let cPage = this.pageContainerValue;
        const elements = [].concat(cPage.elements);
        elements.forEach(el => cPage.removeElement(el));
        cPage.dispose();
        this.pageContainerValue = undefined;
    }
    updatePagesContainer() {
        if (this.isDesignMode)
            return;
        this.getAllQuestions().forEach(q => q.updateElementVisibility());
        this.setPropertyValue("currentPage", undefined);
        const singleName = "single-page";
        const previewName = "preview-page";
        let rootPage = undefined;
        if (this.isSinglePage) {
            const cPage = this.pageContainerValue;
            if (cPage && cPage.name === previewName) {
                rootPage = cPage.elements[0];
                this.disposeContainerPage();
            }
            else {
                rootPage = this.createRootPage(singleName, this.pages);
            }
        }
        if (this.isShowingPreview) {
            rootPage = this.createRootPage(previewName, rootPage ? [rootPage] : this.pages);
        }
        if (rootPage) {
            rootPage.setSurveyImpl(this);
            this.pageContainerValue = rootPage;
            this.currentPage = rootPage;
            if (!!this.currentSingleElementValue) {
                this.visiblePages.forEach(page => page.updateRows());
            }
        }
        if (!this.isSinglePage && !this.isShowingPreview) {
            this.disposeContainerPage();
            let curPage = this.gotoPageFromPreview;
            this.gotoPageFromPreview = null;
            if (Helpers.isValueEmpty(curPage) && this.visiblePageCount > 0) {
                curPage = this.visiblePages[this.visiblePageCount - 1];
            }
            if (!!curPage) {
                this.changeCurrentPageFromPreview = true;
                this.currentPage = curPage;
                this.changeCurrentPageFromPreview = false;
            }
        }
        if (!this.currentPage && this.visiblePageCount > 0) {
            this.currentPage = this.visiblePages[0];
        }
        if (this.isShowingPreview) {
            this.pages.forEach(page => {
                page.onFirstRendering();
            });
        }
        this.pages.forEach(page => {
            if (page.wasRendered) {
                page.updateElementCss(true);
            }
        });
        this.updateButtonsVisibility();
    }
    getSingleElements(includeEl) {
        const res = new Array();
        const pages = this.pages;
        const isSingleInput = this.isSingleVisibleInput;
        for (var i = 0; i < pages.length; i++) {
            const p = pages[i];
            if (!p.isStartPage && p.isVisible) {
                const els = [];
                if (isSingleInput) {
                    p.addQuestionsToList(els, true);
                }
                else {
                    p.elements.forEach(el => els.push(el));
                }
                els.forEach(el => { if (el === includeEl || el.isVisible)
                    res.push(el); });
            }
        }
        return res;
    }
    get currentSingleElement() {
        return !this.isShowingPreview ? this.currentSingleElementValue : undefined;
    }
    set currentSingleElement(val) {
        const oldVal = this.currentSingleElement;
        if (val !== oldVal && !this.isCompleted) {
            const valQuestion = (val === null || val === void 0 ? void 0 : val.isQuestion) ? val : undefined;
            const oldValQuestion = (oldVal === null || oldVal === void 0 ? void 0 : oldVal.isQuestion) ? oldVal : undefined;
            const page = val === null || val === void 0 ? void 0 : val.page;
            const options = !!page && !!oldVal ? this.createPageChangeEventOptions(page, oldVal.page, valQuestion, oldValQuestion) : undefined;
            if (!!options && !this.currentPageChangingFromOptions(options))
                return;
            this.currentSingleElementValue = val;
            if (!!val) {
                if (this.isSingleVisibleInput && val.isQuestion) {
                    val.onSetAsSingleInput();
                }
                page.updateRows();
                if (page !== this.currentPage) {
                    this.currentPage = page;
                }
                else {
                    if (!!valQuestion && this.autoFocusFirstQuestion) {
                        valQuestion.focus();
                    }
                }
                this.updateButtonsVisibility();
                if (!!options) {
                    this.onCurrentPageChanged.fire(this, options);
                }
            }
            else {
                this.visiblePages.forEach(page => page.updateRows());
            }
        }
    }
    get currentSingleQuestion() {
        const res = this.currentSingleElement;
        return !!res && res.isQuestion ? res : undefined;
    }
    set currentSingleQuestion(val) {
        this.currentSingleElement = val;
    }
    supportsNestedSingleInput(question) {
        const options = { question: question, enabled: true };
        this.onCheckSingleInputPerPageMode.fire(this, options);
        return options.enabled;
    }
    changeCurrentSingleElementOnVisibilityChanged() {
        const el = this.currentSingleElement;
        if (!el || el.isVisible)
            return;
        const els = this.getSingleElements(el);
        const index = els.indexOf(el);
        const newEl = (index > 0) ? els[index - 1] : (index < els.length - 1 ? els[index + 1] : undefined);
        this.currentSingleElement = newEl;
    }
    onQuestionsOnPageModeChanged(oldValue) {
        if (this.isShowingPreview || this.isDesignMode)
            return;
        this.skippedPages = [];
        this.currentSingleElement = undefined;
        if (oldValue === "singlePage") {
            this.updatePagesContainer();
        }
        if (oldValue === "inputPerPage") {
            this.getAllQuestions().forEach(q => q.resetSingleInput());
        }
        if (this.isSinglePage) {
            this.updatePagesContainer();
        }
        this.setupSingleInputNavigationActions();
        if (this.isSingleVisibleQuestion) {
            const els = this.getSingleElements();
            if (els.length > 0) {
                this.currentSingleElement = els[0];
            }
        }
    }
    setupSingleInputNavigationActions() {
        const actionAddId = "sv-singleinput-add";
        if (this.isSingleVisibleInput) {
            const addItem = () => {
                this.currentSingleQuestion.singleInputAddItem(true);
                this.resetNavigationButton();
            };
            this.addNavigationItem({ id: actionAddId, visible: false, action: () => addItem() });
        }
        else {
            this.removeNavigationItem(actionAddId);
        }
    }
    getPageStartIndex() {
        return this.firstPageIsStartPage && this.pages.length > 0 ? 1 : 0;
    }
    /**
     * Indicates whether the [current page](#currentPage) is the first page.
     *
     * > If the survey displays the [start page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#start-page), this property contains `false`. Use the [`isStartPageActive`](#isStartPageActive) property to find out whether the start page is currently displayed.
     */
    get isFirstPage() {
        return this.getPropertyValue("isFirstPage");
    }
    /**
     * Indicates whether the [current page](#currentPage) is the last page.
     */
    get isLastPage() {
        return this.getPropertyValue("isLastPage");
    }
    updateNavigationElements() {
        this.updateButtonsVisibility();
    }
    updateButtonsVisibility() {
        this.updateIsFirstLastPageState();
        this.setPropertyValue("isShowPrevButton", this.calcIsShowPrevButton());
        this.setPropertyValue("isShowNextButton", this.calcIsShowNextButton());
        this.setPropertyValue("isCompleteButtonVisible", this.calcIsCompleteButtonVisible());
        this.setPropertyValue("isPreviewButtonVisible", this.calcIsPreviewButtonVisible());
        this.setPropertyValue("isCancelPreviewButtonVisible", this.calcIsCancelPreviewButtonVisible());
        this.updateSingleInputActions();
    }
    updateSingleInputActions() {
        if (!this.isSingleVisibleInput)
            return;
        const q = this.currentSingleQuestion;
        if (!q)
            return;
        const addBtn = this.navigationBar.getActionById("sv-singleinput-add");
        if (addBtn) {
            addBtn.title = q.getSingleInputAddText();
            addBtn.visible = !!addBtn.title;
        }
    }
    get isShowPrevButton() {
        return this.getPropertyValue("isShowPrevButton");
    }
    get isShowNextButton() {
        return this.getPropertyValue("isShowNextButton");
    }
    get isCompleteButtonVisible() {
        return this.getPropertyValue("isCompleteButtonVisible");
    }
    get isPreviewButtonVisible() {
        return this.getPropertyValue("isPreviewButtonVisible");
    }
    get isCancelPreviewButtonVisible() {
        return this.getPropertyValue("isCancelPreviewButtonVisible");
    }
    get isFirstElement() {
        return this.getPropertyValue("isFirstElement");
    }
    get isLastElement() {
        return this.getPropertyValue("isLastElement");
    }
    updateIsFirstLastPageState() {
        const curPage = this.currentPage;
        let fVal = undefined;
        let lVal = undefined;
        const q = this.currentSingleElement;
        if (!!q) {
            let isFirstInput = true;
            let isLastInput = true;
            if (this.isSingleVisibleInput) {
                const inputState = q.getSingleInputElementPos();
                if (inputState !== 0) {
                    isFirstInput = inputState === -1;
                    isLastInput = inputState === 1;
                }
            }
            const questions = this.getSingleElements();
            const index = questions.indexOf(q);
            if (index >= 0) {
                fVal = isFirstInput && index === 0;
                lVal = isLastInput && index === questions.length - 1;
            }
        }
        this.setPropertyValue("isFirstPage", !!curPage && curPage === this.firstVisiblePage && (!q || fVal === true));
        this.setPropertyValue("isLastPage", !!curPage && curPage === this.lastVisiblePage && (!q || lVal === true));
        this.setPropertyValue("isFirstElement", fVal);
        this.setPropertyValue("isLastElement", lVal);
    }
    get isLastPageOrElement() {
        return this.isLastElement !== undefined ? this.isLastElement : this.isLastPage;
    }
    get isFirstPageOrElement() {
        return this.isFirstElement !== undefined ? this.isFirstElement : this.isFirstPage;
    }
    calcIsShowPrevButton() {
        if (this.isFirstPageOrElement || !this.showPrevButton || this.state !== "running")
            return false;
        if (this.isFirstElement !== undefined)
            return true;
        const page = this.visiblePages[this.currentPageNo - 1];
        return page && page.getMaxTimeToFinish() <= 0;
    }
    calcIsShowNextButton() {
        return this.state === "running" && !this.isLastPageOrElement && !this.canBeCompletedByTrigger;
    }
    calcIsCompleteButtonVisible() {
        const state = this.state;
        return this.isEditMode && (this.state === "running" &&
            (this.isLastPageOrElement && !this.showPreviewBeforeComplete || this.canBeCompletedByTrigger)
            || state === "preview") && this.showCompleteButton;
    }
    calcIsPreviewButtonVisible() {
        return (this.isEditMode &&
            this.showPreviewBeforeComplete &&
            this.state == "running" && this.isLastPageOrElement);
    }
    calcIsCancelPreviewButtonVisible() {
        return (this.isEditMode &&
            this.showPreviewBeforeComplete &&
            this.state == "preview");
    }
    get firstVisiblePage() {
        if (this.visiblePageCount === 1)
            return this.visiblePages[0];
        const pages = this.pages;
        for (let i = 0; i < pages.length; i++) {
            if (this.isPageInVisibleList(pages[i]))
                return pages[i];
        }
        return null;
    }
    get lastVisiblePage() {
        if (this.visiblePageCount === 1)
            return this.visiblePages[0];
        const pages = this.pages;
        for (let i = pages.length - 1; i >= 0; i--) {
            if (this.isPageInVisibleList(pages[i]))
                return pages[i];
        }
        return null;
    }
    /**
     * Completes the survey.
     *
     * When you call this method, Form Library performs the following actions:
     *
     * 1. Saves a cookie if the [`cookieName`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#cookieName) property is set.
     * 1. Switches the survey [`state`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#state) to `"completed"`.
     * 1. Raises the [`onComplete`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onComplete) event.
     * 1. Navigates the user to a URL specified by the [`navigateToUrl`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#navigateToUrl) or [`navigateToUrlOnCondition`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#navigateToUrlOnCondition) property.
     *
     * The `doComplete()` method completes the survey regardless of validation errors and the current page. If you need to ensure that survey results are valid and full, call the [`completeLastPage()`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#completeLastPage) method instead.
     *
     * @param isCompleteOnTrigger For internal use.
     * @param completeTrigger For internal use.
     * @returns `false` if survey completion is cancelled within the [`onCompleting`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onCompleting) event handler; otherwise, `true`.
     */
    doComplete(isCompleteOnTrigger = false, completeTrigger) {
        if (this.isCompleted)
            return;
        if (!this.checkOnCompletingEvent(isCompleteOnTrigger, completeTrigger)) {
            this.isCompleted = false;
            return false;
        }
        this.checkOnPageTriggers(true);
        this.stopTimer();
        this.notifyQuestionsOnHidingContent(this.currentPage);
        this.isCompleted = true;
        this.clearUnusedValues();
        this.saveDataOnComplete(isCompleteOnTrigger, completeTrigger);
        this.setCookie();
        return true;
    }
    saveDataOnComplete(isCompleteOnTrigger = false, completeTrigger) {
        let previousCookie = this.hasCookie;
        const showSaveInProgress = (text) => {
            savingDataStarted = true;
            this.setCompletedState("saving", text);
        };
        const showSaveError = (text) => {
            this.setCompletedState("error", text);
        };
        const showSaveSuccess = (text) => {
            this.setCompletedState("success", text);
            this.navigateTo();
        };
        const clearSaveMessages = (text) => {
            this.setCompletedState("", "");
        };
        var savingDataStarted = false;
        var onCompleteOptions = {
            isCompleteOnTrigger: isCompleteOnTrigger,
            completeTrigger: completeTrigger,
            showSaveInProgress: showSaveInProgress,
            showSaveError: showSaveError,
            showSaveSuccess: showSaveSuccess,
            clearSaveMessages: clearSaveMessages,
            //Obsolete functions
            showDataSaving: showSaveInProgress,
            showDataSavingError: showSaveError,
            showDataSavingSuccess: showSaveSuccess,
            showDataSavingClear: clearSaveMessages
        };
        this.onComplete.fire(this, onCompleteOptions);
        if (!previousCookie && this.surveyPostId) {
            this.sendResult();
        }
        if (!savingDataStarted) {
            this.navigateTo();
        }
    }
    checkOnCompletingEvent(isCompleteOnTrigger, completeTrigger) {
        var options = {
            allowComplete: true,
            allow: true,
            isCompleteOnTrigger: isCompleteOnTrigger,
            completeTrigger: completeTrigger
        };
        this.onCompleting.fire(this, options);
        return options.allowComplete && options.allow;
    }
    /**
     * Starts the survey. Applies only if the survey has a [start page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#start-page).
     * @see firstPageIsStartPage
     * @see completeLastPage
     */
    start() {
        if (!this.firstPageIsStartPage)
            return false;
        this.isCurrentPageRendering = true;
        if (this.checkIsPageHasErrors(this.startPage, true))
            return false;
        this.isStartedState = false;
        this.notifyQuestionsOnHidingContent(this.pages[0]);
        this.startTimerFromUI();
        this.onStarted.fire(this, {});
        this.updateVisibleIndexes();
        this.currentPageNo = 0;
        if (!!this.currentPage) {
            this.currentPage.locStrsChanged();
        }
        return true;
    }
    /**
     * Indicates whether the current page is being [validated on a server](#onServerValidateQuestions).
     */
    get isValidatingOnServer() {
        return this.getPropertyValue("isValidatingOnServer", false);
    }
    setIsValidatingOnServer(val) {
        if (val == this.isValidatingOnServer)
            return;
        this.setPropertyValue("isValidatingOnServer", val);
        this.onIsValidatingOnServerChanged();
    }
    createServerValidationOptions(doComplete, isPreview, page) {
        var self = this;
        const options = {
            data: {},
            errors: {},
            survey: this,
            complete: function () {
                self.completeServerValidation(options, isPreview, page);
            },
        };
        if (doComplete && this.isValidateOnComplete) {
            options.data = this.data;
        }
        else {
            var questions = this.activePage.questions;
            for (var i = 0; i < questions.length; i++) {
                var question = questions[i];
                if (!question.visible)
                    continue;
                var value = this.getValue(question.getValueName());
                if (!this.isValueEmpty(value))
                    options.data[question.getValueName()] = value;
            }
        }
        return options;
    }
    onIsValidatingOnServerChanged() { }
    doServerValidation(doComplete, isPreview = false, page) {
        if (!this.onServerValidateQuestions ||
            this.onServerValidateQuestions.isEmpty)
            return false;
        if (!doComplete && this.isValidateOnComplete)
            return false;
        this.setIsValidatingOnServer(true);
        const isFunc = typeof this.onServerValidateQuestions === "function";
        this.serverValidationEventCount = !isFunc ? this.onServerValidateQuestions.length : 1;
        if (isFunc) {
            this.onServerValidateQuestions(this, this.createServerValidationOptions(doComplete, isPreview, page));
        }
        else {
            this.onServerValidateQuestions.fireByCreatingOptions(this, () => { return this.createServerValidationOptions(doComplete, isPreview, page); });
        }
        return true;
    }
    completeServerValidation(options, isPreview, page) {
        if (this.serverValidationEventCount > 1) {
            this.serverValidationEventCount--;
            if (!!options && !!options.errors && Object.keys(options.errors).length === 0)
                return;
        }
        this.serverValidationEventCount = 0;
        this.setIsValidatingOnServer(false);
        if (!options && !options.survey)
            return;
        var self = options.survey;
        var hasErrors = false;
        if (options.errors) {
            var hasToFocus = this.autoFocusFirstError;
            for (var name in options.errors) {
                var question = self.getQuestionByName(name);
                if (question && question["errors"]) {
                    hasErrors = true;
                    question.addError(new CustomError(options.errors[name], this));
                    if (hasToFocus) {
                        hasToFocus = false;
                        if (!!question.page) {
                            this.currentPage = question.page;
                        }
                        question.focus(true);
                    }
                }
            }
            this.fireValidatedErrorsOnPage(this.currentPage);
        }
        if (!hasErrors) {
            if (isPreview) {
                this.showPreviewCore();
            }
            else {
                if (page) {
                    this.currentPage = page;
                }
                else {
                    if (self.isLastPage)
                        self.doComplete();
                    else
                        self.doNextPage();
                }
            }
        }
    }
    doNextPage() {
        var curPage = this.currentPage;
        this.checkOnPageTriggers(false);
        this.sendPartialResult();
        if (!this.isCompleted) {
            if (curPage === this.currentPage) {
                var vPages = this.visiblePages;
                var index = vPages.indexOf(this.currentPage);
                this.currentPage = vPages[index + 1];
            }
        }
        else {
            this.doComplete(true);
        }
    }
    setCompleted(trigger) {
        this.doComplete(true, trigger);
    }
    sendPartialResult() {
        if (this.partialSendEnabled && !this.isCompleted) {
            this.sendResult(this.surveyPostId, this.clientId, true);
        }
    }
    canBeCompleted(trigger, isCompleted) {
        var _a;
        if (!settings.triggers.changeNavigationButtonsOnComplete)
            return;
        const prevCanBeCompleted = this.canBeCompletedByTrigger;
        if (!this.completedByTriggers)
            this.completedByTriggers = {};
        if (isCompleted) {
            this.completedByTriggers[trigger.id] = { trigger: trigger, pageId: (_a = this.currentPage) === null || _a === void 0 ? void 0 : _a.id };
        }
        else {
            delete this.completedByTriggers[trigger.id];
        }
        if (prevCanBeCompleted !== this.canBeCompletedByTrigger) {
            this.updateButtonsVisibility();
        }
    }
    get canBeCompletedByTrigger() {
        var _a;
        if (!this.completedByTriggers)
            return false;
        const keys = Object.keys(this.completedByTriggers);
        if (keys.length === 0)
            return false;
        const id = (_a = this.currentPage) === null || _a === void 0 ? void 0 : _a.id;
        if (!id)
            return true;
        for (let i = 0; i < keys.length; i++) {
            if (id === this.completedByTriggers[keys[i]].pageId)
                return true;
        }
        return false;
    }
    get completedTrigger() {
        if (!this.canBeCompletedByTrigger)
            return undefined;
        const key = Object.keys(this.completedByTriggers)[0];
        return this.completedByTriggers[key].trigger;
    }
    /**
     * Returns HTML content displayed on the [complete page](https://surveyjs.io/form-library/documentation/design-survey/create-a-multi-page-survey#complete-page).
     *
     * To specify HTML content, use the [`completedHtml`](#completedHtml) property.
     */
    get processedCompletedHtml() {
        var html = this.renderedCompletedHtml;
        return !!html ? this.processHtml(html, "completed") : "";
    }
    /**
     * Returns HTML content displayed to a user who has completed the survey before. To identify such users, the survey uses a [cookie name](#cookieName).
     *
     * To specify HTML content, use the [`completedBeforeHtml`](#completedBeforeHtml) property.
     */
    get processedCompletedBeforeHtml() {
        return this.locCompletedBeforeHtml.textOrHtml;
    }
    /**
     * Returns HTML content displayed while a survey JSON schema is [being loaded](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#beginLoading).
     *
     * To specify HTML content, use the [`loadingHtml`](#loadingHtml) property.
     */
    get processedLoadingHtml() {
        return this.locLoadingHtml.textOrHtml;
    }
    getProgressInfo() {
        var pages = this.isDesignMode ? this.pages : this.visiblePages;
        return SurveyElement.getProgressInfoByElements(pages, false);
    }
    get progressBarAriaLabel() {
        return getLocaleString("progressbar", this.getLocale());
    }
    /**
     * Returns text displayed by the progress bar (for instance, "Page 2 of 3" or "Answered 3/8 questions"). Handle the [`onGetProgressText`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onGetProgressText) event to change this text.
     * @see progressValue
     * @see showProgressBar
     * @see progressBarType
     */
    get progressText() {
        return this.progressBar.progressText;
    }
    /**
     * Returns a percentage value that indicates user progress in the survey.
     * @see showProgressBar
     * @see progressBarType
     * @see progressText
     */
    get progressValue() {
        return this.getPropertyValue("progressValue", undefined, () => this.getProgress());
    }
    updateProgressText(onValueChanged = false) {
        if (this.isShowingPreview)
            return;
        if (onValueChanged && this.progressBarType == "pages" && this.onGetProgressText.isEmpty)
            return;
        if (this.progressBarValue) {
            this.progressBarValue.resetProgressText();
        }
        this.resetPropertyValue("progressValue");
    }
    getProgressText() {
        if (!this.isDesignMode && this.currentPage == null)
            return "";
        const options = {
            questionCount: 0,
            answeredQuestionCount: 0,
            requiredQuestionCount: 0,
            requiredAnsweredQuestionCount: 0,
            text: "",
        };
        var type = this.progressBarType.toLowerCase();
        if (type === "questions" ||
            type === "requiredquestions" ||
            type === "correctquestions" ||
            !this.onGetProgressText.isEmpty) {
            var info = this.getProgressInfo();
            options.questionCount = info.questionCount;
            options.answeredQuestionCount = info.answeredQuestionCount;
            options.requiredQuestionCount = info.requiredQuestionCount;
            options.requiredAnsweredQuestionCount =
                info.requiredAnsweredQuestionCount;
        }
        options.text = this.getProgressTextCore(options);
        this.onGetProgressText.fire(this, options);
        return options.text;
    }
    getProgressTextCore(info) {
        var type = this.progressBarType.toLowerCase();
        if (type === "questions") {
            return this.getLocalizationFormatString("questionsProgressText", info.answeredQuestionCount, info.questionCount);
        }
        if (type === "requiredquestions") {
            return this.getLocalizationFormatString("questionsProgressText", info.requiredAnsweredQuestionCount, info.requiredQuestionCount);
        }
        if (type === "correctquestions") {
            var correctAnswersCount = this.getCorrectedAnswerCount();
            return this.getLocalizationFormatString("questionsProgressText", correctAnswersCount, info.questionCount);
        }
        var vPages = this.isDesignMode ? this.pages : this.visiblePages;
        var index = vPages.indexOf(this.currentPage) + 1;
        return this.getLocalizationFormatString("progressText", index, vPages.length);
    }
    getRootCss() {
        return new CssClassBuilder()
            .append(this.css.root)
            .append(this.css.rootProgress + "--" + this.progressBarType)
            .append(this.css.rootMobile, this.isMobile)
            .append(this.css.rootAnimationDisabled, !settings.animationEnabled)
            .append(this.css.rootReadOnly, this.readOnly && !this.isDesignMode)
            .append(this.css.rootCompact, this.isCompact)
            .append(this.css.rootFitToContainer, this.fitToContainer)
            .toString();
    }
    afterRenderSurvey(htmlElement) {
        if (!DomWindowHelper.isAvailable())
            return;
        this.destroyResizeObserver();
        if (Array.isArray(htmlElement)) {
            htmlElement = SurveyElement.GetFirstNonTextElement(htmlElement);
        }
        let observedElement = htmlElement;
        const cssVariables = this.css.variables;
        if (!!cssVariables) {
            const mobileWidth = Number.parseFloat(DomDocumentHelper.getComputedStyle(observedElement).getPropertyValue(cssVariables.mobileWidth));
            if (!!mobileWidth) {
                let isProcessed = false;
                this.resizeObserver = new ResizeObserver((entries) => {
                    DomWindowHelper.requestAnimationFrame(() => {
                        if (isProcessed || !isContainerVisible(observedElement)) {
                            isProcessed = false;
                        }
                        else {
                            isProcessed = this.processResponsiveness(observedElement.offsetWidth, mobileWidth, observedElement.offsetHeight);
                        }
                    });
                });
                this.resizeObserver.observe(observedElement);
            }
        }
        this.onAfterRenderSurvey.fire(this, {
            survey: this,
            htmlElement: htmlElement,
        });
        this.rootElement = htmlElement;
        this.scrollerElement = htmlElement.getElementsByClassName("sv-scroll__scroller")[0];
        this.addScrollEventListener();
    }
    beforeDestroySurveyElement() {
        this.destroyResizeObserver();
        this.removeScrollEventListener();
        this.rootElement = undefined;
        this.scrollerElement = undefined;
    }
    processResponsiveness(width, mobileWidth, height) {
        const isMobile = width < mobileWidth;
        const isMobileChanged = this.isMobile !== isMobile;
        this.setIsMobile(isMobile);
        this.layoutElements.forEach(layoutElement => layoutElement.processResponsiveness && layoutElement.processResponsiveness(width));
        const options = {
            height,
            width,
        };
        this.onResize.fire(this, options);
        // this.setResponsiveStartWidth(width);
        return isMobileChanged;
    }
    triggerResponsiveness(hard) {
        this.getAllQuestions().forEach(question => {
            question.triggerResponsiveness(hard);
        });
    }
    destroyResizeObserver() {
        if (!!this.resizeObserver) {
            this.resizeObserver.disconnect();
            this.resizeObserver = undefined;
        }
    }
    updateQuestionCssClasses(question, cssClasses) {
        this.onUpdateQuestionCssClasses.fire(this, {
            question: question,
            cssClasses: cssClasses,
        });
    }
    updatePanelCssClasses(panel, cssClasses) {
        this.onUpdatePanelCssClasses.fire(this, {
            panel: panel,
            cssClasses: cssClasses,
        });
    }
    updatePageCssClasses(page, cssClasses) {
        this.onUpdatePageCssClasses.fire(this, {
            page: page,
            cssClasses: cssClasses,
        });
    }
    updateChoiceItemCss(question, options) {
        options.question = question;
        this.onUpdateChoiceItemCss.fire(this, options);
    }
    afterRenderPage(htmlElement) {
        if (!this.isDesignMode && !this.focusingQuestionInfo) {
            const doScroll = this.isCurrentPageRendered === false;
            setTimeout(() => this.scrollToTopOnPageChange(doScroll), 1);
        }
        this.focusQuestionInfo();
        this.isCurrentPageRendered = true;
        if (this.onAfterRenderPage.isEmpty)
            return;
        this.onAfterRenderPage.fire(this, {
            page: this.activePage,
            htmlElement: htmlElement,
        });
    }
    afterRenderHeader(htmlElement) {
        if (this.onAfterRenderHeader.isEmpty)
            return;
        this.onAfterRenderHeader.fire(this, {
            htmlElement: htmlElement,
        });
    }
    afterRenderQuestion(question, htmlElement) {
        this.onAfterRenderQuestion.fire(this, {
            question: question,
            htmlElement: htmlElement,
        });
    }
    afterRenderQuestionInput(question, htmlElement) {
        if (this.onAfterRenderQuestionInput.isEmpty)
            return;
        let id = question.inputId;
        const { root } = settings.environment;
        if (!!id && (!htmlElement || htmlElement.id !== id) && typeof root !== "undefined") {
            let el = root.getElementById(id);
            if (!!el) {
                htmlElement = el;
            }
        }
        this.onAfterRenderQuestionInput.fire(this, {
            question: question,
            htmlElement: htmlElement,
        });
    }
    afterRenderPanel(panel, htmlElement) {
        this.onAfterRenderPanel.fire(this, {
            panel: panel,
            htmlElement: htmlElement,
        });
    }
    whenQuestionFocusIn(question) {
        this.onFocusInQuestion.fire(this, {
            question: question
        });
    }
    whenPanelFocusIn(panel) {
        this.onFocusInPanel.fire(this, {
            panel: panel
        });
    }
    rebuildQuestionChoices() {
        this.getAllQuestions().forEach(q => q.surveyChoiceItemVisibilityChange());
    }
    canChangeChoiceItemsVisibility() {
        return !this.onShowingChoiceItem.isEmpty;
    }
    getChoiceItemVisibility(question, item, val) {
        const options = { question: question, item: item, visible: val };
        this.onShowingChoiceItem.fire(this, options);
        return options.visible;
    }
    loadQuestionChoices(options) {
        this.onChoicesLazyLoad.fire(this, options);
    }
    getChoiceDisplayValue(options) {
        if (this.onGetChoiceDisplayValue.isEmpty) {
            options.setItems(null);
        }
        else {
            this.onGetChoiceDisplayValue.fire(this, options);
        }
    }
    matrixBeforeRowAdded(options) {
        this.onMatrixRowAdding.fire(this, options);
    }
    matrixRowAdded(question, row) {
        this.onMatrixRowAdded.fire(this, { question: question, row: row });
    }
    matrixColumnAdded(question, column) {
        this.onMatrixColumnAdded.fire(this, { question: question, column: column });
    }
    multipleTextItemAdded(question, item) {
        this.onMultipleTextItemAdded.fire(this, { question: question, item: item });
    }
    getQuestionByValueNameFromArray(valueName, name, index) {
        var questions = this.getQuestionsByValueName(valueName);
        if (!questions)
            return;
        for (var i = 0; i < questions.length; i++) {
            var res = questions[i].getQuestionFromArray(name, index);
            if (!!res)
                return res;
        }
        return null;
    }
    matrixRowRemoved(question, rowIndex, row) {
        this.onMatrixRowRemoved.fire(this, {
            question: question,
            rowIndex: rowIndex,
            row: row,
        });
    }
    matrixRowRemoving(question, rowIndex, row) {
        var options = {
            question: question,
            rowIndex: rowIndex,
            row: row,
            allow: true,
        };
        this.onMatrixRowRemoving.fire(this, options);
        return options.allow;
    }
    matrixAllowRemoveRow(question, rowIndex, row) {
        const options = { question: question, rowIndex: rowIndex, row: row, allow: true };
        this.onMatrixRenderRemoveButton.fire(this, options);
        return options.allow;
    }
    matrixDetailPanelVisibleChanged(question, rowIndex, row, visible) {
        const options = { question: question, rowIndex: rowIndex, row: row, visible: visible, detailPanel: row.detailPanel };
        this.onMatrixDetailPanelVisibleChanged.fire(this, options);
    }
    matrixCellCreating(question, options) {
        options.question = question;
        this.onMatrixCellCreating.fire(this, options);
    }
    matrixCellCreated(question, options) {
        options.question = question;
        this.onMatrixCellCreated.fire(this, options);
    }
    matrixAfterCellRender(options) {
        var _a;
        const evt = this.onAfterRenderMatrixCell;
        if (!evt.isEmpty) {
            options.question = (_a = options.cellQuestion) === null || _a === void 0 ? void 0 : _a.parentQuestion;
            evt.fire(this, options);
        }
    }
    matrixCellValueChanged(question, options) {
        options.question = question;
        this.onMatrixCellValueChanged.fire(this, options);
    }
    matrixCellValueChanging(question, options) {
        options.question = question;
        this.onMatrixCellValueChanging.fire(this, options);
    }
    get isValidateOnValueChanging() {
        return this.checkErrorsMode === "onValueChanging";
    }
    get isValidateOnValueChanged() {
        return this.checkErrorsMode === "onValueChanged";
    }
    get isValidateOnValueChange() {
        return this.isValidateOnValueChanged || this.isValidateOnValueChanging;
    }
    get isValidateOnComplete() {
        return this.checkErrorsMode === "onComplete" || this.validationAllowSwitchPages && !this.validationAllowComplete;
    }
    matrixCellValidate(question, options) {
        options.question = question;
        this.onMatrixCellValidate.fire(this, options);
        return options.error ? new CustomError(options.error, this) : null;
    }
    dynamicPanelAdded(question, panelIndex, panel, updateIndexes) {
        if (!this.isLoadingFromJson && updateIndexes) {
            this.updateVisibleIndexes(question.page);
        }
        this.onDynamicPanelAdded.fire(this, { question: question, panel: panel, panelIndex: panelIndex });
    }
    dynamicPanelRemoved(question, panelIndex, panel, updateIndexes) {
        var questions = !!panel ? panel.questions : [];
        for (var i = 0; i < questions.length; i++) {
            questions[i].clearOnDeletingContainer();
        }
        if (updateIndexes) {
            this.updateVisibleIndexes(question.page);
        }
        this.onDynamicPanelRemoved.fire(this, {
            question: question,
            panelIndex: panelIndex,
            panel: panel,
        });
    }
    dynamicPanelRemoving(question, panelIndex, panel) {
        const options = {
            question: question,
            panelIndex: panelIndex,
            panel: panel,
            allow: true
        };
        this.onDynamicPanelRemoving.fire(this, options);
        return options.allow;
    }
    dynamicPanelItemValueChanged(question, options) {
        options.question = question;
        this.onDynamicPanelValueChanged.fire(this, options);
    }
    dynamicPanelItemValueChanging(question, options) {
        options.question = question;
        this.onDynamicPanelValueChanging.fire(this, options);
    }
    dynamicPanelGetTabTitle(question, options) {
        options.question = question;
        this.onGetDynamicPanelTabTitle.fire(this, options);
    }
    dynamicPanelCurrentIndexChanged(question, options) {
        options.question = question;
        this.onDynamicPanelCurrentIndexChanged.fire(this, options);
    }
    dragAndDropAllow(options) {
        this.onDragDropAllow.fire(this, options);
        return options.allow;
    }
    elementContentVisibilityChanged(element) {
        if (this.currentPage) {
            this.currentPage.ensureRowsVisibility();
        }
        this.onElementContentVisibilityChanged.fire(this, { element });
    }
    getUpdatedPanelFooterActions(panel, actions, question) {
        const options = {
            question: question,
            panel: panel,
            actions: actions,
        };
        this.onGetPanelFooterActions.fire(this, options);
        return options.actions;
    }
    getUpdatedElementTitleActions(element, titleActions) {
        if (element.isPage)
            return this.getUpdatedPageTitleActions(element, titleActions);
        if (element.isPanel)
            return this.getUpdatedPanelTitleActions(element, titleActions);
        return this.getUpdatedQuestionTitleActions(element, titleActions);
    }
    getTitleActionsResult(titleActions, options) {
        if (titleActions != options.actions)
            return options.actions;
        if (titleActions != options.titleActions)
            return options.titleActions;
        return titleActions;
    }
    getUpdatedQuestionTitleActions(question, titleActions) {
        const options = {
            question: question,
            actions: titleActions,
            titleActions: titleActions,
        };
        this.onGetQuestionTitleActions.fire(this, options);
        return this.getTitleActionsResult(titleActions, options);
    }
    getUpdatedPanelTitleActions(panel, titleActions) {
        const options = {
            panel: panel,
            actions: titleActions,
            titleActions: titleActions,
        };
        this.onGetPanelTitleActions.fire(this, options);
        return this.getTitleActionsResult(titleActions, options);
    }
    getUpdatedPageTitleActions(page, titleActions) {
        var options = {
            page: page,
            actions: titleActions,
            titleActions: titleActions,
        };
        this.onGetPageTitleActions.fire(this, options);
        return this.getTitleActionsResult(titleActions, options);
    }
    getUpdatedMatrixRowActions(question, row, actions) {
        const options = {
            question: question,
            actions: actions,
            row: row,
        };
        this.onGetMatrixRowActions.fire(this, options);
        return options.actions;
    }
    scrollElementToTop(element, question, page, id, scrollIfVisible, scrollIntoViewOptions, passedRootElement, onScolledCallback) {
        const options = {
            element: element,
            question: question,
            page: page,
            elementId: id,
            cancel: false,
            allow: true,
        };
        this.onScrollToTop.fire(this, options);
        if (!options.cancel && options.allow) {
            const elementPage = this.getPageByElement(element);
            const { rootElement } = settings.environment;
            const surveyRootElement = this.rootElement || passedRootElement || rootElement;
            if (this.isLazyRendering && !!elementPage) {
                let elementsToRenderBefore = 1;
                if (!!this.skeletonHeight && !!surveyRootElement && typeof surveyRootElement.getBoundingClientRect === "function") {
                    elementsToRenderBefore = surveyRootElement.getBoundingClientRect().height / this.skeletonHeight - 1;
                }
                elementPage.forceRenderElement(element, () => {
                    const htmlElement = surveyRootElement === null || surveyRootElement === void 0 ? void 0 : surveyRootElement.querySelector(`#${options.elementId}`);
                    this.suspendLazyRendering();
                    SurveyElement.ScrollElementToTop(htmlElement, scrollIfVisible, scrollIntoViewOptions, () => {
                        this.releaseLazyRendering();
                        const pageRootElement = surveyRootElement.querySelector(`#${elementPage.id}`);
                        activateLazyRenderingChecks(pageRootElement);
                        onScolledCallback && onScolledCallback();
                    });
                }, elementsToRenderBefore);
            }
            else {
                if (element.isPage && !this.isSinglePage && !this.isDesignMode && this.rootElement) {
                    const elementToScroll = surveyRootElement.querySelector(classesToSelector(this.css.rootWrapper));
                    SurveyElement.ScrollElementToViewCore(elementToScroll, false, scrollIfVisible, scrollIntoViewOptions, onScolledCallback);
                }
                else {
                    const htmlElement = surveyRootElement === null || surveyRootElement === void 0 ? void 0 : surveyRootElement.querySelector(`#${options.elementId}`);
                    this.suspendLazyRendering();
                    SurveyElement.ScrollElementToTop(htmlElement, scrollIfVisible, scrollIntoViewOptions, () => {
                        this.releaseLazyRendering();
                        activateLazyRenderingChecks(htmlElement);
                        onScolledCallback && onScolledCallback();
                    });
                }
            }
        }
    }
    /**
     * Opens a dialog window for users to select files.
     * @param input A [file input HTML element](https://developer.mozilla.org/en-US/docs/Web/API/HTMLInputElement).
     * @param callback A callback function that you can use to process selected files. Accepts an array of JavaScript <a href="https://developer.mozilla.org/en-US/docs/Web/API/File" target="_blank">File</a> objects.
     * @see onOpenFileChooser
     * @see onUploadFile
     */
    chooseFiles(input, callback, context) {
        if (this.onOpenFileChooser.isEmpty) {
            chooseFiles(input, callback);
        }
        else {
            this.onOpenFileChooser.fire(this, {
                input: input,
                element: context && context.element || this.survey,
                elementType: context && context.elementType,
                item: context && context.item,
                propertyName: context && context.propertyName,
                callback: callback,
                context: context
            });
        }
    }
    /**
     * Uploads files to a server.
     *
     * The following code shows how to call this method:
     *
     * ```js
     * const question = survey.getQuestionByName("myFileQuestion");
     * survey.uploadFiles(
     *   question,
     *   question.name,
     *   question.value,
     *   (data, errors) => {
     *     // ...
     *   }
     * );
     * ```
     * @param question A [File Upload question instance](https://surveyjs.io/form-library/documentation/api-reference/file-model) or [Signature Pad question instance](https://surveyjs.io/form-library/documentation/api-reference/signature-pad-model).
     * @param name The File Upload question's [`name`](https://surveyjs.io/form-library/documentation/api-reference/file-model#name) or Signature Pad question's [`name`](https://surveyjs.io/form-library/documentation/api-reference/signature-pad-model#name).
     * @param files An array of JavaScript <a href="https://developer.mozilla.org/en-US/docs/Web/API/File" target="_blank">File</a> objects that represent files to upload.
     * @param callback A callback function that allows you to access successfully uploaded files as the first argument. If any files fail to upload, the second argument contains an array of error messages.
     * @see onUploadFiles
     * @see downloadFile
     */
    uploadFiles(question, name, files, callback) {
        if (this.onUploadFiles.isEmpty) {
            callback("error", this.getLocString("noUploadFilesHandler"));
        }
        else {
            this.taskManager.runTask("file", (done) => {
                this.onUploadFiles.fire(this, {
                    question: question,
                    name: name,
                    files: files || [],
                    callback: (status, data) => {
                        callback(status, data);
                        done();
                    },
                });
            });
        }
        if (this.surveyPostId) {
            this.uploadFilesCore(name, files, callback);
        }
    }
    downloadFile(question, questionName, fileValue, callback) {
        if (this.onDownloadFile.isEmpty) {
            !!callback && callback("skipped", fileValue.content || fileValue);
        }
        this.onDownloadFile.fire(this, {
            question: question,
            name: questionName,
            content: fileValue.content || fileValue,
            fileValue: fileValue,
            callback: callback,
        });
    }
    clearFiles(question, name, value, fileName, callback) {
        if (this.onClearFiles.isEmpty) {
            !!callback && callback("success", value);
        }
        this.onClearFiles.fire(this, {
            question: question,
            name: name,
            value: value,
            fileName: fileName,
            callback: callback,
        });
    }
    updateChoicesFromServer(question, choices, serverResult) {
        var options = {
            question: question,
            choices: choices,
            serverResult: serverResult,
        };
        this.onChoicesLoaded.fire(this, options);
        return options.choices;
    }
    loadedChoicesFromServer(question) {
        this.locStrsChanged();
    }
    uploadFilesCore(name, files, uploadingCallback) {
        this.reportWarningOnUsingService();
    }
    getPage(index) {
        return this.pages[index];
    }
    /**
     * Adds an existing page to the survey.
     * @param page A page to add.
     * @param index An index at which to insert the page. If you do not specify this parameter, the page will be added to the end.
     * @see addNewPage
     * @see createNewPage
     */
    addPage(page, index = -1) {
        if (page == null)
            return;
        if (index < 0 || index >= this.pages.length) {
            this.pages.push(page);
        }
        else {
            this.pages.splice(index, 0, page);
        }
    }
    /**
     * Creates a new page and adds it to the survey.
     *
     * If you want to switch a survey to the newly added page, assign its index to the [`currentPageNo`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#currentPageNo) property or assign the entire page to the [`currentPage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#currentPage) property.
     *
     * @param name A page name. If you do not specify this parameter, it will be generated automatically.
     * @param index An index at which to insert the page. If you do not specify this parameter, the page will be added to the end.
     * @returns The created and added page.
     * @see addPage
     * @see createNewPage
     */
    addNewPage(name = null, index = -1) {
        var page = this.createNewPage(name);
        this.addPage(page, index);
        return page;
    }
    /**
     * Removes a page from the survey.
     *
     * Pass a `PageModel` object to this method. You can get this object in different ways. For example, you can call the [`getPageByName()`](#getPageByName) method to obtain a `PageModel` object with a specific name or use the [`currentPage`](#currentPage) property to access and delete the current page, as shown in the code below.
     *
     * ```js
     * // Delete the current page
     * survey.removePage(survey.currentPage);
     * ```
     * @param page A page to remove.
     * @see addNewPage
     */
    removePage(page) {
        var index = this.pages.indexOf(page);
        if (index < 0)
            return;
        this.pages.splice(index, 1);
        if (this.currentPage == page) {
            this.currentPage = this.pages.length > 0 ? this.pages[0] : null;
        }
    }
    /**
     * Returns a question with a specified [`name`](https://surveyjs.io/form-library/documentation/api-reference/question#name).
     * @param name A question name.
     * @returns A question with the specified name.
     * @see getAllQuestions
     * @see getQuestionByValueName
     */
    getQuestionByName(name, caseInsensitive = false) {
        if (!name)
            return null;
        if (caseInsensitive) {
            name = name.toLowerCase();
        }
        var hash = !!caseInsensitive
            ? this.questionHashes.namesInsensitive
            : this.questionHashes.names;
        var res = hash[name];
        if (!res)
            return null;
        return res[0];
    }
    findQuestionByName(name) {
        return this.getQuestionByName(name);
    }
    getEditingSurveyElement() { return this.editingObjValue; }
    /**
     * Returns a question with a specified [`valueName`](https://surveyjs.io/form-library/documentation/api-reference/question#valueName).
     *
     * > Since `valueName` does not have to be unique, multiple questions can have the same `valueName` value. In this case, the `getQuestionByValueName()` method returns the first such question. If you need to get all questions with the same `valueName`, call the `getQuestionsByValueName()` method.
     * @param valueName A question's `valueName` property value.
     * @returns A question with a specified `valueName`.
     * @see getAllQuestions
     * @see getQuestionByName
     */
    getQuestionByValueName(valueName, caseInsensitive = false) {
        var res = this.getQuestionsByValueName(valueName, caseInsensitive);
        return !!res ? res[0] : null;
    }
    /**
     * Returns all questions with a specified [`valueName`](https://surveyjs.io/form-library/documentation/api-reference/question#valueName). If a question's `valueName` is undefined, its [`name`](https://surveyjs.io/form-library/documentation/api-reference/question#name) property is used.
     * @param valueName A question's `valueName` property value.
     * @returns An array of questions with a specified `valueName`.
     * @see getAllQuestions
     * @see getQuestionByName
     */
    getQuestionsByValueName(valueName, caseInsensitive = false) {
        var hash = !!caseInsensitive
            ? this.questionHashes.valueNamesInsensitive
            : this.questionHashes.valueNames;
        var res = hash[valueName];
        if (!res)
            return null;
        return res;
    }
    getCalculatedValueByName(name) {
        for (var i = 0; i < this.calculatedValues.length; i++) {
            if (name == this.calculatedValues[i].name)
                return this.calculatedValues[i];
        }
        return null;
    }
    getQuestionsByNames(names, caseInsensitive = false) {
        var result = [];
        if (!names)
            return result;
        for (var i = 0; i < names.length; i++) {
            if (!names[i])
                continue;
            var question = this.getQuestionByName(names[i], caseInsensitive);
            if (question)
                result.push(question);
        }
        return result;
    }
    /**
     * Returns a page to which a specified survey element (question or panel) belongs.
     * @param element A question or panel instance.
     */
    getPageByElement(element) {
        for (var i = 0; i < this.pages.length; i++) {
            var page = this.pages[i];
            if (page.containsElement(element))
                return page;
        }
        return null;
    }
    /**
     * Returns a page to which a specified question belongs.
     * @param question A question instance.
     */
    getPageByQuestion(question) {
        return this.getPageByElement(question);
    }
    /**
     * Returns a page with a specified name.
     * @param name A page [name](https://surveyjs.io/form-library/documentation/api-reference/page-model#name).
     * @returns A page with the specified name.
     */
    getPageByName(name) {
        for (var i = 0; i < this.pages.length; i++) {
            if (this.pages[i].name == name)
                return this.pages[i];
        }
        return null;
    }
    getPagesByNames(names) {
        var result = [];
        if (!names)
            return result;
        for (var i = 0; i < names.length; i++) {
            if (!names[i])
                continue;
            var page = this.getPageByName(names[i]);
            if (page)
                result.push(page);
        }
        return result;
    }
    /**
     * Returns a list of all [questions](https://surveyjs.io/form-library/documentation/api-reference/question) in the survey.
     * @param visibleOnly A Boolean value that specifies whether to include only visible questions.
     * @param includeDesignTime For internal use.
     * @param includeNested A Boolean value that specifies whether to include nested questions, such as questions within matrix cells.
     * @returns An array of questions.
     * @see getQuestionByName
     */
    getAllQuestions(visibleOnly = false, includeDesignTime = false, includeNested = false) {
        if (includeNested) {
            includeDesignTime = false;
            const pages = visibleOnly ? this.visiblePages : this.pages;
            pages.forEach(page => page.onFirstRendering());
        }
        var res = [];
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].addQuestionsToList(res, visibleOnly, includeDesignTime);
        }
        if (!includeNested)
            return res;
        return this.getNestedQuestionsByQuestionArray(res, visibleOnly);
    }
    getNestedQuestionsByQuestionArray(res, visibleOnly) {
        const res2 = [];
        res.forEach(q => {
            q.getNestedQuestions(visibleOnly, true, true).forEach(nQ => res2.push(nQ));
        });
        return res2;
    }
    /**
     * Returns an array of quiz questions. A question counts if it is visible, has an input field, and specifies [`correctAnswer`](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model#correctAnswer).
     *
     * For more information about quizzes, refer to the following tutorial: [Create a Quiz](https://surveyjs.io/form-library/documentation/design-survey/create-a-quiz).
     * @returns An array of quiz questions.
     * @see getQuizQuestionCount
     */
    getQuizQuestions() {
        var result = new Array();
        var startIndex = this.getPageStartIndex();
        for (var i = startIndex; i < this.pages.length; i++) {
            if (!this.pages[i].isVisible)
                continue;
            var questions = this.pages[i].questions;
            for (var j = 0; j < questions.length; j++) {
                var q = questions[j];
                if (q.quizQuestionCount > 0) {
                    result.push(q);
                }
            }
        }
        return result;
    }
    /**
     * Returns a [panel](https://surveyjs.io/form-library/documentation/api-reference/panel-model) with a specified [`name`](https://surveyjs.io/form-library/documentation/api-reference/panel-model#name).
     * @param name A panel name.
     * @returns A panel with the specified name.
     * @see getAllPanels
     */
    getPanelByName(name, caseInsensitive = false) {
        var panels = this.getAllPanels();
        if (caseInsensitive)
            name = name.toLowerCase();
        for (var i = 0; i < panels.length; i++) {
            var panelName = panels[i].name;
            if (caseInsensitive)
                panelName = panelName.toLowerCase();
            if (panelName == name)
                return panels[i];
        }
        return null;
    }
    /**
     * Returns a list of all [panels](https://surveyjs.io/form-library/documentation/api-reference/panel-model) in the survey.
     * @param visibleOnly A Boolean value that specifies whether to include only visible panels.
     * @param includeDesignTime For internal use.
     * @returns An array of panels.
     * @see getPanelByName
     */
    getAllPanels(visibleOnly = false, includeDesignTime = false) {
        var result = new Array();
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].addPanelsIntoList(result, visibleOnly, includeDesignTime);
        }
        return result;
    }
    /**
     * Creates and returns a new page but does not add it to the survey.
     *
     * Call the [`addPage(page)`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#addPage) method to add the created page to the survey later or the [`addNewPage(name, index)`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#addNewPage) method to create _and_ add a page to the survey.
     * @see addPage
     * @see addNewPage
     */
    createNewPage(name) {
        const page = Serializer.createClass("page");
        page.name = name;
        return page;
    }
    getValueChangeReason() {
        if (this.isSettingValueOnExpression)
            return "expression";
        return this.isSettingValueFromTrigger ? "trigger" : undefined;
    }
    questionOnValueChanging(valueName, newValue, questionValueName) {
        if (!!this.editingObj) {
            const prop = Serializer.findProperty(this.editingObj.getType(), valueName);
            if (!!prop)
                newValue = prop.settingValue(this.editingObj, newValue);
        }
        if (this.onValueChanging.isEmpty)
            return newValue;
        var options = {
            name: valueName,
            question: this.getQuestionByValueName(questionValueName || valueName),
            value: this.getUnbindValue(newValue),
            oldValue: this.getValue(valueName),
            reason: this.getValueChangeReason()
        };
        this.onValueChanging.fire(this, options);
        return options.value;
    }
    updateQuestionValue(valueName, newValue) {
        if (this.isLoadingFromJson)
            return;
        var questions = this.getQuestionsByValueName(valueName);
        if (!!questions) {
            for (var i = 0; i < questions.length; i++) {
                var qValue = questions[i].value;
                if ((qValue === newValue && Array.isArray(qValue) && !!this.editingObj) ||
                    !this.isTwoValueEquals(qValue, newValue)) {
                    questions[i].updateValueFromSurvey(newValue, false);
                }
            }
        }
    }
    checkQuestionErrorOnValueChanged(question) {
        if (!this.isNavigationButtonPressed &&
            (this.isValidateOnValueChanged ||
                question.getAllErrors().length > 0)) {
            this.checkQuestionErrorOnValueChangedCore(question);
        }
    }
    checkQuestionErrorOnValueChangedCore(question) {
        var oldErrorCount = question.getAllErrors().length;
        var res = !question.validate(true, {
            isOnValueChanged: !this.isValidateOnValueChanging,
        });
        if (!!question.page && this.isValidateOnValueChange &&
            (oldErrorCount > 0 || question.getAllErrors().length > 0)) {
            this.fireValidatedErrorsOnPage(question.page);
        }
        return res;
    }
    checkErrorsOnValueChanging(valueName, newValue) {
        if (this.isLoadingFromJson)
            return false;
        var questions = this.getQuestionsByValueName(valueName);
        if (!questions)
            return false;
        var res = false;
        for (var i = 0; i < questions.length; i++) {
            var q = questions[i];
            if (!this.isTwoValueEquals(q.valueForSurvey, newValue)) {
                q.value = newValue;
            }
            if (this.checkQuestionErrorOnValueChangedCore(q))
                res = true;
            res = res || q.errors.length > 0;
        }
        return res;
    }
    fireOnValueChanged(name, value, question) {
        this.onValueChanged.fire(this, {
            name: name,
            question: question,
            value: value,
            reason: this.getValueChangeReason()
        });
    }
    notifyQuestionOnValueChanged(valueName, newValue, questionName) {
        if (this.isLoadingFromJson)
            return;
        var questions = this.getQuestionsByValueName(valueName);
        if (!!questions) {
            for (var i = 0; i < questions.length; i++) {
                var question = questions[i];
                this.checkQuestionErrorOnValueChanged(question);
                question.onSurveyValueChanged(newValue);
            }
        }
        this.updateProgressText(true);
        this.fireOnValueChanged(valueName, newValue, !!questionName ? this.getQuestionByName(questionName) : undefined);
        if (this.isDisposed)
            return;
        this.checkElementsBindings(valueName, newValue);
        this.notifyElementsOnAnyValueOrVariableChanged(valueName, questionName);
    }
    checkElementsBindings(valueName, newValue) {
        this.isRunningElementsBindings = true;
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].checkBindings(valueName, newValue);
        }
        this.isRunningElementsBindings = false;
        if (this.updateVisibleIndexAfterBindings) {
            this.updateVisibleIndexes();
            this.updateVisibleIndexAfterBindings = false;
        }
    }
    notifyElementsOnAnyValueOrVariableChanged(name, questionName) {
        if (this.isEndLoadingFromJson === "processing")
            return;
        if (this.isRunningConditions) {
            this.conditionNotifyElementsOnAnyValueOrVariableChanged = true;
            return;
        }
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].onAnyValueChanged(name, questionName);
        }
        if (!this.isEndLoadingFromJson) {
            this.locStrsChanged();
        }
    }
    updateAllQuestionsValue(clearData) {
        var questions = this.getAllQuestions();
        for (var i = 0; i < questions.length; i++) {
            var q = questions[i];
            var valName = q.getValueName();
            q.updateValueFromSurvey(this.getValue(valName), clearData);
            if (q.requireUpdateCommentValue) {
                q.updateCommentFromSurvey(this.getComment(valName));
            }
        }
    }
    notifyAllQuestionsOnValueChanged() {
        var questions = this.getAllQuestions();
        for (var i = 0; i < questions.length; i++) {
            questions[i].onSurveyValueChanged(this.getValue(questions[i].getValueName()));
        }
    }
    checkOnPageTriggers(isOnComplete) {
        var questions = this.getCurrentPageQuestions(true);
        var values = {};
        for (var i = 0; i < questions.length; i++) {
            var question = questions[i];
            var name = question.getValueName();
            values[name] = this.getValue(name);
        }
        this.addCalculatedValuesIntoFilteredValues(values);
        this.checkTriggers(values, true, isOnComplete);
    }
    getCurrentPageQuestions(includeInvsible = false) {
        var result = [];
        var page = this.currentPage;
        if (!page)
            return result;
        for (var i = 0; i < page.questions.length; i++) {
            var question = page.questions[i];
            if ((!includeInvsible && !question.visible) || !question.name)
                continue;
            result.push(question);
        }
        return result;
    }
    checkTriggers(key, isOnNextPage, isOnComplete = false, isOnNavigation = false, name) {
        if (this.isCompleted || this.triggers.length == 0 || this.isDisplayMode)
            return;
        if (this.isTriggerIsRunning) {
            this.triggerValues = this.getFilteredValues();
            for (var k in key) {
                this.triggerKeys[k] = key[k];
            }
            return;
        }
        let isQuestionInvalid = false;
        if (!isOnComplete && name && this.hasRequiredValidQuestionTrigger) {
            const question = this.getQuestionByValueName(name);
            isQuestionInvalid = question && !question.validate(false);
        }
        this.isTriggerIsRunning = true;
        this.triggerKeys = key;
        this.triggerValues = this.getFilteredValues();
        var properties = this.getFilteredProperties();
        let prevCanBeCompleted = this.canBeCompletedByTrigger;
        for (let i = 0; i < this.triggers.length; i++) {
            const trigger = this.triggers[i];
            if (isQuestionInvalid && trigger.requireValidQuestion)
                continue;
            const options = { isOnNextPage: isOnNextPage, isOnComplete: isOnComplete, isOnNavigation: isOnNavigation,
                keys: this.triggerKeys, values: this.triggerValues, properties: properties };
            trigger.checkExpression(options);
        }
        if (prevCanBeCompleted !== this.canBeCompletedByTrigger) {
            this.updateButtonsVisibility();
        }
        this.isTriggerIsRunning = false;
    }
    checkTriggersAndRunConditions(name, newValue, oldValue) {
        var triggerKeys = {};
        triggerKeys[name] = { newValue: newValue, oldValue: oldValue };
        this.runConditionOnValueChanged(name, newValue);
        this.checkTriggers(triggerKeys, false, false, false, name);
    }
    get hasRequiredValidQuestionTrigger() {
        for (let i = 0; i < this.triggers.length; i++) {
            if (this.triggers[i].requireValidQuestion)
                return true;
        }
        return false;
    }
    doElementsOnLoad() {
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].onSurveyLoad();
        }
    }
    get isRunningConditions() {
        return !!this.conditionValues;
    }
    /**
     * Recalculates all [expressions](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions) in the survey.
     */
    runExpressions() {
        this.runConditions();
    }
    runConditions() {
        if (this.isCompleted ||
            this.isEndLoadingFromJson === "processing" ||
            this.isRunningConditions)
            return;
        this.conditionValues = this.getFilteredValues();
        var properties = this.getFilteredProperties();
        var oldCurrentPageIndex = this.pages.indexOf(this.currentPage);
        this.runConditionsCore(properties);
        this.checkIfNewPagesBecomeVisible(oldCurrentPageIndex);
        this.conditionValues = null;
        if (this.isValueChangedOnRunningCondition &&
            this.conditionRunnerCounter <
                settings.maxConditionRunCountOnValueChanged) {
            this.isValueChangedOnRunningCondition = false;
            this.conditionRunnerCounter++;
            this.runConditions();
        }
        else {
            this.isValueChangedOnRunningCondition = false;
            this.conditionRunnerCounter = 0;
            if (this.conditionUpdateVisibleIndexes) {
                this.conditionUpdateVisibleIndexes = false;
                this.updateVisibleIndexes();
            }
            if (this.conditionNotifyElementsOnAnyValueOrVariableChanged) {
                this.conditionNotifyElementsOnAnyValueOrVariableChanged = false;
                this.notifyElementsOnAnyValueOrVariableChanged("");
            }
        }
    }
    runConditionOnValueChanged(name, value) {
        if (this.isRunningConditions) {
            this.conditionValues[name] = value;
            if (this.questionTriggersKeys) {
                this.questionTriggersKeys[name] = value;
            }
            this.isValueChangedOnRunningCondition = true;
        }
        else {
            this.questionTriggersKeys = {};
            this.questionTriggersKeys[name] = value;
            this.runConditions();
            this.runQuestionsTriggers(name, value);
            this.questionTriggersKeys = undefined;
        }
    }
    runConditionsCore(properties) {
        var pages = this.pages;
        for (var i = 0; i < this.calculatedValues.length; i++) {
            this.calculatedValues[i].resetCalculation();
        }
        for (var i = 0; i < this.calculatedValues.length; i++) {
            this.calculatedValues[i].doCalculation(this.calculatedValues, this.conditionValues, properties);
        }
        super.runConditionCore(this.conditionValues, properties);
        for (let i = 0; i < pages.length; i++) {
            pages[i].runCondition(this.conditionValues, properties);
        }
    }
    runQuestionsTriggers(name, value) {
        if (this.isDisplayMode || this.isDesignMode)
            return;
        const questions = this.getAllQuestions();
        questions.forEach(q => {
            q.runTriggers(name, value, this.questionTriggersKeys);
        });
    }
    checkIfNewPagesBecomeVisible(oldCurrentPageIndex) {
        var newCurrentPageIndex = this.pages.indexOf(this.currentPage);
        if (newCurrentPageIndex <= oldCurrentPageIndex + 1)
            return;
        for (var i = oldCurrentPageIndex + 1; i < newCurrentPageIndex; i++) {
            if (this.pages[i].isVisible) {
                this.currentPage = this.pages[i];
                break;
            }
        }
    }
    /**
     * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
     */
    sendResult(postId = null, clientId = null, isPartial = false) {
        if (!this.isEditMode)
            return;
        if (isPartial && this.onPartialSend) {
            this.onPartialSend.fire(this, null);
        }
        if (!postId && this.surveyPostId) {
            postId = this.surveyPostId;
        }
        if (!postId)
            return;
        if (clientId) {
            this.clientId = clientId;
        }
        if (isPartial && !this.clientId)
            return;
        this.reportWarningOnUsingService();
    }
    /**
     * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
     */
    getResult(resultId, questionName) {
        this.reportWarningOnUsingService();
    }
    /**
     * @deprecated Self-hosted Form Library [no longer supports integration with SurveyJS Demo Service](https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service).
     */
    loadSurveyFromService(surveyId = null, clientId = null) {
        if (surveyId) {
            this.surveyId = surveyId;
        }
        if (clientId) {
            this.clientId = clientId;
        }
        this.reportWarningOnUsingService();
    }
    reportWarningOnUsingService() {
        ConsoleWarnings.warn("Self-hosted Form Library no longer supports integration with SurveyJS Demo Service. Learn more: https://surveyjs.io/stay-updated/release-notes/v2.0.0#form-library-removes-apis-for-integration-with-surveyjs-demo-service");
    }
    loadSurveyFromServiceJson(json) {
        if (!json)
            return;
        this.fromJSON(json);
        this.notifyAllQuestionsOnValueChanged();
        this.onLoadSurveyFromService();
        this.onLoadedSurveyFromService.fire(this, {});
    }
    onLoadingSurveyFromService() { }
    onLoadSurveyFromService() { }
    resetVisibleIndexes() {
        var questions = this.getAllQuestions(true);
        for (var i = 0; i < questions.length; i++) {
            questions[i].setVisibleIndex(-1);
        }
        this.updateVisibleIndexes();
    }
    updateVisibleIndexes(page) {
        if (this.isLoadingFromJson || !!this.isEndLoadingFromJson)
            return;
        if (this.isRunningConditions &&
            this.onQuestionVisibleChanged.isEmpty &&
            this.onPageVisibleChanged.isEmpty) {
            //Run update visible index only one time on finishing running conditions
            this.conditionUpdateVisibleIndexes = true;
            return;
        }
        if (this.isRunningElementsBindings) {
            this.updateVisibleIndexAfterBindings = true;
            return;
        }
        this.updatePageVisibleIndexes();
        this.updatePageElementsVisibleIndexes(page);
        this.updateProgressText(true);
    }
    updatePageElementsVisibleIndexes(page) {
        if (this.showQuestionNumbers == "onPage") {
            var visPages = !!page ? [page] : this.visiblePages;
            for (var i = 0; i < visPages.length; i++) {
                visPages[i].setVisibleIndex(0);
            }
        }
        else {
            let index = this.getStartVisibleIndex();
            const pages = this.pages;
            for (let i = 0; i < pages.length; i++) {
                index += pages[i].setVisibleIndex(index);
            }
        }
    }
    getStartVisibleIndex() {
        const val = this.showQuestionNumbers;
        return val === "on" || val === "recursive" ? 0 : -1;
    }
    updatePageVisibleIndexes() {
        this.updateButtonsVisibility();
        var index = 0;
        for (var i = 0; i < this.pages.length; i++) {
            const page = this.pages[i];
            const isPageVisible = page.isVisible && (i > 0 || !page.isStartPage);
            page.visibleIndex = isPageVisible ? index++ : -1;
            page.num = isPageVisible ? page.visibleIndex + 1 : -1;
        }
    }
    fromJSON(json, options) {
        if (!json)
            return;
        this.resetHasLogo();
        this.resetPropertyValue("titleIsEmpty");
        this.questionHashesClear();
        this.jsonErrors = null;
        this.sjsVersion = undefined;
        const jsonConverter = new JsonObject();
        jsonConverter.toObject(json, this, options);
        if (jsonConverter.errors.length > 0) {
            this.jsonErrors = jsonConverter.errors;
        }
        this.onStateAndCurrentPageChanged();
        this.endLoading();
        this.updateState();
        if (!!this.sjsVersion && !!settings.version) {
            if (Helpers.compareVerions(this.sjsVersion, settings.version) > 0) {
                ConsoleWarnings.warn("The version of the survey JSON schema (v"
                    + this.sjsVersion + ") is newer than your current Form Library version ("
                    + settings.version + "). Please update the Form Library to make sure that all survey features work as expected.");
            }
        }
    }
    startLoadingFromJson(json) {
        super.startLoadingFromJson(json);
        if (json && json.locale) {
            this.locale = json.locale;
        }
    }
    setJsonObject(jsonObj) {
        this.fromJSON(jsonObj);
    }
    endLoadingFromJson() {
        this.isEndLoadingFromJson = "processing";
        this.onFirstPageIsStartedChanged();
        super.endLoadingFromJson();
        if (this.hasCookie) {
            this.isCompletedBefore = true;
        }
        this.doElementsOnLoad();
        this.onQuestionsOnPageModeChanged("standard");
        this.isEndLoadingFromJson = "conditions";
        this.runConditions();
        this.notifyElementsOnAnyValueOrVariableChanged("");
        this.isEndLoadingFromJson = null;
        this.updateVisibleIndexes();
        this.updateCurrentPage();
        this.setCalculatedWidthModeUpdater();
        this.onEndLoadingFromJson.fire(this, {});
    }
    updateNavigationCss() {
        const val = this.navigationBarValue;
        if (!!val) {
            val.cssClasses = this.css.actionBar;
            val.containerCss = this.css.footer;
            !!this.updateNavigationItemCssCallback && this.updateNavigationItemCssCallback();
        }
    }
    createNavigationBar() {
        const res = new ActionContainer();
        res.setItems(this.createNavigationActions());
        res.locOwner = this;
        return res;
    }
    createNavigationActions() {
        const defaultComponent = "sv-nav-btn";
        const navStart = new Action({
            id: "sv-nav-start",
            visible: new ComputedUpdater(() => this.isStartPageActive),
            visibleIndex: 10,
            locTitle: this.locStartSurveyText,
            action: () => this.start(),
            component: defaultComponent
        });
        const navPrev = new Action({
            id: "sv-nav-prev",
            visible: new ComputedUpdater(() => this.isShowPrevButton),
            visibleIndex: 20,
            data: {
                mouseDown: () => this.navigationMouseDown(),
            },
            locTitle: this.locPagePrevText,
            action: () => this.performPrevious(),
            component: defaultComponent
        });
        const navNext = new Action({
            id: "sv-nav-next",
            visible: new ComputedUpdater(() => this.isShowNextButton),
            visibleIndex: 30,
            data: {
                mouseDown: () => this.nextPageMouseDown(),
            },
            locTitle: this.locPageNextText,
            action: () => this.nextPageUIClick(),
            component: defaultComponent
        });
        const navPreview = new Action({
            id: "sv-nav-preview",
            visible: new ComputedUpdater(() => this.isPreviewButtonVisible),
            visibleIndex: 40,
            data: {
                mouseDown: () => this.navigationMouseDown(),
            },
            locTitle: this.locPreviewText,
            action: () => this.showPreview(),
            component: defaultComponent
        });
        const navComplete = new Action({
            id: "sv-nav-complete",
            visible: new ComputedUpdater(() => this.isCompleteButtonVisible),
            visibleIndex: 50,
            data: {
                mouseDown: () => this.navigationMouseDown(),
            },
            locTitle: this.locCompleteText,
            action: () => this.taskManager.waitAndExecute(() => this.tryComplete()),
            component: defaultComponent
        });
        this.updateNavigationItemCssCallback = () => {
            navStart.innerCss = this.cssNavigationStart;
            navPrev.innerCss = this.cssNavigationPrev;
            navNext.innerCss = this.cssNavigationNext;
            navPreview.innerCss = this.cssNavigationPreview;
            navComplete.innerCss = this.cssNavigationComplete;
        };
        return [navStart, navPrev, navNext, navPreview, navComplete];
    }
    onBeforeRunConstructor() { }
    onBeforeCreating() { }
    onCreating() { }
    getProcessedTextValue(textValue) {
        this.getProcessedTextValueCore(textValue);
        if (!this.onProcessDynamicText.isEmpty) {
            var wasEmpty = this.isValueEmpty(textValue.value);
            this.onProcessDynamicText.fire(this, textValue);
            textValue.isExists =
                textValue.isExists || (wasEmpty && !this.isValueEmpty(textValue.value));
        }
    }
    getBuiltInVariableValue(name) {
        if (name === "pageno") {
            var page = this.currentPage;
            return page != null ? this.visiblePages.indexOf(page) + 1 : 0;
        }
        if (name === "pagecount") {
            return this.visiblePageCount;
        }
        if (name === "correctedanswers" || name === "correctanswers" || name === "correctedanswercount") {
            return this.getCorrectedAnswerCount();
        }
        if (name === "incorrectedanswers" || name === "incorrectanswers" || name === "incorrectedanswercount") {
            return this.getInCorrectedAnswerCount();
        }
        if (name === "questioncount") {
            return this.getQuizQuestionCount();
        }
        return undefined;
    }
    getProcessedTextValueCore(textValue) {
        var name = textValue.name.toLocaleLowerCase();
        if (["no", "require", "title"].indexOf(name) !== -1) {
            return;
        }
        const builtInVar = this.getBuiltInVariableValue(name);
        if (builtInVar !== undefined) {
            textValue.isExists = true;
            textValue.value = builtInVar;
            return;
        }
        if (name === "locale") {
            textValue.isExists = true;
            textValue.value = !!this.locale
                ? this.locale
                : surveyLocalization.defaultLocale;
            return;
        }
        var variable = this.getVariable(name);
        if (variable !== undefined) {
            textValue.isExists = true;
            textValue.value = variable;
            return;
        }
        var question = this.getFirstName(name);
        if (question) {
            const questionUseDisplayText = question.useDisplayValuesInDynamicTexts;
            textValue.isExists = true;
            const firstName = question.getValueName().toLowerCase();
            name = firstName + name.substring(firstName.length);
            name = name.toLocaleLowerCase();
            var values = {};
            values[firstName] = textValue.returnDisplayValue && questionUseDisplayText
                ? question.getDisplayValue(false, undefined)
                : question.value;
            textValue.value = new ProcessValue().getValue(name, values);
            return;
        }
        this.getProcessedValuesWithoutQuestion(textValue);
    }
    getProcessedValuesWithoutQuestion(textValue) {
        var value = this.getValue(textValue.name);
        if (value !== undefined) {
            textValue.isExists = true;
            textValue.value = value;
            return;
        }
        const processor = new ProcessValue();
        const firstName = processor.getFirstName(textValue.name);
        if (firstName === textValue.name)
            return;
        const data = {};
        let val = this.getValue(firstName);
        if (Helpers.isValueEmpty(val)) {
            val = this.getVariable(firstName);
        }
        if (Helpers.isValueEmpty(val))
            return;
        data[firstName] = val;
        textValue.value = processor.getValue(textValue.name, data);
        textValue.isExists = processor.hasValue(textValue.name, data);
    }
    getFirstName(name) {
        name = name.toLowerCase();
        var question;
        do {
            question = this.getQuestionByValueName(name, true);
            name = this.reduceFirstName(name);
        } while (!question && !!name);
        return question;
    }
    reduceFirstName(name) {
        var pos1 = name.lastIndexOf(".");
        var pos2 = name.lastIndexOf("[");
        if (pos1 < 0 && pos2 < 0)
            return "";
        var pos = Math.max(pos1, pos2);
        return name.substring(0, pos);
    }
    clearUnusedValues() {
        this.isClearingUnsedValues = true;
        var questions = this.getAllQuestions();
        for (var i = 0; i < questions.length; i++) {
            questions[i].clearUnusedValues();
        }
        this.clearInvisibleQuestionValues();
        this.isClearingUnsedValues = false;
    }
    hasVisibleQuestionByValueName(valueName) {
        var questions = this.getQuestionsByValueName(valueName);
        if (!questions)
            return false;
        for (var i = 0; i < questions.length; i++) {
            const q = questions[i];
            if (q.isVisible && q.isParentVisible && !q.parentQuestion)
                return true;
        }
        return false;
    }
    questionsByValueName(valueName) {
        var questions = this.getQuestionsByValueName(valueName);
        return !!questions ? questions : [];
    }
    clearInvisibleQuestionValues() {
        const reason = this.clearInvisibleValues === "none" ? "none" : "onComplete";
        const questions = this.getAllQuestions();
        for (var i = 0; i < questions.length; i++) {
            questions[i].clearValueIfInvisible(reason);
        }
    }
    /**
     * Returns a variable value.
     *
     * [Variables help topic](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#variables (linkStyle))
     * @param name A variable name.
     * @return A variable value.
     * @see setVariable
     * @see getVariableNames
     */
    getVariable(name) {
        if (!name)
            return null;
        name = name.toLowerCase();
        var res = this.variablesHash[name];
        if (!this.isValueEmpty(res))
            return res;
        if (name.indexOf(".") > -1 || name.indexOf("[") > -1) {
            if (new ProcessValue().hasValue(name, this.variablesHash))
                return new ProcessValue().getValue(name, this.variablesHash);
        }
        return res;
    }
    /**
     * Sets a variable value.
     *
     * [Variables help topic](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#variables (linkStyle))
     * @param name A variable name.
     * @param newValue A new variable value.
     * @see getVariable
     * @see getVariableNames
     */
    setVariable(name, newValue) {
        if (!name)
            return;
        const oldValue = this.getVariable(name);
        if (!!this.valuesHash) {
            delete this.valuesHash[name];
        }
        name = name.toLowerCase();
        this.variablesHash[name] = newValue;
        this.notifyElementsOnAnyValueOrVariableChanged(name);
        if (!Helpers.isTwoValueEquals(oldValue, newValue)) {
            this.checkTriggersAndRunConditions(name, newValue, oldValue);
            this.onVariableChanged.fire(this, { name: name, value: newValue });
        }
    }
    /**
     * Returns the names of all variables in the survey.
     *
     * [Variables help topic](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#variables (linkStyle))
     * @returns An array of variable names.
     * @see getVariable
     * @see setVariable
     */
    getVariableNames() {
        var res = [];
        for (var key in this.variablesHash) {
            res.push(key);
        }
        return res;
    }
    //ISurvey data
    getUnbindValue(value) {
        if (!!this.editingObj)
            return value;
        return Helpers.getUnbindValue(value);
    }
    /**
     * Returns a value (answer) for a question with a specified `name`.
     * @param name A question name.
     * @returns A question value (answer).
     * @see data
     * @see setValue
     */
    getValue(name) {
        if (!name || name.length == 0)
            return null;
        var value = this.getDataValueCore(this.valuesHash, name);
        return this.getUnbindValue(value);
    }
    /**
     * Sets a question value (answer).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/create-a-scored-quiz/ (linkStyle))
     *
     * > This method executes all triggers and reevaluates conditions (`visibleIf`, `requiredId`, and others). It also switches the survey to the next page if the [`autoAdvanceEnabled`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#autoAdvanceEnabled) property is enabled and all questions on the current page have correct answers.
     * @param name A question name.
     * @param newValue A new question value.
     * @param locNotification For internal use.
     * @param allowNotifyValueChanged For internal use.
     * @see data
     * @see getValue
     */
    setValue(name, newQuestionValue, locNotification = false, allowNotifyValueChanged = true, questionName) {
        var newValue = newQuestionValue;
        if (allowNotifyValueChanged) {
            newValue = this.questionOnValueChanging(name, newQuestionValue);
        }
        if (this.isValidateOnValueChanging &&
            this.checkErrorsOnValueChanging(name, newValue))
            return;
        if (!this.editingObj &&
            this.isValueEqual(name, newValue) &&
            this.isTwoValueEquals(newValue, newQuestionValue))
            return;
        var oldValue = this.getValue(name);
        if (this.isValueEmpyOnSetValue(name, newValue)) {
            this.deleteDataValueCore(this.valuesHash, name);
        }
        else {
            newValue = this.getUnbindValue(newValue);
            this.setDataValueCore(this.valuesHash, name, newValue);
        }
        this.updateOnSetValue(name, newValue, oldValue, locNotification, allowNotifyValueChanged, questionName);
    }
    isValueEmpyOnSetValue(name, val) {
        if (!this.isValueEmpty(val, false))
            return false;
        if (!this.editingObj || val === null || val === undefined)
            return true;
        return this.editingObj.getDefaultPropertyValue(name) === val;
    }
    updateOnSetValue(name, newValue, oldValue, locNotification = false, allowNotifyValueChanged = true, questionName) {
        this.updateQuestionValue(name, newValue);
        if (locNotification === true || this.isDisposed || this.isRunningElementsBindings)
            return;
        questionName = questionName || name;
        this.checkTriggersAndRunConditions(name, newValue, oldValue);
        if (allowNotifyValueChanged) {
            this.notifyQuestionOnValueChanged(name, newValue, questionName);
        }
        if (locNotification !== "text") {
            this.tryGoNextPageAutomatic(name);
        }
    }
    isValueEqual(name, newValue) {
        if (newValue === "" || newValue === undefined)
            newValue = null;
        var oldValue = this.getValue(name);
        if (oldValue === "" || oldValue === undefined)
            oldValue = null;
        if (newValue === null || oldValue === null)
            return newValue === oldValue;
        return this.isTwoValueEquals(newValue, oldValue);
    }
    doOnPageAdded(page) {
        page.setSurveyImpl(this);
        if (!page.name)
            page.name = this.generateNewName(this.pages, "page");
        this.questionHashesPanelAdded(page);
        this.updateVisibleIndexes();
        if (!!this.runningPages)
            return;
        if (!this.isLoadingFromJson) {
            this.updateProgressText();
            this.updateCurrentPage();
        }
        if (this.canFireAddPage()) {
            var options = { page: page };
            this.onPageAdded.fire(this, options);
        }
    }
    canFireAddPage() {
        return !this.isMovingPage;
    }
    doOnPageRemoved(page) {
        page.setSurveyImpl(null);
        if (!!this.runningPages)
            return;
        if (page === this.currentPage) {
            this.updateCurrentPage();
        }
        this.updateVisibleIndexes();
        this.updateProgressText();
        this.updateLazyRenderingRowsOnRemovingElements();
    }
    generateNewName(elements, baseName) {
        var keys = {};
        for (var i = 0; i < elements.length; i++)
            keys[elements[i]["name"]] = true;
        var index = 1;
        while (keys[baseName + index])
            index++;
        return baseName + index;
    }
    tryGoNextPageAutomatic(name) {
        if (!!this.isEndLoadingFromJson || !this.autoAdvanceEnabled || !this.currentPage)
            return;
        const question = this.getQuestionByValueName(name);
        if (!question || (!!question && (!question.visible || !question.supportAutoAdvance())))
            return;
        if (!question.validate(false) && !question.supportGoNextPageError())
            return;
        if (!!this.currentSingleElement) {
            const curQuestion = this.currentSingleElement;
            const goNextQuestion = () => {
                if (curQuestion !== this.currentSingleElement)
                    return;
                if (!this.isLastElement) {
                    this.performNext();
                }
                else {
                    if (this.autoAdvanceAllowComplete) {
                        this.tryCompleteOrShowPreview();
                    }
                }
            };
            surveyTimerFunctions.safeTimeOut(goNextQuestion, settings.autoAdvanceDelay);
        }
        var questions = this.getCurrentPageQuestions();
        if (questions.indexOf(question) < 0)
            return;
        for (var i = 0; i < questions.length; i++) {
            if (questions[i].hasInput && questions[i].isEmpty())
                return;
        }
        if (this.isLastPage && (this.autoAdvanceEnabled !== true || !this.autoAdvanceAllowComplete))
            return;
        if (this.checkIsCurrentPageHasErrors(false))
            return;
        const curPage = this.currentPage;
        const goNextPage = () => {
            if (curPage !== this.currentPage)
                return;
            if (!this.isLastPage) {
                this.nextPage();
            }
            else {
                this.tryCompleteOrShowPreview();
            }
        };
        surveyTimerFunctions.safeTimeOut(goNextPage, settings.autoAdvanceDelay);
    }
    tryCompleteOrShowPreview() {
        if (this.showPreviewBeforeComplete) {
            this.showPreview();
        }
        else {
            this.tryComplete();
        }
    }
    /**
     * Returns a comment value from a question with a specified `name`.
     * @param name A question name.
     * @returns A comment.
     * @see setComment
     */
    getComment(name) {
        const res = this.getValue(name + this.commentSuffix);
        return res || "";
    }
    /**
     * Sets a comment value to a question with a specified `name`.
     * @param name A question name.
     * @param newValue A new comment value.
     * @param locNotification For internal use.
     * @see getComment
     */
    setComment(name, newValue, locNotification = false) {
        if (!newValue)
            newValue = "";
        if (this.isTwoValueEquals(newValue, this.getComment(name)))
            return;
        const commentName = name + this.commentSuffix;
        newValue = this.questionOnValueChanging(commentName, newValue, name);
        if (this.isValueEmpty(newValue)) {
            this.deleteDataValueCore(this.valuesHash, commentName);
        }
        else {
            this.setDataValueCore(this.valuesHash, commentName, newValue);
        }
        var questions = this.getQuestionsByValueName(name);
        if (!!questions) {
            for (var i = 0; i < questions.length; i++) {
                questions[i].updateCommentFromSurvey(newValue);
                this.checkQuestionErrorOnValueChanged(questions[i]);
            }
        }
        if (!locNotification) {
            this.checkTriggersAndRunConditions(name, this.getValue(name), undefined);
        }
        if (locNotification !== "text") {
            this.tryGoNextPageAutomatic(name);
        }
        var question = this.getQuestionByValueName(name);
        if (question) {
            this.fireOnValueChanged(commentName, newValue, question);
            question.comment = newValue;
            if (question.comment != newValue) {
                question.comment = newValue;
            }
        }
    }
    /**
     * Deletes an answer from survey results.
     * @param {string} name An object property that stores the answer to delete. Pass a question's [`valueName`](https://surveyjs.io/form-library/documentation/api-reference/question#valueName) or [`name`](https://surveyjs.io/form-library/documentation/api-reference/question#name).
     */
    clearValue(name) {
        this.setValue(name, null);
        this.setComment(name, null);
    }
    /**
     * Specifies whether to remove disabled choices from the value in [Dropdown](https://surveyjs.io/form-library/documentation/api-reference/dropdown-menu-model), [Checkboxes](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model), and [Radio Button Group](https://surveyjs.io/form-library/documentation/api-reference/radio-button-question-model) questions.
     *
     * Default value: `false`
     *
     * > This property cannot be specified in the survey JSON schema. Use dot notation to specify it.
     */
    get clearDisabledChoices() {
        return this.getPropertyValue("clearDisabledChoices", false);
    }
    set clearDisabledChoices(val) {
        this.setPropertyValue("clearDisabledChoices", val);
    }
    /**
     * @deprecated Use the [`clearDisabledChoices`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#clearDisabledChoices) property instead.
     */
    get clearValueOnDisableItems() {
        return this.clearDisabledChoices;
    }
    set clearValueOnDisableItems(val) {
        this.clearDisabledChoices = val;
    }
    getQuestionClearIfInvisible(questionClearIf) {
        if (this.isShowingPreview || this.runningPages)
            return "none";
        if (questionClearIf !== "default")
            return questionClearIf;
        return this.clearInvisibleValues;
    }
    questionVisibilityChanged(question, newValue, resetIndexes) {
        if (resetIndexes) {
            this.updateVisibleIndexes(question.page);
        }
        if (!newValue) {
            this.changeCurrentSingleElementOnVisibilityChanged();
        }
        this.onQuestionVisibleChanged.fire(this, {
            question: question,
            name: question.name,
            visible: newValue,
        });
    }
    pageVisibilityChanged(page, newValue) {
        if (this.isLoadingFromJson)
            return;
        if (newValue && !this.currentPage || page === this.currentPage) {
            this.updateCurrentPage();
        }
        this.updateVisibleIndexes();
        if (!newValue) {
            this.changeCurrentSingleElementOnVisibilityChanged();
        }
        const el = this.currentSingleElement;
        const curPage = this.currentPage;
        if (!!el && !!curPage && el.page !== curPage) {
            this.currentSingleElement = curPage.getFirstVisibleElement();
        }
        this.onPageVisibleChanged.fire(this, {
            page: page,
            visible: newValue,
        });
    }
    panelVisibilityChanged(panel, newValue) {
        if (!!panel.page) {
            this.updateVisibleIndexes(panel.page);
            if (!newValue) {
                this.changeCurrentSingleElementOnVisibilityChanged();
            }
        }
        this.onPanelVisibleChanged.fire(this, { panel: panel, visible: newValue });
    }
    questionCreated(question) {
        this.onQuestionCreated.fire(this, { question: question });
    }
    questionAdded(question, index, parentPanel, rootPanel) {
        if (!question.name) {
            question.name = this.generateNewName(this.getAllQuestions(false, true), "question");
        }
        if (!!question.page) {
            this.questionHashesAdded(question);
        }
        if (!this.isLoadingFromJson) {
            if (!this.currentPage) {
                this.updateCurrentPage();
            }
            this.updateVisibleIndexes(question.page);
            this.setCalculatedWidthModeUpdater();
        }
        if (this.canFireAddElement()) {
            this.onQuestionAdded.fire(this, {
                question: question,
                name: question.name,
                index: index,
                parent: parentPanel,
                page: rootPanel,
                parentPanel: parentPanel,
                rootPanel: rootPanel,
            });
        }
    }
    canFireAddElement() {
        return !this.isMovingQuestion;
    }
    questionRemoved(question) {
        this.questionHashesRemoved(question, question.name, question.getValueName());
        this.updateVisibleIndexes(question.page);
        this.onQuestionRemoved.fire(this, {
            question: question,
            name: question.name,
        });
        this.updateLazyRenderingRowsOnRemovingElements();
    }
    questionRenamed(question, oldName, oldValueName) {
        this.questionHashesRemoved(question, oldName, oldValueName);
        this.questionHashesAdded(question);
    }
    questionHashesClear() {
        this.questionHashes.names = {};
        this.questionHashes.namesInsensitive = {};
        this.questionHashes.valueNames = {};
        this.questionHashes.valueNamesInsensitive = {};
    }
    questionHashesPanelAdded(panel) {
        if (this.isLoadingFromJson)
            return;
        var questions = panel.questions;
        for (var i = 0; i < questions.length; i++) {
            this.questionHashesAdded(questions[i]);
        }
    }
    questionHashesAdded(question) {
        this.questionHashAddedCore(this.questionHashes.names, question, question.name);
        this.questionHashAddedCore(this.questionHashes.namesInsensitive, question, question.name.toLowerCase());
        this.questionHashAddedCore(this.questionHashes.valueNames, question, question.getValueName());
        this.questionHashAddedCore(this.questionHashes.valueNamesInsensitive, question, question.getValueName().toLowerCase());
    }
    questionHashesRemoved(question, name, valueName) {
        if (!!name) {
            this.questionHashRemovedCore(this.questionHashes.names, question, name);
            this.questionHashRemovedCore(this.questionHashes.namesInsensitive, question, name.toLowerCase());
        }
        if (!!valueName) {
            this.questionHashRemovedCore(this.questionHashes.valueNames, question, valueName);
            this.questionHashRemovedCore(this.questionHashes.valueNamesInsensitive, question, valueName.toLowerCase());
        }
    }
    questionHashAddedCore(hash, question, name) {
        var res = hash[name];
        if (!!res) {
            var res = hash[name];
            if (res.indexOf(question) < 0) {
                res.push(question);
            }
        }
        else {
            hash[name] = [question];
        }
    }
    questionHashRemovedCore(hash, question, name) {
        var res = hash[name];
        if (!res)
            return;
        var index = res.indexOf(question);
        if (index > -1) {
            res.splice(index, 1);
        }
        if (res.length == 0) {
            delete hash[name];
        }
    }
    panelAdded(panel, index, parentPanel, rootPanel) {
        if (!panel.name) {
            panel.name = this.generateNewName(this.getAllPanels(false, true), "panel");
        }
        this.questionHashesPanelAdded(panel);
        this.updateVisibleIndexes(panel.page);
        if (this.canFireAddElement()) {
            this.onPanelAdded.fire(this, {
                panel: panel,
                name: panel.name,
                index: index,
                parent: parentPanel,
                page: rootPanel,
                parentPanel: parentPanel,
                rootPanel: rootPanel,
            });
        }
    }
    panelRemoved(panel) {
        this.updateVisibleIndexes(panel.page);
        this.onPanelRemoved.fire(this, { panel: panel, name: panel.name });
        this.updateLazyRenderingRowsOnRemovingElements();
    }
    validateQuestion(question, errors, fireCallback) {
        if (!this.onValidateQuestion.isEmpty) {
            var options = {
                name: question.name,
                question: question,
                value: question.value,
                errors: errors,
                error: null,
            };
            this.onValidateQuestion.fire(this, options);
            if (options.error) {
                errors.push(new CustomError(options.error, this));
            }
        }
        if (fireCallback) {
            this.beforeSettingQuestionErrors(question, errors);
        }
    }
    validatePanel(panel, errors, fireCallback) {
        if (panel.isPanel && !this.onValidatePanel.isEmpty) {
            const options = {
                name: panel.name,
                panel: panel,
                error: null,
                errors: errors
            };
            this.onValidatePanel.fire(this, options);
            if (options.error) {
                errors.push(new CustomError(options.error, this));
            }
        }
        if (fireCallback) {
            this.makeRequiredErrorsInvisible(errors);
        }
    }
    processHtml(html, reason) {
        if (!reason)
            reason = "";
        var options = { html: html, reason: reason };
        this.onProcessHtml.fire(this, options);
        return this.processText(options.html, true);
    }
    processText(text, returnDisplayValue) {
        return this.processTextEx({ text: text, returnDisplayValue: returnDisplayValue, doEncoding: false }).text;
    }
    processTextEx(params) {
        const doEncoding = params.doEncoding === undefined ? settings.web.encodeUrlParams : params.doEncoding;
        let text = params.text;
        if (params.runAtDesign || !this.isDesignMode) {
            text = this.textPreProcessor.process(text, params.returnDisplayValue === true, doEncoding, params.replaceUndefinedValues);
        }
        const res = { text: text, hasAllValuesOnLastRun: true };
        res.hasAllValuesOnLastRun = this.textPreProcessor.hasAllValuesOnLastRun;
        return res;
    }
    get textPreProcessor() {
        if (!this.textPreProcessorValue) {
            this.textPreProcessorValue = new TextPreProcessor();
            this.textPreProcessorValue.onProcess = (textValue) => {
                this.getProcessedTextValue(textValue);
            };
        }
        return this.textPreProcessorValue;
    }
    getSurveyMarkdownHtml(element, text, name, item) {
        const options = {
            element: element,
            text: text,
            name: name,
            item: item,
            html: null
        };
        this.onTextMarkdown.fire(this, options);
        return options.html;
    }
    getCorrectedAnswerCount() {
        return this.getCorrectAnswerCount();
    }
    /**
     * Returns the number of correct answers in a quiz.
     *
     * For more information about quizzes, refer to the following tutorial: [Create a Quiz](https://surveyjs.io/form-library/documentation/design-survey/create-a-quiz).
     * @returns The number of correct answers in a quiz.
     * @see getQuizQuestionCount
     * @see getIncorrectAnswerCount
     */
    getCorrectAnswerCount() {
        return this.getCorrectedAnswerCountCore(true);
    }
    /**
     * Returns the number of quiz questions. A question counts if it is visible, has an input field, and specifies [`correctAnswer`](https://surveyjs.io/form-library/documentation/api-reference/checkbox-question-model#correctAnswer).
     *
     * This number may be different from `getQuizQuestions().length` because certain question types (for instance, matrix-like types) include more than one question.
     *
     * For more information about quizzes, refer to the following tutorial: [Create a Quiz](https://surveyjs.io/form-library/documentation/design-survey/create-a-quiz).
     * @returns The number of quiz questions.
     * @see getQuizQuestions
     */
    getQuizQuestionCount() {
        var questions = this.getQuizQuestions();
        var res = 0;
        for (var i = 0; i < questions.length; i++) {
            res += questions[i].quizQuestionCount;
        }
        return res;
    }
    getInCorrectedAnswerCount() {
        return this.getIncorrectAnswerCount();
    }
    getInCorrectAnswerCount() {
        return this.getIncorrectAnswerCount();
    }
    /**
     * Returns the number of incorrect answers in a quiz.
     *
     * For more information about quizzes, refer to the following tutorial: [Create a Quiz](https://surveyjs.io/form-library/documentation/design-survey/create-a-quiz).
     * @returns The number of incorrect answers in a quiz.
     * @see getCorrectAnswerCount
     */
    getIncorrectAnswerCount() {
        return this.getCorrectedAnswerCountCore(false);
    }
    onCorrectQuestionAnswer(question, options) {
        if (this.onIsAnswerCorrect.isEmpty)
            return;
        options.question = question;
        this.onIsAnswerCorrect.fire(this, options);
    }
    getCorrectedAnswerCountCore(isCorrect) {
        var questions = this.getQuizQuestions();
        var counter = 0;
        for (let i = 0; i < questions.length; i++) {
            const q = questions[i];
            const correctCount = q.correctAnswerCount;
            if (isCorrect) {
                counter += correctCount;
            }
            else {
                counter += q.quizQuestionCount - correctCount;
            }
        }
        return counter;
    }
    getCorrectedAnswers() {
        return this.getCorrectedAnswerCount();
    }
    getInCorrectedAnswers() {
        return this.getInCorrectedAnswerCount();
    }
    /**
     * @deprecated Use the [`showTimer`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showTimer) and [`timerLocation`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#timerLocation) properties instead.
     */
    get showTimerPanel() {
        if (!this.showTimer)
            return "none";
        return this.timerLocation;
    }
    set showTimerPanel(val) {
        this.showTimer = val !== "none";
        if (this.showTimer) {
            this.timerLocation = val;
        }
    }
    /**
     * Specifies the timer's visibility. Applies only to [quiz surveys](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz).
     *
     * Default value: `false`
     *
     * If you set this property to `true`, the timer starts automatically when the survey begins. To specify time limits, use the [`timeLimit`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#timeLimit) and [`timeLimitPerPage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#timeLimitPerPage) properties.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/make-quiz-javascript/ (linkStyle))
     *
     * The timer displays information about time spent on an individual page and the entire survey. If you want to display only the page timer or the survey timer, set the [`timerInfoMode`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#timerInfoMode) property to `"page"` or `"survey"`.
     *
     * You can enable the timer without displaying it. In this case, you need to specify the required time limits and use the [`startTimer()`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#startTimer) and [`stopTimer()`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#stopTimer) methods to control the timer.
     * @see timerLocation
     * @see timeSpent
     * @see onTimerTick
     */
    get showTimer() {
        return this.getPropertyValue("showTimer");
    }
    set showTimer(val) {
        this.setPropertyValue("showTimer", val);
    }
    /**
     * Specifies the timer's position relative to the survey. Applies only if the [`showTimer`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showTimer) property is set to `true`.
     *
     * Possible values:
     *
     * - `"top"` (default) - Displays the timer at the top of the survey.
     * - `"bottom"` - Displays the timer at the bottom of the survey.
     * @see onTimerTick
     */
    get timerLocation() {
        return this.getPropertyValue("timerLocation");
    }
    set timerLocation(val) {
        this.setPropertyValue("timerLocation", val);
    }
    get isTimerPanelShowingOnTop() {
        return this.showTimer && this.timerLocation === "top";
    }
    get isTimerPanelShowingOnBottom() {
        return this.showTimer && this.timerLocation === "bottom";
    }
    /**
     * Specifies whether the timer panel displays timers for the current page, the entire survey, or both. Applies only if the timer panel is [visible](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#showTimer).
     *
     * Possible values:
     *
     * - `"survey"` - Displays only the survey timer.
     * - `"page"` - Displays only the page timer.
     * - `"combined"` (default) - Displays both the survey and page timers.
     * @see timeSpent
     * @see onTimerTick
     * @see startTimer
     * @see stopTimer
     */
    get timerInfoMode() {
        return this.getTimerInfoVal(this.getPropertyValue("timerInfoMode"));
    }
    set timerInfoMode(val) {
        this.setPropertyValue("timerInfoMode", val);
    }
    getTimerInfoVal(val) {
        return val === "all" ? "combined" : val;
    }
    /**
     * @deprecated Use the [`timerInfoMode`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#timerInfoMode) property instead.
     */
    get showTimerPanelMode() {
        const res = this.timerInfoMode;
        return res === "combined" ? "all" : res;
    }
    set showTimerPanelMode(val) {
        this.timerInfoMode = this.getTimerInfoVal(val);
    }
    updateGridColumns() {
        this.pages.forEach(page => page.updateGridColumns());
    }
    /**
      * Specifies how to calculate the survey width.
      *
      * Possible values:
      *
      * - `"static"` - A survey has a [fixed width](#width).
      * - `"responsive"` - A survey occupies all available horizontal space and stretches or shrinks horizontally to fit in the screen size.
      * - `"auto"` (default) - Survey width depends on a question type and corresponds to the `"static"` or `"responsive"` mode.
    */
    // `custom/precise` - The survey width is specified by the width property. // in-future
    get widthMode() {
        return this.getPropertyValue("widthMode");
    }
    set widthMode(val) {
        this.setPropertyValue("widthMode", val);
    }
    setCalculatedWidthModeUpdater() {
        if (this.isLoadingFromJson)
            return;
        if (this.calculatedWidthModeUpdater)
            this.calculatedWidthModeUpdater.dispose();
        this.calculatedWidthModeUpdater = new ComputedUpdater(() => this.calculateWidthMode());
        this.calculatedWidthMode = this.calculatedWidthModeUpdater;
    }
    calculateWidthMode() {
        if (this.widthMode == "auto") {
            let isResponsive = false;
            if (this.questionsOnPageMode != "inputPerPage") {
                this.pages.forEach((page) => {
                    if (page.needResponsiveWidth())
                        isResponsive = true;
                });
            }
            return isResponsive ? "responsive" : "static";
        }
        return this.widthMode;
    }
    /**
     * A survey width in CSS values.
     *
     * Default value: `undefined` (the survey inherits the width from its container)
     * @see onResize
     */
    get width() {
        return this.getPropertyValue("width");
    }
    set width(val) {
        this.setPropertyValue("width", val);
    }
    get renderedWidth() {
        const isStaticWidth = this.getPropertyValue("calculatedWidthMode") == "static";
        let width = this.getPropertyValue("width");
        if (this.isScaled && this.responsiveStartWidth > 1) {
            let initialWidth = this.responsiveStartWidth;
            try {
                width = width || this.staticStartWidth;
                initialWidth = !isNaN(width) ? width : parseFloat(width.toString().replace("px", ""));
            }
            catch (e) { }
            return (isStaticWidth ? initialWidth : this.responsiveStartWidth) * this.widthScale / 100 + "px";
        }
        if (width && !isNaN(width))
            width = width + "px";
        return isStaticWidth && width || undefined;
    }
    setStaticStartWidth(width) {
        this.staticStartWidth = width;
    }
    setResponsiveStartWidth(width) {
        this.responsiveStartWidth = width;
    }
    get isScaled() {
        return Math.abs(this.widthScale - 100) > 0.001;
    }
    get timerInfo() {
        return this.getTimerInfo();
    }
    get timerClock() {
        let major;
        let minor;
        if (!!this.currentPage) {
            let { spent, limit, minorSpent, minorLimit } = this.getTimerInfo();
            if (limit > 0)
                major = this.getDisplayClockTime(limit - spent);
            else {
                major = this.getDisplayClockTime(spent);
            }
            if (minorSpent !== undefined) {
                if (minorLimit > 0) {
                    minor = this.getDisplayClockTime(minorLimit - minorSpent);
                }
                else {
                    minor = this.getDisplayClockTime(minorSpent);
                }
            }
        }
        return { majorText: major, minorText: minor };
    }
    get timerInfoText() {
        const options = { text: this.getTimerInfoText() };
        this.onTimerPanelInfoText.fire(this, options);
        var loc = new LocalizableString(this, true);
        loc.text = options.text;
        return loc.textOrHtml;
    }
    getTimerInfo() {
        let page = this.currentPage;
        if (!page)
            return { spent: 0, limit: 0 };
        let pageSpent = page.timeSpent;
        let surveySpent = this.timeSpent;
        let pageLimitSec = page.getMaxTimeToFinish();
        let surveyLimit = this.timeLimit;
        if (this.timerInfoMode == "page") {
            return { spent: pageSpent, limit: pageLimitSec };
        }
        if (this.timerInfoMode == "survey") {
            return { spent: surveySpent, limit: surveyLimit };
        }
        else {
            if (pageLimitSec > 0 && surveyLimit > 0) {
                return { spent: pageSpent, limit: pageLimitSec, minorSpent: surveySpent, minorLimit: surveyLimit };
            }
            else if (pageLimitSec > 0) {
                return { spent: pageSpent, limit: pageLimitSec, minorSpent: surveySpent };
            }
            else if (surveyLimit > 0) {
                return { spent: surveySpent, limit: surveyLimit, minorSpent: pageSpent };
            }
            else {
                return { spent: pageSpent, minorSpent: surveySpent };
            }
        }
    }
    getTimerInfoText() {
        var page = this.currentPage;
        if (!page)
            return "";
        var pageSpent = this.getDisplayTime(page.timeSpent);
        var surveySpent = this.getDisplayTime(this.timeSpent);
        var pageLimitSec = page.getMaxTimeToFinish();
        var pageLimit = this.getDisplayTime(pageLimitSec);
        var surveyLimit = this.getDisplayTime(this.timeLimit);
        if (this.timerInfoMode == "page")
            return this.getTimerInfoPageText(page, pageSpent, pageLimit);
        if (this.timerInfoMode == "survey")
            return this.getTimerInfoSurveyText(surveySpent, surveyLimit);
        if (this.timerInfoMode == "combined") {
            if (pageLimitSec <= 0 && this.timeLimit <= 0) {
                return this.getLocalizationFormatString("timerSpentAll", pageSpent, surveySpent);
            }
            if (pageLimitSec > 0 && this.timeLimit > 0) {
                return this.getLocalizationFormatString("timerLimitAll", pageSpent, pageLimit, surveySpent, surveyLimit);
            }
            let pageText = this.getTimerInfoPageText(page, pageSpent, pageLimit);
            let surveyText = this.getTimerInfoSurveyText(surveySpent, surveyLimit);
            return pageText + " " + surveyText;
        }
        return "";
    }
    getTimerInfoPageText(page, pageSpent, pageLimit) {
        return !!page && page.getMaxTimeToFinish() > 0
            ? this.getLocalizationFormatString("timerLimitPage", pageSpent, pageLimit)
            : this.getLocalizationFormatString("timerSpentPage", pageSpent, pageLimit);
    }
    getTimerInfoSurveyText(surveySpent, surveyLimit) {
        const strName = this.timeLimit > 0 ? "timerLimitSurvey" : "timerSpentSurvey";
        return this.getLocalizationFormatString(strName, surveySpent, surveyLimit);
    }
    getDisplayClockTime(val) {
        if (val < 0) {
            val = 0;
        }
        const min = Math.floor(val / 60);
        const sec = val % 60;
        let secStr = sec.toString();
        if (sec < 10) {
            secStr = "0" + secStr;
        }
        return `${min}:${secStr}`;
    }
    getDisplayTime(val) {
        const min = Math.floor(val / 60);
        const sec = val % 60;
        let res = "";
        if (min > 0) {
            res += min + " " + this.getLocalizationString("timerMin");
        }
        if (res && sec == 0)
            return res;
        if (res)
            res += " ";
        return res + sec + " " + this.getLocalizationString("timerSec");
    }
    get timerModel() { return this.timerModelValue; }
    /**
     * Starts a timer that calculates how many seconds a respondent has spent on the survey. Applies only to [quiz surveys](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz).
     * @see stopTimer
     * @see timeLimit
     * @see timeLimitPerPage
     * @see timeSpent
     * @see onTimerTick
     */
    startTimer() {
        if (this.isEditMode) {
            this.timerModel.start();
        }
    }
    startTimerFromUI() {
        if (this.showTimer && this.state === "running") {
            this.startTimer();
        }
    }
    /**
     * Stops the timer. Applies only to [quiz surveys](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz).
     * @see startTimer
     * @see timeLimit
     * @see timeLimitPerPage
     * @see timeSpent
     * @see onTimerTick
     */
    stopTimer() {
        this.timerModel.stop();
    }
    /**
     * A time period that a respondent has spent on the survey so far; measured in seconds. Applies only to [quiz surveys](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz).
     *
     * Assign a number to this property if you need to start the quiz timer from a specific time (for instance, if you want to continue an interrupted quiz).
     *
     * You can also find out how many seconds a respondent has spent on an individual survey page. To do this, use the [`timeSpent`](https://surveyjs.io/form-library/documentation/api-reference/page-model#timeSpent) property of a [`PageModel`](https://surveyjs.io/form-library/documentation/api-reference/page-model) object.
     * @see timeLimit
     * @see timeLimitPerPage
     * @see startTimer
     */
    get timeSpent() { return this.timerModel.spent; }
    set timeSpent(val) { this.timerModel.spent = val; }
    /**
     * A time period that a respondent has to complete the survey; measured in seconds. Applies only to [quiz surveys](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz).
     *
     * Default value: 0 (time is unlimited)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/make-quiz-javascript/ (linkStyle))
     * @see timeLimitPerPage
     * @see startTimer
     * @see timeSpent
     */
    get timeLimit() {
        return this.getPropertyValue("timeLimit", 0);
    }
    set timeLimit(val) {
        this.setPropertyValue("timeLimit", val);
    }
    /**
     * @deprecated Use the [`timeLimit`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#timeLimit) property instead.
     */
    get maxTimeToFinish() {
        return this.timeLimit;
    }
    set maxTimeToFinish(val) {
        this.timeLimit = val;
    }
    /**
     * A time period that a respondent has to complete each survey page; measured in seconds. Applies only to [quiz surveys](https://surveyjs.io/form-library/documentation/design-survey-create-a-quiz).
     *
     * Default value: 0 (time is unlimited)
     *
     * You can also use `PageModel`'s [`timeLimit`](https://surveyjs.io/form-library/documentation/api-reference/page-model#timeLimit) property to specify a time period for an individual survey page.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/make-quiz-javascript/ (linkStyle))
     * @see timeLimit
     * @see startTimer
     * @see timeSpent
     */
    get timeLimitPerPage() {
        return this.getPropertyValue("timeLimitPerPage", 0);
    }
    set timeLimitPerPage(val) {
        this.setPropertyValue("timeLimitPerPage", val);
    }
    /**
     * @deprecated Use the [`timeLimitPerPage`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#timeLimitPerPage) property instead.
     */
    get maxTimeToFinishPage() {
        return this.timeLimitPerPage;
    }
    set maxTimeToFinishPage(val) {
        this.timeLimitPerPage = val;
    }
    doTimer(page) {
        this.onTimerTick.fire(this, {});
        if (this.timeLimit > 0 && this.timeLimit <= this.timeSpent) {
            this.timeSpent = this.timeLimit;
            this.tryComplete();
        }
        if (page) {
            var pageLimit = page.getMaxTimeToFinish();
            if (pageLimit > 0 && pageLimit == page.timeSpent) {
                if (this.isLastPage) {
                    this.tryComplete();
                }
                else {
                    this.nextPage();
                }
            }
        }
    }
    get inSurvey() {
        return true;
    }
    //ISurveyImplementor
    getSurveyData() {
        return this;
    }
    getSurvey() {
        return this;
    }
    getTextProcessor() {
        return this;
    }
    //ISurveyTriggerOwner
    getObjects(pages, questions) {
        var result = [];
        Array.prototype.push.apply(result, this.getPagesByNames(pages));
        Array.prototype.push.apply(result, this.getQuestionsByNames(questions));
        return result;
    }
    setTriggerValue(name, value, isVariable) {
        if (!name)
            return;
        if (isVariable) {
            this.setVariable(name, value);
        }
        else {
            var question = this.getQuestionByName(name);
            this.startSetValueFromTrigger();
            if (!!question) {
                question.value = value;
            }
            else {
                var processor = new ProcessValue();
                var firstName = processor.getFirstName(name);
                if (firstName == name) {
                    this.setValue(name, value);
                }
                else {
                    if (!this.getQuestionByName(firstName))
                        return;
                    var data = this.getUnbindValue(this.getFilteredValues());
                    processor.setValue(data, name, value);
                    this.setValue(firstName, data[firstName]);
                }
            }
            this.finishSetValueFromTrigger();
        }
    }
    copyTriggerValue(name, fromName, copyDisplayValue) {
        if (!name || !fromName)
            return;
        let value;
        if (copyDisplayValue) {
            value = this.processText("{" + fromName + "}", true);
        }
        else {
            const processor = new ProcessValue();
            value = processor.getValue(fromName, this.getFilteredValues());
        }
        this.setTriggerValue(name, value, false);
    }
    triggerExecuted(trigger) {
        this.onTriggerExecuted.fire(this, { trigger: trigger });
    }
    get isSettingValueFromTrigger() { return this.setValueFromTriggerCounter > 0; }
    startSetValueFromTrigger() {
        this.setValueFromTriggerCounter++;
    }
    finishSetValueFromTrigger() {
        this.setValueFromTriggerCounter--;
    }
    startMovingQuestion() {
        this.isMovingQuestion = true;
    }
    stopMovingQuestion() {
        this.isMovingQuestion = false;
    }
    get isQuestionDragging() { return this.isMovingQuestion; }
    startMovingPage() {
        this.isMovingPage = true;
    }
    stopMovingPage() {
        this.isMovingPage = false;
    }
    /**
     * Focuses a question with a specified name. Switches the current page if needed.
     * @param name A question name.
     * @returns `false` if the survey does not contain a question with the specified name or this question is hidden; otherwise, `true`.
     * @see focusFirstQuestion
     * @see autoFocusFirstQuestion
     */
    focusQuestion(name) {
        return this.focusQuestionByInstance(this.getQuestionByName(name, true));
    }
    focusQuestionByInstance(question, onError = false) {
        var _a;
        if (!question || !question.isVisible || !question.page)
            return false;
        const oldQuestion = (_a = this.focusingQuestionInfo) === null || _a === void 0 ? void 0 : _a.question;
        if (oldQuestion === question)
            return false;
        this.focusingQuestionInfo = { question: question, onError: onError };
        const curElement = this.currentSingleElement;
        this.skippedPages.push({ from: curElement || this.currentPage, to: curElement ? question : question.page });
        const isNeedWaitForPageRendered = this.activePage !== question.page && !question.page.isStartPage;
        if (isNeedWaitForPageRendered) {
            this.currentPage = question.page;
        }
        if (this.isSingleVisibleQuestion && !this.isDesignMode) {
            this.currentSingleElement = question;
        }
        if (!isNeedWaitForPageRendered) {
            this.focusQuestionInfo();
        }
        return true;
    }
    focusQuestionInfo() {
        var _a;
        const question = (_a = this.focusingQuestionInfo) === null || _a === void 0 ? void 0 : _a.question;
        if (!!question && !question.isDisposed) {
            question.focus(this.focusingQuestionInfo.onError);
        }
        this.focusingQuestionInfo = undefined;
    }
    questionEditFinishCallback(question, event) {
        const enterKeyAction = this.enterKeyAction || settings.enterKeyAction;
        if (enterKeyAction == "loseFocus")
            event.target.blur();
        if (enterKeyAction == "moveToNextEditor") {
            const allQuestions = this.currentPage.questions;
            const questionIndex = allQuestions.indexOf(question);
            if (questionIndex > -1 && questionIndex < allQuestions.length - 1) {
                allQuestions[questionIndex + 1].focus();
            }
            else {
                event.target.blur();
            }
        }
    }
    elementWrapperComponentNameCore(componentName, element, wrapperName, reason, item) {
        if (this.onElementWrapperComponentName.isEmpty)
            return componentName;
        const options = { componentName: componentName, element: element, wrapperName: wrapperName, reason: reason, item: item };
        this.onElementWrapperComponentName.fire(this, options);
        return options.componentName;
    }
    elementWrapperDataCore(data, element, wrapperName, reason, item) {
        if (this.onElementWrapperComponentData.isEmpty)
            return data;
        const options = { data: data, element: element, wrapperName: wrapperName, reason: reason, item: item };
        this.onElementWrapperComponentData.fire(this, options);
        return options.data;
    }
    getElementWrapperComponentName(element, reason) {
        const res = reason === "logo-image" ? "sv-logo-image" : SurveyModel.TemplateRendererComponentName;
        return this.elementWrapperComponentNameCore(res, element, "component", reason);
    }
    getQuestionContentWrapperComponentName(element) {
        return this.elementWrapperComponentNameCore(SurveyModel.TemplateRendererComponentName, element, "content-component");
    }
    getRowWrapperComponentName(row) {
        return this.elementWrapperComponentNameCore(SurveyModel.TemplateRendererComponentName, row, "row");
    }
    getItemValueWrapperComponentName(item, question) {
        return this.elementWrapperComponentNameCore(SurveyModel.TemplateRendererComponentName, question, "itemvalue", undefined, item);
    }
    getElementWrapperComponentData(element, reason) {
        return this.elementWrapperDataCore(element, element, "component", reason);
    }
    getRowWrapperComponentData(row) {
        return this.elementWrapperDataCore(row, row, "row");
    }
    getItemValueWrapperComponentData(item, question) {
        return this.elementWrapperDataCore(item, question, "itemvalue", undefined, item);
    }
    getMatrixCellTemplateData(cell) {
        const res = cell.question;
        return this.elementWrapperDataCore(res, res, "cell");
    }
    searchText(text) {
        if (!!text)
            text = text.toLowerCase();
        var res = [];
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].searchText(text, res);
        }
        return res;
    }
    getSkeletonComponentName(element) {
        return this.skeletonComponentName;
    }
    /**
     * Adds an element to the survey layout.
     *
     * This method accepts an object with the following layout element properties:
     *
     * - `id`: `string` | `"timerpanel"` | `"progress-buttons"` | `"progress-questions"` | `"progress-pages"` | `"progress-correctquestions"` | `"progress-requiredquestions"` | `"toc-navigation"` | `"buttons-navigation"`\
     * A layout element identifier. You can use possible values to access and relocate or customize predefined layout elements.
     *
     * - `container`: `"header"` | `"footer"` | `"left"` | `"right"` | `"contentTop"` | `"contentBottom"`\
     * A layout container that holds the element. If you want to display the element within multiple containers, set this property to an array of possible values.
     *
     * - `component`: `string`\
     * The name of the component that renders the layout element.
     *
     * - `data`: `any`\
     * Data passed as props to `component`.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/progress-bar-with-percentage/ (linkStyle))
     * @param layoutElement A layout element configuration.
     * @returns The configuration of the previous layout element with the same `id`.
     */
    addLayoutElement(layoutElement) {
        const existingLayoutElement = this.removeLayoutElement(layoutElement.id);
        this.layoutElements.push(layoutElement);
        return existingLayoutElement;
    }
    findLayoutElement(layoutElementId) {
        const layoutElement = this.layoutElements.filter(a => a.id === layoutElementId)[0];
        return layoutElement;
    }
    removeLayoutElement(layoutElementId) {
        const layoutElement = this.findLayoutElement(layoutElementId);
        if (!!layoutElement) {
            const layoutElementIndex = this.layoutElements.indexOf(layoutElement);
            this.layoutElements.splice(layoutElementIndex, 1);
        }
        return layoutElement;
    }
    getContainerContent(container) {
        const containerLayoutElements = new Array();
        for (let layoutElement of this.layoutElements) {
            if (this.mode !== "display" && isStrCiEqual(layoutElement.id, "timerpanel")) {
                if (container === "header") {
                    if (this.isTimerPanelShowingOnTop && !this.isStartPageActive) {
                        containerLayoutElements.push(layoutElement);
                    }
                }
                if (container === "footer") {
                    if (this.isTimerPanelShowingOnBottom && !this.isStartPageActive) {
                        containerLayoutElements.push(layoutElement);
                    }
                }
            }
            else if (this.state === "running" && isStrCiEqual(layoutElement.id, this.progressBarComponentName)) {
                if (this.questionsOnPageMode != "singlePage" || this.progressBarType == "questions") {
                    const headerLayoutElement = this.findLayoutElement("advanced-header");
                    const advHeader = headerLayoutElement && headerLayoutElement.data;
                    let isBelowHeader = !advHeader || advHeader.hasBackground;
                    if (isStrCiEqual(this.progressBarLocation, "aboveHeader")) {
                        isBelowHeader = false;
                    }
                    if (isStrCiEqual(this.progressBarLocation, "belowHeader")) {
                        isBelowHeader = true;
                    }
                    if (this.showTOC && !(advHeader && advHeader.hasBackground) && this.isShowProgressBarOnTop && !this.isStartPageActive) {
                        if (container === "center") {
                            if (!isBelowHeader) {
                                layoutElement.index = -150;
                            }
                            else {
                                delete layoutElement.index;
                            }
                            containerLayoutElements.push(layoutElement);
                        }
                    }
                    else {
                        if (container === "header" && !isBelowHeader) {
                            layoutElement.index = -150;
                            if (this.isShowProgressBarOnTop && !this.isStartPageActive) {
                                containerLayoutElements.push(layoutElement);
                            }
                        }
                        if (container === "center" && isBelowHeader) {
                            if (!!layoutElement.index) {
                                delete layoutElement.index;
                            }
                            if (this.isShowProgressBarOnTop && !this.isStartPageActive) {
                                containerLayoutElements.push(layoutElement);
                            }
                        }
                    }
                    if (container === "footer") {
                        if (this.isShowProgressBarOnBottom && !this.isStartPageActive) {
                            containerLayoutElements.push(layoutElement);
                        }
                    }
                }
            }
            else if (isStrCiEqual(layoutElement.id, "buttons-navigation")) {
                if (container === "contentTop") {
                    if (this.isNavigationButtonsShowingOnTop) {
                        containerLayoutElements.push(layoutElement);
                    }
                }
                if (container === "contentBottom") {
                    if (this.isNavigationButtonsShowingOnBottom) {
                        containerLayoutElements.push(layoutElement);
                    }
                }
            }
            else if (this.state === "running" && isStrCiEqual(layoutElement.id, "toc-navigation") && this.showTOC) {
                if (container === "left") {
                    if (["left", "both"].indexOf(this.tocLocation) !== -1) {
                        containerLayoutElements.push(layoutElement);
                    }
                }
                if (container === "right") {
                    if (["right", "both"].indexOf(this.tocLocation) !== -1) {
                        containerLayoutElements.push(layoutElement);
                    }
                }
            }
            else if (isStrCiEqual(layoutElement.id, "advanced-header")) {
                if ((this.state === "running" || this.state === "starting" || (this.showHeaderOnCompletePage === true && this.state === "completed"))) {
                    const advHeader = layoutElement && layoutElement.data;
                    if (this.showTOC && !(advHeader && advHeader.hasBackground)) {
                        if (container === "contentTop") {
                            containerLayoutElements.push(layoutElement);
                        }
                    }
                    else {
                        if (layoutElement.container === container) {
                            containerLayoutElements.push(layoutElement);
                        }
                    }
                }
            }
            else {
                if (Array.isArray(layoutElement.container) && layoutElement.container.indexOf(container) !== -1 || layoutElement.container === container) {
                    containerLayoutElements.push(layoutElement);
                }
            }
        }
        containerLayoutElements.sort((a, b) => (a.index || 0) - (b.index || 0));
        containerLayoutElements.forEach(el => {
            if (!!el.getData) {
                el.data = el.getData();
            }
        });
        return containerLayoutElements;
    }
    processPopupVisiblityChanged(question, popup, visible) {
        this.onPopupVisibleChanged.fire(this, { question, popup, visible });
    }
    processOpenDropdownMenu(question, options) {
        const newOptions = Object.assign({ question }, options);
        this.onOpenDropdownMenu.fire(this, newOptions);
        options.menuType = newOptions.menuType;
    }
    getCssTitleExpandableSvg() {
        return null;
    }
    createCustomChoiceItem(options) {
        this.onCreateCustomChoiceItem.fire(this, options);
    }
    /**
     * Applies a specified theme to the survey.
     *
     * [Themes & Styles](https://surveyjs.io/form-library/documentation/manage-default-themes-and-styles (linkStyle))
     * @param theme An [`ITheme`](https://surveyjs.io/form-library/documentation/api-reference/itheme) object with theme settings.
     */
    applyTheme(theme) {
        if (!theme)
            return;
        Object.keys(theme).forEach((key) => {
            if (key === "header") {
                return;
            }
            if (key === "isPanelless") {
                this.isCompact = theme[key];
            }
            else {
                this[key] = theme[key];
            }
        });
        if ("header" in theme && !theme.headerView) {
            this.headerView = "advanced";
        }
        if (this.headerView !== "basic") {
            this.removeLayoutElement("advanced-header");
            const advHeader = new Cover();
            advHeader.fromTheme(theme);
            this.insertAdvancedHeader(advHeader);
        }
        this.themeChanged(theme);
    }
    themeChanged(theme) {
        this.getAllQuestions().forEach(q => q.themeChanged(theme));
    }
    /**
     * Disposes of the survey model.
     *
     * Call this method to release resources if your application contains multiple survey models or if you re-create a survey model at runtime.
     */
    dispose() {
        this.unConnectEditingObj();
        this.removeScrollEventListener();
        this.destroyResizeObserver();
        this.rootElement = undefined;
        if (this.layoutElements) {
            for (var i = 0; i < this.layoutElements.length; i++) {
                if (!!this.layoutElements[i].data && this.layoutElements[i].data !== this && this.layoutElements[i].data.dispose) {
                    this.layoutElements[i].data.dispose();
                }
            }
            this.layoutElements.splice(0, this.layoutElements.length);
        }
        super.dispose();
        this.editingObj = null;
        if (!this.pages)
            return;
        this.currentPage = null;
        for (var i = 0; i < this.pages.length; i++) {
            this.pages[i].setSurveyImpl(undefined);
            this.pages[i].dispose();
        }
        this.pages.splice(0, this.pages.length);
        if (this.disposeCallback) {
            this.disposeCallback();
        }
    }
    // private _lastScrollTop = 0;
    _isElementShouldBeSticky(selector) {
        var _a;
        if (!selector)
            return false;
        const topStickyContainer = (_a = this.scrollerElement) === null || _a === void 0 ? void 0 : _a.querySelector(selector);
        if (!!topStickyContainer) {
            // const scrollDirection = this.rootElement.scrollTop > this._lastScrollTop ? "down" : "up";
            // this._lastScrollTop = this.rootElement.scrollTop;
            return !!this.scrollerElement && this.scrollerElement.scrollTop > 0 && topStickyContainer.getBoundingClientRect().y <= this.scrollerElement.getBoundingClientRect().y;
        }
        return false;
    }
    get rootScrollDisabled() {
        return !(this.fitToContainer && this.formScrollDisabled);
    }
    get formScrollDisabled() {
        return !this.backgroundImage || this.backgroundImageAttachment !== "fixed";
    }
    onScroll() {
        if (!!this.rootElement) {
            if (this._isElementShouldBeSticky(".sv-components-container-center")) {
                this.rootElement.classList && this.rootElement.classList.add("sv-root--sticky-top");
            }
            else {
                this.rootElement.classList && this.rootElement.classList.remove("sv-root--sticky-top");
            }
            if (!!this.tocModel) {
                this.tocModel.updateStickyTOCSize(this.rootElement);
            }
        }
        if (this.onScrollCallback) {
            this.onScrollCallback();
        }
    }
    addScrollEventListener() {
        this.scrollHandler = () => { this.onScroll(); };
        this.rootElement.addEventListener("scroll", this.scrollHandler);
        if (!!this.rootElement.getElementsByTagName("form")[0]) {
            this.rootElement.getElementsByTagName("form")[0].addEventListener("scroll", this.scrollHandler);
        }
        if (!!this.scrollerElement) {
            this.scrollerElement.addEventListener("scroll", this.scrollHandler);
        }
    }
    removeScrollEventListener() {
        if (!!this.rootElement && !!this.scrollHandler) {
            this.rootElement.removeEventListener("scroll", this.scrollHandler);
            if (!!this.rootElement.getElementsByTagName("form")[0]) {
                this.rootElement.getElementsByTagName("form")[0].removeEventListener("scroll", this.scrollHandler);
            }
            if (!!this.scrollerElement) {
                this.scrollerElement.removeEventListener("scroll", this.scrollHandler);
            }
        }
    }
}
SurveyModel.TemplateRendererComponentName = "sv-template-renderer";
// private static stylesManager: StylesManager = null;
SurveyModel.platform = "unknown";
__decorate([
    property()
], SurveyModel.prototype, "completedCss", void 0);
__decorate([
    property()
], SurveyModel.prototype, "completedBeforeCss", void 0);
__decorate([
    property()
], SurveyModel.prototype, "loadingBodyCss", void 0);
__decorate([
    property()
], SurveyModel.prototype, "containerCss", void 0);
__decorate([
    property({ onSet: (newValue, target) => { target.updateCss(); } })
], SurveyModel.prototype, "fitToContainer", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            if (newValue === "basic") {
                target.removeLayoutElement("advanced-header");
            }
            else {
                const layoutElement = target.findLayoutElement("advanced-header");
                if (!layoutElement) {
                    const advHeader = new Cover();
                    target.insertAdvancedHeader(advHeader);
                }
            }
        }
    })
], SurveyModel.prototype, "headerView", void 0);
__decorate([
    property()
], SurveyModel.prototype, "showBrandInfo", void 0);
__decorate([
    property()
], SurveyModel.prototype, "enterKeyAction", void 0);
__decorate([
    property()
], SurveyModel.prototype, "lazyRenderFirstBatchSizeValue", void 0);
__decorate([
    property({ defaultValue: {} })
], SurveyModel.prototype, "cssVariables", void 0);
__decorate([
    property()
], SurveyModel.prototype, "_isMobile", void 0);
__decorate([
    property()
], SurveyModel.prototype, "_isCompact", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            target.updateCss();
        }
    })
], SurveyModel.prototype, "backgroundImage", void 0);
__decorate([
    property()
], SurveyModel.prototype, "backgroundImageFit", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            target.updateCss();
        }
    })
], SurveyModel.prototype, "backgroundImageAttachment", void 0);
__decorate([
    property()
], SurveyModel.prototype, "wrapperFormCss", void 0);
__decorate([
    property({
        getDefaultValue: (self) => {
            return self.progressBarType === "buttons";
        },
    })
], SurveyModel.prototype, "progressBarShowPageTitles", void 0);
__decorate([
    property()
], SurveyModel.prototype, "progressBarShowPageNumbers", void 0);
__decorate([
    property()
], SurveyModel.prototype, "progressBarInheritWidthFrom", void 0);
__decorate([
    property({ defaultValue: true })
], SurveyModel.prototype, "validationEnabled", void 0);
__decorate([
    property()
], SurveyModel.prototype, "rootCss", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            target.updateGridColumns();
        }
    })
], SurveyModel.prototype, "gridLayoutEnabled", void 0);
__decorate([
    property()
], SurveyModel.prototype, "calculatedWidthMode", void 0);
__decorate([
    property({
        defaultValue: 100, onSet(val, target, prevVal) {
            target.pages.forEach(p => p.updateRootStyle());
        },
    })
], SurveyModel.prototype, "widthScale", void 0);
__decorate([
    property()
], SurveyModel.prototype, "staticStartWidth", void 0);
__decorate([
    property()
], SurveyModel.prototype, "responsiveStartWidth", void 0);
__decorate([
    propertyArray()
], SurveyModel.prototype, "layoutElements", void 0);
function isStrCiEqual(a, b) {
    if (!a)
        return false;
    if (!b)
        return false;
    return a.toUpperCase() === b.toUpperCase();
}
Serializer.addClass("survey", [
    {
        name: "locale",
        choices: () => {
            return surveyLocalization.getLocales(true);
        },
        onGetValue: (obj) => {
            return obj.locale == surveyLocalization.defaultLocale ? null : obj.locale;
        },
    },
    { name: "title", serializationProperty: "locTitle", dependsOn: "locale" },
    {
        name: "description:text",
        serializationProperty: "locDescription",
        dependsOn: "locale",
    },
    { name: "logo:file", serializationProperty: "locLogo" },
    { name: "logoWidth", default: "auto", minValue: 0 },
    { name: "logoHeight", default: "40px", minValue: 0 },
    {
        name: "logoFit",
        default: "contain",
        choices: ["none", "contain", "cover", "fill"],
    },
    {
        name: "logoPosition",
        default: "left",
        choices: ["none", "left", "right", "top", "bottom"],
    },
    { name: "autoFocusFirstQuestion:boolean", alternativeName: "focusFirstQuestionAutomatic" },
    { name: "autoFocusFirstError:boolean", default: true, alternativeName: "focusOnFirstError" },
    { name: "completedHtml:html", serializationProperty: "locCompletedHtml" },
    {
        name: "completedBeforeHtml:html",
        serializationProperty: "locCompletedBeforeHtml",
    },
    {
        name: "completedHtmlOnCondition:htmlconditions",
        className: "htmlconditionitem", isArray: true
    },
    { name: "loadingHtml:html", serializationProperty: "locLoadingHtml" },
    { name: "pages:surveypages", className: "page", isArray: true, onSerializeValue: (obj) => { return obj.originalPages || obj.pages; } },
    {
        name: "elements",
        alternativeName: "questions",
        baseClassName: "question",
        visible: false,
        isLightSerializable: false,
        onGetValue: function (obj) {
            return null;
        },
        onSetValue: function (obj, value, jsonConverter) {
            obj.pages.splice(0, obj.pages.length);
            var page = obj.addNewPage("");
            jsonConverter.toObject({ questions: value }, page, jsonConverter === null || jsonConverter === void 0 ? void 0 : jsonConverter.options);
        },
    },
    {
        name: "triggers:triggers",
        baseClassName: "surveytrigger",
        classNamePart: "trigger",
    },
    {
        name: "calculatedValues:calculatedvalues",
        className: "calculatedvalue", isArray: true
    },
    { name: "sjsVersion", visible: false },
    { name: "surveyId", visible: false },
    { name: "surveyPostId", visible: false },
    { name: "surveyShowDataSaving:boolean", visible: false },
    "cookieName",
    { name: "partialSendEnabled:boolean", alternativeName: "sendResultOnPageNext" },
    {
        name: "showNavigationButtons:boolean",
        default: true,
    },
    {
        name: "navigationButtonsLocation",
        default: "bottom",
        choices: ["top", "bottom", "topBottom"],
    },
    {
        name: "showPrevButton:boolean",
        default: true,
        visibleIf: (obj) => { return obj.showNavigationButtons !== "none"; }
    },
    { name: "showTitle:boolean", default: true },
    { name: "showPageTitles:boolean", default: true },
    { name: "showCompletePage:boolean", default: true, alternativeName: "showCompletedPage" },
    "navigateToUrl",
    {
        name: "navigateToUrlOnCondition:urlconditions",
        className: "urlconditionitem", isArray: true
    },
    {
        name: "questionOrder", alternativeName: "questionsOrder",
        default: "initial",
        choices: ["initial", "random"],
    },
    {
        name: "matrixDragHandleArea",
        visible: false,
        default: "entireItem",
        choices: ["entireItem", "icon"]
    },
    "showPageNumbers:boolean",
    {
        name: "showQuestionNumbers",
        default: "off",
        choices: ["on", "onPage", "recursive", "off"],
    },
    {
        name: "questionTitleLocation",
        default: "top",
        choices: ["top", "bottom", "left"],
    },
    {
        name: "questionDescriptionLocation",
        default: "underTitle",
        choices: ["underInput", "underTitle"],
    },
    { name: "questionErrorLocation", default: "top", choices: ["top", "bottom"] },
    {
        name: "showProgressBar:boolean",
        default: false,
        onSetValue: (obj, value, jsonConv) => {
            obj && obj.setShowProgressBar(value);
        },
    },
    {
        name: "progressBarLocation",
        default: "auto",
        choices: ["auto", "aboveheader", "belowheader", "bottom", "topbottom"],
        visibleIf: (obj) => { return obj.showProgressBar; }
    },
    {
        name: "progressBarType",
        default: "pages",
        choices: [
            "pages",
            "questions",
            "requiredQuestions",
            "correctQuestions",
        ],
        visibleIf: (obj) => { return obj.showProgressBar; }
    },
    {
        name: "progressBarShowPageTitles:switch",
        category: "navigation",
        visibleIf: (obj) => { return obj.showProgressBar && obj.progressBarType === "pages"; }
    },
    {
        name: "progressBarShowPageNumbers:switch",
        default: false,
        category: "navigation",
        visibleIf: (obj) => { return obj.showProgressBar && obj.progressBarType === "pages"; }
    },
    {
        name: "progressBarInheritWidthFrom",
        default: "container",
        choices: ["container", "survey"],
        category: "navigation",
        visibleIf: (obj) => { return obj.showProgressBar && obj.progressBarType === "pages"; }
    },
    {
        name: "showTOC:switch",
        default: false
    },
    {
        name: "tocLocation", default: "left", choices: ["left", "right"],
        dependsOn: ["showTOC"],
        visibleIf: (survey) => { return !!survey && survey.showTOC; }
    },
    { name: "readOnly:boolean", default: false },
    { name: "mode", default: "edit", choices: ["edit", "display"], visible: false },
    { name: "storeOthersAsComment:boolean", default: true },
    { name: "maxTextLength:number", default: 0, minValue: 0 },
    { name: "maxCommentLength:number", default: 0, minValue: 0, alternativeName: "maxOthersLength" },
    {
        name: "autoAdvanceEnabled:boolean", alternativeName: "goNextPageAutomatic",
        onSetValue: function (obj, value) {
            if (value !== "autogonext") {
                value = Helpers.isTwoValueEquals(value, true);
            }
            if (value === "autogonext") {
                value = true;
            }
            obj.setPropertyValue("autoAdvanceEnabled", value);
        }
    },
    {
        name: "autoAdvanceAllowComplete:boolean", default: true, alternativeName: "allowCompleteSurveyAutomatic",
        visibleIf: (obj) => obj.autoAdvanceEnabled === true
    },
    {
        name: "clearInvisibleValues",
        default: "onComplete",
        choices: ["none", "onComplete", "onHidden", "onHiddenContainer"],
    },
    {
        name: "checkErrorsMode",
        default: "onNextPage",
        choices: ["onNextPage", "onValueChanged", "onComplete"],
    },
    { name: "validateVisitedEmptyFields:boolean", dependsOn: "checkErrorsMode", visibleIf: (obj) => obj.checkErrorsMode === "onValueChanged" },
    {
        name: "textUpdateMode",
        default: "onBlur",
        choices: ["onBlur", "onTyping"],
    },
    { name: "autoGrowComment:boolean", default: false },
    { name: "allowResizeComment:boolean", default: true },
    { name: "commentAreaRows:number", minValue: 1 },
    {
        name: "startSurveyText",
        serializationProperty: "locStartSurveyText",
        visibleIf: (obj) => { return obj.firstPageIsStartPage; }
    },
    {
        name: "pagePrevText",
        serializationProperty: "locPagePrevText",
        visibleIf: (obj) => { return obj.showNavigationButtons !== "none" && obj.showPrevButton; }
    },
    {
        name: "pageNextText",
        serializationProperty: "locPageNextText",
        visibleIf: (obj) => { return obj.showNavigationButtons !== "none"; }
    },
    {
        name: "completeText",
        serializationProperty: "locCompleteText",
        visibleIf: (obj) => { return obj.showNavigationButtons !== "none"; }
    },
    {
        name: "previewText",
        serializationProperty: "locPreviewText",
        visibleIf: (obj) => { return obj.showPreviewBeforeComplete; }
    },
    {
        name: "editText",
        serializationProperty: "locEditText",
        visibleIf: (obj) => { return obj.showPreviewBeforeComplete; }
    },
    { name: "requiredMark", default: "*", alternativeName: "requiredText" },
    {
        name: "questionStartIndex",
        dependsOn: ["showQuestionNumbers"],
        visibleIf: (survey) => { return !survey || survey.showQuestionNumbers !== "off"; }
    },
    {
        name: "questionTitlePattern",
        default: "numTitleRequire",
        dependsOn: ["questionStartIndex", "requiredMark"],
        choices: (obj) => {
            if (!obj)
                return [];
            return obj.getQuestionTitlePatternOptions();
        },
    },
    {
        name: "questionTitleTemplate",
        visible: false,
        isSerializable: false,
        serializationProperty: "locQuestionTitleTemplate",
    },
    { name: "firstPageIsStartPage:boolean", default: false, alternativeName: "firstPageIsStarted" },
    {
        name: "isSinglePage:boolean",
        default: false,
        visible: false,
        isSerializable: false,
    },
    {
        name: "questionsOnPageMode",
        default: "standard",
        choices: ["standard", "singlePage", "questionPerPage", "inputPerPage"],
    },
    {
        name: "showPreviewBeforeComplete:boolean",
        default: false,
        onSetValue: (obj, value, jsonConv) => {
            obj && obj.setShowPreviewBeforeComplete(value);
        },
    },
    {
        name: "previewMode",
        default: "allQuestions",
        choices: ["allQuestions", "answeredQuestions"],
        visibleIf: (obj) => { return obj.showPreviewBeforeComplete; }
    },
    { name: "showTimer:boolean" },
    { name: "timeLimit:number", alternativeName: "maxTimeToFinish", default: 0, minValue: 0, enableIf: (obj) => obj.showTimer },
    { name: "timeLimitPerPage:number", alternativeName: "maxTimeToFinishPage", default: 0, minValue: 0, enableIf: (obj) => obj.showTimer },
    { name: "timerLocation", default: "top", choices: ["top", "bottom"], enableIf: (obj) => obj.showTimer },
    { name: "timerInfoMode", alternativeName: "showTimerPanelMode",
        default: "combined", choices: ["page", "survey", "combined"], enableIf: (obj) => obj.showTimer },
    { name: "showTimerPanel", visible: false, isSerializable: false },
    {
        name: "widthMode",
        default: "auto",
        choices: ["auto", "static", "responsive"],
    },
    { name: "gridLayoutEnabled:boolean", default: false },
    { name: "width", visibleIf: (obj) => { return obj.widthMode === "static"; } },
    { name: "fitToContainer:boolean", default: true, visible: false },
    { name: "headerView", default: "basic", choices: ["basic", "advanced"], visible: false },
    { name: "backgroundImage:file", visible: false },
    { name: "backgroundImageFit", default: "cover", choices: ["auto", "contain", "cover"], visible: false },
    { name: "backgroundImageAttachment", default: "scroll", choices: ["scroll", "fixed"], visible: false },
    { name: "backgroundOpacity:number", minValue: 0, maxValue: 1, default: 1, visible: false },
    { name: "showBrandInfo:boolean", default: false, visible: false }
]);

/**
 * A base class for multiple-choice question types ([Checkboxes](https://surveyjs.io/form-library/documentation/questioncheckboxmodel), [Dropdown](https://surveyjs.io/form-library/documentation/questiondropdownmodel), [Radio Button Group](https://surveyjs.io/form-library/documentation/questionradiogroupmodel), etc.).
 */
class QuestionSelectBase extends Question {
    get waitingChoicesByURL() {
        return !this.isChoicesLoaded && this.hasChoicesUrl;
    }
    get selectedItemValues() { return this.getPropertyValue("selectedItemValues"); }
    set selectedItemValues(val) { this.setPropertyValue("selectedItemValues", val); }
    constructor(name) {
        super(name);
        this.isSettingDefaultValue = false;
        this.isSettingComment = false;
        this.isRunningChoices = false;
        this.isFirstLoadChoicesFromUrl = true;
        this.isUpdatingChoicesDependedQuestions = false;
        this._renderedChoices = [];
        this.renderedChoicesAnimation = new AnimationGroup(this.getRenderedChoicesAnimationOptions(), (val) => {
            this._renderedChoices = val;
            this.renderedChoicesChangedCallback && this.renderedChoicesChangedCallback();
        }, () => this._renderedChoices);
        this.headItemsCount = 0;
        this.footItemsCount = 0;
        this.prevIsOtherSelected = false;
        this.otherItemValue = this.createItemValue("other");
        this.noneItemValue = this.createNoneItem(settings.noneItemValue, "noneText", "noneItemText");
        this.refuseItemValue = this.createNoneItem(settings.refuseItemValue, "refuseText", "refuseItemText");
        this.dontKnowItemValue = this.createNoneItem(settings.dontKnowItemValue, "dontKnowText", "dontKnowItemText");
        this.createItemValues("choices");
        this.registerPropertyChangedHandlers(["choices"], () => {
            if (!this.filterItems()) {
                this.onVisibleChoicesChanged();
            }
        });
        this.createItemValues("customChoices");
        this.registerPropertyChangedHandlers(["customChoices"], () => {
            this.onVisibleChoicesChanged();
        });
        this.registerPropertyChangedHandlers(["choicesFromQuestion", "choicesFromQuestionMode", "choiceValuesFromQuestion",
            "choiceTextsFromQuestion", "showNoneItem", "showRefuseItem", "showDontKnowItem", "isUsingRestful", "isMessagePanelVisible"], () => {
            this.onVisibleChoicesChanged();
        });
        this.registerPropertyChangedHandlers(["hideIfChoicesEmpty"], () => {
            this.onVisibleChanged();
        });
        this.registerPropertyChangedHandlers(["selecteditemValues"], (newVal) => {
            this.onSelectedItemValuesChangedHandler(newVal);
        });
        this.createNewArray("visibleChoices", () => this.updateRenderedChoices(), () => this.updateRenderedChoices());
        this.setNewRestfulProperty();
        var locOtherText = this.createLocalizableString("otherText", this.otherItemValue, true, "otherItemText");
        this.createLocalizableString("otherErrorText", this, true, "otherRequiredError");
        this.createLocalizableString("otherPlaceholder", this, false, true);
        this.otherItemValue.locOwner = this;
        this.otherItemValue.setLocText(locOtherText);
        this.choicesByUrl.createItemValue = (value) => {
            return this.createItemValue(value);
        };
        this.choicesByUrl.beforeSendRequestCallback = () => {
            this.onBeforeSendRequest();
        };
        this.choicesByUrl.getResultCallback = (items) => {
            this.onLoadChoicesFromUrl(items);
        };
        this.choicesByUrl.updateResultCallback = (items, serverResult) => {
            if (this.survey) {
                return this.survey.updateChoicesFromServer(this, items, serverResult);
            }
            return items;
        };
    }
    getType() {
        return "selectbase";
    }
    dispose() {
        super.dispose();
        const q = this.getQuestionWithChoices();
        if (!!q) {
            q.removeDependedQuestion(this);
        }
    }
    get otherTextAreaModel() {
        if (!this.otherTextAreaModelValue) {
            this.otherTextAreaModelValue = new TextAreaModel(this.getOtherTextAreaOptions());
        }
        return this.otherTextAreaModelValue;
    }
    getOtherTextAreaOptions() {
        const options = {
            question: this,
            id: () => this.otherId,
            propertyNames: ["otherValue", "comment"],
            className: () => this.cssClasses.other,
            placeholder: () => this.otherPlaceholder,
            isDisabledAttr: () => this.isInputReadOnly || false,
            rows: () => this.commentAreaRows,
            maxLength: () => this.getOthersMaxLength(),
            autoGrow: () => this.survey && this.survey.autoGrowComment,
            ariaRequired: () => this.ariaRequired || this.a11y_input_ariaRequired,
            ariaLabel: () => this.ariaLabel || this.a11y_input_ariaLabel,
            getTextValue: () => { return this.otherValue; },
            onTextAreaChange: (e) => { this.onOtherValueChange(e); },
            onTextAreaInput: (e) => { this.onOtherValueInput(e); },
        };
        return options;
    }
    resetDependedQuestion() {
        this.choicesFromQuestion = "";
    }
    get otherId() {
        return this.id + "_other";
    }
    getCommentElementsId() {
        return [this.commentId, this.otherId];
    }
    getItemValueType() {
        return "itemvalue";
    }
    createItemValue(value, text) {
        const res = Serializer.createClass(this.getItemValueType(), { value: value });
        res.locOwner = this;
        if (!!text)
            res.text = text;
        return res;
    }
    hasErrors(fireCallback = true, rec = null) {
        if (!rec || rec.isOnValueChanged !== true) {
            this.clearIncorrectValues();
        }
        return super.hasErrors(fireCallback, rec);
    }
    get isUsingCarryForward() {
        return !!this.carryForwardQuestionType;
    }
    get carryForwardQuestionType() {
        return this.getPropertyValue("carryForwardQuestionType");
    }
    setCarryForwardQuestionType(selBaseQuestion, arrayQuestion) {
        const mode = selBaseQuestion ? "select" : (arrayQuestion ? "array" : undefined);
        this.setPropertyValue("carryForwardQuestionType", mode);
    }
    get isUsingRestful() {
        return this.getPropertyValueWithoutDefault("isUsingRestful") || false;
    }
    updateIsUsingRestful() {
        this.setPropertyValueDirectly("isUsingRestful", this.hasChoicesUrl);
    }
    supportGoNextPageError() {
        return !this.isOtherSelected || !!this.otherValue;
    }
    isLayoutTypeSupported(layoutType) {
        return true;
    }
    localeChanged() {
        super.localeChanged();
        if (this.choicesOrder !== "none") {
            this.updateVisibleChoices();
            this.onVisibleChoicesChanged();
        }
    }
    locStrsChanged() {
        super.locStrsChanged();
        if (!!this.choicesFromUrl) {
            ItemValue.locStrsChanged(this.choicesFromUrl);
            ItemValue.locStrsChanged(this.visibleChoices);
        }
        if (this.isUsingCarryForward) {
            ItemValue.locStrsChanged(this.visibleChoices);
        }
    }
    updatePrevOtherErrorValue(val) {
        const oldVal = this.otherValue;
        if (val !== oldVal) {
            this.prevOtherErrorValue = oldVal;
        }
    }
    get otherValue() {
        if (!this.showCommentArea)
            return this.comment;
        return this.otherValueCore;
    }
    set otherValue(val) {
        this.updatePrevOtherErrorValue(val);
        if (!this.showCommentArea) {
            this.comment = val;
        }
        else {
            this.setOtherValueInternally(val);
        }
    }
    get otherValueCore() {
        return this.getPropertyValue("otherValue");
    }
    set otherValueCore(val) {
        this.setPropertyValue("otherValue", val);
    }
    /**
     * Returns the "Other" choice item. Use this property to change the item's `value` or `text`.
     * @see showOtherItem
     */
    get otherItem() {
        return this.otherItemValue;
    }
    /**
     * Returns `true` if the "Other" choice item is selected.
     * @see showOtherItem
     */
    get isOtherSelected() {
        return this.hasOther && this.getHasOther(this.renderedValue);
    }
    get isNoneSelected() {
        return this.showNoneItem && this.getIsItemValue(this.renderedValue, this.noneItem);
    }
    /**
     * Specifies whether to display the "None" choice item.
     *
     * When users select the "None" item in multi-select questions, all other items become unselected.
     *
     * [Dropdown Demo](https://surveyjs.io/form-library/examples/create-dropdown-menu-in-javascript/ (linkStyle))
     *
     * [Checkboxes Demo](https://surveyjs.io/form-library/examples/create-checkboxes-question-in-javascript/ (linkStyle))
     *
     * [Radio Button Group Demo](https://surveyjs.io/form-library/examples/single-select-radio-button-group/ (linkStyle))
     * @see noneItem
     * @see noneText
     * @see [settings.noneItemValue](https://surveyjs.io/form-library/documentation/api-reference/settings#noneItemValue)
     * @see [settings.specialChoicesOrder](https://surveyjs.io/form-library/documentation/api-reference/settings#specialChoicesOrder)
     */
    get showNoneItem() {
        return this.getPropertyValue("showNoneItem");
    }
    set showNoneItem(val) {
        this.setPropertyValue("showNoneItem", val);
    }
    get hasNone() {
        return this.showNoneItem;
    }
    set hasNone(val) {
        this.showNoneItem = val;
    }
    /**
     * Returns the "None" choice item. Use this property to change the item's `value` or `text`.
     * @see showNoneItem
     */
    get noneItem() {
        return this.noneItemValue;
    }
    /**
     * Gets or sets a caption for the "None" choice item.
     * @see showNoneItem
     */
    get noneText() {
        return this.getLocalizableStringText("noneText");
    }
    set noneText(val) {
        this.setLocalizableStringText("noneText", val);
    }
    get locNoneText() {
        return this.getLocalizableString("noneText");
    }
    /**
     * Specifies whether to display the "Refuse to answer" choice item.
     *
     * When users select the "Refuse to answer" item in multi-select questions, all other items become unselected.
     * @see refuseItem
     * @see refuseItemText
     * @see [settings.refuseItemValue](https://surveyjs.io/form-library/documentation/api-reference/settings#refuseItemValue)
     * @see [settings.specialChoicesOrder](https://surveyjs.io/form-library/documentation/api-reference/settings#specialChoicesOrder)
     */
    get showRefuseItem() {
        return this.getPropertyValue("showRefuseItem");
    }
    set showRefuseItem(val) {
        this.setPropertyValue("showRefuseItem", val);
    }
    /**
     * Returns the "Refuse to answer" choice item. Use this property to change the item's `value` or `text`.
     * @see showRefuseItem
     */
    get refuseItem() {
        return this.refuseItemValue;
    }
    /**
     * Gets or sets a caption for the "Refuse to answer" choice item.
     * @see showRefuseItem
     */
    get refuseText() {
        return this.getLocalizableStringText("refuseText");
    }
    set refuseText(val) {
        this.setLocalizableStringText("refuseText", val);
    }
    get locRefuseText() {
        return this.getLocalizableString("refuseText");
    }
    /**
     * Specifies whether to display the "Don't know" choice item.
     *
     * When users select the "Don't know" item in multi-select questions, all other items become unselected.
     * @see dontKnowItem
     * @see dontKnowItemText
     * @see [settings.dontKnowItemValue](https://surveyjs.io/form-library/documentation/api-reference/settings#dontKnowItemValue)
     * @see [settings.specialChoicesOrder](https://surveyjs.io/form-library/documentation/api-reference/settings#specialChoicesOrder)
     */
    get showDontKnowItem() {
        return this.getPropertyValue("showDontKnowItem");
    }
    set showDontKnowItem(val) {
        this.setPropertyValue("showDontKnowItem", val);
    }
    /**
     * Returns the "Don't know" choice item. Use this property to change the item's `value` or `text`.
     * @see showDontKnowItem
     */
    get dontKnowItem() {
        return this.dontKnowItemValue;
    }
    /**
     * Gets or sets a caption for the "Don't know" choice item.
     * @see showDontKnowItem
     */
    get dontKnowText() {
        return this.getLocalizableStringText("dontKnowText");
    }
    set dontKnowText(val) {
        this.setLocalizableStringText("dontKnowText", val);
    }
    get locDontKnowText() {
        return this.getLocalizableString("dontKnowText");
    }
    createNoneItem(defaultValue, name, locName) {
        const item = this.createItemValue(defaultValue);
        item.isExclusive = true;
        const locStr = this.createLocalizableString(name, item, true, locName);
        item.locOwner = this;
        item.setLocText(locStr);
        return item;
    }
    /**
     * A Boolean expression that is evaluated against each choice item. If the expression evaluates to `false`, the choice item becomes hidden.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Use the `{item}` placeholder to reference the current choice item in the expression.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see visibleIf
     * @see choicesEnableIf
     */
    get choicesVisibleIf() {
        return this.getPropertyValue("choicesVisibleIf", "");
    }
    set choicesVisibleIf(val) {
        this.setPropertyValue("choicesVisibleIf", val);
        this.filterItems();
    }
    /**
     * A Boolean expression that is evaluated against each choice item. If the expression evaluates to `false`, the choice item becomes read-only.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Use the `{item}` placeholder to reference the current choice item in the expression.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey-conditional-logic#conditional-visibility).
     * @see enableIf
     * @see choicesVisibleIf
     */
    get choicesEnableIf() {
        return this.getPropertyValue("choicesEnableIf", "");
    }
    set choicesEnableIf(val) {
        this.setPropertyValue("choicesEnableIf", val);
        this.filterItems();
    }
    surveyChoiceItemVisibilityChange() {
        this.filterItems();
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        this.runItemsEnableCondition(values, properties);
        this.runItemsCondition(values, properties);
        this.choices.forEach(item => {
            item.runConditionCore(values, properties);
        });
    }
    isTextValue() {
        return true; //for comments and others
    }
    setDefaultValue() {
        this.isSettingDefaultValue =
            !this.isValueEmpty(this.defaultValue) &&
                this.hasUnknownValue(this.defaultValue);
        this.prevOtherValue = undefined;
        const prevComment = this.comment;
        super.setDefaultValue();
        this.isSettingDefaultValue = false;
        if (this.comment && this.getStoreOthersAsComment() && prevComment !== this.comment) {
            this.setValueCore(this.setOtherValueIntoValue(this.value));
            this.setCommentIntoData(this.comment);
        }
    }
    getIsMultipleValue() {
        return false;
    }
    convertDefaultValue(val) {
        if (val == null || val == undefined)
            return val;
        if (this.getIsMultipleValue()) {
            if (!Array.isArray(val))
                return [val];
        }
        else {
            if (Array.isArray(val) && val.length > 0)
                return val[0];
        }
        return val;
    }
    filterItems() {
        if (this.isLoadingFromJson ||
            !this.data ||
            this.areInvisibleElementsShowing)
            return false;
        var values = this.getDataFilteredValues();
        var properties = this.getDataFilteredProperties();
        this.runItemsEnableCondition(values, properties);
        return this.runItemsCondition(values, properties);
    }
    runItemsCondition(values, properties) {
        this.setConditionalChoicesRunner();
        var hasChanges = this.runConditionsForItems(values, properties);
        if (!!this.filteredChoicesValue &&
            this.filteredChoicesValue.length === this.activeChoices.length) {
            this.filteredChoicesValue = undefined;
        }
        if (hasChanges) {
            this.onVisibleChoicesChanged();
            this.clearIncorrectValues();
        }
        return hasChanges;
    }
    runItemsEnableCondition(values, properties) {
        this.setConditionalEnableChoicesRunner();
        var hasChanged = ItemValue.runEnabledConditionsForItems(this.activeChoices, this.conditionChoicesEnableIfRunner, values, properties, (item, val) => {
            return val && this.onEnableItemCallBack(item);
        });
        if (hasChanged) {
            this.clearDisabledValues();
        }
        this.onAfterRunItemsEnableCondition();
    }
    onAfterRunItemsEnableCondition() { }
    onEnableItemCallBack(item) {
        return true;
    }
    onSelectedItemValuesChangedHandler(newValue) {
        var _a;
        (_a = this.survey) === null || _a === void 0 ? void 0 : _a.loadedChoicesFromServer(this);
    }
    getItemIfChoicesNotContainThisValue(value, text) {
        if (this.waitingChoicesByURL) {
            return this.createItemValue(value, text);
        }
        else {
            return null;
        }
    }
    getSingleSelectedItem() {
        const selectedItemValues = this.selectedItemValues;
        if (this.isEmpty())
            return null;
        const itemValue = ItemValue.getItemByValue(this.visibleChoices, this.value);
        this.onGetSingleSelectedItem(itemValue);
        if (!itemValue && (!selectedItemValues || this.value != selectedItemValues.id)) {
            this.updateSelectedItemValues();
        }
        return itemValue || selectedItemValues || (this.isOtherSelected ? this.otherItem : this.getItemIfChoicesNotContainThisValue(this.value));
    }
    onGetSingleSelectedItem(selectedItemByValue) { }
    getMultipleSelectedItems() {
        return [];
    }
    setConditionalChoicesRunner() {
        if (this.choicesVisibleIf) {
            if (!this.conditionChoicesVisibleIfRunner) {
                this.conditionChoicesVisibleIfRunner = new ConditionRunner(this.choicesVisibleIf);
            }
            this.conditionChoicesVisibleIfRunner.expression = this.choicesVisibleIf;
        }
        else {
            this.conditionChoicesVisibleIfRunner = null;
        }
    }
    setConditionalEnableChoicesRunner() {
        if (this.choicesEnableIf) {
            if (!this.conditionChoicesEnableIfRunner) {
                this.conditionChoicesEnableIfRunner = new ConditionRunner(this.choicesEnableIf);
            }
            this.conditionChoicesEnableIfRunner.expression = this.choicesEnableIf;
        }
        else {
            this.conditionChoicesEnableIfRunner = null;
        }
    }
    canSurveyChangeItemVisibility() {
        return !!this.survey && this.survey.canChangeChoiceItemsVisibility();
    }
    changeItemVisibility() {
        return this.canSurveyChangeItemVisibility() ?
            (item, val) => this.survey.getChoiceItemVisibility(this, item, val)
            : null;
    }
    runConditionsForItems(values, properties) {
        this.filteredChoicesValue = [];
        const calcVisibility = this.changeItemVisibility();
        return ItemValue.runConditionsForItems(this.activeChoices, this.getFilteredChoices(), this.areInvisibleElementsShowing
            ? null
            : this.conditionChoicesVisibleIfRunner, values, properties, !this.survey || !this.survey.areInvisibleElementsShowing, (item, val) => {
            return !!calcVisibility ? calcVisibility(item, val) : val;
        });
    }
    getHasOther(val) {
        return this.getIsItemValue(val, this.otherItem);
    }
    getIsItemValue(val, item) {
        return val === item.value;
    }
    get validatedValue() {
        return this.rendredValueToDataCore(this.value);
    }
    createRestful() {
        return new ChoicesRestful();
    }
    setNewRestfulProperty() {
        this.setPropertyValue("choicesByUrl", this.createRestful());
        this.choicesByUrl.owner = this;
        this.choicesByUrl.loadingOwner = this;
    }
    get autoOtherMode() {
        return this.getPropertyValue("autoOtherMode");
    }
    set autoOtherMode(val) {
        this.setPropertyValue("autoOtherMode", val);
    }
    getQuestionComment() {
        if (this.showCommentArea)
            return super.getQuestionComment();
        if (!!this.otherValueCore)
            return this.otherValueCore;
        if (this.hasComment || this.getStoreOthersAsComment())
            return super.getQuestionComment();
        return this.otherValueCore;
    }
    selectOtherValueFromComment(val) {
        if (val) {
            this.prevIsOtherSelected = true;
        }
        this.value = val ? this.otherItem.value : undefined;
    }
    setQuestionComment(newValue) {
        this.updatePrevOtherErrorValue(newValue);
        if (this.showCommentArea) {
            super.setQuestionComment(newValue);
            return;
        }
        this.onUpdateCommentOnAutoOtherMode(newValue);
        if (this.getStoreOthersAsComment())
            super.setQuestionComment(newValue);
        else {
            this.setOtherValueInternally(newValue);
        }
        this.updateChoicesDependedQuestions();
    }
    onUpdateCommentOnAutoOtherMode(newValue) {
        if (!this.autoOtherMode)
            return;
        this.prevOtherValue = undefined;
        const isSelected = this.isOtherSelected;
        if (!isSelected && !!newValue || isSelected && !newValue) {
            this.selectOtherValueFromComment(!!newValue);
        }
    }
    setOtherValueInternally(newValue) {
        if (!this.isSettingComment && newValue != this.otherValueCore) {
            this.isSettingComment = true;
            this.otherValueCore = newValue;
            if (this.isOtherSelected && !this.isRenderedValueSetting) {
                this.value = this.getValueOnSettingOther(newValue);
            }
            this.isSettingComment = false;
        }
    }
    getValueOnSettingOther(otherValue) {
        const val = this.rendredValueToData(this.renderedValue);
        if (this.showCommentArea || this.getStoreOthersAsComment())
            return val;
        const item = ItemValue.getItemByValue(this.visibleChoices, otherValue);
        if (!item || item === this.otherItem)
            return val;
        this.otherValueCore = "";
        if (!Array.isArray(val))
            return otherValue;
        const index = val.indexOf(this.otherItem.value);
        if (index > -1) {
            val.splice(index, 1);
        }
        if (val.indexOf(otherValue) < 0) {
            val.push(otherValue);
        }
        return val;
    }
    clearValue(keepComment) {
        super.clearValue(keepComment);
        this.prevOtherValue = undefined;
        this.selectedItemValues = undefined;
    }
    updateCommentFromSurvey(newValue) {
        super.updateCommentFromSurvey(newValue);
        this.prevOtherValue = undefined;
    }
    get renderedValue() {
        return this.getPropertyValue("renderedValue", null);
    }
    set renderedValue(val) {
        if (this.isReadOnlyAttr)
            return;
        this.setPropertyValue("renderedValue", val);
        var val = this.rendredValueToData(val);
        if (!this.isTwoValueEquals(val, this.value)) {
            this.value = val;
        }
    }
    setQuestionValue(newValue, updateIsAnswered = true, updateComment = true) {
        if (this.isLoadingFromJson ||
            this.isTwoValueEquals(this.value, newValue))
            return;
        super.setQuestionValue(newValue, updateIsAnswered);
        this.setPropertyValue("renderedValue", this.rendredValueFromData(newValue));
        this.updateChoicesDependedQuestions();
        if (this.hasComment || !updateComment)
            return;
        var isOtherSel = this.isOtherSelected;
        if (isOtherSel && !!this.prevOtherValue) {
            var oldOtherValue = this.prevOtherValue;
            this.prevOtherValue = undefined;
            this.otherValue = oldOtherValue;
        }
        if (!isOtherSel && !!this.otherValue) {
            if (this.getStoreOthersAsComment() && !this.autoOtherMode) {
                this.prevOtherValue = this.otherValue;
            }
            this.makeCommentEmpty = true;
            this.otherValueCore = "";
            this.setPropertyValue("comment", "");
        }
    }
    setValueCore(newValue) {
        super.setValueCore(newValue);
        if (this.makeCommentEmpty) {
            this.setCommentIntoData("");
            this.makeCommentEmpty = false;
        }
    }
    setNewValue(newValue) {
        newValue = this.valueFromData(newValue);
        if ((!this.choicesByUrl.isRunning &&
            !this.choicesByUrl.isWaitingForParameters) ||
            !this.isValueEmpty(newValue)) {
            this.cachedValueForUrlRequests = newValue;
        }
        super.setNewValue(newValue);
    }
    valueFromData(val) {
        let choiceitem = ItemValue.getItemByValue(this.activeChoices, val);
        if (!!choiceitem) {
            return choiceitem.value;
        }
        return super.valueFromData(val);
    }
    rendredValueFromData(val) {
        if (this.getStoreOthersAsComment())
            return val;
        return this.renderedValueFromDataCore(val);
    }
    rendredValueToData(val) {
        if (this.getStoreOthersAsComment())
            return val;
        return this.rendredValueToDataCore(val);
    }
    renderedValueFromDataCore(val) {
        if (!this.hasUnknownValue(val, true, false))
            return this.valueFromData(val);
        this.otherValue = val;
        return this.otherItem.value;
    }
    rendredValueToDataCore(val) {
        if (val == this.otherItem.value && this.needConvertRenderedOtherToDataValue()) {
            val = this.otherValue;
        }
        return val;
    }
    needConvertRenderedOtherToDataValue() {
        let val = this.otherValue;
        if (!val)
            return false;
        val = val.trim();
        if (!val)
            return false;
        return this.hasUnknownValue(val, true, false);
    }
    getIsQuestionReady() {
        return super.getIsQuestionReady() && !this.waitingChoicesByURL && !this.waitingGetChoiceDisplayValueResponse;
    }
    updateSelectedItemValues() {
        if (this.waitingGetChoiceDisplayValueResponse || !this.survey || this.isEmpty())
            return;
        const value = this.value;
        const valueArray = Array.isArray(value) ? value : [value];
        const hasItemWithoutValues = valueArray.some(val => !ItemValue.getItemByValue(this.choices, val));
        if (hasItemWithoutValues && (this.choicesLazyLoadEnabled || this.hasChoicesUrl)) {
            this.waitingGetChoiceDisplayValueResponse = true;
            this.updateIsReady();
            this.survey.getChoiceDisplayValue({
                question: this,
                values: valueArray,
                setItems: (displayValues, ...customValues) => {
                    this.waitingGetChoiceDisplayValueResponse = false;
                    if (!displayValues || !displayValues.length) {
                        this.updateIsReady();
                        return;
                    }
                    const items = displayValues.map((displayValue, index) => this.createItemValue(valueArray[index], displayValue));
                    this.setCustomValuesIntoItems(items, customValues);
                    if (Array.isArray(value)) {
                        this.selectedItemValues = items;
                    }
                    else {
                        this.selectedItemValues = items[0];
                    }
                    this.updateIsReady();
                }
            });
        }
    }
    setCustomValuesIntoItems(items, customValues) {
        if (!Array.isArray(customValues) || customValues.length === 0)
            return;
        customValues.forEach(customValue => {
            const vals = customValue.values;
            const propName = customValue.propertyName;
            if (Array.isArray(vals)) {
                for (let i = 0; i < items.length && i < vals.length; i++) {
                    items[i][propName] = vals[i];
                }
            }
        });
    }
    hasUnknownValue(val, includeOther = false, isFilteredChoices = true, checkEmptyValue = false) {
        if (!Array.isArray(val))
            return this.hasUnknownValueItem(val, includeOther, isFilteredChoices, checkEmptyValue);
        for (let i = 0; i < val.length; i++) {
            if (this.hasUnknownValueItem(val, includeOther, isFilteredChoices, checkEmptyValue))
                return true;
        }
        return false;
    }
    hasUnknownValueItem(val, includeOther = false, isFilteredChoices = true, checkEmptyValue = false) {
        if (!checkEmptyValue && this.isValueEmpty(val))
            return false;
        if (includeOther && val == this.otherItem.value)
            return false;
        if (this.showNoneItem && val == this.noneItem.value)
            return false;
        if (this.showRefuseItem && val == this.refuseItem.value)
            return false;
        if (this.showDontKnowItem && val == this.dontKnowItem.value)
            return false;
        var choices = isFilteredChoices
            ? this.getFilteredChoices()
            : this.activeChoices;
        return ItemValue.getItemByValue(choices, val) == null;
    }
    isValueDisabled(val) {
        var itemValue = ItemValue.getItemByValue(this.getFilteredChoices(), val);
        return !!itemValue && !itemValue.isEnabled;
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        this.updateVisibleChoices();
    }
    /**
     * An array of choice items that were added by a user. Applies only if the [`allowCustomChoices`](#allowCustomChoices) is set to `true` for this question.
     *
     * > Custom choices will only be stored temporarily for the duration of the current browser session. If you want to save them in a database or another data storage, handle the [`onCreateCustomChoiceItem`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onCreateCustomChoiceItem) event.
     * @hidefor QuestionImagePickerModel, QuestionRadiogroupModel, QuestionRankingModel, QuestionCheckboxModel
     */
    get customChoices() {
        return this.getPropertyValue("customChoices");
    }
    set customChoices(val) {
        this.setPropertyValue("customChoices", val);
    }
    /**
     * Configures access to a RESTful service that returns choice items. Refer to the [`ChoicesRestful`](https://surveyjs.io/form-library/documentation/choicesrestful) class description for more information. You can also specify additional application-wide settings using the [`settings.web`](https://surveyjs.io/form-library/documentation/api-reference/settings#web) object.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/dropdown-menu-load-data-from-restful-service/ (linkStyle))
     * @see choices
     * @see [settings.specialChoicesOrder](https://surveyjs.io/form-library/documentation/api-reference/settings#specialChoicesOrder)
     */
    get choicesByUrl() {
        return this.getPropertyValue("choicesByUrl");
    }
    set choicesByUrl(val) {
        if (!val)
            return;
        this.setNewRestfulProperty();
        this.choicesByUrl.fromJSON(val.toJSON());
    }
    /**
     * Gets or sets choice items. This property accepts an array of objects with the following structure:
     *
     * ```js
     * {
     *   "value": any, // A unique value to be saved in the survey results.
     *   "text": String, // A display text. This property supports Markdown. When `text` is undefined, `value` is used.
     *   "imageLink": String // A link to the image or video that represents this choice value. Applies only to Image Picker questions.
     *   "customProperty": any // Any property that you find useful.
     * }
     * ```
     *
     * To enable Markdown support for the `text` property, implement Markdown-to-HTML conversion in the [`onTextMarkdown`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onTextMarkdown) event handler. For an example, refer to the following demo: [Convert Markdown to HTML with markdown-it](https://surveyjs.io/form-library/examples/edit-survey-questions-markdown/).
     *
     * If you add custom properties, refer to the following help topic to learn how to serialize them into JSON: [Add Custom Properties to Property Grid](https://surveyjs.io/survey-creator/documentation/property-grid#add-custom-properties-to-the-property-grid).
     *
     * If you need to specify only the `value` property, you can set the `choices` property to an array of primitive values, for example, `[ "item1", "item2", "item3" ]`. These values are both saved in survey results and used as display text.
     *
     * [Dropdown Demo](https://surveyjs.io/form-library/examples/create-dropdown-menu-in-javascript/ (linkStyle))
     *
     * [Checkboxes Demo](https://surveyjs.io/form-library/examples/create-checkboxes-question-in-javascript/ (linkStyle))
     *
     * [Radio Button Group Demo](https://surveyjs.io/form-library/examples/single-select-radio-button-group/ (linkStyle))
     *
     * [Ranking Demo](https://surveyjs.io/form-library/examples/add-ranking-question-to-form/ (linkStyle))
     *
     * [Image Picker Demo](https://surveyjs.io/form-library/examples/image-picker-question/ (linkStyle))
     *
     * [Conditionally Display Choice Options](https://surveyjs.io/form-library/examples/how-to-conditionally-display-choice-options/ (linkStyle))
     * @see choicesByUrl
     * @see choicesFromQuestion
     * @see [settings.specialChoicesOrder](https://surveyjs.io/form-library/documentation/api-reference/settings#specialChoicesOrder)
     */
    get choices() {
        return this.getPropertyValue("choices");
    }
    set choices(newValue) {
        this.setPropertyValue("choices", newValue);
    }
    /**
     * Copies choice items from a specified question. Accepts a question name.
     *
     * If you specify this property, the [`choices`](#choices), [`choicesVisibleIf`](#choicesVisibleIf), [`choicesEnableIf`](#choicesEnableIf), and [`choicesOrder`](#choicesEnableIf) properties do not apply because their values are copied.
     *
     * In addition, you can specify the [`choicesFromQuestionMode`](#choicesFromQuestionMode) property if you do not want to copy all choice items.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/carry-forward-responses/ (linkStyle))
     */
    get choicesFromQuestion() {
        return this.getPropertyValue("choicesFromQuestion");
    }
    set choicesFromQuestion(val) {
        var question = this.getQuestionWithChoices();
        this.isLockVisibleChoices = !!question && question.name === val;
        if (!!question && question.name !== val) {
            question.removeDependedQuestion(this);
            if (this.isInDesignMode && !this.isLoadingFromJson && !!val) {
                this.setPropertyValue("choicesFromQuestion", undefined);
            }
        }
        this.setPropertyValue("choicesFromQuestion", val);
        this.isLockVisibleChoices = false;
    }
    /**
     * Specifies which choice items to copy from another question. Applies only when the [`choicesFromQuestion`](#choicesFromQuestion) property is specified.
     *
     * Possible values:
     *
     * - `"all"` (default) - Copies all choice items.
     * - `"selected"` - Copies only selected choice items.
     * - `"unselected"` - Copies only unselected choice items.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/carry-forward-responses/ (linkStyle))
     *
     * > Use the [`visibleChoices`](#visibleChoices) property to access copied choice items in code.
     */
    get choicesFromQuestionMode() {
        return this.getPropertyValue("choicesFromQuestionMode");
    }
    set choicesFromQuestionMode(val) {
        this.setPropertyValue("choicesFromQuestionMode", val);
    }
    /**
     * Specifies which matrix column or dynamic panel question supplies choice values. Use this property to construct choice items based on cell values in Dynamic Matrix and question values in Dynamic Panel.
     *
     * Each choice item consists of a value saved in survey results and a text displayed in the UI. To construct a choice item, assign the `name` of a Dynamic Matrix or Dynamic Panel to the [`choicesFromQuestion`](#choicesFromQuestion) property and specify which dynamic panel question or matrix column supplies values and which provides texts. Use the `choiceValuesFromQuestion` and [`choiceTextsFromQuestion`](#choiceTextsFromQuestion) properties for this purpose. If a choice text is empty, a choice value is used as a display text and saved in survey results.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/pipe-answers-from-dynamic-matrix-or-panel/ (linkStyle))
     */
    get choiceValuesFromQuestion() {
        return this.getPropertyValue("choiceValuesFromQuestion");
    }
    set choiceValuesFromQuestion(val) {
        this.setPropertyValue("choiceValuesFromQuestion", val);
    }
    /**
     * Specifies which matrix column or dynamic panel question supplies choice texts. Use this property to construct choice items based on cell values in Dynamic Matrix and question values in Dynamic Panel.
     *
     * Each choice item consists of a value saved in survey results and a text displayed in the UI. To construct a choice item, assign the `name` of a Dynamic Matrix or Dynamic Panel to the [`choicesFromQuestion`](#choicesFromQuestion) property and specify which dynamic panel question or matrix column supplies values and which provides texts. Use the [`choiceValuesFromQuestion`](#choiceValuesFromQuestion) and `choiceTextsFromQuestion` properties for this purpose. If a choice text is empty, a choice value is used as a display text and saved in survey results.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/pipe-answers-from-dynamic-matrix-or-panel/ (linkStyle))
     */
    get choiceTextsFromQuestion() {
        return this.getPropertyValue("choiceTextsFromQuestion");
    }
    set choiceTextsFromQuestion(val) {
        this.setPropertyValue("choiceTextsFromQuestion", val);
    }
    /**
     * Specifies whether to hide the question if no choice items are visible.
     *
     * This property is useful if you show or hide choice items at runtime based on a [condition](https://surveyjs.io/form-library/documentation/questionselectbase#choicesVisibleIf).
     */
    get hideIfChoicesEmpty() {
        return this.getPropertyValue("hideIfChoicesEmpty");
    }
    set hideIfChoicesEmpty(val) {
        this.setPropertyValue("hideIfChoicesEmpty", val);
    }
    /**
     * Specifies whether to keep values that cannot be assigned to this question, for example, choices unlisted in the `choices` array.
     *
     * > This property cannot be specified in the survey JSON schema. Use dot notation to specify it.
     * @see clearIncorrectValues
     */
    get keepIncorrectValues() {
        return this.getPropertyValue("keepIncorrectValues", false);
    }
    set keepIncorrectValues(val) {
        this.setPropertyValue("keepIncorrectValues", val);
    }
    get storeOthersAsComment() {
        return this.getPropertyValue("storeOthersAsComment");
    }
    set storeOthersAsComment(val) {
        this.setPropertyValue("storeOthersAsComment", val);
    }
    /**
     * Specifies the sort order of choice items.
     *
     * Possible values:
     *
     * - `"none"` (default) - Preserves the original order of choice items.
     * - `"asc"`- Sorts choice items in ascending order.
     * - `"desc"`- Sorts choice items in ascending order.
     * - `"random"` - Displays choice items in random order.
     * @see [settings.specialChoicesOrder](https://surveyjs.io/form-library/documentation/api-reference/settings#specialChoicesOrder)
     */
    get choicesOrder() {
        return this.getPropertyValue("choicesOrder");
    }
    set choicesOrder(val) {
        val = val.toLowerCase();
        if (val == this.choicesOrder)
            return;
        this.setPropertyValue("choicesOrder", val);
        this.onVisibleChoicesChanged();
    }
    /**
     * Gets or sets a caption for the "Other" choice item.
     * @see showOtherItem
     */
    get otherText() {
        return this.getLocalizableStringText("otherText");
    }
    set otherText(val) {
        this.setLocalizableStringText("otherText", val);
        this.onVisibleChoicesChanged();
    }
    get locOtherText() {
        return this.getLocalizableString("otherText");
    }
    /**
     * Displays the "Select All", "None", and "Other" choices on individual rows.
     *
     * [Checkboxes Demo](https://surveyjs.io/form-library/examples/create-checkboxes-question-in-javascript/ (linkStyle))
     *
     * [Radio Button Group Demo](https://surveyjs.io/form-library/examples/single-select-radio-button-group/ (linkStyle))
     * @see showNoneItem
     * @see showOtherItem
     * @see [settings.specialChoicesOrder](https://surveyjs.io/form-library/documentation/api-reference/settings#specialChoicesOrder)
     */
    get separateSpecialChoices() { return this.getPropertyValue("separateSpecialChoices"); }
    set separateSpecialChoices(val) { this.setPropertyValue("separateSpecialChoices", val); }
    /**
     * A placeholder for the comment area. Applies when the `showOtherItem` or `showCommentArea` property is `true`.
     * @see showOtherItem
     * @see showCommentArea
     */
    get otherPlaceholder() { return this.getLocalizableStringText("otherPlaceholder"); }
    set otherPlaceholder(val) { this.setLocalizableStringText("otherPlaceholder", val); }
    get locOtherPlaceholder() { return this.getLocalizableString("otherPlaceholder"); }
    get otherPlaceHolder() {
        return this.otherPlaceholder;
    }
    set otherPlaceHolder(newValue) {
        this.otherPlaceholder = newValue;
    }
    /**
     * Gets or sets an error message displayed when users select the "Other" choice item but leave the comment area empty.
     * @see showOtherItem
     */
    get otherErrorText() {
        return this.getLocalizableStringText("otherErrorText");
    }
    set otherErrorText(val) {
        this.setLocalizableStringText("otherErrorText", val);
    }
    get locOtherErrorText() {
        return this.getLocalizableString("otherErrorText");
    }
    /**
     * An array of visible choice items. Includes the "Select All", "Other", and "None" choice items if they are visible. Items are sorted according to the `choicesOrder` value.
     * @see showNoneItem
     * @see showOtherItem
     * @see choicesOrder
     * @see choices
     * @see enabledChoices
     */
    get visibleChoices() {
        return this.getPropertyValue("visibleChoices");
    }
    /**
     * An array of choice items with which users can interact. Includes the "Select All", "Other", and "None" choice items if they are not disabled. Items are sorted according to the `choicesOrder` value.
     * @see showNoneItem
     * @see showOtherItem
     * @see choicesOrder
     * @see choices
     * @see visibleChoices
     */
    get enabledChoices() {
        var res = [];
        var items = this.visibleChoices;
        for (var i = 0; i < items.length; i++) {
            if (items[i].isEnabled)
                res.push(items[i]);
        }
        return res;
    }
    updateVisibleChoices() {
        if (this.isLoadingFromJson || this.isDisposed)
            return;
        var calcValue = this.calcVisibleChoices();
        var newValue = new Array();
        (calcValue || []).forEach(choice => newValue.push(choice));
        const oldValue = this.visibleChoices;
        if (!this.isTwoValueEquals(oldValue, newValue) || this.choicesLazyLoadEnabled) {
            this.setArrayPropertyDirectly("visibleChoices", newValue);
            this.updateRenderedChoices();
        }
    }
    calcVisibleChoices() {
        let res = new Array();
        this.customChoices.forEach(choice => res.push(choice));
        this.getFilteredChoices().forEach(choice => res.push(choice));
        res = this.sortArrayByChoicesOrder(res);
        this.addToVisibleChoices(res, this.isAddDefaultItems);
        return res;
    }
    setCanShowOptionItemCallback(func) {
        this.canShowOptionItemCallback = func;
        if (!!func) {
            this.onVisibleChoicesChanged();
        }
    }
    get newItem() { return this.newItemValue; }
    addToVisibleChoices(items, isAddAll) {
        this.headItemsCount = 0;
        this.footItemsCount = 0;
        if (!this.isEmptyActiveChoicesInDesign) {
            this.addNewItemToVisibleChoices(items, isAddAll);
        }
        const dict = new Array();
        this.addNonChoicesItems(dict, isAddAll);
        dict.sort((a, b) => {
            if (a.index === b.index)
                return 0;
            return a.index < b.index ? -1 : 1;
        });
        for (let i = 0; i < dict.length; i++) {
            const rec = dict[i];
            if (rec.index < 0) {
                items.splice(i, 0, rec.item);
                this.headItemsCount++;
            }
            else {
                items.push(rec.item);
                this.footItemsCount++;
            }
        }
    }
    addNewItemToVisibleChoices(items, isAddAll) {
        if (!isAddAll)
            return;
        if (!this.newItemValue) {
            this.newItemValue = this.createItemValue("newitem"); //TODO
            this.newItemValue.isGhost = true;
            this.newItemValue.registerFunctionOnPropertyValueChanged("isVisible", () => {
                this.updateVisibleChoices();
            });
        }
        if (this.newItemValue.isVisible && !this.isUsingCarryForward
            && this.canShowOptionItem(this.newItemValue, isAddAll, false)) {
            this.footItemsCount = 1;
            items.push(this.newItemValue);
        }
    }
    addNonChoicesItems(dict, isAddAll) {
        if (this.supportNone()) {
            this.addNonChoiceItem(dict, this.noneItem, isAddAll, this.showNoneItem, settings.specialChoicesOrder.noneItem);
        }
        if (this.supportRefuse()) {
            this.addNonChoiceItem(dict, this.refuseItem, isAddAll, this.showRefuseItem, settings.specialChoicesOrder.refuseItem);
        }
        if (this.supportDontKnow()) {
            this.addNonChoiceItem(dict, this.dontKnowItem, isAddAll, this.showDontKnowItem, settings.specialChoicesOrder.dontKnowItem);
        }
        if (this.supportOther()) {
            this.addNonChoiceItem(dict, this.otherItem, isAddAll, this.hasOther, settings.specialChoicesOrder.otherItem);
        }
    }
    addNonChoiceItem(dict, item, isAddAll, showItem, order) {
        if (this.canShowOptionItem(item, isAddAll, showItem)) {
            order.forEach(val => dict.push({ index: val, item: item }));
        }
    }
    canShowOptionItem(item, isAddAll, hasItem) {
        let res = (isAddAll && (!!this.canShowOptionItemCallback ? this.canShowOptionItemCallback(item) : true)) || hasItem;
        if (this.canSurveyChangeItemVisibility()) {
            const calc = this.changeItemVisibility();
            return calc(item, res);
        }
        return res;
    }
    isItemInList(item) {
        if (item === this.otherItem)
            return this.hasOther;
        if (item === this.noneItem)
            return this.showNoneItem;
        if (item === this.refuseItem)
            return this.showRefuseItem;
        if (item === this.dontKnowItem)
            return this.showDontKnowItem;
        if (item === this.newItemValue)
            return false;
        return true;
    }
    get isAddDefaultItems() {
        return settings.showDefaultItemsInCreator && this.isInDesignMode &&
            !this.customWidget;
    }
    getPlainData(options = {
        includeEmpty: true,
        includeQuestionTypes: false,
    }) {
        var questionPlainData = super.getPlainData(options);
        if (!!questionPlainData) {
            var values = Array.isArray(this.value) ? this.value : [this.value];
            questionPlainData.isNode = true;
            questionPlainData.data = (questionPlainData.data || []).concat(values.map((dataValue, index) => {
                var choice = ItemValue.getItemByValue(this.visibleChoices, dataValue);
                var choiceDataItem = {
                    name: index,
                    title: this.getLocalizationString("choices_Choice"),
                    value: dataValue,
                    displayValue: this.getChoicesDisplayValue(this.visibleChoices, dataValue),
                    getString: (val) => typeof val === "object" ? JSON.stringify(val) : val,
                    isNode: false,
                };
                if (!!choice) {
                    (options.calculations || []).forEach((calculation) => {
                        choiceDataItem[calculation.propertyName] =
                            choice[calculation.propertyName];
                    });
                }
                if (this.isOtherSelected && this.otherItemValue === choice) {
                    choiceDataItem.isOther = true;
                    choiceDataItem.displayValue = this.otherValue;
                }
                return choiceDataItem;
            }));
        }
        return questionPlainData;
    }
    getDisplayValueCore(keysAsText, value) {
        if (!this.useDisplayValuesInDynamicTexts)
            return value;
        return this.getChoicesDisplayValue(this.visibleChoices, value);
    }
    getDisplayValueEmpty() {
        return ItemValue.getTextOrHtmlByValue(this.visibleChoices, undefined);
    }
    getChoicesDisplayValue(items, val) {
        if (val == this.otherItemValue.value)
            return this.otherValue ? this.otherValue : this.locOtherText.textOrHtml;
        const selItem = this.getSingleSelectedItem();
        if (!!selItem && this.isTwoValueEquals(selItem.value, val))
            return selItem.locText.textOrHtml;
        var str = ItemValue.getTextOrHtmlByValue(items, val);
        return str == "" && val ? val : str;
    }
    getDisplayArrayValue(keysAsText, value, onGetValueCallback) {
        var items = this.visibleChoices;
        var strs = [];
        const vals = [];
        for (var i = 0; i < value.length; i++) {
            vals.push(!onGetValueCallback ? value[i] : onGetValueCallback(i));
        }
        if (Helpers.isTwoValueEquals(this.value, vals)) {
            this.getMultipleSelectedItems().forEach((item, index) => strs.push(this.getItemDisplayValue(item, vals[index])));
        }
        if (strs.length === 0) {
            for (var i = 0; i < vals.length; i++) {
                let valStr = this.getChoicesDisplayValue(items, vals[i]);
                if (valStr) {
                    strs.push(valStr);
                }
            }
        }
        return strs.join(settings.choicesSeparator);
    }
    getItemDisplayValue(item, val) {
        if (item === this.otherItem) {
            if (this.hasOther && this.showCommentArea && !!val) {
                return val;
            }
            if (this.comment) {
                return this.comment;
            }
        }
        return item.locText.textOrHtml;
    }
    getFilteredChoices() {
        return this.filteredChoicesValue
            ? this.filteredChoicesValue
            : this.activeChoices;
    }
    get activeChoices() {
        const question = this.getCarryForwardQuestion();
        if (this.carryForwardQuestionType === "select") {
            question.addDependedQuestion(this);
            return this.getChoicesFromSelectQuestion(question);
        }
        if (this.carryForwardQuestionType === "array") {
            question.addDependedQuestion(this);
            return this.getChoicesFromArrayQuestion(question);
        }
        if (this.isEmptyActiveChoicesInDesign)
            return [];
        return this.choicesFromUrl ? this.choicesFromUrl : this.getChoices();
    }
    get isMessagePanelVisible() {
        return this.getPropertyValue("isMessagePanelVisible", false);
    }
    set isMessagePanelVisible(val) {
        this.setPropertyValue("isMessagePanelVisible", val);
    }
    get isEmptyActiveChoicesInDesign() {
        return this.isInDesignMode && (this.hasChoicesUrl || this.isMessagePanelVisible);
    }
    getCarryForwardQuestion(data) {
        const question = this.findCarryForwardQuestion(data);
        const selBaseQuestion = this.getQuestionWithChoicesCore(question);
        const arrayQuestion = !selBaseQuestion ? this.getQuestionWithArrayValue(question) : null;
        this.setCarryForwardQuestionType(!!selBaseQuestion, !!arrayQuestion);
        return !!selBaseQuestion || !!arrayQuestion ? question : null;
    }
    getIsReadyDependsOn() {
        const res = super.getIsReadyDependsOn();
        if (this.carryForwardQuestion) {
            res.push(this.carryForwardQuestion);
        }
        return res;
    }
    getQuestionWithChoices() {
        return this.getQuestionWithChoicesCore(this.findCarryForwardQuestion());
    }
    findCarryForwardQuestion(data) {
        var _a;
        if (!data) {
            data = this.data || ((_a = this.parentQuestion) === null || _a === void 0 ? void 0 : _a.data);
        }
        this.carryForwardQuestion = null;
        if (this.choicesFromQuestion && data) {
            this.carryForwardQuestion = data.findQuestionByName(this.choicesFromQuestion);
        }
        return this.carryForwardQuestion;
    }
    getQuestionWithChoicesCore(question) {
        if (!!question && !!question.visibleChoices && (Serializer.isDescendantOf(question.getType(), "selectbase")) && question !== this)
            return question;
        return null;
    }
    getQuestionWithArrayValue(question) {
        return !!question && question.isValueArray ? question : null;
    }
    getChoicesFromArrayQuestion(question) {
        if (this.isInDesignMode)
            return [];
        const val = question.value;
        if (!Array.isArray(val))
            return [];
        const res = [];
        for (var i = 0; i < val.length; i++) {
            const obj = val[i];
            if (!Helpers.isValueObject(obj))
                continue;
            const key = this.getValueKeyName(obj);
            if (!!key && !this.isValueEmpty(obj[key])) {
                const text = !!this.choiceTextsFromQuestion ? obj[this.choiceTextsFromQuestion] : undefined;
                res.push(this.createItemValue(obj[key], text));
            }
        }
        return res;
    }
    getValueKeyName(obj) {
        if (this.choiceValuesFromQuestion)
            return this.choiceValuesFromQuestion;
        const keys = Object.keys(obj);
        return keys.length > 0 ? keys[0] : undefined;
    }
    getChoicesFromSelectQuestion(question) {
        if (this.isInDesignMode)
            return [];
        const res = [];
        var isSelected = this.choicesFromQuestionMode == "selected"
            ? true
            : this.choicesFromQuestionMode == "unselected"
                ? false
                : undefined;
        const choices = question.visibleChoices;
        for (var i = 0; i < choices.length; i++) {
            if (question.isBuiltInChoice(choices[i]))
                continue;
            if (isSelected === undefined) {
                res.push(this.copyChoiceItem(choices[i]));
                continue;
            }
            var itemsSelected = question.isItemSelected(choices[i]);
            if ((itemsSelected && isSelected) || (!itemsSelected && !isSelected)) {
                res.push(this.copyChoiceItem(choices[i]));
            }
        }
        if (this.choicesFromQuestionMode === "selected" && !this.showOtherItem && question.isOtherSelected && !!question.comment) {
            res.push(this.createItemValue(question.otherItem.value, question.comment));
        }
        return res;
    }
    copyChoiceItem(item) {
        const res = this.createItemValue(item.value);
        res.setData(item);
        return res;
    }
    get hasActiveChoices() {
        var choices = this.visibleChoices;
        if (!choices || choices.length == 0) {
            this.onVisibleChoicesChanged();
            choices = this.visibleChoices;
        }
        for (var i = 0; i < choices.length; i++) {
            if (!this.isBuiltInChoice(choices[i]))
                return true;
        }
        return false;
    }
    isBuiltInChoice(item) {
        return [this.otherItem, this.noneItem, this.refuseItem, this.dontKnowItem, this.newItemValue].indexOf(item) > -1;
    }
    isNoneItem(item) {
        return item.isExclusive === true;
    }
    getChoices() {
        return this.choices;
    }
    /**
     * Specifies whether to display the "Other" choice item.
     *
     * [Dropdown Demo](https://surveyjs.io/form-library/examples/create-dropdown-menu-in-javascript/ (linkStyle))
     *
     * [Checkboxes Demo](https://surveyjs.io/form-library/examples/create-checkboxes-question-in-javascript/ (linkStyle))
     *
     * [Radio Button Group Demo](https://surveyjs.io/form-library/examples/single-select-radio-button-group/ (linkStyle))
     * @see otherText
     * @see otherItem
     * @see otherErrorText
     * @see showCommentArea
     * @see [settings.specialChoicesOrder](https://surveyjs.io/form-library/documentation/api-reference/settings#specialChoicesOrder)
     */
    get showOtherItem() {
        return this.getPropertyValue("showOtherItem", false);
    }
    set showOtherItem(val) {
        if (!this.supportOther() || this.showOtherItem == val)
            return;
        this.setPropertyValue("showOtherItem", val);
        this.onVisibleChoicesChanged();
    }
    get hasOther() {
        return this.showOtherItem;
    }
    set hasOther(val) {
        this.showOtherItem = val;
    }
    get requireUpdateCommentValue() { return this.hasComment || this.showOtherItem; }
    supportOther() {
        return this.isSupportProperty("showOtherItem");
    }
    supportNone() {
        return this.isSupportProperty("showNoneItem");
    }
    supportRefuse() {
        return this.isSupportProperty("showRefuseItem");
    }
    supportDontKnow() {
        return this.isSupportProperty("showDontKnowItem");
    }
    isSupportProperty(propName) {
        return (!this.isDesignMode ||
            this.getPropertyByName(propName).visible);
    }
    onCheckForErrors(errors, isOnValueChanged, fireCallback) {
        super.onCheckForErrors(errors, isOnValueChanged, fireCallback);
        if (!this.hasOther || !this.isOtherSelected || this.otherValue
            || isOnValueChanged && !this.prevOtherErrorValue)
            return;
        const otherEmptyError = new OtherEmptyError(this.otherErrorText, this);
        otherEmptyError.onUpdateErrorTextCallback = err => { err.text = this.otherErrorText; };
        errors.push(otherEmptyError);
    }
    setSurveyImpl(value, isLight) {
        this.isRunningChoices = true;
        super.setSurveyImpl(value, isLight);
        this.isRunningChoices = false;
        this.runChoicesByUrl();
        if (this.isAddDefaultItems) {
            this.updateVisibleChoices();
        }
    }
    setSurveyCore(value) {
        super.setSurveyCore(value);
        if (!!value && !!this.choicesFromQuestion) {
            this.onVisibleChoicesChanged();
        }
    }
    getStoreOthersAsComment() {
        if (this.isSettingDefaultValue)
            return false;
        if (this.showCommentArea)
            return false;
        return (this.storeOthersAsComment === true ||
            (this.storeOthersAsComment == "default" &&
                (this.survey != null ? this.survey.storeOthersAsComment : true)) ||
            (this.hasChoicesUrl && !this.choicesFromUrl));
    }
    onSurveyLoad() {
        this.runChoicesByUrl();
        this.onVisibleChoicesChanged();
        super.onSurveyLoad();
    }
    onAnyValueChanged(name, questionName) {
        super.onAnyValueChanged(name, questionName);
        if (name != this.getValueName()) {
            this.runChoicesByUrl();
        }
        const chQuestion = this.choicesFromQuestion;
        if (!!name && chQuestion && (name === chQuestion || questionName === chQuestion)) {
            this.onVisibleChoicesChanged();
            this.clearIncorrectValues();
        }
    }
    updateValueFromSurvey(newValue, clearData) {
        var newComment = "";
        if (this.hasOther && this.activeChoices.length > 0 &&
            !this.isRunningChoices &&
            !this.choicesByUrl.isRunning &&
            this.getStoreOthersAsComment()) {
            if (this.hasUnknownValue(newValue) && !this.getHasOther(newValue)) {
                newComment = this.getCommentFromValue(newValue);
                newValue = this.setOtherValueIntoValue(newValue);
            }
            else {
                if (this.data) {
                    newComment = this.data.getComment(this.getValueName());
                }
            }
        }
        super.updateValueFromSurvey(newValue, clearData);
        if ((this.isRunningChoices || this.choicesByUrl.isRunning) && !this.isEmpty()) {
            this.cachedValueForUrlRequests = this.value;
        }
        if (!!newComment) {
            this.setNewComment(newComment);
        }
    }
    getCommentFromValue(newValue) {
        return newValue;
    }
    setOtherValueIntoValue(newValue) {
        return this.otherItem.value;
    }
    onOtherValueInput(event) {
        if (this.isInputTextUpdate) {
            if (event.target) {
                this.otherValue = event.target.value;
            }
        }
        else {
            this.updateCommentElements();
        }
    }
    onOtherValueChange(event) {
        this.otherValue = event.target.value;
        if (this.otherValue !== event.target.value) {
            event.target.value = this.otherValue;
        }
    }
    runChoicesByUrl() {
        this.updateIsUsingRestful();
        if (!this.choicesByUrl || this.isLoadingFromJson || this.isRunningChoices || this.isInDesignMode)
            return;
        var processor = this.surveyImpl
            ? this.surveyImpl.getTextProcessor()
            : this.textProcessor;
        if (!processor)
            processor = this.survey;
        if (!processor)
            return;
        this.updateIsReady();
        this.isRunningChoices = true;
        this.choicesByUrl.run(processor);
        this.isRunningChoices = false;
    }
    onBeforeSendRequest() {
        if (settings.web.disableQuestionWhileLoadingChoices === true && !this.isReadOnly) {
            this.enableOnLoadingChoices = true;
            this.readOnly = true;
        }
    }
    onLoadChoicesFromUrl(array) {
        if (this.enableOnLoadingChoices) {
            this.readOnly = false;
        }
        const errors = [];
        if (!this.isReadOnly) {
            if (this.choicesByUrl && this.choicesByUrl.error) {
                errors.push(this.choicesByUrl.error);
            }
        }
        var newChoices = null;
        var checkCachedValuesOnExisting = true;
        if (this.isFirstLoadChoicesFromUrl &&
            !this.cachedValueForUrlRequests &&
            this.defaultValue) {
            this.cachedValueForUrlRequests = this.defaultValue;
            checkCachedValuesOnExisting = false;
        }
        if (this.isValueEmpty(this.cachedValueForUrlRequests)) {
            this.cachedValueForUrlRequests = this.value;
        }
        var cachedValues = this.createCachedValueForUrlRequests(this.cachedValueForUrlRequests, checkCachedValuesOnExisting);
        if (array && (array.length > 0 || this.choicesByUrl.allowEmptyResponse)) {
            newChoices = new Array();
            ItemValue.setData(newChoices, array);
        }
        if (!!newChoices) {
            for (var i = 0; i < newChoices.length; i++) {
                newChoices[i].locOwner = this;
            }
        }
        this.setChoicesFromUrl(newChoices, errors, cachedValues);
    }
    canAvoidSettChoicesFromUrl(newChoices) {
        if (this.isFirstLoadChoicesFromUrl)
            return false;
        const chocesAreEmpty = !newChoices || Array.isArray(newChoices) && newChoices.length === 0;
        if (chocesAreEmpty && !this.isEmpty())
            return false;
        return Helpers.isTwoValueEquals(this.choicesFromUrl, newChoices);
    }
    setChoicesFromUrl(newChoices, errors, cachedValues) {
        if (this.canAvoidSettChoicesFromUrl(newChoices))
            return;
        this.isFirstLoadChoicesFromUrl = false;
        this.choicesFromUrl = newChoices;
        this.filterItems();
        this.onVisibleChoicesChanged();
        if (newChoices) {
            var newValue = this.updateCachedValueForUrlRequests(cachedValues, newChoices);
            if (!!newValue && !this.isReadOnly) {
                var hasChanged = !this.isTwoValueEquals(this.value, newValue.value);
                try {
                    if (!this.isValueEmpty(newValue.value)) {
                        this.allowNotifyValueChanged = false;
                        this.setQuestionValue(undefined, true, false);
                    }
                    this.allowNotifyValueChanged = hasChanged;
                    if (hasChanged) {
                        this.value = newValue.value;
                    }
                    else {
                        this.setQuestionValue(newValue.value);
                    }
                }
                finally {
                    this.allowNotifyValueChanged = true;
                }
            }
        }
        if (!this.isReadOnly && !newChoices && !this.isFirstLoadChoicesFromUrl) {
            this.value = null;
        }
        this.errors = errors;
        this.choicesLoaded();
    }
    createCachedValueForUrlRequests(val, checkOnExisting) {
        if (this.isValueEmpty(val))
            return null;
        if (Array.isArray(val)) {
            var res = [];
            for (var i = 0; i < val.length; i++) {
                res.push(this.createCachedValueForUrlRequests(val[i], true));
            }
            return res;
        }
        var isExists = checkOnExisting ? !this.hasUnknownValue(val) : true;
        return { value: val, isExists: isExists };
    }
    updateCachedValueForUrlRequests(val, newChoices) {
        if (this.isValueEmpty(val))
            return null;
        if (Array.isArray(val)) {
            var res = [];
            for (var i = 0; i < val.length; i++) {
                var updatedValue = this.updateCachedValueForUrlRequests(val[i], newChoices);
                if (updatedValue && !this.isValueEmpty(updatedValue.value)) {
                    var newValue = updatedValue.value;
                    var item = ItemValue.getItemByValue(newChoices, updatedValue.value);
                    if (!!item) {
                        newValue = item.value;
                    }
                    res.push(newValue);
                }
            }
            return { value: res };
        }
        var value = val.isExists && this.hasUnknownValue(val.value) ? null : val.value;
        var item = ItemValue.getItemByValue(newChoices, value);
        if (!!item) {
            value = item.value;
        }
        return { value: value };
    }
    updateChoicesDependedQuestions() {
        if (this.isLoadingFromJson || this.isUpdatingChoicesDependedQuestions ||
            !this.allowNotifyValueChanged || this.choicesByUrl.isRunning)
            return;
        this.isUpdatingChoicesDependedQuestions = true;
        this.updateDependedQuestions();
        this.isUpdatingChoicesDependedQuestions = false;
    }
    updateDependedQuestion() {
        this.onVisibleChoicesChanged();
        this.clearIncorrectValues();
    }
    onSurveyValueChanged(newValue) {
        super.onSurveyValueChanged(newValue);
        this.updateChoicesDependedQuestions();
    }
    onVisibleChoicesChanged() {
        if (this.isLoadingFromJson || this.isLockVisibleChoices)
            return;
        this.updateVisibleChoices();
        this.onVisibleChanged();
        if (!!this.visibleChoicesChangedCallback) {
            this.visibleChoicesChangedCallback();
        }
        this.updateChoicesDependedQuestions();
    }
    isVisibleCore() {
        const superVal = super.isVisibleCore();
        if (!this.hideIfChoicesEmpty || !superVal)
            return superVal;
        var choices = this.isUsingCarryForward ? this.visibleChoices : this.getFilteredChoices();
        return !choices || choices.length > 0;
    }
    sortArrayByChoicesOrder(array) {
        const res = array.slice();
        if (this.isInDesignMode)
            return res;
        const order = this.choicesOrder.toLowerCase();
        if (order == "asc")
            return this.sortArray(res, 1);
        if (order == "desc")
            return this.sortArray(res, -1);
        if (order == "random")
            return this.randomizeArray(res);
        return res;
    }
    sortArray(array, mult) {
        return array.sort(function (a, b) {
            return Helpers.compareStrings(a.calculatedText, b.calculatedText) * mult;
        });
    }
    randomizeArray(array) {
        return Helpers.randomizeArray(array);
    }
    get hasChoicesUrl() {
        return this.choicesByUrl && !!this.choicesByUrl.url;
    }
    clearIncorrectValues() {
        if (!this.canClearIncorrectValues() || !this.hasValueToClearIncorrectValues())
            return;
        if (this.clearIncorrectValuesCallback) {
            this.clearIncorrectValuesCallback();
        }
        else {
            this.clearIncorrectValuesCore();
        }
    }
    canClearIncorrectValues() {
        if (this.canAddCustomChoices())
            return false;
        if (this.carryForwardQuestion && !this.carryForwardQuestion.isReady)
            return false;
        if (!!this.survey && this.survey.questionsByValueName(this.getValueName()).length > 1)
            return false;
        if (this.hasChoicesUrl && (!this.choicesFromUrl || this.choicesFromUrl.length == 0))
            return false;
        return true;
    }
    canAddCustomChoices() {
        return false;
    }
    hasValueToClearIncorrectValues() {
        if (!!this.survey && this.survey.keepIncorrectValues)
            return false;
        return !this.keepIncorrectValues && !this.isEmpty();
    }
    clearValueIfInvisibleCore(reason) {
        super.clearValueIfInvisibleCore(reason);
        this.clearIncorrectValues();
    }
    /**
     * Returns `true` if a passed choice item is selected.
     *
     * To obtain a choice item to check, use the `noneItem` or `otherItem` property or the `choices` array.
     * @param item A choice item.
     * @see noneItem
     * @see otherItem
     * @see choices
     */
    isItemSelected(item) {
        if (item === this.otherItem)
            return this.isOtherSelected;
        return this.isItemSelectedCore(item);
    }
    isItemSelectedCore(item) {
        return item.value === this.value;
    }
    clearDisabledValues() {
        if (!this.survey || !this.survey.clearDisabledChoices)
            return;
        this.clearDisabledValuesCore();
    }
    clearIncorrectValuesCore() {
        var val = this.value;
        if (this.canClearValueAnUnknown(val)) {
            this.clearValue(true);
        }
    }
    canClearValueAnUnknown(val) {
        if (!this.getStoreOthersAsComment() && this.isOtherSelected)
            return false;
        return this.hasUnknownValue(val, true, true, true);
    }
    clearDisabledValuesCore() {
        if (this.isValueDisabled(this.value)) {
            this.clearValue(true);
        }
    }
    clearUnusedValues() {
        super.clearUnusedValues();
        if (!this.isOtherSelected) {
            this.otherValue = "";
        }
        if (!this.showCommentArea && (!this.getStoreOthersAsComment() && !this.isOtherSelected)) {
            this.comment = "";
        }
    }
    getColumnClass() {
        return new CssClassBuilder()
            .append(this.cssClasses.column)
            .append("sv-q-column-" + this.colCount, this.hasColumns)
            .toString();
    }
    getItemIndex(item) {
        return this.visibleChoices.indexOf(item);
    }
    getItemClass(item) {
        const options = { item: item };
        var res = this.getItemClassCore(item, options);
        options.css = res;
        if (!!this.survey) {
            this.survey.updateChoiceItemCss(this, options);
        }
        return options.css;
    }
    getCurrentColCount() {
        return this.colCount;
    }
    getItemClassCore(item, options) {
        const builder = new CssClassBuilder()
            .append(this.cssClasses.item)
            .append(this.cssClasses.itemInline, !this.hasColumns && this.colCount === 0)
            .append("sv-q-col-" + this.getCurrentColCount(), !this.hasColumns && this.colCount !== 0)
            .append(this.cssClasses.itemOnError, this.hasCssError());
        const readOnlyStyles = this.getIsDisableAndReadOnlyStyles(!item.isEnabled);
        const isReadOnly = readOnlyStyles[0];
        const isDisabled = readOnlyStyles[1];
        const isChecked = this.isItemSelected(item) ||
            (this.isOtherSelected && this.otherItem.value === item.value);
        const allowHover = !isDisabled && !isChecked && !(!!this.survey && this.survey.isDesignMode);
        const isNone = item === this.noneItem;
        options.isDisabled = isDisabled || isReadOnly;
        options.isChecked = isChecked;
        options.isNone = isNone;
        return builder
            .append(this.cssClasses.itemDisabled, isDisabled)
            .append(this.cssClasses.itemReadOnly, isReadOnly)
            .append(this.cssClasses.itemPreview, this.isPreviewStyle)
            .append(this.cssClasses.itemChecked, isChecked)
            .append(this.cssClasses.itemHover, allowHover)
            .append(this.cssClasses.itemNone, isNone)
            .toString();
    }
    getLabelClass(item) {
        return new CssClassBuilder()
            .append(this.cssClasses.label)
            .append(this.cssClasses.labelChecked, this.isItemSelected(item))
            .toString();
    }
    getControlLabelClass(item) {
        return new CssClassBuilder()
            .append(this.cssClasses.controlLabel)
            .append(this.cssClasses.controlLabelChecked, this.isItemSelected(item))
            .toString() || undefined;
    }
    updateRenderedChoices() {
        this.renderedChoices = this.onGetRenderedChoicesCallback ? this.onGetRenderedChoicesCallback(this.visibleChoices) : this.visibleChoices;
    }
    getRenderedChoicesAnimationOptions() {
        return {
            isAnimationEnabled: () => {
                return this.animationAllowed;
            },
            getRerenderEvent: () => {
                return this.onElementRerendered;
            },
            getKey: (item) => item != this.newItemValue ? item.value : this.newItemValue,
            getLeaveOptions: (item) => {
                let cssClass = this.cssClasses.itemLeave;
                if (this.hasColumns) {
                    const index = this.bodyItems.indexOf(item);
                    if (index !== -1 && index !== this.bodyItems.length - 1) {
                        cssClass = "";
                    }
                }
                return {
                    cssClass,
                    onBeforeRunAnimation: prepareElementForVerticalAnimation,
                    onAfterRunAnimation: cleanHtmlElementAfterAnimation
                };
            },
            getAnimatedElement: (item) => {
                return item.getRootElement();
            },
            getEnterOptions: (item) => {
                let cssClass = this.cssClasses.itemEnter;
                if (this.hasColumns) {
                    const index = this.bodyItems.indexOf(item);
                    if (index !== -1 && index !== this.bodyItems.length - 1) {
                        cssClass = "";
                    }
                }
                return {
                    cssClass: cssClass,
                    onBeforeRunAnimation: (el) => {
                        if (this.getCurrentColCount() == 0 && this.bodyItems.indexOf(item) >= 0) {
                            const leftPosition = el.parentElement.firstElementChild.offsetLeft;
                            if (el.offsetLeft > leftPosition) {
                                setPropertiesOnElementForAnimation(el, { moveAnimationDuration: "0s", fadeAnimationDelay: "0s" }, "--");
                            }
                        }
                        prepareElementForVerticalAnimation(el);
                    },
                    onAfterRunAnimation: cleanHtmlElementAfterAnimation
                };
            }
        };
    }
    get renderedChoices() {
        return this._renderedChoices;
    }
    set renderedChoices(val) {
        this.renderedChoicesAnimation.sync(val);
    }
    get headItems() {
        const count = (this.separateSpecialChoices || this.isInDesignMode) ? this.headItemsCount : 0;
        const res = [];
        for (let i = 0; i < count; i++) {
            if (this.renderedChoices[i]) {
                res.push(this.renderedChoices[i]);
            }
        }
        return res;
    }
    get footItems() {
        const count = (this.separateSpecialChoices || this.isInDesignMode) ? this.footItemsCount : 0;
        const res = [];
        const items = this.renderedChoices;
        for (let i = 0; i < count; i++) {
            if (this.renderedChoices[items.length - count + i]) {
                res.push(this.renderedChoices[items.length - count + i]);
            }
        }
        return res;
    }
    get dataChoices() {
        return this.renderedChoices.filter((item) => !this.isBuiltInChoice(item));
    }
    get bodyItems() {
        return (this.hasHeadItems || this.hasFootItems) ? this.dataChoices : this.renderedChoices;
    }
    get hasHeadItems() {
        return this.headItems.length > 0;
    }
    get hasFootItems() {
        return this.footItems.length > 0;
    }
    get itemFlowDirection() {
        return settings.itemFlowDirection;
    }
    get columns() {
        if (!this.hasColumns || this.renderedChoices.length === 0)
            return [];
        const colCount = this.getCurrentColCount();
        let choicesToBuildColumns = (!this.separateSpecialChoices && !this.isInDesignMode) ?
            this.renderedChoices : this.dataChoices;
        if (this.itemFlowDirection === "column") {
            return this.getColumnsWithColumnItemFlow(choicesToBuildColumns, colCount);
        }
        else {
            return this.getColumnsWithRowItemFlow(choicesToBuildColumns, colCount);
        }
    }
    getColumnsWithColumnItemFlow(choices, colCount) {
        const columns = [];
        let maxColumnHeight = Math.floor(choices.length / colCount);
        if (choices.length % colCount) {
            maxColumnHeight += 1;
        }
        let choicesLeft = choices.length;
        let columnsLeft = colCount;
        let indexShift = 0;
        for (let i = 0; i < colCount; i++) {
            const column = [];
            for (let j = 0; j < maxColumnHeight; j++) {
                if (choicesLeft <= columnsLeft) {
                    maxColumnHeight = 1;
                }
                const choice = choices[j + indexShift];
                if (choice) {
                    column.push(choice);
                    choicesLeft--;
                }
            }
            columns.push(column);
            columnsLeft--;
            indexShift += column.length;
        }
        return columns;
    }
    getColumnsWithRowItemFlow(choices, colCount) {
        const columns = [];
        for (let i = 0; i < colCount; i++) {
            const column = [];
            for (let j = i; j < choices.length; j += colCount) {
                column.push(choices[j]);
            }
            columns.push(column);
        }
        return columns;
    }
    getItemsColumnKey(itemsColumn) {
        return (itemsColumn || []).map(c => c.value || "").join("");
    }
    get hasColumns() {
        return !this.isMobile &&
            (this.getCurrentColCount() > 1);
    }
    get rowLayout() {
        return this.getCurrentColCount() == 0 && !(this.hasFootItems || this.hasHeadItems);
    }
    get blockedRow() {
        return this.getCurrentColCount() == 0 && (this.hasFootItems || this.hasHeadItems);
    }
    choicesLoaded() {
        this.isChoicesLoaded = true;
        this.updateIsReady();
        if (this.survey) {
            this.survey.loadedChoicesFromServer(this);
        }
        if (this.loadedChoicesFromServerCallback) {
            this.loadedChoicesFromServerCallback();
        }
    }
    getItemValueWrapperComponentName(item) {
        const survey = this.survey;
        if (survey) {
            return survey.getItemValueWrapperComponentName(item, this);
        }
        return SurveyModel.TemplateRendererComponentName;
    }
    getItemValueWrapperComponentData(item) {
        const survey = this.survey;
        if (survey) {
            return survey.getItemValueWrapperComponentData(item, this);
        }
        return item;
    }
    ariaItemChecked(item) {
        return this.renderedValue === item.value ? "true" : "false";
    }
    isOtherItem(item) {
        return this.hasOther && item.value == this.otherItem.value;
    }
    get itemSvgIcon() {
        if (this.isPreviewStyle && this.cssClasses.itemPreviewSvgIconId) {
            return this.cssClasses.itemPreviewSvgIconId;
        }
        return this.cssClasses.itemSvgIconId;
    }
    getSelectBaseRootCss() {
        return new CssClassBuilder()
            .append(this.getQuestionRootCss())
            .append(this.cssClasses.rootRow, this.rowLayout)
            .toString();
    }
    allowMobileInDesignMode() {
        return true;
    }
    getAriaItemLabel(item) {
        return item.locText.renderedHtml;
    }
    getItemId(item) {
        return this.inputId + "_" + this.getItemIndex(item);
    }
    get questionName() {
        return this.name + "_" + this.id;
    }
    getItemEnabled(item) {
        return !this.isDisabledAttr && item.isEnabled;
    }
    focusOtherComment() {
        var _a;
        SurveyElement.FocusElement(this.otherId, false, (_a = this.survey) === null || _a === void 0 ? void 0 : _a.rootElement);
    }
    onValueChanged() {
        super.onValueChanged();
        if (!this.isDesignMode && !this.prevIsOtherSelected && this.isOtherSelected && !this.isSettingDefaultValue) {
            this.focusOtherComment();
        }
        this.prevIsOtherSelected = this.isOtherSelected;
    }
    getDefaultItemComponent() {
        return "";
    }
    /**
     * The name of a component used to render items.
     *
     * [Dropdown Demo](https://surveyjs.io/form-library/examples/dropdown-box-with-custom-items/ (linkStyle))
     *
     * [Ranking Demo](https://surveyjs.io/form-library/examples/ranking-with-custom-items/ (linkStyle))
     *
     * [Checkboxes and Radio Button Group Demo](https://surveyjs.io/form-library/examples/add-custom-items-to-single-and-multi-select-questions/ (linkStyle))
     */
    get itemComponent() {
        return this.getPropertyValue("itemComponent", this.getDefaultItemComponent());
    }
    set itemComponent(value) {
        this.setPropertyValue("itemComponent", value);
    }
}
__decorate([
    propertyArray()
], QuestionSelectBase.prototype, "_renderedChoices", void 0);
/**
 * A base class for multiple-selection question types that can display choice items in multiple columns ([Checkbox](https://surveyjs.io/form-library/documentation/questioncheckboxmodel), [Radiogroup](https://surveyjs.io/form-library/documentation/questionradiogroupmodel), [Image Picker](https://surveyjs.io/form-library/documentation/questionimagepickermodel)).
 */
class QuestionCheckboxBase extends QuestionSelectBase {
    constructor(name) {
        super(name);
    }
    /**
     * Gets or sets the number of columns used to arrange choice items.
     *
     * Set this property to 0 if you want to display all items in one line. The default value depends on the available width.
     * @see separateSpecialChoices
     */
    get colCount() {
        return this.getPropertyValue("colCount", this.isFlowLayout ? 0 : undefined);
    }
    set colCount(value) {
        if (value < 0 || value > 5 || this.isFlowLayout)
            return;
        this.setPropertyValue("colCount", value);
        this.fireCallback(this.colCountChangedCallback);
    }
    onParentChanged() {
        super.onParentChanged();
        if (this.isFlowLayout) {
            this.setPropertyValue("colCount", null);
        }
    }
    onParentQuestionChanged() {
        this.onVisibleChoicesChanged();
    }
    getSearchableItemValueKeys(keys) {
        keys.push("choices");
    }
}
function checkCopyPropVisibility(obj, mode) {
    var _a;
    if (!obj)
        return false;
    if (!!obj.templateQuestion) {
        const data = (_a = obj.colOwner) === null || _a === void 0 ? void 0 : _a.data;
        obj = obj.templateQuestion;
        if (!obj.getCarryForwardQuestion(data))
            return false;
    }
    return obj.carryForwardQuestionType === mode;
}
Serializer.addClass("selectbase", [
    { name: "showCommentArea:switch", layout: "row", visible: true, category: "general" },
    "choicesFromQuestion:question_carryforward",
    {
        name: "choices:itemvalue[]", uniqueProperty: "value",
        baseValue: function () {
            return getLocaleString("choices_Item");
        },
        dependsOn: "choicesFromQuestion",
        visibleIf: (obj) => {
            return !obj.choicesFromQuestion;
        },
    },
    {
        name: "choicesFromQuestionMode",
        default: "all",
        choices: ["all", "selected", "unselected"],
        dependsOn: "choicesFromQuestion",
        visibleIf: (obj) => {
            return checkCopyPropVisibility(obj, "select");
        },
    },
    {
        name: "choiceValuesFromQuestion",
        dependsOn: "choicesFromQuestion",
        visibleIf: (obj) => {
            return checkCopyPropVisibility(obj, "array");
        },
    },
    {
        name: "choiceTextsFromQuestion",
        dependsOn: "choicesFromQuestion",
        visibleIf: (obj) => {
            return checkCopyPropVisibility(obj, "array");
        },
    },
    {
        name: "choicesOrder",
        default: "none",
        choices: ["none", "asc", "desc", "random"],
        dependsOn: "choicesFromQuestion",
        visibleIf: (obj) => {
            return !obj.choicesFromQuestion;
        },
    },
    {
        name: "choicesByUrl:restfull",
        className: "choicesByUrl",
        onGetValue: function (obj) {
            return obj.choicesByUrl.getData();
        },
        onSetValue: function (obj, value) {
            obj.choicesByUrl.setData(value);
        },
    },
    "hideIfChoicesEmpty:boolean",
    "choicesVisibleIf:condition",
    {
        name: "choicesEnableIf:condition",
        dependsOn: "choicesFromQuestion",
        visibleIf: (obj) => {
            return !obj.choicesFromQuestion;
        },
    },
    { name: "defaultValue:value", visibleIf: (obj) => !obj.choicesFromQuestion, dependsOn: "choicesFromQuestion" },
    { name: "correctAnswer:value", visibleIf: (obj) => !obj.choicesFromQuestion, dependsOn: "choicesFromQuestion" },
    { name: "separateSpecialChoices:boolean", visible: false },
    { name: "showOtherItem:boolean", alternativeName: "hasOther" },
    { name: "showNoneItem:boolean", alternativeName: "hasNone" },
    { name: "showRefuseItem:boolean", visible: false, version: "1.9.128" },
    { name: "showDontKnowItem:boolean", visible: false, version: "1.9.128" },
    {
        name: "otherPlaceholder",
        alternativeName: "otherPlaceHolder",
        serializationProperty: "locOtherPlaceholder",
        dependsOn: "showOtherItem",
        visibleIf: function (obj) {
            return obj.hasOther;
        },
    },
    {
        name: "noneText",
        serializationProperty: "locNoneText",
        dependsOn: "showNoneItem",
        visibleIf: function (obj) {
            return obj.showNoneItem;
        },
    },
    {
        name: "refuseText",
        serializationProperty: "locRefuseText",
        dependsOn: "showRefuseItem",
        visibleIf: function (obj) {
            return obj.showRefuseItem;
        },
    },
    {
        name: "dontKnowText",
        serializationProperty: "locDontKnowText",
        dependsOn: "showDontKnowItem",
        visibleIf: function (obj) {
            return obj.showDontKnowItem;
        },
    },
    {
        name: "otherText",
        serializationProperty: "locOtherText",
        dependsOn: "showOtherItem",
        visibleIf: function (obj) {
            return obj.hasOther;
        },
    },
    {
        name: "otherErrorText",
        serializationProperty: "locOtherErrorText",
        dependsOn: "showOtherItem",
        visibleIf: function (obj) {
            return obj.hasOther;
        },
    },
    {
        name: "storeOthersAsComment",
        default: "default",
        choices: ["default", true, false],
        visible: false,
    }
], null, "question");
Serializer.addClass("checkboxbase", [
    {
        name: "colCount:number",
        default: 1,
        choices: [0, 1, 2, 3, 4, 5],
        layout: "row",
    }
], null, "selectbase");

class DropdownListModel extends Base {
    get focusFirstInputSelector() {
        return this.getFocusFirstInputSelector();
    }
    getFocusFirstInputSelector() {
        if (IsTouch) {
            return this.isValueEmpty(this.question.value) ? this.itemSelector : this.selectedItemSelector;
        }
        else {
            return (!this.listModel.showFilter && !!this.question.value) ? this.selectedItemSelector : "";
        }
    }
    resetItemsSettings() {
        this.itemsSettings.skip = 0;
        this.itemsSettings.take = Math.max(this.minPageSize, this.question.choicesLazyLoadPageSize);
        this.itemsSettings.totalCount = 0;
        this.itemsSettings.items = [];
    }
    setItems(items, totalCount) {
        this.itemsSettings.items = [].concat(this.itemsSettings.items, items);
        this.itemsSettings.totalCount = totalCount;
        this.listModel.isAllDataLoaded = this.choicesLazyLoadEnabled && this.itemsSettings.items.length == this.itemsSettings.totalCount;
        this.question.choices = this.itemsSettings.items;
    }
    _loadQuestionChoices(callbackAfterItemsLoaded) {
        const _filterString = this.filterString;
        this.setIsChoicesLoading(true);
        this.question.survey.loadQuestionChoices({
            question: this.question,
            filter: this.filterString,
            skip: this.itemsSettings.skip,
            take: this.itemsSettings.take,
            setItems: (items, totalCount) => {
                this.setItems(items || [], totalCount || 0);
                this.popupRecalculatePosition(this.itemsSettings.skip === this.itemsSettings.take);
                if (!!callbackAfterItemsLoaded) {
                    callbackAfterItemsLoaded();
                }
                this.processCustomValue(_filterString);
                this.setIsChoicesLoading(false);
            }
        });
        this.itemsSettings.skip += this.itemsSettings.take;
    }
    setIsChoicesLoading(newValue) {
        if (!!this.question.setIsChoicesLoading) {
            this.question.setIsChoicesLoading(newValue);
        }
    }
    processCustomValue(newValue) {
        if (!this.allowCustomChoices)
            return;
        const value = newValue || this.filterString;
        const item = this.listModel.visibleActions.filter(action => Helpers.isTwoValueEquals(action.text, value, false, false))[0];
        if (!!item) {
            this.customValue = undefined;
        }
        else {
            this.customValue = value;
            this.updateItems();
            this.listModel.focusFirstVisibleItem();
        }
    }
    updateQuestionChoices(callbackAfterItemsLoaded) {
        const isUpdate = (this.itemsSettings.skip + 1) < this.itemsSettings.totalCount;
        if (!this.itemsSettings.skip || isUpdate) {
            this.resetTimer();
            if (!!this.filterString && settings.dropdownSearchDelay > 0) {
                this.timer = setTimeout(() => {
                    this._loadQuestionChoices(callbackAfterItemsLoaded);
                }, settings.dropdownSearchDelay);
            }
            else {
                this._loadQuestionChoices(callbackAfterItemsLoaded);
            }
        }
    }
    resetTimer() {
        if (!!this.timer) {
            clearTimeout(this.timer);
            this.timer = undefined;
        }
    }
    updatePopupFocusFirstInputSelector() {
        this._popupModel.focusFirstInputSelector = this.focusFirstInputSelector;
    }
    getDropdownMenuOptions() {
        const windowWidth = DomWindowHelper.getInnerWidth();
        const windowHeight = DomWindowHelper.getInnerHeight();
        const isTablet = calculateIsTablet(windowWidth, windowHeight);
        let menuType = "dropdown";
        let deviceType = "desktop";
        if (IsTouch) {
            menuType = "popup";
            deviceType = isTablet ? "tablet" : "mobile";
        }
        return {
            menuType: menuType,
            deviceType: deviceType,
            hasTouchScreen: IsTouch,
            screenHeight: windowHeight,
            screenWidth: windowWidth
        };
    }
    checkFocusRemainsWithinComponent(event) {
        if (!this.question.cssClasses.root || !(event === null || event === void 0 ? void 0 : event.target))
            return false;
        const rootElement = event.target.closest(classesToSelector(this.question.cssClasses.root));
        return (rootElement && rootElement.contains(event.relatedTarget));
    }
    createButtons() {
        this.editorButtons = new ActionContainer();
        this.editorButtons.containerCss = "sd-dropdown-action-bar";
        this.chevronButton = new Action({
            id: "chevron",
            css: "sd-editor-chevron-button",
            iconName: this.question.cssClasses.chevronButtonIconId || "icon-chevron",
            iconSize: "auto",
            showTitle: false,
            locTitle: this.locSelectCaption,
            disableTabStop: true,
            enabled: new ComputedUpdater(() => {
                return !this.question.isInputReadOnly;
            }),
            visible: new ComputedUpdater(() => {
                return !this.question.isPreviewStyle;
            }),
            action: (context) => {
                this.onClick();
            }
        });
        this.clearButton = new Action({
            id: "clear",
            css: "sd-editor-clean-button",
            iconName: this.question.cssClasses.cleanButtonIconId || "icon-cancel-24x24",
            iconSize: "auto",
            showTitle: false,
            locTitle: this.locClearCaption,
            disableTabStop: true,
            enabled: new ComputedUpdater(() => {
                return !this.question.isInputReadOnly;
            }),
            visible: new ComputedUpdater(() => {
                const isEmpty = this.question.isEmpty();
                const isReadOnly = this.question.isReadOnly;
                return this.question.allowClear && !isEmpty && !isReadOnly;
            }),
            action: (context) => {
                this.onClear();
            }
        });
        this.editorButtons.setItems([this.clearButton, this.chevronButton]);
        this.editorButtons.actions.forEach(action => action.cssClasses = {
            item: "sd-editor-button-item",
            itemIcon: "sv-editor-button-item__icon",
            itemPressed: "sd-editor-button-item--pressed",
        });
    }
    createPopup() {
        const popupOptions = { verticalPosition: "bottom", horizontalPosition: "center", showPointer: false };
        this._popupModel = new PopupModel("sv-list", { model: this.listModel }, popupOptions);
        this._popupModel.displayMode = IsTouch ? "overlay" : "popup";
        this._popupModel.positionMode = "fixed";
        this._popupModel.isFocusedContainer = false;
        this._popupModel.isFocusedContent = IsTouch;
        this._popupModel.setWidthByTarget = !IsTouch;
        this._popupModel.locale = this.question.getLocale();
        this.updatePopupFocusFirstInputSelector();
        this.listModel.registerPropertyChangedHandlers(["showFilter"], () => {
            this.updatePopupFocusFirstInputSelector();
        });
        this._popupModel.onVisibilityChanged.add((_, option) => {
            this.popupVisibilityChanged(option.isVisible);
            this.chevronButton.pressed = option.isVisible;
        });
    }
    popupVisibilityChanged(isVisible) {
        if (isVisible) {
            this.listModel.renderElements = true;
        }
        if (isVisible && this.choicesLazyLoadEnabled) {
            this.listModel.actions = [];
            this.resetItemsSettings();
            this.updateQuestionChoices();
        }
        if (isVisible) {
            this.updatePopupFocusFirstInputSelector();
            const dropdownMenuOptions = this.getDropdownMenuOptions();
            this.question.processOpenDropdownMenu(dropdownMenuOptions);
            const displayModeUpdated = this._popupModel.updateDisplayMode(dropdownMenuOptions.menuType);
            if (displayModeUpdated) {
                this.listModel.setSearchEnabled(this.inputAvailable && dropdownMenuOptions.menuType !== "dropdown");
            }
            if (!!this.question.onOpenedCallBack) {
                this.question.onOpenedCallBack();
            }
        }
        if (!isVisible) {
            this.onHidePopup();
        }
        this.ariaExpanded = isVisible ? "true" : "false";
        this.question.processPopupVisiblilityChanged(this.popupModel, isVisible);
    }
    setFilterStringToListModel(newValue) {
        this.listModel.filterString = newValue;
        this.listModel.resetFocusedItem();
        if (this.question.selectedItem && this.question.selectedItem.text.indexOf(newValue) >= 0) {
            this.listModel.focusedItem = this.getAvailableItems().filter(item => item.id == this.question.selectedItem.value)[0];
            if (this.listModel.filterString) {
                this.listModel.actions.map(a => a.selectedValue = false);
            }
            return;
        }
        if (!this.listModel.focusedItem || !this.listModel.isItemVisible(this.listModel.focusedItem)) {
            this.listModel.focusFirstVisibleItem();
        }
    }
    setTextWrapEnabled(newValue) {
        this.listModel.textWrapEnabled = newValue;
    }
    popupRecalculatePosition(isResetHeight) {
        setTimeout(() => {
            this.popupModel.recalculatePosition(isResetHeight);
        }, 1);
    }
    onHidePopup() {
        this.resetFilterString();
        this.question.suggestedItem = null;
        if (this.choicesLazyLoadEnabled) {
            this.resetItemsSettings();
        }
        this.customValue = undefined;
        this.resetCustomItemValue();
    }
    getAvailableItems() {
        if (this.allowCustomChoices) {
            return [].concat(this.question.visibleChoices, [this.customItemValue]);
        }
        return this.question.visibleChoices;
    }
    setOnTextSearchCallbackForListModel(listModel) {
        listModel.setOnTextSearchCallback((item, textToSearch) => {
            if (item.id === this.customItemValue.id)
                return item.visible;
            if (this.filteredItems)
                return this.filteredItems.indexOf(item) >= 0;
            let textInLow = item.text.toLocaleLowerCase();
            textInLow = settings.comparator.normalizeTextCallback(textInLow, "filter");
            const index = textInLow.indexOf(textToSearch.toLocaleLowerCase());
            return this.question.searchMode == "startsWith" ? index == 0 : index > -1;
        });
    }
    createListModel() {
        const visibleItems = this.getAvailableItems();
        let _onSelectionChanged = this.onSelectionChanged;
        if (!_onSelectionChanged) {
            _onSelectionChanged = (item) => {
                this.setQuestionValue(item);
                this.popupModel.hide();
            };
        }
        const listOptions = {
            items: visibleItems,
            onSelectionChanged: _onSelectionChanged,
            allowSelection: false,
            locOwner: this.question,
            elementId: this.listElementId
        };
        const res = new ListModel(listOptions);
        this.setOnTextSearchCallbackForListModel(res);
        res.renderElements = false;
        res.forceShowFilter = this.question.choicesLazyLoadEnabled;
        res.areSameItemsCallback = (item1, item2) => {
            return item1 === item2;
        };
        return res;
    }
    setQuestionValue(item) {
        if (this.allowCustomChoices && item.id === this.customItemValue.id) {
            const newChoice = this.createCustomItem();
            if (!!newChoice) {
                this.question.value = newChoice.id;
                this.hintString = "";
            }
        }
        else {
            this.question.value = item.id;
            if (this.searchEnabled)
                this.applyInputString(item);
        }
    }
    createCustomItem() {
        const newChoice = new ItemValue(this.customValue);
        const options = {
            item: newChoice,
            question: this.question,
            allow: true
        };
        this.question.survey.createCustomChoiceItem(options);
        if (!options.allow) {
            this.clear();
            return null;
        }
        this.question.customChoices.push(newChoice);
        this.customValue = undefined;
        this.updateItems();
        return newChoice;
    }
    updateAfterListModelCreated(model) {
        model.isItemSelected = (action) => !!action.selected;
        model.onPropertyChanged.add((sender, options) => {
            if (options.name == "hasVerticalScroller") {
                this.hasScroll = options.newValue;
            }
        });
        model.isAllDataLoaded = !this.choicesLazyLoadEnabled;
        model.actions.forEach(a => a.disableTabStop = true);
        model.setOnFilterStringChangedCallback(this.listModelFilterStringChanged);
    }
    getPopupCssClasses() { return "sv-single-select-list"; }
    updateCssClasses(popupCssClass, listCssClasses) {
        this.popupModel.cssClass = new CssClassBuilder().append(popupCssClass).append(this.getPopupCssClasses()).toString();
        this.listModel.cssClasses = listCssClasses;
    }
    resetFilterString() {
        if (!!this.filterString) {
            this.filterString = undefined;
        }
    }
    clear() {
        this.customValue = undefined;
        this.inputString = null;
        this.hintString = "";
        this.resetFilterString();
    }
    onSetFilterString() {
        this.filteredItems = undefined;
        if (!this.filterString && !this.popupModel.isVisible)
            return;
        const options = { question: this.question, choices: this.getAvailableItems(), filter: this.filterString, filteredChoices: undefined };
        this.question.survey.onChoicesSearch.fire(this.question.survey, options);
        this.filteredItems = options.filteredChoices;
        if (!!this.filterString && !this.popupModel.isVisible) {
            this.popupModel.show();
        }
        const updateAfterFilterStringChanged = () => {
            this.setFilterStringToListModel(this.filterString);
            if (this.filterString)
                this.applyHintString();
            this.popupRecalculatePosition(true);
        };
        if (this.choicesLazyLoadEnabled) {
            this.resetItemsSettings();
            this.updateQuestionChoices(updateAfterFilterStringChanged);
        }
        else {
            updateAfterFilterStringChanged();
        }
    }
    get isAllDataLoaded() {
        return !!this.itemsSettings.totalCount && this.itemsSettings.items.length == this.itemsSettings.totalCount;
    }
    loadQuestionChoices(callbackAfterItemsLoaded) {
        if (this.isAllDataLoaded)
            return;
        this._loadQuestionChoices(callbackAfterItemsLoaded);
    }
    get canShowSelectedItem() {
        return !this.focused || this._markdownMode || !this.searchEnabled;
    }
    get needRenderInput() {
        return !this.question.isInputReadOnly || !!this.placeholderRendered;
    }
    updateCustomItemValue() {
        if (this.customValue) {
            this.customItemValue.text = this.getLocalizationFormatString("createCustomItem", this.customValue);
            this.customItemValue.visible = true;
        }
        else {
            this.resetCustomItemValue();
        }
    }
    resetCustomItemValue() {
        this.customItemValue.text = "";
        this.customItemValue.visible = false;
    }
    get customItemValue() {
        if (!this._customItemValue) {
            this._customItemValue = new ItemValue("newCustomItem", this.getLocalizationFormatString("createCustomItem", this.customValue));
            this._customItemValue.css = "sv-list-item--custom-value";
        }
        return this._customItemValue;
    }
    applyInputString(item) {
        const hasHtml = item === null || item === void 0 ? void 0 : item.locText.hasHtml;
        if (hasHtml || this.question.inputFieldComponentName) {
            this._markdownMode = true;
            this.inputString = this.cleanHtml(item === null || item === void 0 ? void 0 : item.locText.getHtmlValue());
            this.hintString = "";
        }
        else {
            this.inputString = item === null || item === void 0 ? void 0 : item.title;
            this.hintString = item === null || item === void 0 ? void 0 : item.title;
        }
    }
    cleanHtml(html) {
        if (!this.htmlCleanerElement)
            return "";
        this.htmlCleanerElement.innerHTML = html;
        return this.htmlCleanerElement.textContent;
    }
    fixInputCase() {
        const hintStringMiddle = this.hintStringMiddle;
        if (hintStringMiddle && this.inputString != hintStringMiddle)
            this.inputString = hintStringMiddle;
    }
    applyHintString() {
        const item = this.listModel.focusedItem || this.question.selectedItem;
        const hasHtml = item === null || item === void 0 ? void 0 : item.locText.hasHtml;
        if (hasHtml || this.question.inputFieldComponentName) {
            this._markdownMode = true;
            this.hintString = "";
        }
        else if (item === this.customItemValue) {
            this.hintString = "";
        }
        else {
            this.hintString = item === null || item === void 0 ? void 0 : item.title;
        }
    }
    get inputStringRendered() {
        return this.inputString || "";
    }
    set inputStringRendered(val) {
        var _a;
        this.inputString = val;
        this.filterString = val;
        if (!this.choicesLazyLoadEnabled) {
            this.processCustomValue();
        }
        if (!val || !this.searchEnabled || ((_a = this.listModel.focusedItem) === null || _a === void 0 ? void 0 : _a.id) === this.customItemValue.id) {
            this.hintString = "";
        }
    }
    get placeholderRendered() {
        return (this.hintString || this.question.readOnly || !this.question.isEmpty()) ? "" : this.inputPlaceholder;
    }
    get listElementId() {
        return this.question.inputId + "_list";
    }
    get hintStringLC() {
        var _a;
        return ((_a = this.hintString) === null || _a === void 0 ? void 0 : _a.toLowerCase()) || "";
    }
    get inputStringLC() {
        var _a;
        return ((_a = this.inputString) === null || _a === void 0 ? void 0 : _a.toLowerCase()) || "";
    }
    get showHintPrefix() {
        return !!this.inputString && this.hintStringLC.indexOf(this.inputStringLC) > 0;
    }
    get hintStringPrefix() {
        if (!this.inputString)
            return null;
        return this.hintString.substring(0, this.hintStringLC.indexOf(this.inputStringLC));
    }
    get showHintString() {
        return !!this.searchEnabled && !!(this.hintStringLC || this.inputStringLC) ||
            !this.searchEnabled && this.hintStringLC && this.question.isEmpty();
    }
    get hintStringSuffix() {
        return this.hintStringLC.indexOf(this.inputStringLC) >= 0 ? this.hintString.substring(this.hintStringLC.indexOf(this.inputStringLC) + this.inputStringLC.length) : "";
    }
    get hintStringMiddle() {
        const start = this.hintStringLC.indexOf(this.inputStringLC);
        if (start == -1)
            return null;
        return this.hintString.substring(start, start + this.inputStringLC.length);
    }
    constructor(question, onSelectionChanged) {
        super();
        this.question = question;
        this.onSelectionChanged = onSelectionChanged;
        this.minPageSize = 25;
        this.loadingItemHeight = 40;
        this.timer = undefined;
        this._markdownMode = false;
        this.filteredItems = undefined;
        this.selectedItemSelector = ".sv-list__item--selected";
        this.itemSelector = ".sv-list__item";
        this.itemsSettings = { skip: 0, take: 0, totalCount: 0, items: [] };
        this.listModelFilterStringChanged = (newValue) => {
            if (this.filterString !== newValue) {
                this.filterString = newValue;
                if (!this.choicesLazyLoadEnabled) {
                    this.processCustomValue();
                }
            }
        };
        this.questionPropertyChangedHandler = (sender, options) => {
            this.onPropertyChangedHandler(sender, options);
        };
        this.ariaExpanded = "false";
        this.createLocalizableString("clearCaption", this.question, false, true);
        this.createLocalizableString("selectCaption", this.question, false, true);
        this.htmlCleanerElement = DomDocumentHelper.createElement("div");
        question.onPropertyChanged.add(this.questionPropertyChangedHandler);
        this.showInputFieldComponent = this.question.showInputFieldComponent;
        this.listModel = this.createListModel();
        this.setChoicesLazyLoadEnabled(this.question.choicesLazyLoadEnabled);
        this.setInputPlaceholder(this.question.placeholder);
        this.updateAfterListModelCreated(this.listModel);
        this.setSearchEnabled(this.question.searchEnabled);
        this.setAllowCustomChoices(this.question.allowCustomChoices);
        this.setTextWrapEnabled(this.question.textWrapEnabled);
        this.createPopup();
        this.createButtons();
        this.resetItemsSettings();
        const classes = question.cssClasses;
        this.updateCssClasses(classes.popup, classes.list);
    }
    get popupModel() {
        return this._popupModel;
    }
    get clearCaption() {
        return this.getLocalizableStringText("clearCaption");
    }
    set clearCaption(value) {
        this.setLocalizableStringText("clearCaption", value);
    }
    get locClearCaption() {
        return this.getLocalizableString("clearCaption");
    }
    get selectCaption() {
        return this.getLocalizableStringText("selectCaption");
    }
    set selectCaption(value) {
        this.setLocalizableStringText("selectCaption", value);
    }
    get locSelectCaption() {
        return this.getLocalizableString("selectCaption");
    }
    get inputAvailable() {
        return this.searchEnabled || this.allowCustomChoices;
    }
    get noTabIndex() {
        return this.question.isInputReadOnly || this.inputAvailable;
    }
    get filterReadOnly() {
        return !this.filterStringEnabled || !this.focused;
    }
    get filterStringEnabled() {
        return !this.question.isInputReadOnly && this.inputAvailable;
    }
    get inputMode() {
        return IsTouch ? "none" : "text";
    }
    get popupEnabled() {
        return !this.question.isInputReadOnly;
    }
    get ariaQuestionRole() { return this.filterStringEnabled ? undefined : "combobox"; }
    get ariaQuestionRequired() { return this.ariaQuestionRole ? this.question.a11y_input_ariaRequired : undefined; }
    get ariaQuestionInvalid() { return this.ariaQuestionRole ? this.question.a11y_input_ariaInvalid : undefined; }
    get ariaQuestionErrorMessage() { return this.ariaQuestionRole ? this.question.a11y_input_ariaErrormessage : undefined; }
    get ariaQuestionLabel() { return this.ariaQuestionRole ? this.question.a11y_input_ariaLabel : undefined; }
    get ariaQuestionLabelledby() { return this.ariaQuestionRole ? this.question.a11y_input_ariaLabelledBy : undefined; }
    get ariaQuestionDescribedby() { return this.ariaQuestionRole ? this.question.a11y_input_ariaDescribedBy : undefined; }
    get ariaQuestionControls() { return this.ariaQuestionRole && this.popupEnabled ? this.listElementId : undefined; }
    get ariaQuestionExpanded() { return this.ariaQuestionRole ? (this.popupEnabled ? this.ariaExpanded : "false") : undefined; }
    get ariaQuestionActivedescendant() { return this.ariaQuestionRole ? this.ariaActivedescendant : undefined; }
    get ariaInputRole() { return this.filterStringEnabled ? "combobox" : undefined; }
    get ariaInputRequired() { return this.ariaInputRole ? this.question.a11y_input_ariaRequired : undefined; }
    get ariaInputInvalid() { return this.ariaInputRole ? this.question.a11y_input_ariaInvalid : undefined; }
    get ariaInputErrorMessage() { return this.ariaInputRole ? this.question.a11y_input_ariaErrormessage : undefined; }
    get ariaInputLabel() { return this.ariaInputRole ? this.question.a11y_input_ariaLabel : undefined; }
    get ariaInputLabelledby() { return this.ariaInputRole ? this.question.a11y_input_ariaLabelledBy : undefined; }
    get ariaInputDescribedby() { return this.ariaInputRole ? this.question.a11y_input_ariaDescribedBy : undefined; }
    get ariaInputControls() { return this.ariaInputRole && this.popupEnabled ? this.listElementId : undefined; }
    get ariaInputExpanded() { return this.ariaInputRole ? (this.popupEnabled ? this.ariaExpanded : "false") : undefined; }
    get ariaInputActivedescendant() { return this.ariaInputRole ? this.ariaActivedescendant : undefined; }
    setSearchEnabled(newValue) {
        this.listModel.setSearchEnabled(IsTouch && (newValue || this.question.allowCustomChoices));
        this.searchEnabled = newValue;
    }
    setAllowCustomChoices(newValue) {
        this.allowCustomChoices = newValue;
        if (newValue) {
            this.searchEnabled = newValue;
        }
    }
    setChoicesLazyLoadEnabled(newValue) {
        this.choicesLazyLoadEnabled = newValue;
    }
    setInputPlaceholder(newValue) {
        this.inputPlaceholder = newValue;
    }
    updateItems() {
        this.listModel.setItems(this.getAvailableItems());
    }
    onClick(event) {
        if (this.question.readOnly || this.question.isDesignMode || this.question.isPreviewStyle || this.question.isReadOnlyAttr)
            return;
        this._popupModel.toggleVisibility();
        this.focusItemOnClickAndPopup();
        this.question.focusInputElement(false);
    }
    chevronPointerDown(event) {
        if (this._popupModel.isVisible) {
            event.preventDefault();
        }
    }
    onPropertyChangedHandler(sender, options) {
        if (options.name == "value") {
            this.showInputFieldComponent = this.question.showInputFieldComponent;
        }
        if (options.name == "textWrapEnabled") {
            this.setTextWrapEnabled(options.newValue);
        }
    }
    focusItemOnClickAndPopup() {
        if (this._popupModel.isVisible && this.question.value)
            this.changeSelectionWithKeyboard(false);
    }
    onClear(event) {
        this.question.clearValue(true);
        this._popupModel.hide();
        if (event) {
            event.preventDefault();
            event.stopPropagation();
        }
    }
    getSelectedAction() {
        return this.question.selectedItem || null;
    }
    changeSelectionWithKeyboard(reverse) {
        var _a;
        let focusedItem = this.listModel.focusedItem;
        if (!focusedItem && this.question.selectedItem) {
            if (ItemValue.getItemByValue(this.question.visibleChoices, this.question.value)) {
                this.listModel.focusedItem = this.question.selectedItem;
            }
        }
        else {
            if (reverse) {
                this.listModel.focusPrevVisibleItem();
            }
            else {
                this.listModel.focusNextVisibleItem();
            }
        }
        this.beforeScrollToFocusedItem(focusedItem);
        this.scrollToFocusedItem();
        this.afterScrollToFocusedItem();
        this.ariaActivedescendant = (_a = this.listModel.focusedItem) === null || _a === void 0 ? void 0 : _a.elementId;
    }
    beforeScrollToFocusedItem(focusedItem) {
        if (this.question.value && focusedItem) {
            focusedItem.selectedValue = false;
            this.listModel.focusedItem.selectedValue = !this.listModel.filterString;
            this.question.suggestedItem = this.listModel.focusedItem;
        }
    }
    afterScrollToFocusedItem() {
        var _a;
        if (this.question.value && !this.listModel.filterString && this.searchEnabled) {
            this.applyInputString(this.listModel.focusedItem || this.question.selectedItem);
        }
        else {
            this.applyHintString();
        }
        this.fixInputCase();
        this.ariaActivedescendant = (_a = this.listModel.focusedItem) === null || _a === void 0 ? void 0 : _a.elementId;
    }
    keyHandler(event) {
        let isStopPropagation = false;
        const char = event.which || event.keyCode;
        if (this.popupModel.isVisible && event.keyCode === 38) {
            this.changeSelectionWithKeyboard(true);
            isStopPropagation = true;
        }
        else if (event.keyCode === 40) {
            this.popupModel.show();
            this.changeSelectionWithKeyboard(false);
            isStopPropagation = true;
        }
        else if (!this.popupModel.isVisible && event.keyCode === 32) {
            this.popupModel.show();
            this.changeSelectionWithKeyboard(false);
            isStopPropagation = true;
        }
        else if (!this.popupModel.isVisible && event.keyCode === 13) {
            this.question.survey.questionEditFinishCallback(this.question, event);
            isStopPropagation = true;
        }
        else if (this.popupModel.isVisible && (event.keyCode === 13 || event.keyCode === 32 && (!this.searchEnabled || !this.inputString))) {
            if (event.keyCode === 13 && this.searchEnabled && !this.inputString && this.question instanceof QuestionDropdownModel && !this._markdownMode && this.question.value) {
                this._popupModel.hide();
                this.onClear(event);
            }
            else {
                this.listModel.selectFocusedItem();
                this.onFocus(event);
            }
            isStopPropagation = true;
        }
        else if (char === 46 || char === 8) {
            if (!this.inputAvailable) {
                this.onClear(event);
            }
        }
        else if (event.keyCode === 27) {
            this._popupModel.hide();
            this.hintString = "";
            this.onEscape();
        }
        else {
            if (event.keyCode === 38 || event.keyCode === 40 || event.keyCode === 32 && !this.searchEnabled) {
                isStopPropagation = true;
            }
            if (event.keyCode === 32 && this.searchEnabled) {
                return;
            }
            doKey2ClickUp(event, { processEsc: false, disableTabStop: this.question.isInputReadOnly });
        }
        if (isStopPropagation) {
            event.preventDefault();
            event.stopPropagation();
        }
    }
    onEscape() {
        if (this.searchEnabled)
            this.applyInputString(this.question.selectedItem);
    }
    onScroll(event) {
        const target = event.target;
        if ((target.scrollHeight - (target.scrollTop + target.offsetHeight)) <= this.loadingItemHeight) {
            this.updateQuestionChoices();
        }
    }
    onBlur(event) {
        if (this.checkFocusRemainsWithinComponent(event))
            return;
        this.focused = false;
        if (this.popupModel.isVisible && this.popupModel.displayMode == "overlay") {
            return;
        }
        doKey2ClickBlur(event);
        this._popupModel.hide();
        this.resetFilterString();
        this.inputString = null;
        this.hintString = "";
        event.stopPropagation();
    }
    onFocus(event) {
        this.focused = true;
        this.setInputStringFromSelectedItem(this.question.selectedItem);
    }
    setInputStringFromSelectedItem(newValue) {
        if (!this.focused)
            return;
        if (this.searchEnabled && !!newValue) {
            this.applyInputString(newValue);
        }
        else {
            this.inputString = null;
        }
    }
    dispose() {
        super.dispose();
        this.question && this.question.onPropertyChanged.remove(this.questionPropertyChangedHandler);
        this.questionPropertyChangedHandler = undefined;
        if (!!this.listModel) {
            this.listModel.dispose();
        }
        if (!!this.popupModel) {
            this.popupModel.dispose();
        }
        this.htmlCleanerElement = undefined;
    }
    scrollToFocusedItem() {
        this.listModel.scrollToFocusedItem();
    }
}
__decorate([
    property({ defaultValue: false })
], DropdownListModel.prototype, "focused", void 0);
__decorate([
    property({ defaultValue: false })
], DropdownListModel.prototype, "allowCustomChoices", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            target.updateCustomItemValue();
        }
    })
], DropdownListModel.prototype, "customValue", void 0);
__decorate([
    property({ defaultValue: true })
], DropdownListModel.prototype, "searchEnabled", void 0);
__decorate([
    property()
], DropdownListModel.prototype, "choicesLazyLoadEnabled", void 0);
__decorate([
    property({
        defaultValue: "",
        onSet: (_, target) => {
            target.onSetFilterString();
        }
    })
], DropdownListModel.prototype, "filterString", void 0);
__decorate([
    property({
        defaultValue: "",
        onSet: (newValue, target) => {
            target.question.inputHasValue = !!newValue;
        }
    })
], DropdownListModel.prototype, "inputString", void 0);
__decorate([
    property({})
], DropdownListModel.prototype, "showInputFieldComponent", void 0);
__decorate([
    property()
], DropdownListModel.prototype, "ariaActivedescendant", void 0);
__decorate([
    property()
], DropdownListModel.prototype, "ariaExpanded", void 0);
__decorate([
    property()
], DropdownListModel.prototype, "inputPlaceholder", void 0);
__decorate([
    property({
        defaultValue: false,
        onSet: (newVal, target) => {
            if (newVal) {
                target.listModel.addScrollEventListener((e) => { target.onScroll(e); });
            }
            else {
                target.listModel.removeScrollEventListener();
            }
        }
    })
], DropdownListModel.prototype, "hasScroll", void 0);
__decorate([
    property({ defaultValue: "" })
], DropdownListModel.prototype, "hintString", void 0);

/**
 * A class that describes the Dropdown question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-dropdown/ (linkStyle))
 */
class QuestionDropdownModel extends QuestionSelectBase {
    constructor(name) {
        super(name);
        this.lastSelectedItemValue = null;
        this.minMaxChoices = [];
        this.onOpened = this.addEvent();
        this.createLocalizableString("placeholder", this, false, true);
        this.createLocalizableString("readOnlyText", this, true);
        this.registerPropertyChangedHandlers(["choicesMin", "choicesMax", "choicesStep"], () => {
            this.onVisibleChoicesChanged();
        });
        this.registerPropertyChangedHandlers(["value", "renderAs", "showOtherItem", "otherText", "placeholder", "choices", "visibleChoices"], () => {
            this.getSingleSelectedItem();
            this.updateReadOnlyText();
        });
        this.updateReadOnlyText();
    }
    locStrsChanged() {
        super.locStrsChanged();
        this.updateReadOnlyText();
        this.updateInputPlaceholder(this.placeholder);
    }
    updateReadOnlyText() {
        this.readOnlyText = this.calculateReadOnlyText();
    }
    updateInputPlaceholder(val) {
        if (!!this.dropdownListModelValue) {
            this.dropdownListModel.setInputPlaceholder(val);
        }
    }
    get showOptionsCaption() {
        return this.allowClear;
    }
    set showOptionsCaption(val) {
        this.allowClear = val;
    }
    get showClearButton() {
        return this.allowClear && !this.isEmpty();
    }
    get optionsCaption() {
        return this.placeholder;
    }
    set optionsCaption(val) {
        this.placeholder = val;
    }
    /**
     * A placeholder for the input field.
     */
    get placeholder() {
        return this.getLocalizableStringText("placeholder");
    }
    set placeholder(val) {
        this.setLocalizableStringText("placeholder", val);
        this.updateInputPlaceholder(val);
    }
    get locPlaceholder() {
        return this.getLocalizableString("placeholder");
    }
    getType() {
        return "dropdown";
    }
    get isNewA11yStructure() {
        return true;
    }
    get a11yQuestionAriaRole() {
        return this.searchEnabled ? null : "combobox";
    }
    get a11yInputAriaRole() {
        return this.searchEnabled ? "combobox" : null;
    }
    /**
     * Returns the selected choice item. If no item is selected, returns `null`.
     */
    get selectedItem() { return this.getSingleSelectedItem(); }
    onGetSingleSelectedItem(selectedItemByValue) {
        if (!!selectedItemByValue) {
            this.lastSelectedItemValue = selectedItemByValue;
        }
    }
    supportAutoAdvance() {
        return !this.isOtherSelected;
    }
    getChoices() {
        var items = super.getChoices();
        if (this.choicesMax <= this.choicesMin)
            return items;
        var res = [];
        for (var i = 0; i < items.length; i++) {
            res.push(items[i]);
        }
        if (this.minMaxChoices.length === 0 ||
            this.minMaxChoices.length !==
                (this.choicesMax - this.choicesMin) / this.choicesStep + 1) {
            this.minMaxChoices = [];
            for (var i = this.choicesMin; i <= this.choicesMax; i += this.choicesStep) {
                this.minMaxChoices.push(this.createItemValue(i));
            }
        }
        res = res.concat(this.minMaxChoices);
        return res;
    }
    /**
     * Use the `choicesMin`, `choicesMax`, and `choicesStep` properties to generate choice items automatically. For example, the configuration below generates three choice items: [10, 20, 30].
     *
     * ```js
     * "choicesMin": 10,
     * "choicesMax": 30
     * "choicesStep": 10
     * ```
     * @see choicesMax
     * @see choicesStep
     */
    get choicesMin() {
        return this.getPropertyValue("choicesMin");
    }
    set choicesMin(val) {
        this.setPropertyValue("choicesMin", val);
    }
    /**
     * Use the `choicesMin`, `choicesMax`, and `choicesStep` properties to generate choice items automatically. For example, the configuration below generates three choice items: [10, 20, 30].
     *
     * ```js
     * "choicesMin": 10,
     * "choicesMax": 30
     * "choicesStep": 10
     * ```
     * @see choicesMin
     * @see choicesStep
     */
    get choicesMax() {
        return this.getPropertyValue("choicesMax");
    }
    set choicesMax(val) {
        this.setPropertyValue("choicesMax", val);
    }
    /**
     * Use the `choicesMin`, `choicesMax`, and `choicesStep` properties to generate choice items automatically. For example, the configuration below generates three choice items: [10, 20, 30].
     *
     * ```js
     * "choicesMin": 10,
     * "choicesMax": 30
     * "choicesStep": 10
     * ```
     *
     * The default value of the `choicesStep` property is 1.
     * @see choicesMin
     * @see choicesMax
     */
    get choicesStep() {
        return this.getPropertyValue("choicesStep");
    }
    set choicesStep(val) {
        if (val < 1)
            val = 1;
        this.setPropertyValue("choicesStep", val);
    }
    get autocomplete() {
        return this.getPropertyValue("autocomplete");
    }
    set autocomplete(val) {
        this.setPropertyValue("autocomplete", val);
    }
    get readOnlyText() {
        return this.getLocalizableStringText("readOnlyText");
    }
    set readOnlyText(val) {
        this.setLocalizableStringText("readOnlyText", val);
    }
    get locReadOnlyText() {
        return this.getLocalizableString("readOnlyText");
    }
    calculateReadOnlyText() {
        if (this.renderAs == "select") {
            if (this.isOtherSelected)
                return this.otherText;
            if (this.isNoneSelected)
                return this.noneText;
            if (!!this.selectedItem)
                return this.selectedItemText;
        }
        return !!this.selectedItem ? this.selectedItemText : this.placeholder;
    }
    getControlClass() {
        return new CssClassBuilder()
            .append(this.cssClasses.control)
            .append(this.cssClasses.controlEmpty, this.isEmpty())
            .append(this.cssClasses.onError, this.hasCssError())
            .append(this.cssClasses.controlDisabled, this.isDisabledStyle)
            .append(this.cssClasses.controlReadOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.controlPreview, this.isPreviewStyle)
            .append(this.cssClasses.controlInputFieldComponent, !!this.inputFieldComponentName)
            .toString();
    }
    updateCssClasses(res, css) {
        super.updateCssClasses(res, css);
        if (this.useDropdownList) {
            updateListCssValues(res, css);
        }
    }
    calcCssClasses(css) {
        const classes = super.calcCssClasses(css);
        if (this.dropdownListModelValue) {
            this.dropdownListModel.updateCssClasses(classes.popup, classes.list);
        }
        return classes;
    }
    get selectedItemLocText() {
        const item = this.suggestedItem || this.selectedItem;
        return item === null || item === void 0 ? void 0 : item.locText;
    }
    get inputFieldComponentName() {
        return this.inputFieldComponent || this.itemComponent;
    }
    get showSelectedItemLocText() {
        return !this.inputHasValue && !this.inputFieldComponentName && !!this.selectedItemLocText && this.dropdownListModel.canShowSelectedItem;
    }
    get showInputFieldComponent() {
        return !this.inputHasValue && !!this.inputFieldComponentName && !this.isEmpty();
    }
    get selectedItemText() {
        const item = this.selectedItem;
        return !!item ? item.text : "";
    }
    get useDropdownList() { return this.renderAs !== "select"; }
    get dropdownListModel() {
        if (this.useDropdownList && !this.dropdownListModelValue) {
            this.dropdownListModelValue = new DropdownListModel(this);
        }
        return this.dropdownListModelValue;
    }
    set dropdownListModel(val) {
        this.dropdownListModelValue = val;
    }
    get popupModel() {
        return this.dropdownListModel.popupModel;
    }
    onOpenedCallBack() {
        this.onOpened.fire(this, { question: this, choices: this.choices });
    }
    onSelectedItemValuesChangedHandler(newValue) {
        var _a;
        (_a = this.dropdownListModelValue) === null || _a === void 0 ? void 0 : _a.setInputStringFromSelectedItem(newValue);
        super.onSelectedItemValuesChangedHandler(newValue);
    }
    hasUnknownValue(val, includeOther, isFilteredChoices, checkEmptyValue) {
        if (this.choicesLazyLoadEnabled) {
            return false;
        }
        return super.hasUnknownValue(val, includeOther, isFilteredChoices, checkEmptyValue);
    }
    needConvertRenderedOtherToDataValue() {
        var _a;
        const val = (_a = this.otherValue) === null || _a === void 0 ? void 0 : _a.trim();
        if (!val)
            return false;
        return super.hasUnknownValue(val, true, false);
    }
    getItemIfChoicesNotContainThisValue(value, text) {
        if (this.choicesLazyLoadEnabled) {
            return this.createItemValue(value, text);
        }
        else {
            return super.getItemIfChoicesNotContainThisValue(value, text);
        }
    }
    onVisibleChoicesChanged() {
        super.onVisibleChoicesChanged();
        if (!!this.dropdownListModelValue) {
            this.dropdownListModel.updateItems();
        }
    }
    canAddCustomChoices() {
        return this.allowCustomChoices;
    }
    getIsQuestionReady() {
        return super.getIsQuestionReady() && !this.isChoicesLoading;
    }
    ensureQuestionIsReady() {
        super.ensureQuestionIsReady();
        if (!!this.dropdownListModel && this.choicesLazyLoadEnabled) {
            this.dropdownListModel.loadQuestionChoices();
        }
    }
    setIsChoicesLoading(value) {
        this.isChoicesLoading = value;
        this.updateIsReady();
    }
    getFirstInputElementId() {
        return this.inputId + (this.searchEnabled || this.allowCustomChoices ? "_0" : "");
    }
    getInputId() {
        return this.inputId + "_0";
    }
    clearValue(keepComment) {
        var _a;
        super.clearValue(keepComment);
        this.lastSelectedItemValue = null;
        (_a = this.dropdownListModelValue) === null || _a === void 0 ? void 0 : _a.clear();
    }
    afterRenderCore(el) {
        super.afterRenderCore(el);
        if (!!this.dropdownListModelValue) {
            this.dropdownListModelValue.clear();
        }
    }
    onClick(e) {
        !!this.onOpenedCallBack && this.onOpenedCallBack();
    }
    onKeyUp(event) {
        const char = event.which || event.keyCode;
        if (char === 46) {
            this.clearValue(true);
            event.preventDefault();
            event.stopPropagation();
        }
    }
    supportEmptyValidation() { return true; }
    onBlurCore(event) {
        this.dropdownListModel.onBlur(event);
        super.onBlurCore(event);
    }
    onFocusCore(event) {
        this.dropdownListModel.onFocus(event);
        super.onFocusCore(event);
    }
    dispose() {
        super.dispose();
        if (!!this.dropdownListModelValue) {
            this.dropdownListModelValue.dispose();
            this.dropdownListModelValue = undefined;
        }
    }
}
__decorate([
    property()
], QuestionDropdownModel.prototype, "allowClear", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            if (!!target.dropdownListModelValue) {
                target.dropdownListModel.setSearchEnabled(newValue);
            }
        }
    })
], QuestionDropdownModel.prototype, "searchEnabled", void 0);
__decorate([
    property()
], QuestionDropdownModel.prototype, "searchMode", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            if (!!target.dropdownListModelValue) {
                target.dropdownListModel.setAllowCustomChoices(newValue);
            }
        }
    })
], QuestionDropdownModel.prototype, "allowCustomChoices", void 0);
__decorate([
    property()
], QuestionDropdownModel.prototype, "textWrapEnabled", void 0);
__decorate([
    property({ defaultValue: false })
], QuestionDropdownModel.prototype, "inputHasValue", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            if (!!target.dropdownListModelValue) {
                target.dropdownListModel.setChoicesLazyLoadEnabled(newValue);
            }
        }
    })
], QuestionDropdownModel.prototype, "choicesLazyLoadEnabled", void 0);
__decorate([
    property()
], QuestionDropdownModel.prototype, "choicesLazyLoadPageSize", void 0);
__decorate([
    property()
], QuestionDropdownModel.prototype, "suggestedItem", void 0);
Serializer.addClass("dropdown", [
    { name: "placeholder", alternativeName: "optionsCaption", serializationProperty: "locPlaceholder" },
    { name: "allowClear:boolean", alternativeName: "showOptionsCaption", default: true },
    { name: "choicesMin:number", default: 0 },
    { name: "choicesMax:number", default: 0 },
    { name: "choicesStep:number", default: 1, minValue: 1 },
    { name: "autocomplete", alternativeName: "autoComplete", choices: settings.questions.dataList, },
    { name: "textWrapEnabled:boolean", default: true },
    { name: "renderAs", default: "default", visible: false },
    { name: "searchEnabled:boolean", default: true, visible: false },
    {
        name: "allowCustomChoices:boolean", default: false,
        visibleIf: (obj) => !obj.choicesFromQuestion, dependsOn: "choicesFromQuestion"
    },
    { name: "searchMode", default: "contains", choices: ["contains", "startsWith"], },
    { name: "choicesLazyLoadEnabled:boolean", default: false, visible: false },
    { name: "choicesLazyLoadPageSize:number", default: 25, visible: false },
    { name: "inputFieldComponent", visible: false },
    { name: "itemComponent", visible: false, default: "" }
], function () {
    return new QuestionDropdownModel("");
}, "selectbase");
QuestionFactory.Instance.registerQuestion("dropdown", (name) => {
    var q = new QuestionDropdownModel(name);
    q.choices = QuestionFactory.DefaultChoices;
    return q;
});

class MatrixRowModel extends Base {
    constructor(item, fullName, data, value) {
        super();
        this.item = item;
        this.fullName = fullName;
        this.data = data;
        this.setValueDirectly(value);
        this.cellClick = (column) => {
            this.value = column.value;
        };
        this.registerPropertyChangedHandlers(["value"], () => {
            if (this.data)
                this.data.onMatrixRowChanged(this);
        });
        if (this.data && this.data.hasErrorInRow(this)) {
            this.hasError = true;
        }
    }
    get name() {
        return this.item.value;
    }
    get text() {
        return this.item.text;
    }
    get locText() {
        return this.item.locText;
    }
    get value() {
        return this.getPropertyValue("value");
    }
    set value(val) {
        if (!this.isReadOnly) {
            this.setValueDirectly(this.data.getCorrectedRowValue(val));
        }
    }
    setValueDirectly(val) {
        this.setPropertyValue("value", val);
    }
    get isReadOnly() { return !this.item.enabled || this.data.isInputReadOnly; }
    get isReadOnlyAttr() { return this.data.isReadOnlyAttr; }
    get isDisabledAttr() { return !this.item.enabled || this.data.isDisabledAttr; }
    get rowTextClasses() {
        return new CssClassBuilder().append(this.data.cssClasses.rowTextCell).toString();
    }
    get hasError() {
        return this.getPropertyValue("hasError", false);
    }
    set hasError(val) {
        this.setPropertyValue("hasError", val);
    }
    get rowClasses() {
        const cssClasses = this.data.cssClasses;
        return new CssClassBuilder().append(cssClasses.row)
            .append(cssClasses.rowError, this.hasError)
            .append(cssClasses.rowReadOnly, this.isReadOnly)
            .append(cssClasses.rowDisabled, this.data.isDisabledStyle)
            .toString();
    }
}
class MatrixCells extends Base {
    constructor(cellsOwner) {
        super();
        this.cellsOwner = cellsOwner;
        this.values = {};
        this.locs = {};
    }
    getType() { return "cells"; }
    get isEmpty() {
        return Object.keys(this.values).length == 0;
    }
    valuesChanged() {
        if (!this.locNotification && !!this.onValuesChanged) {
            this.onValuesChanged();
        }
    }
    getDefaultCellLocText(column) {
        return this.getCellLocCore(this.defaultRowValue, column);
    }
    getCellDisplayLocText(row, column) {
        return this.getCellLocCore(row, column);
    }
    getCellLocCore(row, col) {
        row = this.getCellRowColumnValue(row, this.rows);
        col = this.getCellRowColumnValue(col, this.columns);
        if (Helpers.isValueEmpty(row) || Helpers.isValueEmpty(col))
            return null;
        if (!this.locs[row]) {
            this.locs[row] = {};
        }
        let res = this.locs[row][col];
        if (!res) {
            res = this.createString();
            res.setJson(this.getCellLocData(row, col));
            res.onGetTextCallback = (str) => {
                if (!str) {
                    const column = ItemValue.getItemByValue(this.columns, col);
                    if (column) {
                        return column.locText.getJson() || column.value;
                    }
                }
                return str;
            };
            res.onStrChanged = (oldValue, newValue) => {
                this.updateValues(row, col, newValue);
            };
            this.locs[row][col] = res;
        }
        return res;
    }
    get defaultRowValue() { return settings.matrix.defaultRowName; }
    getCellLocData(row, col) {
        let data = this.getCellLocDataFromValue(row, col);
        if (data)
            return data;
        return this.getCellLocDataFromValue(this.defaultRowValue, col);
    }
    getCellLocDataFromValue(row, column) {
        if (!this.values[row])
            return null;
        if (!this.values[row][column])
            return null;
        return this.values[row][column];
    }
    getCellText(row, column) {
        var loc = this.getCellLocCore(row, column);
        return loc ? loc.calculatedText : null;
    }
    setCellText(row, column, val) {
        const loc = this.getCellLocCore(row, column);
        if (loc) {
            loc.text = val;
        }
    }
    updateValues(row, column, val) {
        if (val) {
            if (!this.values[row])
                this.values[row] = {};
            this.values[row][column] = val;
            this.valuesChanged();
        }
        else {
            if (this.values[row] && this.values[row][column]) {
                delete this.values[row][column];
                if (Object.keys(this.values[row]).length == 0) {
                    delete this.values[row];
                }
                this.valuesChanged();
            }
        }
    }
    getDefaultCellText(column) {
        var loc = this.getCellLocCore(this.defaultRowValue, column);
        return loc ? loc.calculatedText : null;
    }
    setDefaultCellText(column, val) {
        this.setCellText(this.defaultRowValue, column, val);
    }
    getCellDisplayText(row, column) {
        var loc = this.getCellDisplayLocText(row, column);
        return loc ? loc.calculatedText : null;
    }
    get rows() {
        return this.cellsOwner ? this.cellsOwner.getRows() : [];
    }
    get columns() {
        return this.cellsOwner ? this.cellsOwner.getColumns() : [];
    }
    getCellRowColumnValue(val, values) {
        if (val === null || val === undefined)
            return null;
        if (typeof val == "number") {
            if (val < 0 || val >= values.length)
                return null;
            val = values[val].value;
        }
        if (val.value)
            return val.value;
        return val;
    }
    getJson() {
        if (this.isEmpty)
            return null;
        const defaultRow = this.values[this.defaultRowValue];
        const res = {};
        for (let row in this.values) {
            const resRow = {};
            const rowValues = this.values[row];
            for (let col in rowValues) {
                if (row === this.defaultRowValue || !defaultRow || defaultRow[col] !== rowValues[col]) {
                    const loc = this.getCellLocCore(row, col);
                    resRow[col] = loc ? loc.getJson() : rowValues[col];
                }
            }
            res[row] = resRow;
        }
        return res;
    }
    setJson(value, isLoading) {
        this.values = {};
        if (!!value) {
            for (var row in value) {
                if (row == "pos")
                    continue;
                var rowValues = value[row];
                this.values[row] = {};
                for (var col in rowValues) {
                    if (col == "pos")
                        continue;
                    this.values[row][col] = rowValues[col];
                }
            }
        }
        this.locNotification = true;
        this.runFuncOnLocs((row, col, loc) => loc.setJson(this.getCellLocData(row, col)));
        this.locNotification = false;
        this.valuesChanged();
    }
    locStrsChanged() {
        this.runFuncOnLocs((row, col, loc) => loc.strChanged());
    }
    runFuncOnLocs(func) {
        for (let row in this.locs) {
            const rowValues = this.locs[row];
            for (let col in rowValues) {
                func(row, col, rowValues[col]);
            }
        }
    }
    createString() {
        return new LocalizableString(this.cellsOwner, true);
    }
}
/**
  * A class that describes the Single-Select Matrix question type.
  *
  * [View Demo](https://surveyjs.io/form-library/examples/single-selection-matrix-table-question/ (linkStyle))
  */
class QuestionMatrixModel extends QuestionMatrixBaseModel {
    constructor(name) {
        super(name);
        this.isRowChanging = false;
        this.emptyLocalizableString = new LocalizableString(this);
        this.cellsValue = new MatrixCells(this);
        this.cellsValue.onValuesChanged = () => {
            this.updateHasCellText();
            this.propertyValueChanged("cells", this.cells, this.cells);
        };
        this.registerPropertyChangedHandlers(["columns"], () => {
            this.onColumnsChanged();
        });
        this.registerPropertyChangedHandlers(["rows"], () => {
            this.runCondition(this.getDataFilteredValues(), this.getDataFilteredProperties());
            this.onRowsChanged();
        });
        this.registerPropertyChangedHandlers(["hideIfRowsEmpty"], () => {
            this.updateVisibilityBasedOnRows();
        });
    }
    getType() {
        return "matrix";
    }
    /**
     * The name of a component used to render cells.
     */
    get cellComponent() {
        return this.getPropertyValue("cellComponent");
    }
    set itemComponent(value) {
        this.setPropertyValue("cellComponent", value);
    }
    get hasSingleInput() {
        return false;
    }
    /**
     * Specifies whether each row requires an answer. If a respondent skips a row, the question displays a validation error.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/single-selection-matrix-table-question/ (linkStyle))
     * @see isRequired
     * @see eachRowUnique
     * @see validators
     */
    get eachRowRequired() {
        return this.getPropertyValue("eachRowRequired");
    }
    set eachRowRequired(val) {
        this.setPropertyValue("eachRowRequired", val);
    }
    /**
     * @deprecated Use the [`eachRowRequired`](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-question-model#eachRowRequired) property instead.
     */
    get isAllRowRequired() {
        return this.eachRowRequired;
    }
    set isAllRowRequired(val) {
        this.eachRowRequired = val;
    }
    /**
     * Specifies whether answers in all rows should be unique. If any answers duplicate, the question displays a validation error.
     * @see eachRowRequired
     * @see validators
     */
    get eachRowUnique() {
        return this.getPropertyValue("eachRowUnique");
    }
    set eachRowUnique(val) {
        this.setPropertyValue("eachRowUnique", val);
    }
    get hasRows() {
        return this.rows.length > 0;
    }
    /**
     * Specifies a sort order for matrix rows.
     *
     * Possible values:
     *
     * - `"initial"` (default) - Preserves the original order of the `rows` array.
     * - `"random"` - Arranges matrix rows in random order each time the question is displayed.
     * @see rows
     */
    get rowOrder() {
        return this.getPropertyValue("rowOrder");
    }
    set rowOrder(val) {
        val = val.toLowerCase();
        if (val == this.rowOrder)
            return;
        this.setPropertyValue("rowOrder", val);
        this.onRowsChanged();
    }
    /**
     * @deprecated Use the [`rowOrder`](https://surveyjs.io/form-library/documentation/api-reference/matrix-table-question-model#rowOrder) property instead.
     */
    get rowsOrder() {
        return this.rowOrder;
    }
    set rowsOrder(val) {
        this.rowOrder = val;
    }
    /**
     * Specifies whether to hide the question when the matrix has no visible rows.
     * @see rowsVisibleIf
     */
    get hideIfRowsEmpty() {
        return this.getPropertyValue("hideIfRowsEmpty");
    }
    set hideIfRowsEmpty(val) {
        this.setPropertyValue("hideIfRowsEmpty", val);
    }
    getRows() {
        return this.rows;
    }
    getColumns() {
        return this.visibleColumns;
    }
    addColumn(value, text) {
        var col = new ItemValue(value, text);
        this.columns.push(col);
        return col;
    }
    getItemClass(row, column) {
        const isChecked = row.value == column.value;
        const isDisabled = this.isReadOnly;
        const allowHover = !isChecked && !isDisabled;
        const hasCellText = this.hasCellText;
        const css = this.cssClasses;
        return new CssClassBuilder()
            .append(css.cell, hasCellText)
            .append(hasCellText ? css.cellText : css.label)
            .append(css.itemOnError, !hasCellText && (this.eachRowRequired || this.eachRowUnique ? row.hasError : this.hasCssError()))
            .append(hasCellText ? css.cellTextSelected : css.itemChecked, isChecked)
            .append(hasCellText ? css.cellTextDisabled : css.itemDisabled, this.isDisabledStyle)
            .append(hasCellText ? css.cellTextReadOnly : css.itemReadOnly, this.isReadOnlyStyle)
            .append(hasCellText ? css.cellTextPreview : css.itemPreview, this.isPreviewStyle)
            .append(css.itemHover, allowHover && !hasCellText)
            .toString();
    }
    get itemSvgIcon() {
        if (this.isPreviewStyle && this.cssClasses.itemPreviewSvgIconId) {
            return this.cssClasses.itemPreviewSvgIconId;
        }
        return this.cssClasses.itemSvgIconId;
    }
    locStrsChanged() {
        super.locStrsChanged();
        this.cells.locStrsChanged();
    }
    getQuizQuestionCount() {
        var res = 0;
        for (var i = 0; i < this.rows.length; i++) {
            if (!this.isValueEmpty(this.correctAnswer[this.rows[i].value]))
                res++;
        }
        return res;
    }
    getCorrectAnswerCount() {
        var res = 0;
        var value = this.value;
        for (var i = 0; i < this.rows.length; i++) {
            var row = this.rows[i].value;
            if (!this.isValueEmpty(value[row]) &&
                this.isTwoValueEquals(this.correctAnswer[row], value[row]))
                res++;
        }
        return res;
    }
    runConditionCore(values, properties) {
        ItemValue.runEnabledConditionsForItems(this.rows, undefined, values, properties);
        super.runConditionCore(values, properties);
    }
    createRowsVisibleIfRunner() {
        return !!this.rowsVisibleIf ? new ConditionRunner(this.rowsVisibleIf) : null;
    }
    onRowsChanged() {
        this.clearGeneratedRows();
        super.onRowsChanged();
    }
    getVisibleRows() {
        if (!!this.generatedVisibleRows)
            return this.generatedVisibleRows;
        const result = new Array();
        let val = this.value;
        if (!val)
            val = {};
        const rows = this.filteredRows || this.rows;
        for (let i = 0; i < rows.length; i++) {
            const row = rows[i];
            if (this.isValueEmpty(row.value))
                continue;
            const rowId = this.id + "_" + row.value.toString().replace(/\s/g, "_");
            result.push(this.createMatrixRow(row, rowId, val[row.value]));
        }
        this.generatedVisibleRows = result;
        return result;
    }
    getRowByName(name) {
        const rows = this.visibleRows;
        for (let i = 0; i < rows.length; i++) {
            if (rows[i].name === name)
                return rows[i];
        }
        return null;
    }
    getSingleInputQuestionsCore(question, checkDynamic) {
        if (!!this.nestedQuestionsValue)
            return this.nestedQuestionsValue;
        const res = [];
        this.visibleRows.forEach(row => {
            const question = Serializer.createClass("radiogroup");
            question.name = row.name;
            question.locTitle.sharedData = row.locText;
            question.choices = this.visibleColumns;
            question.value = row.value;
            question.isRequired = this.isAllRowRequired;
            question.setSurveyImpl(this);
            question.setParentQuestion(this);
            res.push(question);
        });
        this.nestedQuestionsValue = res;
        return res;
    }
    resetSingleInput() {
        super.resetSingleInput();
        if (this.nestedQuestionsValue) {
            this.nestedQuestionsValue.forEach(q => q.dispose());
            this.nestedQuestionsValue = null;
        }
    }
    //#region For simple radiogroup questions setSurveyImpl
    getSurveyData() { return this; }
    getTextProcessor() { var _a; return (_a = this.surveyImpl) === null || _a === void 0 ? void 0 : _a.getTextProcessor(); }
    getValue(name) {
        const row = this.getRowByName(name);
        return !!row ? row.value : undefined;
    }
    setValue(name, newValue, locNotification, allowNotifyValueChanged, questionName) {
        this.getRowByName(name).value = newValue;
    }
    getVariable(name) { var _a; return (_a = this.data) === null || _a === void 0 ? void 0 : _a.getVariable(name); }
    setVariable(name, newValue) { var _a; (_a = this.data) === null || _a === void 0 ? void 0 : _a.setVariable(name, newValue); }
    getComment(name) { var _a; return (_a = this.data) === null || _a === void 0 ? void 0 : _a.getComment(name); }
    setComment(name, newValue, locNotification) { var _a; (_a = this.data) === null || _a === void 0 ? void 0 : _a.setComment(name, newValue, locNotification); }
    getAllValues() { var _a; return (_a = this.data) === null || _a === void 0 ? void 0 : _a.getAllValues(); }
    getFilteredValues() { var _a; return (_a = this.data) === null || _a === void 0 ? void 0 : _a.getFilteredValues(); }
    getFilteredProperties() { var _a; return (_a = this.data) === null || _a === void 0 ? void 0 : _a.getFilteredProperties(); }
    findQuestionByName(name) { var _a; return (_a = this.data) === null || _a === void 0 ? void 0 : _a.findQuestionByName(name); }
    getEditingSurveyElement() { var _a; return (_a = this.data) === null || _a === void 0 ? void 0 : _a.getEditingSurveyElement(); }
    //#endregion
    sortVisibleRows(array) {
        if (!!this.survey && this.survey.isDesignMode)
            return array;
        var order = this.rowOrder.toLowerCase();
        if (order === "random")
            return Helpers.randomizeArray(array);
        return array;
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        this.rows = this.sortVisibleRows(this.rows);
        this.onRowsChanged();
        this.onColumnsChanged();
    }
    isNewValueCorrect(val) {
        return Helpers.isValueObject(val, true);
    }
    processRowsOnSet(newRows) {
        return this.sortVisibleRows(newRows);
    }
    get visibleRows() {
        return this.getVisibleRows();
    }
    /**
     * An array of matrix cells. Use this array to get or set cell values.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/questiontype-matrix-rubric/ (linkStyle))
     */
    get cells() {
        return this.cellsValue;
    }
    set cells(value) {
        this.cells.setJson(value && value.getJson ? value.getJson() : null);
    }
    get hasCellText() {
        return this.getPropertyValue("hasCellText", false);
    }
    updateHasCellText() {
        this.setPropertyValue("hasCellText", !this.cells.isEmpty);
    }
    setCellText(row, column, val) {
        this.cells.setCellText(row, column, val);
    }
    getCellText(row, column) {
        return this.cells.getCellText(row, column);
    }
    setDefaultCellText(column, val) {
        this.cells.setDefaultCellText(column, val);
    }
    getDefaultCellText(column) {
        return this.cells.getDefaultCellText(column);
    }
    getCellDisplayText(row, column) {
        return this.cells.getCellDisplayText(row, column);
    }
    getCellDisplayLocText(row, column) {
        var loc = this.cells.getCellDisplayLocText(row, column);
        return loc ? loc : this.emptyLocalizableString;
    }
    supportAutoAdvance() {
        return this.isMouseDown === true && this.hasValuesInAllRows();
    }
    onCheckForErrors(errors, isOnValueChanged, fireCallback) {
        super.onCheckForErrors(errors, isOnValueChanged, fireCallback);
        if (!isOnValueChanged || this.hasCssError()) {
            const rowsErrors = { noValue: false, isNotUnique: false };
            this.checkErrorsAllRows(fireCallback, rowsErrors);
            if (rowsErrors.noValue) {
                errors.push(new RequiredInAllRowsError(null, this));
            }
            if (rowsErrors.isNotUnique) {
                errors.push(new EachRowUniqueError(null, this));
            }
        }
    }
    hasValuesInAllRows() {
        const rowsErrors = { noValue: false, isNotUnique: false };
        this.checkErrorsAllRows(false, rowsErrors, true);
        return !rowsErrors.noValue;
    }
    checkErrorsAllRows(modifyErrors, res, allRowsRequired) {
        var rows = this.generatedVisibleRows;
        if (!rows)
            rows = this.visibleRows;
        if (!rows)
            return;
        const rowsRequired = this.eachRowRequired || allRowsRequired;
        const rowsUnique = this.eachRowUnique;
        res.noValue = false;
        res.isNotUnique = false;
        if (modifyErrors) {
            this.errorsInRow = undefined;
        }
        if (!rowsRequired && !rowsUnique)
            return;
        const hash = {};
        for (var i = 0; i < rows.length; i++) {
            const val = rows[i].value;
            let isEmpty = this.isValueEmpty(val);
            const isNotUnique = rowsUnique && (!isEmpty && hash[val] === true);
            isEmpty = isEmpty && rowsRequired;
            if (modifyErrors && (isEmpty || isNotUnique)) {
                this.addErrorIntoRow(rows[i]);
            }
            if (!isEmpty) {
                hash[val] = true;
            }
            res.noValue = res.noValue || isEmpty;
            res.isNotUnique = res.isNotUnique || isNotUnique;
        }
        if (modifyErrors) {
            rows.forEach(row => {
                row.hasError = this.hasErrorInRow(row);
            });
        }
    }
    addErrorIntoRow(row) {
        if (!this.errorsInRow)
            this.errorsInRow = {};
        this.errorsInRow[row.name] = true;
        row.hasError = true;
    }
    refreshRowsErrors() {
        if (!this.errorsInRow)
            return;
        this.checkErrorsAllRows(true, { noValue: false, isNotUnique: false });
    }
    getIsAnswered() {
        return super.getIsAnswered() && this.hasValuesInAllRows();
    }
    createMatrixRow(item, fullName, value) {
        var row = new MatrixRowModel(item, fullName, this, value);
        this.onMatrixRowCreated(row);
        return row;
    }
    onMatrixRowCreated(row) { }
    setQuestionValue(newValue, updateIsAnswered = true) {
        super.setQuestionValue(newValue, this.isRowChanging || updateIsAnswered);
        if (!this.generatedVisibleRows || this.generatedVisibleRows.length == 0)
            return;
        this.isRowChanging = true;
        var val = this.value;
        if (!val)
            val = {};
        if (this.rows.length == 0) {
            this.generatedVisibleRows[0].setValueDirectly(val);
        }
        else {
            for (var i = 0; i < this.generatedVisibleRows.length; i++) {
                var row = this.generatedVisibleRows[i];
                var rowVal = val[row.name];
                if (this.isValueEmpty(rowVal))
                    rowVal = null;
                this.generatedVisibleRows[i].setValueDirectly(rowVal);
            }
        }
        this.refreshRowsErrors();
        this.updateIsAnswered();
        this.isRowChanging = false;
    }
    getDisplayValueCore(keysAsText, value) {
        var res = {};
        for (var key in value) {
            var newKey = keysAsText
                ? ItemValue.getTextOrHtmlByValue(this.rows, key)
                : key;
            if (!newKey)
                newKey = key;
            var newValue = ItemValue.getTextOrHtmlByValue(this.columns, value[key]);
            if (!newValue)
                newValue = value[key];
            res[newKey] = newValue;
        }
        return res;
    }
    getPlainData(options = {
        includeEmpty: true,
    }) {
        var questionPlainData = super.getPlainData(options);
        if (!!questionPlainData) {
            var values = this.createValueCopy();
            questionPlainData.isNode = true;
            questionPlainData.data = Object.keys(values || {}).map((rowName) => {
                var row = this.rows.filter((r) => r.value === rowName)[0];
                var rowDataItem = {
                    name: rowName,
                    title: !!row ? row.text : "row",
                    value: values[rowName],
                    displayValue: ItemValue.getTextOrHtmlByValue(this.visibleColumns, values[rowName]),
                    getString: (val) => typeof val === "object" ? JSON.stringify(val) : val,
                    isNode: false,
                };
                var item = ItemValue.getItemByValue(this.visibleColumns, values[rowName]);
                if (!!item) {
                    (options.calculations || []).forEach((calculation) => {
                        rowDataItem[calculation.propertyName] =
                            item[calculation.propertyName];
                    });
                }
                return rowDataItem;
            });
        }
        return questionPlainData;
    }
    addConditionObjectsByContext(objects, context) {
        for (var i = 0; i < this.rows.length; i++) {
            var row = this.rows[i];
            if (!!row.value) {
                objects.push({
                    name: this.getValueName() + "." + row.value,
                    text: this.processedTitle + "." + row.calculatedText,
                    question: this,
                });
            }
        }
    }
    getConditionJson(operator = null, path = null) {
        if (!path)
            return super.getConditionJson(operator);
        var question = new QuestionDropdownModel(path);
        question.choices = this.columns;
        var json = new JsonObject().toJsonObject(question);
        json["type"] = question.getType();
        return json;
    }
    clearIncorrectValues() {
        this.clearInvisibleValuesInRowsAndColumns(true, true, true);
        super.clearIncorrectValues();
    }
    clearValueIfInvisibleCore(reason) {
        super.clearValueIfInvisibleCore(reason);
        this.clearInvisibleValuesInRowsAndColumns(true, true, false);
    }
    clearInvisibleColumnValues() {
        this.clearInvisibleValuesInRowsAndColumns(false, true, false);
    }
    clearInvisibleValuesInRows() {
        this.clearInvisibleValuesInRowsAndColumns(true, false, false);
    }
    clearInvisibleValuesInRowsAndColumns(inRows, inColumns, inCorrectRows) {
        if (this.isEmpty())
            return;
        let updatedData = this.getUnbindValue(this.value);
        const newData = {};
        var rows = this.rows;
        for (var i = 0; i < rows.length; i++) {
            var key = rows[i].value;
            if (!!updatedData[key]) {
                if (inRows && !rows[i].isVisible || inColumns && !this.getVisibleColumnByValue(updatedData[key])) {
                    delete updatedData[key];
                }
                else {
                    newData[key] = updatedData[key];
                }
            }
        }
        if (inCorrectRows) {
            updatedData = newData;
        }
        if (this.isTwoValueEquals(updatedData, this.value))
            return;
        this.value = updatedData;
    }
    getVisibleColumnByValue(val) {
        const col = ItemValue.getItemByValue(this.columns, val);
        return !!col && col.isVisible ? col : null;
    }
    getFirstInputElementId() {
        var rows = this.generatedVisibleRows;
        if (!rows)
            rows = this.visibleRows;
        if (rows.length > 0 && this.visibleColumns.length > 0) {
            return this.inputId + "_" + rows[0].name + "_" + 0;
        }
        return super.getFirstInputElementId();
    }
    //IMatrixData
    onMatrixRowChanged(row) {
        if (this.isRowChanging)
            return;
        this.isRowChanging = true;
        if (!this.hasRows) {
            this.setNewValue(row.value);
        }
        else {
            var newValue = this.value;
            if (!newValue) {
                newValue = {};
            }
            newValue[row.name] = row.value;
            this.setNewValue(newValue);
        }
        this.isRowChanging = false;
    }
    getCorrectedRowValue(value) {
        for (var i = 0; i < this.columns.length; i++) {
            if (value === this.columns[i].value)
                return value;
        }
        for (var i = 0; i < this.columns.length; i++) {
            if (this.isTwoValueEquals(value, this.columns[i].value))
                return this.columns[i].value;
        }
        return value;
    }
    hasErrorInRow(row) {
        return !!this.errorsInRow && !!this.errorsInRow[row.name];
    }
    getSearchableItemValueKeys(keys) {
        keys.push("columns");
        keys.push("rows");
    }
    get SurveyModel() {
        return this.survey;
    }
    getColumnHeaderWrapperComponentName(cell) {
        return this.SurveyModel.getElementWrapperComponentName({ column: cell }, "column-header");
    }
    getColumnHeaderWrapperComponentData(cell) {
        return this.SurveyModel.getElementWrapperComponentData({ column: cell }, "column-header");
    }
    getRowHeaderWrapperComponentName(cell) {
        return this.SurveyModel.getElementWrapperComponentName({ row: cell }, "row-header");
    }
    getRowHeaderWrapperComponentData(cell) {
        return this.SurveyModel.getElementWrapperComponentData({ row: cell }, "row-header");
    }
}
Serializer.addClass("matrix", [
    "rowTitleWidth",
    {
        name: "columns:itemvalue[]", uniqueProperty: "value",
        baseValue: function () {
            return getLocaleString("matrix_column");
        },
    },
    {
        name: "rows:itemvalue[]", uniqueProperty: "value",
        baseValue: function () {
            return getLocaleString("matrix_row");
        },
    },
    { name: "cells:cells", serializationProperty: "cells" },
    {
        name: "rowOrder", alternativeName: "rowsOrder",
        default: "initial",
        choices: ["initial", "random"],
    },
    { name: "eachRowRequired:boolean", alternativeName: "isAllRowRequired" },
    { name: "eachRowUnique:boolean", category: "validation" },
    "hideIfRowsEmpty:boolean",
    { name: "cellComponent", visible: false, default: "survey-matrix-cell" }
], function () {
    return new QuestionMatrixModel("");
}, "matrixbase");
QuestionFactory.Instance.registerQuestion("matrix", (name) => {
    var q = new QuestionMatrixModel(name);
    q.rows = QuestionFactory.DefaultRows;
    q.columns = QuestionFactory.DefaultColums;
    return q;
});

class CharacterCounter extends Base {
    updateRemainingCharacterCounter(newValue, maxLength) {
        this.remainingCharacterCounter = Helpers.getRemainingCharacterCounterText(newValue, maxLength);
    }
}
__decorate([
    property()
], CharacterCounter.prototype, "remainingCharacterCounter", void 0);
/**
 * A base class for the [Single-Line Input](https://surveyjs.io/form-library/documentation/questiontextmodel) and [Long Text](https://surveyjs.io/form-library/documentation/questioncommentmodel) question types.
 */
class QuestionTextBase extends Question {
    constructor(name) {
        super(name);
        this.characterCounter = new CharacterCounter();
    }
    isTextValue() {
        return true;
    }
    /**
     * The maximum text length measured in characters. Assign 0 if the length should be unlimited.
     *
     * Default value: -1 (inherits the actual value from the `SurveyModel`'s [`maxTextLength`](https://surveyjs.io/form-library/documentation/surveymodel#maxTextLength) property).
     *
     * [Long Text Demo](https://surveyjs.io/form-library/examples/add-open-ended-question-to-a-form/ (linkStyle))
     */
    get maxLength() {
        return this.getPropertyValue("maxLength");
    }
    set maxLength(val) {
        this.setPropertyValue("maxLength", val);
        this.updateRemainingCharacterCounter(this.value);
    }
    getMaxLength() {
        return Helpers.getMaxLength(this.maxLength, this.survey ? this.survey.maxTextLength : -1);
    }
    updateRemainingCharacterCounter(newValue) {
        this.characterCounter.updateRemainingCharacterCounter(newValue, this.getMaxLength());
    }
    get placeHolder() { return this.placeholder; }
    set placeHolder(val) { this.placeholder = val; }
    get locPlaceHolder() { return this.locPlaceholder; }
    getType() {
        return "textbase";
    }
    isEmpty() {
        return super.isEmpty() || this.value === "";
    }
    /**
     * Specifies when to update the question value.
     *
     * Possible values:
     *
     * - `"onBlur"` - Updates the value after the input field loses focus.
     * - `"onTyping"` - Updates the value on every key press.
     * - `"default"` (default) - Inherits the value from the `SurveyModel`'s [`textUpdateMode`](https://surveyjs.io/form-library/documentation/surveymodel#textUpdateMode) property.
     *
     * > Do not use the `"onTyping"` mode if your survey contains many expressions. Expressions are re-evaluated each time a question value is changed. In `"onTyping"` mode, the question value changes frequently. This may cause performance degradation.
     */
    get textUpdateMode() {
        return this.getPropertyValue("textUpdateMode");
    }
    set textUpdateMode(val) {
        this.setPropertyValue("textUpdateMode", val);
    }
    getIsInputTextUpdate() {
        if (this.textUpdateMode == "default")
            return super.getIsInputTextUpdate();
        return this.textUpdateMode == "onTyping";
    }
    get renderedPlaceholder() {
        const func = () => {
            return this.hasPlaceholder() ? this.placeHolder : undefined;
        };
        return this.getPropertyValue("renderedPlaceholder", undefined, func);
    }
    onReadOnlyChanged() {
        super.onReadOnlyChanged();
        this.resetRenderedPlaceholder();
    }
    localeChanged() {
        super.localeChanged();
        this.resetRenderedPlaceholder();
    }
    supportEmptyValidation() { return true; }
    resetRenderedPlaceholder() {
        this.resetPropertyValue("renderedPlaceholder");
    }
    hasPlaceholder() {
        return !this.isReadOnly;
    }
    setNewValue(newValue) {
        super.setNewValue(newValue);
        this.updateRemainingCharacterCounter(newValue);
    }
    setQuestionValue(newValue, updateIsAnswered = true) {
        super.setQuestionValue(newValue, updateIsAnswered);
        this.updateRemainingCharacterCounter(newValue);
    }
    convertToCorrectValue(val) {
        if (Array.isArray(val))
            return val.join(this.getValueSeparator());
        return val;
    }
    getValueSeparator() { return ", "; }
    getControlCssClassBuilder() {
        return new CssClassBuilder()
            .append(this.cssClasses.root)
            .append(this.cssClasses.onError, this.hasCssError())
            .append(this.cssClasses.controlDisabled, this.isDisabledStyle)
            .append(this.cssClasses.controlReadOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.controlPreview, this.isPreviewStyle);
    }
    getControlClass() {
        return this.getControlCssClassBuilder().toString();
    }
    //a11y
    get isNewA11yStructure() {
        return true;
    }
}
__decorate([
    property({ localizable: true, onSet: (val, target) => target.resetRenderedPlaceholder() })
], QuestionTextBase.prototype, "placeholder", void 0);
Serializer.addClass("textbase", [], function () {
    return new QuestionTextBase("");
}, "question");

class InputElementAdapter {
    setInputValue(value) {
        if (this.inputElement.maxLength >= 0 && this.inputElement.maxLength < value.length) {
            value = value.slice(0, this.inputElement.maxLength);
        }
        this.inputElement.value = value;
    }
    constructor(inputMaskInstance, inputElement, value) {
        this.inputMaskInstance = inputMaskInstance;
        this.inputElement = inputElement;
        this.prevUnmaskedValue = undefined;
        this.inputMaskInstancePropertyChangedHandler = (sender, options) => {
            if (options.name !== "saveMaskedValue") {
                const maskedValue = this.inputMaskInstance.getMaskedValue(this.prevUnmaskedValue);
                this.setInputValue(maskedValue);
            }
        };
        this.clickHandler = (event) => {
            if (this.inputElement.value == this.inputMaskInstance.getMaskedValue("")) {
                this.inputElement.setSelectionRange(0, 0);
            }
        };
        this.beforeInputHandler = (event) => {
            const args = this.createArgs(event);
            const result = this.inputMaskInstance.processInput(args);
            this.setInputValue(result.value);
            this.inputElement.setSelectionRange(result.caretPosition, result.caretPosition);
            if (!result.cancelPreventDefault) {
                event.preventDefault();
            }
        };
        this.changeHandler = (event) => {
            const result = this.inputMaskInstance.processInput({ prevValue: "", insertedChars: event.target.value, selectionStart: 0, selectionEnd: 0 });
            this.setInputValue(result.value);
        };
        let _value = value;
        if (_value === null || _value === undefined) {
            _value = "";
        }
        this.setInputValue(inputMaskInstance.saveMaskedValue ? _value : inputMaskInstance.getMaskedValue(_value));
        this.prevUnmaskedValue = _value;
        inputMaskInstance.onPropertyChanged.add(this.inputMaskInstancePropertyChangedHandler);
        this.addInputEventListener();
    }
    createArgs(event) {
        const args = {
            insertedChars: event.data,
            selectionStart: event.target.selectionStart,
            selectionEnd: event.target.selectionEnd,
            prevValue: event.target.value,
            inputDirection: "forward"
        };
        if (event.inputType === "deleteContentBackward") {
            args.inputDirection = "backward";
            if (args.selectionStart === args.selectionEnd) {
                args.selectionStart = Math.max(args.selectionStart - 1, 0);
            }
        }
        if (event.inputType === "deleteContentForward" && args.selectionStart === args.selectionEnd) {
            args.selectionEnd += 1;
        }
        return args;
    }
    addInputEventListener() {
        if (!!this.inputElement) {
            this.inputElement.addEventListener("beforeinput", this.beforeInputHandler);
            this.inputElement.addEventListener("click", this.clickHandler);
            this.inputElement.addEventListener("focus", this.clickHandler);
            this.inputElement.addEventListener("change", this.changeHandler);
        }
    }
    removeInputEventListener() {
        if (!!this.inputElement) {
            this.inputElement.removeEventListener("beforeinput", this.beforeInputHandler);
            this.inputElement.removeEventListener("click", this.clickHandler);
            this.inputElement.removeEventListener("focus", this.clickHandler);
            this.inputElement.removeEventListener("change", this.changeHandler);
        }
    }
    dispose() {
        this.removeInputEventListener();
        this.inputElement = undefined;
        this.inputMaskInstance.onPropertyChanged.remove(this.inputMaskInstancePropertyChangedHandler);
    }
}

var numberDefinition = /[0-9]/;
function getAvailableMaskTypeChoices() {
    const classes = Serializer.getChildrenClasses("masksettings") || [];
    const choices = classes.map((cl) => {
        let value = cl.name;
        if (cl.name.indexOf("mask") !== -1) {
            value = value.slice(0, value.indexOf("mask"));
        }
        return value;
    });
    choices.unshift("none");
    return choices;
}

/**
 * A class that describes the Single-Line Input question type, which is used to create textual, numeric, date-time, and color input fields.
 *
 * [Text Entry Demo](https://surveyjs.io/form-library/examples/text-entry-question/ (linkStyle))
 *
 * [Date-Time Entry Demo](https://surveyjs.io/form-library/examples/datetime-entry-question/ (linkStyle))
 *
 * [Numeric Entry Demo](https://surveyjs.io/form-library/examples/numeric-entry-question/ (linkStyle))
 *
 * [Color Input Demo](https://surveyjs.io/form-library/examples/color-input-question/ (linkStyle))
 */
class QuestionTextModel extends QuestionTextBase {
    createMaskAdapter() {
        if (!!this.input && !this.maskTypeIsEmpty) {
            this.maskInputAdapter = new InputElementAdapter(this.maskInstance, this.input, this.value);
        }
    }
    deleteMaskAdapter() {
        if (this.maskInputAdapter) {
            this.maskInputAdapter.dispose();
            this.maskInputAdapter = undefined;
        }
    }
    updateMaskAdapter() {
        this.deleteMaskAdapter();
        this.createMaskAdapter();
    }
    onSetMaskType(newValue) {
        this.setNewMaskSettingsProperty();
        this.updateMaskAdapter();
    }
    get maskTypeIsEmpty() {
        switch (this.inputType) {
            case "tel":
            case "text": return this.maskType === "none";
            default: return true;
        }
    }
    /**
     * An object with properties that configure the mask applied to the input.
     *
     * Available properties depend on the specified [`maskType`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#maskType) and belong to corresponding classes. Refer to the class APIs for a full list of properties:
     *
     * | `maskType` | Class |
     * | ---------- | ----- |
     * | `"numeric"` | [`InputMaskNumeric`](https://surveyjs.io/form-library/documentation/api-reference/inputmasknumeric) |
     * | `"currency"` | [`InputMaskCurrency`](https://surveyjs.io/form-library/documentation/api-reference/inputmaskcurrency) |
     * | `"datetime"` | [`InputMaskDateTime`](https://surveyjs.io/form-library/documentation/api-reference/inputmaskdatetime) |
     * | `"pattern"` | [`InputMaskPattern`](https://surveyjs.io/form-library/documentation/api-reference/inputmaskpattern) |
     *
     * [View Demo](https://surveyjs.io/form-library/examples/masked-input-fields/ (linkStyle))
     */
    get maskSettings() {
        return this.getPropertyValue("maskSettings");
    }
    set maskSettings(val) {
        if (!val)
            return;
        const oldValue = this.maskSettings;
        if (oldValue) {
            oldValue.dispose();
        }
        this.setNewMaskSettingsProperty();
        this.maskSettings.fromJSON(val.toJSON());
        this.updateMaskAdapter();
    }
    setNewMaskSettingsProperty() {
        this.setPropertyValue("maskSettings", this.createMaskSettings());
    }
    createMaskSettings() {
        let maskClassName = (!this.maskType || this.maskType === "none") ? "masksettings" : (this.maskType + "mask");
        if (!Serializer.findClass(maskClassName)) {
            maskClassName = "masksettings";
        }
        const inputMask = Serializer.createClass(maskClassName);
        inputMask.onPropertyChanged.add((_, options) => {
            this.onNestedPropertyChanged.fire(this, { name: "maskSettings", newValue: options.newValue, nestedName: options.name });
            this.updateInputValue();
        });
        inputMask.owner = this;
        return inputMask;
    }
    constructor(name) {
        super(name);
        //web-based methods
        this._isWaitingForEnter = false;
        this.onCompositionUpdate = (event) => {
            if (this.isInputTextUpdate) {
                setTimeout(() => {
                    this.updateValueOnEvent(event);
                }, 1);
            }
            this.updateRemainingCharacterCounter(event.target.value);
        };
        this.onKeyUp = (event) => {
            this.updateDateValidationMessage(event);
            if (this.isInputTextUpdate) {
                if (!this._isWaitingForEnter || event.keyCode === 13) {
                    this.updateValueOnEvent(event);
                    this._isWaitingForEnter = false;
                }
            }
            else {
                if (event.keyCode === 13) {
                    this.updateValueOnEvent(event);
                }
            }
            this.updateRemainingCharacterCounter(event.target.value);
        };
        this.readOnlyBlocker = (event) => {
            if (this.isReadOnlyAttr && ["color", "range"].indexOf(this.inputType) > -1) {
                event.preventDefault();
                return true;
            }
        };
        this.onKeyDown = (event) => {
            if (this.readOnlyBlocker(event)) {
                return;
            }
            this.onKeyDownPreprocess && this.onKeyDownPreprocess(event);
            if (this.isInputTextUpdate) {
                this._isWaitingForEnter = event.keyCode === 229;
            }
            this.onTextKeyDownHandler(event);
        };
        this.onChange = (event) => {
            this.updateDateValidationMessage(event);
            const elementIsFocused = event.target === settings.environment.root.activeElement;
            if (elementIsFocused) {
                if (this.isInputTextUpdate) {
                    this.updateValueOnEvent(event);
                }
            }
            else {
                this.updateValueOnEvent(event);
            }
            this.updateRemainingCharacterCounter(event.target.value);
        };
        this.createLocalizableString("minErrorText", this, true, "minError");
        this.createLocalizableString("maxErrorText", this, true, "maxError");
        this.setNewMaskSettingsProperty();
        this.locDataListValue = new LocalizableStrings(this);
        this.locDataListValue.onValueChanged = (oldValue, newValue) => {
            this.propertyValueChanged("dataList", oldValue, newValue);
        };
        this.registerPropertyChangedHandlers(["min", "max", "inputType", "minValueExpression", "maxValueExpression"], () => {
            this.setRenderedMinMax();
        });
        this.registerPropertyChangedHandlers(["inputType", "inputSize"], () => {
            this.resetInputSize();
            this.resetRenderedPlaceholder();
        });
    }
    isTextValue() {
        return this.isDateInputType || ["text", "number", "password"].indexOf(this.inputType) > -1;
    }
    getType() {
        return "text";
    }
    onSurveyLoad() {
        super.onSurveyLoad();
        this.setRenderedMinMax();
    }
    /**
     * A value passed on to the [`type`](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#input_types) attribute of the underlying `<input>` element.
     *
     * Default value: `"text"`
     *
     * [Text Entry Demo](https://surveyjs.io/form-library/examples/text-entry-question/ (linkStyle))
     *
     * [Date-Time Entry Demo](https://surveyjs.io/form-library/examples/datetime-entry-question/ (linkStyle))
     *
     * [Numeric Entry Demo](https://surveyjs.io/form-library/examples/numeric-entry-question/ (linkStyle))
     *
     * [Color Input Demo](https://surveyjs.io/form-library/examples/color-input-question/ (linkStyle))
     */
    get inputType() {
        return this.getPropertyValue("inputType");
    }
    set inputType(val) {
        val = val.toLowerCase();
        if (val === "datetime_local" || val === "datetime")
            val = "datetime-local";
        this.setPropertyValue("inputType", val.toLowerCase());
        if (!this.isLoadingFromJson) {
            this.min = undefined;
            this.max = undefined;
            this.step = undefined;
        }
        this.updateMaskAdapter();
    }
    getMaxLength() {
        if (!this.isTextInput)
            return null;
        return super.getMaxLength();
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        if (!!this.minValueExpression || !!this.maxValueExpression) {
            this.setRenderedMinMax(values, properties);
        }
    }
    getDisplayValueCore(keysAsText, value) {
        if (!this.maskTypeIsEmpty && !Helpers.isValueEmpty(value))
            return this.maskInstance.getMaskedValue(value);
        return super.getDisplayValueCore(keysAsText, value);
    }
    isLayoutTypeSupported(layoutType) {
        return true;
    }
    /**
     * A value passed on to the [`size`](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/size) attribute of the underlying `<input>` element.
     */
    get inputSize() {
        return this.getPropertyValue("inputSize");
    }
    set inputSize(val) {
        this.setPropertyValue("inputSize", val);
    }
    /**
     * @deprecated Use the [`inputSize`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#inputSize) property instead.
     */
    get size() {
        return this.inputSize;
    }
    set size(val) {
        this.inputSize = val;
    }
    get isTextInput() {
        return (["text", "search", "tel", "url", "email", "password"].indexOf(this.inputType) > -1);
    }
    get renderedInputSize() {
        return this.getPropertyValue("renderedInputSize", undefined, () => {
            const size = this.calInputSize();
            return size > 0 ? size : undefined;
        });
    }
    get inputWidth() {
        return this.getPropertyValue("inputWidth", undefined, () => {
            return this.calInputSize() > 0 ? "auto" : "";
        });
    }
    calInputSize() {
        if (!this.isTextInput)
            return 0;
        let size = this.inputSize > 0 ? this.inputSize : 0;
        if (size < 1 && this.parent && !!this.parent["inputSize"]) {
            size = this.parent["inputSize"];
        }
        return size;
    }
    resetInputSize() {
        this.resetPropertyValue("renderedInputSize");
        this.resetPropertyValue("inputWidth");
    }
    /**
     * A value passed on to the [`autocomplete`](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/autocomplete) attribute of the underlying `<input>` element.
     */
    get autocomplete() {
        return this.getPropertyValue("autocomplete");
    }
    set autocomplete(val) {
        this.setPropertyValue("autocomplete", val);
    }
    /**
     * A value passed on to the [`min`](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/min) attribute of the underlying `<input>` element.
     * @see minValueExpression
     */
    get min() {
        return this.getPropertyValue("min");
    }
    set min(val) {
        if (this.isValueExpression(val)) {
            this.minValueExpression = val.substring(1);
            return;
        }
        this.setPropertyValue("min", val);
    }
    /**
     * A value passed on to the [`max`](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/max) attribute of the underlying `<input>` element.
     * @see maxValueExpression
     */
    get max() {
        return this.getPropertyValue("max");
    }
    set max(val) {
        if (this.isValueExpression(val)) {
            this.maxValueExpression = val.substring(1);
            return;
        }
        this.setPropertyValue("max", val);
    }
    /**
     * The minimum value specified as an expression. For example, `"minValueExpression": "today(-1)"` sets the minimum value to yesterday.
     * @see min
     */
    get minValueExpression() {
        return this.getPropertyValue("minValueExpression", "");
    }
    set minValueExpression(val) {
        this.setPropertyValue("minValueExpression", val);
    }
    /**
     * The maximum value specified as an expression. For example, `"maxValueExpression": "today(1)"` sets the maximum value to tomorrow.
     * @see max
     */
    get maxValueExpression() {
        return this.getPropertyValue("maxValueExpression", "");
    }
    set maxValueExpression(val) {
        this.setPropertyValue("maxValueExpression", val);
    }
    get renderedMin() {
        return this.getPropertyValue("renderedMin");
    }
    get renderedMax() {
        return this.getPropertyValue("renderedMax");
    }
    /**
     * An error message to display when the question value is less than the minimum accepted value.
     * @see min
     * @see minValueExpression
     */
    get minErrorText() {
        return this.getLocalizableStringText("minErrorText");
    }
    set minErrorText(val) {
        this.setLocalizableStringText("minErrorText", val);
    }
    get locMinErrorText() {
        return this.getLocalizableString("minErrorText");
    }
    /**
     * An error message to display when the question value exceeds the maximum accepted value.
     * @see max
     * @see maxValueExpression
     */
    get maxErrorText() {
        return this.getLocalizableStringText("maxErrorText");
    }
    set maxErrorText(val) {
        this.setLocalizableStringText("maxErrorText", val);
    }
    get locMaxErrorText() {
        return this.getLocalizableString("maxErrorText");
    }
    /**
     * Returns `true` if the specified `inputType` supports the `min` and `max` properties.
     * @see inputType
     * @see min
     * @see max
     */
    get isMinMaxType() {
        return isMinMaxType(this);
    }
    get maskInstance() {
        return this.maskSettings;
    }
    get inputValue() {
        if (!this._inputValue && !this.maskTypeIsEmpty)
            return this.maskInstance.getMaskedValue("");
        return this._inputValue;
    }
    set inputValue(val) {
        let value = val;
        this._inputValue = val;
        if (!this.maskTypeIsEmpty) {
            value = this.maskInstance.getUnmaskedValue(val);
            this._inputValue = this.maskInstance.getMaskedValue(value);
            if (!!value && this.maskSettings.saveMaskedValue) {
                value = this._inputValue;
            }
        }
        this.value = value;
    }
    getExpressionValue(val) {
        if (!this.maskTypeIsEmpty && this.maskSettings.saveMaskedValue)
            return this.maskInstance.getUnmaskedValue(val);
        return val;
    }
    convertToCorrectValue(val) {
        if (val !== undefined && val !== null && typeof val !== "string" && !this.maskTypeIsEmpty && this.maskSettings.saveMaskedValue) {
            return this.maskInstance.getMaskedValue(val);
        }
        return super.convertToCorrectValue(val);
    }
    onChangeQuestionValue(newValue) {
        super.onChangeQuestionValue(newValue);
        this.updateInputValue();
    }
    updateInputValue() {
        const _value = this.value;
        if (this.maskTypeIsEmpty) {
            this._inputValue = _value;
        }
        else if (this.maskSettings.saveMaskedValue) {
            this._inputValue = (_value !== undefined && _value !== null) ? _value : this.maskInstance.getMaskedValue("");
        }
        else {
            this._inputValue = this.maskInstance.getMaskedValue(_value);
        }
    }
    hasToConvertToUTC(val) {
        return settings.storeUtcDates && this.isDateTimeLocaleType() && !!val;
    }
    createDate(val) {
        return createDate("question-text", val);
    }
    valueForSurveyCore(val) {
        if (this.hasToConvertToUTC(val)) {
            val = this.createDate(val).toISOString();
        }
        return super.valueForSurveyCore(val);
    }
    valueFromDataCore(val) {
        if (this.hasToConvertToUTC(val)) {
            const d = this.createDate(val);
            const locale_d = this.createDate(d.getTime() - d.getTimezoneOffset() * 60 * 1000);
            let res = locale_d.toISOString();
            val = res.substring(0, res.length - 2);
        }
        return super.valueFromDataCore(val);
    }
    onCheckForErrors(errors, isOnValueChanged, fireCallback) {
        super.onCheckForErrors(errors, isOnValueChanged, fireCallback);
        if (isOnValueChanged)
            return;
        if (this.isValueLessMin) {
            const minError = new CustomError(this.getMinMaxErrorText(this.minErrorText, this.getCalculatedMinMax(this.renderedMin)), this);
            minError.onUpdateErrorTextCallback = err => {
                err.text = this.getMinMaxErrorText(this.minErrorText, this.getCalculatedMinMax(this.renderedMin));
            };
            errors.push(minError);
        }
        if (this.isValueGreaterMax) {
            const maxError = new CustomError(this.getMinMaxErrorText(this.maxErrorText, this.getCalculatedMinMax(this.renderedMax)), this);
            maxError.onUpdateErrorTextCallback = err => {
                err.text = this.getMinMaxErrorText(this.maxErrorText, this.getCalculatedMinMax(this.renderedMax));
            };
            errors.push(maxError);
        }
        if (!!this.dateValidationMessage) {
            errors.push(new CustomError(this.dateValidationMessage, this));
        }
        const valName = this.getValidatorTitle();
        const emailValidator = new EmailValidator();
        emailValidator.errorOwner = this;
        if (this.inputType === "email" &&
            !this.validators.some((v) => v.getType() === "emailvalidator")) {
            const validateResult = emailValidator.validate(this.value, valName);
            if (!!validateResult && !!validateResult.error) {
                errors.push(validateResult.error);
            }
        }
    }
    canSetValueToSurvey() {
        if (!this.isMinMaxType)
            return true;
        const isValid = !this.isValueLessMin && !this.isValueGreaterMax;
        if ((!isValid || this.errors.length > 0) && !!this.survey &&
            (this.survey.isValidateOnValueChanging || this.survey.isValidateOnValueChanged)) {
            this.hasErrors();
        }
        return isValid;
    }
    convertFuncValuetoQuestionValue(val) {
        let type = this.maskTypeIsEmpty ? this.inputType : this.maskSettings.getTypeForExpressions();
        return Helpers.convertValToQuestionVal(val, type);
    }
    getMinMaxErrorText(errorText, value) {
        if (Helpers.isValueEmpty(value))
            return errorText;
        let errorValue = value.toString();
        if (this.inputType === "date" && !!value.toDateString) {
            errorValue = value.toDateString();
        }
        return errorText.replace("{0}", errorValue);
    }
    get isValueLessMin() {
        return (!this.isValueEmpty(this.renderedMin) && !this.isEmpty() &&
            this.getCalculatedMinMax(this.value) <
                this.getCalculatedMinMax(this.renderedMin));
    }
    get isValueGreaterMax() {
        return (!this.isValueEmpty(this.renderedMax) && !this.isEmpty() &&
            this.getCalculatedMinMax(this.value) >
                this.getCalculatedMinMax(this.renderedMax));
    }
    get isDateInputType() {
        return this.inputType === "date" || this.isDateTimeLocaleType();
    }
    isDateTimeLocaleType() {
        return this.inputType === "datetime-local";
    }
    getCalculatedMinMax(minMax) {
        if (this.isValueEmpty(minMax))
            return minMax;
        return this.isDateInputType ? this.createDate(minMax) : minMax;
    }
    setRenderedMinMax(values = null, properties = null) {
        this.minValueRunner = this.getDefaultRunner(this.minValueRunner, this.minValueExpression);
        this.setValueAndRunExpression(this.minValueRunner, this.min, (val) => {
            if (!val && this.isDateInputType && !!settings.minDate) {
                val = settings.minDate;
            }
            this.setPropertyValue("renderedMin", val);
        }, values, properties);
        this.maxValueRunner = this.getDefaultRunner(this.maxValueRunner, this.maxValueExpression);
        this.setValueAndRunExpression(this.maxValueRunner, this.max, (val) => {
            if (!val && this.isDateInputType) {
                val = !!settings.maxDate ? settings.maxDate : "2999-12-31";
            }
            this.setPropertyValue("renderedMax", val);
        }, values, properties);
    }
    /**
     * A value passed on to the [`step`](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/step) attribute of the underlying `<input>` element.
     */
    get step() {
        return this.getPropertyValue("step");
    }
    set step(val) {
        this.setPropertyValue("step", val);
    }
    get renderedStep() {
        if (this.isValueEmpty(this.step)) {
            return this.inputType !== "number" ? undefined : "any";
        }
        return this.step;
    }
    getIsInputTextUpdate() {
        return this.maskTypeIsEmpty ? super.getIsInputTextUpdate() : false;
    }
    supportAutoAdvance() {
        return !this.getIsInputTextUpdate() && !this.isDateInputType;
    }
    supportGoNextPageError() {
        return !this.isDateInputType;
    }
    /**
     * An array of predefined options from which users can select. This property configures an HTML [`<datalist>`](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/datalist) element and associates it with the underlying `input` element.
     */
    get dataList() {
        return this.locDataList.value;
    }
    set dataList(val) {
        this.locDataList.value = val;
    }
    get locDataList() {
        return this.locDataListValue;
    }
    get dataListId() {
        return this.locDataList.hasValue() ? this.id + "_datalist" : undefined;
    }
    setNewValue(newValue) {
        newValue = this.correctValueType(newValue);
        if (!!newValue) {
            this.dateValidationMessage = undefined;
        }
        super.setNewValue(newValue);
    }
    correctValueType(newValue) {
        if (!newValue)
            return newValue;
        if (this.inputType === "number" || this.inputType === "range") {
            return Helpers.isNumber(newValue) ? Helpers.getNumber(newValue) : "";
        }
        if (this.inputType === "month") {
            const d = this.createDate(newValue);
            const isUtc = d.toISOString().indexOf(newValue) == 0 && newValue.indexOf("T") == -1;
            const month = isUtc ? d.getUTCMonth() : d.getMonth();
            const year = isUtc ? d.getUTCFullYear() : d.getFullYear();
            const m = month + 1;
            return year + "-" + (m < 10 ? "0" : "") + m;
        }
        return newValue;
    }
    hasPlaceholder() {
        return !this.isReadOnly && this.inputType !== "range";
    }
    getControlCssClassBuilder() {
        const maxLength = this.getMaxLength();
        return super.getControlCssClassBuilder()
            .append(this.cssClasses.constrolWithCharacterCounter, !!maxLength)
            .append(this.cssClasses.characterCounterBig, maxLength > 99);
    }
    isReadOnlyRenderDiv() {
        return this.isReadOnly && settings.readOnly.textRenderMode === "div";
    }
    get inputStyle() {
        var style = {};
        style.width = this.inputWidth;
        this.updateTextAlign(style);
        return style;
    }
    updateTextAlign(style) {
        if (this.inputTextAlignment !== "auto") {
            style.textAlign = this.inputTextAlignment;
        }
        else if (!this.maskTypeIsEmpty && this.maskSettings.getTextAlignment() !== "auto") {
            style.textAlign = this.maskSettings.getTextAlignment();
        }
    }
    updateValueOnEvent(event) {
        const newValue = event.target.value;
        if (!this.isTwoValueEquals(this.value, newValue)) {
            this.inputValue = newValue;
        }
    }
    updateDateValidationMessage(event) {
        this.dateValidationMessage = this.isDateInputType && !!event.target ? event.target.validationMessage : undefined;
    }
    onBlurCore(event) {
        this.updateDateValidationMessage(event);
        this.updateValueOnEvent(event);
        this.updateRemainingCharacterCounter(event.target.value);
        super.onBlurCore(event);
    }
    onFocusCore(event) {
        this.updateRemainingCharacterCounter(event.target.value);
        super.onFocusCore(event);
    }
    afterRenderQuestionElement(el) {
        if (!!el) {
            this.input = el instanceof HTMLInputElement ? el : el.querySelector("input");
            this.createMaskAdapter();
        }
        super.afterRenderQuestionElement(el);
    }
    beforeDestroyQuestionElement(el) {
        this.deleteMaskAdapter();
        this.input = undefined;
    }
}
__decorate([
    property({
        onSet: (newValue, target) => { target.onSetMaskType(newValue); }
    })
], QuestionTextModel.prototype, "maskType", void 0);
__decorate([
    property()
], QuestionTextModel.prototype, "inputTextAlignment", void 0);
__decorate([
    property()
], QuestionTextModel.prototype, "_inputValue", void 0);
const minMaxTypes = [
    "number",
    "range",
    "date",
    "datetime-local",
    "month",
    "time",
    "week",
];
function isMinMaxType(obj) {
    const t = !!obj ? obj.inputType : "";
    if (!t)
        return false;
    return minMaxTypes.indexOf(t) > -1;
}
function getWeekTimeNumber(str, delimiter) {
    const strs = str.split(delimiter);
    if (strs.length !== 2)
        return -1;
    if (!Helpers.isNumber(strs[0]) || !Helpers.isNumber(strs[1]))
        return -1;
    return parseFloat(strs[0]) * 60 + parseFloat(strs[1]);
}
function isMinBiggerWeekTime(minStr, maxStr, delimiter) {
    const min = getWeekTimeNumber(minStr, delimiter);
    const max = getWeekTimeNumber(maxStr, delimiter);
    if (min < 0 || max < 0)
        return false;
    return min > max;
}
function getCorrectMinMax$1(obj, min, max, isMax) {
    let val = isMax ? max : min;
    if (!isMinMaxType(obj))
        return val;
    if (Helpers.isValueEmpty(min) || Helpers.isValueEmpty(max))
        return val;
    if (obj.inputType.indexOf("date") === 0 || obj.inputType === "month") {
        const isMonth = obj.inputType === "month";
        const reason = "question-text-minmax";
        const dMin = createDate(reason, isMonth ? min + "-01" : min);
        const dMax = createDate(reason, isMonth ? max + "-01" : max);
        if (!dMin || !dMax)
            return val;
        if (dMin > dMax)
            return isMax ? min : max;
    }
    if (obj.inputType === "week" || obj.inputType === "time") {
        const delimiter = obj.inputType === "week" ? "-W" : ":";
        if (isMinBiggerWeekTime(min, max, delimiter))
            return isMax ? min : max;
        return val;
    }
    if (obj.inputType === "number") {
        if (!Helpers.isNumber(min) || !Helpers.isNumber(max))
            return val;
        if (Helpers.getNumber(min) > Helpers.getNumber(max))
            return isMax ? min : max;
    }
    if (typeof min === "string" || typeof max === "string")
        return val;
    if (min > max)
        return isMax ? min : max;
    return val;
}
function propertyEditorMinMaxUpdate(obj, propertyEditor) {
    if (!!obj && !!obj.inputType) {
        propertyEditor.inputType = obj.inputType !== "range" ? obj.inputType : "number";
        propertyEditor.textUpdateMode = "onBlur";
    }
}
Serializer.addClass("text", [
    {
        name: "inputType",
        default: "text",
        choices: settings.questions.inputTypes,
    },
    {
        name: "inputSize:number", alternativeName: "size", minValue: 0, dependsOn: "inputType",
        visibleIf: function (obj) {
            if (!obj)
                return false;
            return obj.isTextInput;
        }
    },
    {
        name: "textUpdateMode",
        default: "default",
        choices: ["default", "onBlur", "onTyping"],
        dependsOn: "inputType",
        visibleIf: function (obj) {
            if (!obj)
                return false;
            return obj.isTextInput;
        },
    },
    {
        name: "autocomplete",
        alternativeName: "autoComplete",
        choices: settings.questions.dataList,
    },
    {
        name: "min",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            return isMinMaxType(obj);
        },
        onPropertyEditorUpdate: function (obj, propertyEditor) {
            propertyEditorMinMaxUpdate(obj, propertyEditor);
        },
        onSettingValue: (obj, val) => {
            return getCorrectMinMax$1(obj, val, obj.max, false);
        },
    },
    {
        name: "max",
        dependsOn: "inputType",
        nextToProperty: "*min",
        visibleIf: function (obj) {
            return isMinMaxType(obj);
        },
        onSettingValue: (obj, val) => {
            return getCorrectMinMax$1(obj, obj.min, val, true);
        },
        onPropertyEditorUpdate: function (obj, propertyEditor) {
            propertyEditorMinMaxUpdate(obj, propertyEditor);
        },
    },
    {
        name: "minValueExpression:expression",
        category: "logic",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            return isMinMaxType(obj);
        },
    },
    {
        name: "maxValueExpression:expression",
        category: "logic",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            return isMinMaxType(obj);
        },
    },
    {
        name: "minErrorText",
        serializationProperty: "locMinErrorText",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            return isMinMaxType(obj);
        },
    },
    {
        name: "maxErrorText",
        serializationProperty: "locMaxErrorText",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            return isMinMaxType(obj);
        },
    },
    { name: "inputTextAlignment", default: "auto", choices: ["left", "right", "auto"] },
    {
        name: "maskType",
        default: "none",
        visibleIndex: 0,
        dependsOn: "inputType",
        visibleIf: (obj) => {
            return obj.inputType === "text" || obj.inputType === "tel";
        },
        choices: (obj) => {
            const choices = getAvailableMaskTypeChoices();
            return choices;
        }
    },
    {
        name: "maskSettings:masksettings",
        className: "masksettings",
        visibleIndex: 1,
        dependsOn: ["inputType", "maskType"],
        visibleIf: (obj) => {
            return obj.inputType === "text" || obj.inputType === "tel";
        },
        onGetValue: function (obj) {
            return obj.maskSettings.getData();
        },
        onSetValue: function (obj, value) {
            obj.maskSettings.setData(value);
        },
    },
    {
        name: "step:number",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            if (!obj)
                return false;
            return obj.inputType === "number" || obj.inputType === "range";
        },
    },
    {
        name: "maxLength:number",
        default: -1,
        dependsOn: "inputType",
        visibleIf: function (obj) {
            if (!obj)
                return false;
            return obj.isTextInput;
        },
    },
    {
        name: "placeholder",
        alternativeName: "placeHolder",
        serializationProperty: "locPlaceholder",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            if (!obj)
                return false;
            return obj.isTextInput;
        },
    },
    {
        name: "dataList:string[]",
        serializationProperty: "locDataList",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            if (!obj)
                return false;
            return obj.inputType === "text";
        },
    },
], function () {
    return new QuestionTextModel("");
}, "textbase");
QuestionFactory.Instance.registerQuestion("text", (name) => {
    return new QuestionTextModel(name);
});

class MultipleTextEditorModel extends QuestionTextModel {
    get a11y_input_ariaLabel() {
        return this.locTitle.renderedHtml;
    }
    get a11y_input_ariaLabelledBy() {
        return null;
    }
    get a11y_input_ariaDescribedBy() {
        return null;
    }
}
/**
 * A class that describes an [item](https://surveyjs.io/form-library/documentation/api-reference/multiple-text-entry-question-model#items) in a Multiple Textboxes question.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/multiple-text-box-question/ (linkStyle))
 */
class MultipleTextItemModel extends Base {
    constructor(name = null, title = null) {
        super();
        this.focusIn = () => {
            this.editor.focusIn();
        };
        this.editorValue = this.createEditor(name);
        this.maskSettings = this.editorValue.maskSettings;
        this.editor.questionTitleTemplateCallback = function () {
            return "";
        };
        this.editor.titleLocation = "left";
        if (title) {
            this.title = title;
        }
        this.editor.onPropertyChanged.add((sender, options) => {
            if (options.name !== "maskSettings") {
                this.onPropertyChanged.fire(this, options);
            }
        });
    }
    getType() {
        return "multipletextitem";
    }
    get id() {
        return this.editor.id;
    }
    getOriginalObj() {
        return this.editor;
    }
    /**
     * An item ID that is not visible to respondents.
     *
     * > Item IDs must be unique.
     * @see title
     */
    get name() {
        return this.editor.name;
    }
    set name(val) {
        this.editor.name = val;
    }
    get question() {
        return this.data;
    }
    get editor() {
        return this.editorValue;
    }
    createEditor(name) {
        return new MultipleTextEditorModel(name);
    }
    addUsedLocales(locales) {
        super.addUsedLocales(locales);
        this.editor.addUsedLocales(locales);
    }
    localeChanged() {
        super.localeChanged();
        this.editor.localeChanged();
    }
    locStrsChanged() {
        super.locStrsChanged();
        this.editor.locStrsChanged();
    }
    setData(data) {
        this.data = data;
        if (!!data) {
            this.editor.defaultValue = data.getItemDefaultValue(this.name);
            this.editor.setSurveyImpl(this);
            this.editor.parent = data;
            this.editor.setParentQuestion(data);
        }
    }
    /**
     * Marks the item as required. If a respondent leaves this item empty, the question displays a [validation error](#requiredErrorText).
     */
    get isRequired() {
        return this.editor.isRequired;
    }
    set isRequired(val) {
        this.editor.isRequired = val;
    }
    /**
     * A value passed on to the [`type`](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#input_types) attribute of the underlying `<input>` element.
     *
     * Default value: `"text"`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/multiple-text-box-question/ (linkStyle))
     */
    get inputType() {
        return this.editor.inputType;
    }
    set inputType(val) {
        this.editor.inputType = val;
    }
    /**
     * A user-friendly item label to display. If `title` is undefined, [`name`](https://surveyjs.io/form-library/documentation/api-reference/multipletextitemmodel#name) is displayed instead.
     */
    get title() {
        return this.editor.title;
    }
    set title(val) {
        this.editor.title = val;
    }
    get locTitle() {
        return this.editor.locTitle;
    }
    get fullTitle() {
        return this.editor.fullTitle;
    }
    /**
     * The maximum text length measured in characters. Assign 0 if the length should be unlimited.
     *
     * Default value: -1 (inherits the actual value from the `SurveyModel`'s [`maxTextLength`](https://surveyjs.io/form-library/documentation/surveymodel#maxTextLength) property).
     */
    get maxLength() {
        return this.editor.maxLength;
    }
    set maxLength(val) {
        this.editor.maxLength = val;
    }
    getMaxLength() {
        var survey = this.getSurvey();
        return Helpers.getMaxLength(this.maxLength, survey ? survey.maxTextLength : -1);
    }
    /**
     * A placeholder for the input field.
     */
    get placeholder() {
        return this.editor.placeholder;
    }
    set placeholder(val) {
        this.editor.placeholder = val;
    }
    get locPlaceholder() {
        return this.editor.locPlaceholder;
    }
    get placeHolder() {
        return this.placeholder;
    }
    set placeHolder(val) {
        this.placeholder = val;
    }
    get locPlaceHolder() {
        return this.locPlaceholder;
    }
    /**
     * Specifies a custom error message for a [required item](#isRequired).
     */
    get requiredErrorText() {
        return this.editor.requiredErrorText;
    }
    set requiredErrorText(val) {
        this.editor.requiredErrorText = val;
    }
    get locRequiredErrorText() {
        return this.editor.locRequiredErrorText;
    }
    /**
     * A value passed on to the [`size`](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/size) attribute of the underlying `<input>` element.
     *
     * If you want to set a uniform `inputSize` for all text box items, use the [`inputSize`](https://surveyjs.io/form-library/documentation/api-reference/multiple-text-entry-question-model#inputSize) property within the Multiple Textboxes configuration.
     */
    get inputSize() { return this.editor.inputSize; }
    set inputSize(val) { this.editor.inputSize = val; }
    /**
     * @deprecated Use the [`inputSize`](https://surveyjs.io/form-library/documentation/api-reference/multipletextitemmodel#inputSize) property instead.
     */
    get size() { return this.inputSize; }
    set size(val) { this.inputSize = val; }
    /**
     * An [expression](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions) used to calculate the default item value.
     * @see minValueExpression
     * @see maxValueExpression
     */
    get defaultValueExpression() {
        return this.editor.defaultValueExpression;
    }
    set defaultValueExpression(val) {
        this.editor.defaultValueExpression = val;
    }
    /**
     * An [expression](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions) used to calculate the minimum item value.
     * @see maxValueExpression
     * @see defaultValueExpression
     */
    get minValueExpression() {
        return this.editor.minValueExpression;
    }
    set minValueExpression(val) {
        this.editor.minValueExpression = val;
    }
    /**
     * An [expression](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#expressions) used to calculate the maximum item value.
     * @see minValueExpression
     * @see defaultValueExpression
     */
    get maxValueExpression() {
        return this.editor.maxValueExpression;
    }
    set maxValueExpression(val) {
        this.editor.maxValueExpression = val;
    }
    /**
     * Item validators.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/multiple-text-box-question/ (linkStyle))
     */
    get validators() {
        return this.editor.validators;
    }
    set validators(val) {
        this.editor.validators = val;
    }
    getValidators() {
        return this.validators;
    }
    /**
     * Specifies the type of a mask applied to the input.
     *
     * Possible values:
     *
     * - `"none"` (default)
     * - `"numeric"`
     * - `"currency"`
     * - `"datetime"`
     * - `"pattern"`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/masked-input-fields/ (linkStyle))
     * @see maskSettings
     */
    get maskType() {
        return this.editor.maskType;
    }
    set maskType(val) {
        this.editor.maskType = val;
        this.maskSettings = this.editor.maskSettings;
    }
    /**
     * An object with properties that configure the mask applied to the input.
     *
     * Available properties depend on the specified [`maskType`](#maskType) and belong to corresponding classes. Refer to the class APIs for a full list of properties:
     *
     * | `maskType` | Class |
     * | ---------- | ----- |
     * | `"numeric"` | [`InputMaskNumeric`](https://surveyjs.io/form-library/documentation/api-reference/inputmasknumeric) |
     * | `"currency"` | [`InputMaskCurrency`](https://surveyjs.io/form-library/documentation/api-reference/inputmaskcurrency) |
     * | `"datetime"` | [`InputMaskDateTime`](https://surveyjs.io/form-library/documentation/api-reference/inputmaskdatetime) |
     * | `"pattern"` | [`InputMaskPattern`](https://surveyjs.io/form-library/documentation/api-reference/inputmaskpattern) |
     *
     * [View Demo](https://surveyjs.io/form-library/examples/masked-input-fields/ (linkStyle))
     */
    get maskSettings() {
        return this.getPropertyValue("maskSettings");
    }
    set maskSettings(val) {
        this.setPropertyValue("maskSettings", val);
        if (this.editor.maskSettings !== val) {
            this.editor.maskSettings = val;
        }
    }
    /**
     * Specifies text alignment within the input field.
     *
     * Possible values:
     *
     * - `"left"` - Aligns input text to the left side.
     * - `"right"` - Aligns input text to the right side.
     * - `"auto"` (default) - Applies right alignment if a [numeric or currency input mask](https://surveyjs.io/form-library/documentation/api-reference/multipletextitemmodel#maskType) is specified. Otherwise, applies left alignment.
     */
    get inputTextAlignment() {
        return this.editor.inputTextAlignment;
    }
    set inputTextAlignment(val) {
        this.editor.inputTextAlignment = val;
    }
    /**
     * An item value.
     */
    get value() {
        return this.data ? this.data.getMultipleTextValue(this.name) : null;
    }
    set value(value) {
        if (this.data != null) {
            this.data.setMultipleTextValue(this.name, value);
        }
    }
    isEmpty() {
        return this.editor.isEmpty();
    }
    onValueChanged(newValue) {
        if (this.valueChangedCallback)
            this.valueChangedCallback(newValue);
    }
    //ISurveyImpl
    getSurveyData() {
        return this;
    }
    getSurvey() {
        return this.data ? this.data.getSurvey() : null;
    }
    getTextProcessor() {
        return this.data ? this.data.getTextProcessor() : null;
    }
    //ISurveyData
    getValue(name) {
        if (!this.data)
            return null;
        return this.data.getMultipleTextValue(name);
    }
    setValue(name, value) {
        if (this.data) {
            this.data.setMultipleTextValue(name, value);
        }
    }
    getVariable(name) {
        return undefined;
    }
    setVariable(name, newValue) { }
    getComment(name) {
        return null;
    }
    setComment(name, newValue) { }
    getAllValues() {
        if (this.data)
            return this.data.getAllValues();
        return this.value;
    }
    getFilteredValues() {
        return this.getAllValues();
    }
    getFilteredProperties() {
        return { survey: this.getSurvey() };
    }
    findQuestionByName(name) {
        const survey = this.getSurvey();
        return !!survey ? survey.getQuestionByName(name) : null;
    }
    getEditingSurveyElement() { return undefined; }
    //IValidatorOwner
    getValidatorTitle() {
        return this.title;
    }
    get validatedValue() {
        return this.value;
    }
    set validatedValue(val) {
        this.value = val;
    }
    getDataFilteredValues() {
        return this.getFilteredValues();
    }
    getDataFilteredProperties() {
        return this.getFilteredProperties();
    }
}
/**
 * A class that describes the Multiple Text question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-multipletext/ (linkStyle))
 */
class QuestionMultipleTextModel extends Question {
    static addDefaultItems(question) {
        var names = QuestionFactory.DefaultMutlipleTextItems;
        for (var i = 0; i < names.length; i++)
            question.addItem(names[i]);
    }
    constructor(name) {
        super(name);
        this.isMultipleItemValueChanging = false;
        this.createNewArray("items", (item) => {
            item.setData(this);
            if (this.survey) {
                this.survey.multipleTextItemAdded(this, item);
            }
        });
        this.registerPropertyChangedHandlers(["items", "colCount", "itemErrorLocation"], () => {
            this.calcVisibleRows();
        });
        this.registerPropertyChangedHandlers(["inputSize"], () => { this.resetItemsSize(); });
    }
    getType() {
        return "multipletext";
    }
    setSurveyImpl(value, isLight) {
        super.setSurveyImpl(value, isLight);
        for (var i = 0; i < this.items.length; i++) {
            this.items[i].setData(this);
        }
    }
    get isAllowTitleLeft() {
        return false;
    }
    get hasSingleInput() { return false; }
    get isContainer() { return true; }
    get id() {
        return this.getPropertyValue("id");
    }
    set id(val) {
        var _a;
        (_a = this.items) === null || _a === void 0 ? void 0 : _a.map((item, index) => item.editor.id = val + "_" + index);
        this.setPropertyValue("id", val);
    }
    onSurveyLoad() {
        this.editorsOnSurveyLoad();
        super.onSurveyLoad();
        if (!Helpers.isValueEmpty(this.rows)) {
            this.calcVisibleRows();
        }
    }
    setQuestionValue(newValue, updateIsAnswered = true) {
        super.setQuestionValue(newValue, updateIsAnswered);
        this.performForEveryEditor((item) => {
            item.editor.updateValueFromSurvey(item.value);
        });
        this.updateIsAnswered();
    }
    onSurveyValueChanged(newValue) {
        super.onSurveyValueChanged(newValue);
        this.performForEveryEditor((item) => {
            item.editor.onSurveyValueChanged(item.value);
        });
    }
    resetItemsSize() {
        this.performForEveryEditor((item) => {
            item.editor.resetInputSize();
        });
    }
    editorsOnSurveyLoad() {
        this.performForEveryEditor((item) => {
            item.editor.onSurveyLoad();
        });
    }
    performForEveryEditor(func) {
        for (var i = 0; i < this.items.length; i++) {
            var item = this.items[i];
            if (item.editor) {
                func(item);
            }
        }
    }
    /**
     * Gets or sets an array of [`MultipleTextItemModel`](https://surveyjs.io/form-library/documentation/api-reference/multipletextitemmodel) objects that represent input items.
     *
     * Each object in this array should have at least the following properties:
     *
     * ```js
     * {
     *   "name": any, // A unique value used to identify an input item and save an item value to survey results.
     *   "title": String // An item caption. When `title` is undefined, `name` is used. This property supports Markdown.
     * }
     * ```
     *
     * To enable Markdown support for the `title` property, implement Markdown-to-HTML conversion in the [`onTextMarkdown`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onTextMarkdown) event handler. For an example, refer to the following demo: [Convert Markdown to HTML with markdown-it](https://surveyjs.io/form-library/examples/edit-survey-questions-markdown/).
     *
     * [View Demo](https://surveyjs.io/form-library/examples/multiple-text-box-question/ (linkStyle))
     * @see itemTitleWidth
     * @see addItem
     */
    get items() {
        return this.getPropertyValue("items");
    }
    set items(val) {
        this.setPropertyValue("items", val);
    }
    /**
     * Adds a new input item.
     * @param name An item name.
     * @param title *(Optional)* An item title.
     * @see items
     */
    addItem(name, title = null) {
        var item = this.createTextItem(name, title);
        this.items.push(item);
        return item;
    }
    getItemByName(name) {
        for (var i = 0; i < this.items.length; i++) {
            if (this.items[i].name == name)
                return this.items[i];
        }
        return null;
    }
    getElementsInDesign(includeHidden = false) {
        let elements;
        elements = super.getElementsInDesign(includeHidden);
        return elements.concat(this.items);
    }
    addConditionObjectsByContext(objects, context) {
        for (var i = 0; i < this.items.length; i++) {
            var item = this.items[i];
            objects.push({
                name: this.getValueName() + "." + item.name,
                text: this.processedTitle + "." + item.fullTitle,
                question: this,
            });
        }
    }
    collectNestedQuestionsCore(questions, visibleOnly, includeNested, includeItSelf) {
        if (includeItSelf) {
            questions.push(this);
        }
        this.items.forEach(item => item.editor.addNestedQuestion(questions, visibleOnly, includeNested, includeItSelf));
    }
    getConditionJson(operator = null, path = null) {
        if (!path)
            return super.getConditionJson(operator);
        var item = this.getItemByName(path);
        if (!item)
            return null;
        var json = new JsonObject().toJsonObject(item);
        json["type"] = "text";
        return json;
    }
    locStrsChanged() {
        super.locStrsChanged();
        for (var i = 0; i < this.items.length; i++) {
            this.items[i].locStrsChanged();
        }
    }
    localeChanged() {
        super.localeChanged();
        for (var i = 0; i < this.items.length; i++) {
            this.items[i].localeChanged();
        }
    }
    /**
     * Specifies the error message position relative to individual input fields.
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the [`errorLocation`](#errorLocation) property.
     * - `"top"` - Displays error messages above input fields.
     * - `"bottom"` - Displays error messages below input fields.
     */
    get itemErrorLocation() {
        return this.getPropertyValue("itemErrorLocation");
    }
    set itemErrorLocation(val) {
        this.setPropertyValue("itemErrorLocation", val);
    }
    getQuestionErrorLocation() {
        if (this.itemErrorLocation !== "default")
            return this.itemErrorLocation;
        return this.getErrorLocation();
    }
    get showItemErrorOnTop() {
        return this.getQuestionErrorLocation() == "top";
    }
    get showItemErrorOnBottom() {
        return this.getQuestionErrorLocation() == "bottom";
    }
    getChildErrorLocation(child) {
        return this.getQuestionErrorLocation();
    }
    isNewValueCorrect(val) {
        return Helpers.isValueObject(val, true);
    }
    supportAutoAdvance() {
        for (var i = 0; i < this.items.length; i++) {
            if (this.items[i].isEmpty())
                return false;
        }
        return true;
    }
    /**
     * The number of columns used to arrange input items. Accepts the following values: 1, 2, 3, 4, 5.
     *
     * Default value: 1
     */
    get colCount() {
        return this.getPropertyValue("colCount");
    }
    set colCount(val) {
        if (val < 1 || val > 5)
            return;
        this.setPropertyValue("colCount", val);
    }
    /**
     * A value passed on to the [`inputSize`](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/size) attribute of the underlying `<input>` elements.
     */
    get inputSize() {
        return this.getPropertyValue("inputSize");
    }
    set inputSize(val) {
        this.setPropertyValue("inputSize", val);
    }
    /**
     * @deprecated Use the [`inputSize`](https://surveyjs.io/form-library/documentation/api-reference/multiple-text-entry-question-model#inputSize) property instead.
     */
    get itemSize() { return this.inputSize; }
    set itemSize(val) { this.inputSize = val; }
    /**
     * Specifies a uniform width for all text box titles. Accepts CSS values.
     *
     * Default value: `""` (the width of each title depends on the title length)
     * @see items
     * @see itemErrorLocation
     */
    get itemTitleWidth() {
        return this.getPropertyValue("itemTitleWidth") || "";
    }
    set itemTitleWidth(val) {
        this.setPropertyValue("itemTitleWidth", val);
    }
    onRowCreated(row) {
        return row;
    }
    calcVisibleRows() {
        const colCount = this.colCount;
        const items = this.items;
        let index = 0;
        let row;
        let errorRow;
        let rows = [];
        for (var i = 0; i < items.length; i++) {
            if (index == 0) {
                row = this.onRowCreated(new MutlipleTextRow());
                errorRow = this.onRowCreated(new MutlipleTextErrorRow());
                if (this.showItemErrorOnTop) {
                    rows.push(errorRow);
                    rows.push(row);
                }
                else {
                    rows.push(row);
                    rows.push(errorRow);
                }
            }
            row.cells.push(new MultipleTextCell(items[i], this));
            errorRow.cells.push(new MultipleTextErrorCell(items[i], this));
            index++;
            if (index >= colCount || i == items.length - 1) {
                index = 0;
                errorRow.onAfterCreated();
            }
        }
        this.rows = rows;
    }
    getRows() {
        if (Helpers.isValueEmpty(this.rows)) {
            this.calcVisibleRows();
        }
        return this.rows;
    }
    onValueChanged() {
        super.onValueChanged();
        this.onItemValueChanged();
    }
    createTextItem(name, title) {
        return new MultipleTextItemModel(name, title);
    }
    onItemValueChanged() {
        if (this.isMultipleItemValueChanging)
            return;
        for (var i = 0; i < this.items.length; i++) {
            var itemValue = null;
            if (this.value && this.items[i].name in this.value) {
                itemValue = this.value[this.items[i].name];
            }
            this.items[i].onValueChanged(itemValue);
        }
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        this.items.forEach(item => item.editor.runCondition(values, properties));
    }
    getIsRunningValidators() {
        if (super.getIsRunningValidators())
            return true;
        for (var i = 0; i < this.items.length; i++) {
            if (this.items[i].editor.isRunningValidators)
                return true;
        }
        return false;
    }
    hasErrors(fireCallback = true, rec = null) {
        var res = false;
        for (var i = 0; i < this.items.length; i++) {
            this.items[i].editor.onCompletedAsyncValidators = (hasErrors) => {
                this.raiseOnCompletedAsyncValidators();
            };
            if (!!rec &&
                rec.isOnValueChanged === true &&
                this.items[i].editor.isEmpty())
                continue;
            res = this.items[i].editor.hasErrors(fireCallback, rec) || res;
        }
        return super.hasErrors(fireCallback) || res;
    }
    getAllErrors() {
        var result = super.getAllErrors();
        for (var i = 0; i < this.items.length; i++) {
            var errors = this.items[i].editor.getAllErrors();
            if (errors && errors.length > 0) {
                result = result.concat(errors);
            }
        }
        return result;
    }
    clearErrors() {
        super.clearErrors();
        for (var i = 0; i < this.items.length; i++) {
            this.items[i].editor.clearErrors();
        }
    }
    getContainsErrors() {
        var res = super.getContainsErrors();
        if (res)
            return res;
        var items = this.items;
        for (var i = 0; i < items.length; i++) {
            if (items[i].editor.containsErrors)
                return true;
        }
        return false;
    }
    getIsAnswered() {
        if (!super.getIsAnswered())
            return false;
        for (var i = 0; i < this.items.length; i++) {
            var editor = this.items[i].editor;
            if (editor.isVisible && !editor.isAnswered)
                return false;
        }
        return true;
    }
    getProgressInfo() {
        var elements = [];
        for (var i = 0; i < this.items.length; i++) {
            elements.push(this.items[i].editor);
        }
        return SurveyElement.getProgressInfoByElements(elements, this.isRequired);
    }
    getDisplayValueCore(keysAsText, value) {
        if (!value)
            return value;
        var res = {};
        for (var i = 0; i < this.items.length; i++) {
            var item = this.items[i];
            var val = value[item.name];
            if (Helpers.isValueEmpty(val))
                continue;
            var itemName = item.name;
            if (keysAsText && !!item.title) {
                itemName = item.title;
            }
            res[itemName] = item.editor.getDisplayValue(keysAsText, val);
        }
        return res;
    }
    allowMobileInDesignMode() {
        return true;
    }
    //IMultipleTextData
    getMultipleTextValue(name) {
        if (!this.value)
            return null;
        return this.value[name];
    }
    setMultipleTextValue(name, value) {
        this.isMultipleItemValueChanging = true;
        if (this.isValueEmpty(value)) {
            value = undefined;
        }
        var newValue = this.value;
        if (!newValue) {
            newValue = {};
        }
        newValue[name] = value;
        this.setNewValue(newValue);
        this.isMultipleItemValueChanging = false;
    }
    getItemDefaultValue(name) {
        return !!this.defaultValue ? this.defaultValue[name] : null;
    }
    getTextProcessor() {
        return this.textProcessor;
    }
    getAllValues() {
        return this.data ? this.data.getAllValues() : null;
    }
    //IPanel
    addElement(element, index) { }
    removeElement(element) {
        return false;
    }
    getQuestionTitleLocation() {
        return "left";
    }
    getQuestionTitleWidth() {
        return undefined;
    }
    getColumsForElement(el) {
        return [];
    }
    updateColumns() { }
    getQuestionStartIndex() {
        return this.getStartIndex();
    }
    getChildrenLayoutType() {
        return "row";
    }
    elementWidthChanged(el) { }
    get elements() {
        return [];
    }
    indexOf(el) {
        return -1;
    }
    ensureRowsVisibility() {
        // do nothing
    }
    validateContainerOnly() {
        // do nothing
    }
    onQuestionValueChanged(el) {
        // do nothing
    }
    getItemLabelCss(item) {
        return new CssClassBuilder()
            .append(this.cssClasses.itemLabel)
            .append(this.cssClasses.itemLabelDisabled, this.isDisabledStyle)
            .append(this.cssClasses.itemLabelReadOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.itemLabelPreview, this.isPreviewStyle)
            .append(this.cssClasses.itemLabelAnswered, item.editor.isAnswered)
            .append(this.cssClasses.itemLabelAllowFocus, !this.isDesignMode)
            .append(this.cssClasses.itemLabelOnError, item.editor.errors.length > 0)
            .append(this.cssClasses.itemWithCharacterCounter, !!item.getMaxLength())
            .toString();
    }
    getItemCss() {
        return new CssClassBuilder().append(this.cssClasses.item).toString();
    }
    getItemTitleCss() {
        return new CssClassBuilder().append(this.cssClasses.itemTitle).toString();
    }
    get ariaRole() {
        return "group";
    }
    get ariaRequired() {
        return null;
    }
    get ariaInvalid() {
        return null;
    }
}
__decorate([
    propertyArray()
], QuestionMultipleTextModel.prototype, "rows", void 0);
class MutlipleTextRow extends Base {
    constructor() {
        super(...arguments);
        this.isVisible = true;
        this.cells = [];
    }
}
__decorate([
    property()
], MutlipleTextRow.prototype, "isVisible", void 0);
__decorate([
    propertyArray()
], MutlipleTextRow.prototype, "cells", void 0);
class MutlipleTextErrorRow extends MutlipleTextRow {
    onAfterCreated() {
        const callback = () => {
            this.isVisible = this.cells.some((cell) => { var _a, _b; return ((_a = cell.item) === null || _a === void 0 ? void 0 : _a.editor) && ((_b = cell.item) === null || _b === void 0 ? void 0 : _b.editor.hasVisibleErrors); });
        };
        this.cells.forEach((cell) => {
            var _a, _b;
            if ((_a = cell.item) === null || _a === void 0 ? void 0 : _a.editor) {
                (_b = cell.item) === null || _b === void 0 ? void 0 : _b.editor.registerFunctionOnPropertyValueChanged("hasVisibleErrors", callback);
            }
        });
        callback();
    }
}
class MultipleTextCell {
    constructor(item, question) {
        this.item = item;
        this.question = question;
        this.isErrorsCell = false;
    }
    getClassName() {
        return new CssClassBuilder().append(this.question.cssClasses.cell).toString();
    }
    get className() {
        return this.getClassName();
    }
}
class MultipleTextErrorCell extends MultipleTextCell {
    constructor() {
        super(...arguments);
        this.isErrorsCell = true;
    }
    getClassName() {
        return new CssClassBuilder()
            .append(super.getClassName())
            .append(this.question.cssClasses.cellError)
            .append(this.question.cssClasses.cellErrorTop, this.question.showItemErrorOnTop)
            .append(this.question.cssClasses.cellErrorBottom, this.question.showItemErrorOnBottom)
            .toString();
    }
}
Serializer.addClass("multipletextitem", [
    { name: "!name", isUnique: true },
    "isRequired:boolean",
    { name: "placeholder", alternativeName: "placeHolder", serializationProperty: "locPlaceholder" },
    {
        name: "inputType",
        default: "text",
        choices: settings.questions.inputTypes,
    },
    {
        name: "maskType",
        default: "none",
        visibleIndex: 0,
        dependsOn: "inputType",
        visibleIf: (obj) => {
            return obj.inputType === "text";
        },
        choices: (obj) => {
            const choices = getAvailableMaskTypeChoices();
            return choices;
        }
    },
    {
        name: "maskSettings:masksettings",
        className: "masksettings",
        visibleIndex: 1,
        dependsOn: "inputType",
        visibleIf: (obj) => {
            return obj.inputType === "text";
        },
        onGetValue: function (obj) {
            return obj.maskSettings.getData();
        },
        onSetValue: function (obj, value) {
            obj.maskSettings.setData(value);
        },
    },
    { name: "inputTextAlignment", default: "auto", choices: ["left", "right", "auto"] },
    { name: "title", serializationProperty: "locTitle" },
    { name: "maxLength:number", default: -1 },
    { name: "inputSize:number", alternativeName: "size", minValue: 0 },
    {
        name: "requiredErrorText:text",
        serializationProperty: "locRequiredErrorText",
    },
    { name: "defaultValueExpression:expression", visible: false },
    {
        name: "minValueExpression:expression",
        category: "logic",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            return isMinMaxType(obj);
        },
    },
    {
        name: "maxValueExpression:expression",
        category: "logic",
        dependsOn: "inputType",
        visibleIf: function (obj) {
            return isMinMaxType(obj);
        },
    },
    {
        name: "validators:validators",
        baseClassName: "surveyvalidator",
        classNamePart: "validator",
    },
], function () {
    return new MultipleTextItemModel("");
});
Serializer.addClass("multipletext", [
    { name: "!items:textitems", className: "multipletextitem", isArray: true },
    { name: "inputSize:number", minValue: 0, visible: false, alternativeName: "itemSize" },
    { name: "colCount:number", default: 1, choices: [1, 2, 3, 4, 5] },
    { name: "itemErrorLocation", default: "default", choices: ["default", "top", "bottom"], visible: false },
    { name: "itemTitleWidth", category: "layout" }
], function () {
    return new QuestionMultipleTextModel("");
}, "question");
QuestionFactory.Instance.registerQuestion("multipletext", (name) => {
    var q = new QuestionMultipleTextModel(name);
    QuestionMultipleTextModel.addDefaultItems(q);
    return q;
});

/**
 * The flow panel object. It is a container with flow layout where you can mix questions with markdown text.
 *
 */
class FlowPanelModel extends PanelModel {
    constructor(name = "") {
        super(name);
        this.createLocalizableString("content", this, true);
        this.registerPropertyChangedHandlers(["content"], () => {
            this.onContentChanged();
        });
    }
    getType() {
        return "flowpanel";
    }
    getChildrenLayoutType() {
        return "flow";
    }
    onSurveyLoad() {
        super.onSurveyLoad();
        this.onContentChanged();
    }
    get content() {
        return this.getLocalizableStringText("content");
    }
    set content(val) {
        this.setLocalizableStringText("content", val);
    }
    get locContent() {
        return this.getLocalizableString("content");
    }
    get html() {
        return this.getPropertyValue("html", "");
    }
    set html(val) {
        this.setPropertyValue("html", val);
    }
    onContentChanged() {
        var html = "";
        if (!!this.onCustomHtmlProducing) {
            html = this.onCustomHtmlProducing();
        }
        else {
            html = this.produceHtml();
        }
        this.html = html;
        if (!!this.contentChangedCallback)
            this.contentChangedCallback();
    }
    produceHtml() {
        var html = [];
        //contentElementNamePrefix
        var regEx = /{(.*?(element:)[^$].*?)}/g;
        var str = this.content;
        var startIndex = 0;
        var res = null;
        while ((res = regEx.exec(str)) !== null) {
            if (res.index > startIndex) {
                html.push(str.substring(startIndex, res.index));
                startIndex = res.index;
            }
            var question = this.getQuestionFromText(res[0]);
            if (!!question) {
                html.push(this.getHtmlForQuestion(question));
            }
            else {
                html.push(str.substring(startIndex, res.index + res[0].length));
            }
            startIndex = res.index + res[0].length;
        }
        if (startIndex < str.length) {
            html.push(str.substring(startIndex, str.length));
        }
        return html.join("").replace(new RegExp("<br>", "g"), "<br/>");
    }
    getQuestionFromText(str) {
        str = str.substring(1, str.length - 1);
        str = str.replace(FlowPanelModel.contentElementNamePrefix, "").trim();
        return this.getQuestionByName(str);
    }
    getHtmlForQuestion(question) {
        if (!!this.onGetHtmlForQuestion)
            return this.onGetHtmlForQuestion(question);
        return "";
    }
    getQuestionHtmlId(question) {
        return this.name + "_" + question.id;
    }
    onAddElement(element, index) {
        super.onAddElement(element, index);
        this.addElementToContent(element);
        element.renderWidth = "";
    }
    onRemoveElement(element) {
        var searchStr = this.getElementContentText(element);
        this.content = this.content.replace(searchStr, "");
        super.onRemoveElement(element);
    }
    dragDropMoveElement(src, target, targetIndex) { }
    addElementToContent(element) {
        if (this.isLoadingFromJson)
            return;
        var text = this.getElementContentText(element);
        if (!this.insertTextAtCursor(text)) {
            this.content = this.content + text;
        }
    }
    insertTextAtCursor(text, prevName = null) {
        if (!this.isDesignMode || !DomWindowHelper.isAvailable())
            return false;
        let sel = DomWindowHelper.getSelection();
        if (sel.getRangeAt && sel.rangeCount) {
            let range = sel.getRangeAt(0);
            range.deleteContents();
            const textElement = new Text(text);
            range.insertNode(textElement);
            var self = this;
            if (self.getContent) {
                var str = self.getContent(prevName);
                this.content = str;
            }
            return true;
        }
        return false;
    }
    getElementContentText(element) {
        return "{" + FlowPanelModel.contentElementNamePrefix + element.name + "}";
    }
}
FlowPanelModel.contentElementNamePrefix = "element:";
Serializer.addClass("flowpanel", [{ name: "content:html", serializationProperty: "locContent" }], function () {
    return new FlowPanelModel();
}, "panel");

class DefaultTitleModel {
    static getIconCss(cssClasses, isCollapsed) {
        return new CssClassBuilder()
            .append(cssClasses.icon)
            .append(cssClasses.iconExpanded, !isCollapsed)
            .toString();
    }
}

/**
 * A base class for question types that cannot have a value ([Html](https://surveyjs.io/form-library/documentation/questionhtmlmodel), [Image](https://surveyjs.io/form-library/documentation/questionimagemodel)).
 *
 * This class does not implement new functionality&mdash;it only redefines default values of certain properties inherited from the [`Question`](https://surveyjs.io/form-library/documentation/question) class.
 */
class QuestionNonValue extends Question {
    constructor(name) {
        super(name);
    }
    getType() {
        return "nonvalue";
    }
    get hasInput() {
        return false;
    }
    get hasTitle() {
        return false;
    }
    getTitleLocation() {
        return "";
    }
    get hasComment() {
        return false;
    }
    hasErrors(fireCallback = true, rec = null) {
        return false;
    }
    getAllErrors() {
        return [];
    }
    supportAutoAdvance() {
        return false;
    }
    addConditionObjectsByContext(objects, context) { }
    getConditionJson(operator = null, path = null) {
        return null;
    }
    get ariaRole() {
        return null;
    }
    get ariaRequired() {
        return null;
    }
}
Serializer.addClass("nonvalue", [
    { name: "title", visible: false },
    { name: "description", visible: false },
    { name: "valueName", visible: false },
    { name: "enableIf", visible: false },
    { name: "defaultValue", visible: false },
    { name: "correctAnswer", visible: false },
    { name: "clearIfInvisible", visible: false },
    { name: "isRequired", visible: false, isSerializable: false },
    { name: "requiredErrorText", visible: false },
    { name: "readOnly", visible: false },
    { name: "requiredIf", visible: false },
    { name: "validators", visible: false },
    { name: "titleLocation", visible: false },
    { name: "showTitle", visible: false, isSerializable: false },
    { name: "showCommentArea", visible: false },
    { name: "useDisplayValuesInDynamicTexts", alternativeName: "useDisplayValuesInTitle", visible: false },
], function () {
    return new QuestionNonValue("");
}, "question");

/**
 * A Model for an question that renders empty "div" tag. It used as a base class for some custom widgets
 */
class QuestionEmptyModel extends Question {
    constructor(name) {
        super(name);
    }
    getType() {
        return "empty";
    }
}
Serializer.addClass("empty", [], function () {
    return new QuestionEmptyModel("");
}, "question");

class CheckboxItem extends ItemValue {
    get isExclusive() {
        return this.getPropertyValue("isExclusive");
    }
    set isExclusive(val) {
        this.setPropertyValue("isExclusive", val);
    }
    getBaseType() { return "checkboxitem"; }
}
/**
 * A class that describes the Checkboxes question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-checkbox/ (linkStyle))
 */
class QuestionCheckboxModel extends QuestionCheckboxBase {
    constructor(name) {
        super(name);
        this.invisibleOldValues = {};
        this.isChangingValueOnClearIncorrect = false;
        this.selectAllItemValue = this.createSelectAllItem();
        this.registerPropertyChangedHandlers(["showSelectAllItem", "selectAllText"], () => {
            this.onVisibleChoicesChanged();
        });
    }
    getDefaultItemComponent() {
        return "survey-checkbox-item";
    }
    getType() {
        return "checkbox";
    }
    getItemValueType() {
        return "checkboxitem";
    }
    createSelectAllItem() {
        const res = this.createItemValue("");
        res.value = "";
        res.id = "selectall";
        this.selectAllItemText = this.createLocalizableString("selectAllText", res, true, "selectAllItemText");
        res.locOwner = this;
        res.setLocText(this.selectAllItemText);
        return res;
    }
    onCreating() {
        super.onCreating();
        this.createNewArray("renderedValue");
        this.createNewArray("value");
    }
    getFirstInputElementId() {
        return this.inputId + "_0";
    }
    /**
     * Specifies a property name used to store selected values.
     *
     * Set this property if you want to store selected values in an array of objects instead of an array of primitive values. For example, if you set `valuePropertyName` to `"car"`, the `value` property will contain an array of objects `[{ car: "Ford" }, { car: "Tesla" }]`, not an array of string values `[ "Ford", "Tesla" ]`.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/merge-question-values/ (linkStyle))
     */
    get valuePropertyName() {
        return this.getPropertyValue("valuePropertyName");
    }
    set valuePropertyName(val) {
        this.setPropertyValue("valuePropertyName", val);
    }
    getQuestionFromArray(name, index) {
        if (!!name && name === this.valuePropertyName) {
            const v = this.value;
            if (Array.isArray(v) && index < v.length)
                return this;
        }
        return null;
    }
    getDependedQuestionsByValueName(isDependOn) {
        if (isDependOn && !!this.valuePropertyName)
            return [];
        return super.getDependedQuestionsByValueName(isDependOn);
    }
    /**
     * Returns the "Select All" choice item. Use this property to change the item's `value` or `text`.
     * @see showSelectAllItem
     */
    get selectAllItem() {
        return this.selectAllItemValue;
    }
    /**
     * Gets or sets a caption for the "Select All" choice item.
     * @see showSelectAllItem
     */
    get selectAllText() {
        return this.getLocalizableStringText("selectAllText");
    }
    set selectAllText(val) {
        this.setLocalizableStringText("selectAllText", val);
    }
    get locSelectAllText() {
        return this.getLocalizableString("selectAllText");
    }
    /**
     * Enable this property to display a "Select All" item. When users select it, all other choice items, except "Other" and "None", also become selected.
     * @see selectAll
     * @see isAllSelected
     * @see separateSpecialChoices
     */
    get showSelectAllItem() {
        return this.getPropertyValue("showSelectAllItem");
    }
    set showSelectAllItem(val) {
        this.setPropertyValue("showSelectAllItem", val);
    }
    get hasSelectAll() {
        return this.showSelectAllItem;
    }
    set hasSelectAll(val) {
        this.showSelectAllItem = val;
    }
    /**
     * Returns `true` if all choice items, except "Other" and "None", are selected.
     * @see showSelectAllItem
     */
    get isAllSelected() {
        return this.allElementsSelected();
    }
    set isAllSelected(val) {
        if (val) {
            this.selectAll();
        }
        else {
            this.clearValue(true);
        }
    }
    toggleSelectAll() {
        this.isAllSelected = !this.isAllSelected;
    }
    allElementsSelected() {
        if (this.isNoneItemsSelected())
            return false;
        const items = this.getVisibleEnableItems();
        if (items.length === 0)
            return false;
        const val = this.value;
        if (!val || !Array.isArray(val) || val.length === 0)
            return false;
        if (val.length < items.length)
            return false;
        const rVal = [];
        for (let i = 0; i < val.length; i++) {
            rVal.push(this.getRealValue(val[i]));
        }
        for (let i = 0; i < items.length; i++) {
            if (rVal.indexOf(items[i].value) < 0)
                return false;
        }
        return true;
    }
    isNoneItemsSelected() {
        const noneItems = this.getNoneItems();
        for (let i = 0; i < noneItems.length; i++) {
            if (this.isItemSelected(noneItems[i]))
                return true;
        }
        return false;
    }
    getNoneItems() {
        const res = new Array();
        this.visibleChoices.forEach((item) => {
            if (this.isNoneItem(item)) {
                res.push(item);
            }
        });
        return res;
    }
    /**
     * Selects all choice items, except "Other" and "None".
     *
     * To clear selection, call the `clearValue()` method.
     * @see clearValue
     */
    selectAll() {
        const val = [];
        const items = this.getVisibleEnableItems();
        for (let i = 0; i < items.length; i++) {
            val.push(items[i].value);
        }
        this.renderedValue = val;
    }
    clickItemHandler(item, checked) {
        if (this.isReadOnlyAttr)
            return;
        if (item === this.selectAllItem) {
            if (checked === true || checked === false) {
                this.isAllSelected = checked;
            }
            else {
                this.toggleSelectAll();
            }
        }
        else {
            if (this.isNoneItem(item)) {
                this.renderedValue = checked ? [item.value] : [];
            }
            else {
                const newValue = [].concat(this.renderedValue || []);
                const index = newValue.indexOf(item.value);
                if (checked) {
                    if (index < 0) {
                        newValue.push(item.value);
                    }
                }
                else {
                    if (index > -1) {
                        newValue.splice(index, 1);
                    }
                }
                this.renderedValue = newValue;
            }
        }
    }
    isItemSelectedCore(item) {
        if (item === this.selectAllItem)
            return this.isAllSelected;
        var val = this.renderedValue;
        if (!val || !Array.isArray(val))
            return false;
        for (var i = 0; i < val.length; i++) {
            if (this.isTwoValueEquals(val[i], item.value))
                return true;
        }
        return false;
    }
    hasUnknownValueItem(val, includeOther = false, isFilteredChoices = true, checkEmptyValue = false) {
        const propName = this.valuePropertyName;
        if (!!propName && typeof val === "object" && val[propName] !== undefined) {
            val = val[propName];
        }
        return super.hasUnknownValueItem(val, includeOther, isFilteredChoices, checkEmptyValue);
    }
    convertFuncValuetoQuestionValue(val) {
        if (!!this.valuePropertyName && Array.isArray(val) && val.length > 0) {
            const res = [];
            val.forEach(item => {
                const isObj = typeof item === "object";
                let obj = isObj ? item : {};
                if (!isObj) {
                    obj[this.valuePropertyName] = item;
                }
                res.push(obj);
            });
            val = res;
        }
        return super.convertDefaultValue(val);
    }
    getRealValue(val) {
        if (!val)
            return val;
        return !this.valuePropertyName ? val : val[this.valuePropertyName];
    }
    get isValueArray() { return true; }
    /**
     * Specifies the maximum number of selected choices.
     *
     * Default value: 0 (unlimited)
     *
     * > This property only limits the number of choice items that can be selected by users. You can select any number of choice items in code, regardless of the `maxSelectedChoices` value.
     *
     * [Ranking Demo](https://surveyjs.io/form-library/examples/select-items-to-rank/ (linkStyle))
     * @see minSelectedChoices
     */
    get maxSelectedChoices() {
        return this.getPropertyValue("maxSelectedChoices");
    }
    set maxSelectedChoices(val) {
        if (val < 0)
            val = 0;
        this.setPropertyValue("maxSelectedChoices", val);
        this.filterItems();
    }
    /**
     * Specifies the minimum number of selected choices.
     *
     * Default value: 0 (unlimited)
     *
     * > This property only limits the number of choice items that can be selected by users. You can select any number of choice items in code, regardless of the `minSelectedChoices` value.
     *
     * [Ranking Demo](https://surveyjs.io/form-library/examples/select-items-to-rank/ (linkStyle))
     * @see maxSelectedChoices
     */
    get minSelectedChoices() {
        return this.getPropertyValue("minSelectedChoices");
    }
    set minSelectedChoices(val) {
        if (val < 0)
            val = 0;
        this.setPropertyValue("minSelectedChoices", val);
    }
    /**
     * An array of selected choice items. Includes the "Other" and "None" choice items if they are selected, but not "Select All". Items are sorted in the order they were selected.
     * @see visibleChoices
     * @see enabledChoices
     */
    get selectedChoices() {
        const val = this.renderedValue;
        const visChoices = this.visibleChoices;
        const selectedItemValues = this.selectedItemValues;
        if (this.isEmpty())
            return [];
        const allChoices = !!this.defaultSelectedItemValues ? [].concat(this.defaultSelectedItemValues, visChoices) : visChoices;
        const itemValues = val.map((item) => { return ItemValue.getItemByValue(allChoices, item); }).filter(item => !!item);
        if (!itemValues.length && !selectedItemValues) {
            this.updateSelectedItemValues();
        }
        const validValues = this.validateItemValues(itemValues);
        return validValues;
    }
    get selectedItems() { return this.selectedChoices; }
    get hasFilteredValue() { return !!this.valuePropertyName; }
    getFilteredName() {
        let res = super.getFilteredName();
        if (this.hasFilteredValue) {
            res += "-unwrapped";
        }
        return res;
    }
    getFilteredValue() {
        if (this.hasFilteredValue)
            return this.renderedValue;
        return super.getFilteredValue();
    }
    getMultipleSelectedItems() {
        return this.selectedChoices;
    }
    validateItemValues(itemValues) {
        if (!!itemValues.length)
            return itemValues;
        const selectedItemValues = this.selectedItemValues;
        if (!!selectedItemValues && !!selectedItemValues.length) {
            this.defaultSelectedItemValues = [].concat(selectedItemValues);
            return selectedItemValues;
        }
        const val = this.renderedValue;
        return val.map((item) => this.createItemValue(item));
    }
    getAnswerCorrectIgnoreOrder() { return true; }
    onCheckForErrors(errors, isOnValueChanged, fireCallback) {
        super.onCheckForErrors(errors, isOnValueChanged, fireCallback);
        if (isOnValueChanged)
            return;
        if (this.checkMinSelectedChoicesUnreached()) {
            const minError = new CustomError(this.getLocalizationFormatString("minSelectError", this.minSelectedChoices), this);
            errors.push(minError);
        }
    }
    onVisibleChoicesChanged() {
        super.onVisibleChoicesChanged();
        this.updateSelectAllItemProps();
    }
    onEnableItemCallBack(item) {
        if (!this.shouldCheckMaxSelectedChoices())
            return true;
        return this.isItemSelected(item);
    }
    onAfterRunItemsEnableCondition() {
        this.updateSelectAllItemProps();
        if (this.maxSelectedChoices < 1) {
            this.otherItem.setIsEnabled(true);
            return;
        }
        if (this.hasOther) {
            this.otherItem.setIsEnabled(!this.shouldCheckMaxSelectedChoices() || this.isOtherSelected);
        }
    }
    updateSelectAllItemProps() {
        if (!this.hasSelectAll)
            return;
        this.selectAllItem.setIsEnabled(this.getSelectAllEnabled());
    }
    getSelectAllEnabled() {
        if (!this.hasSelectAll)
            return true;
        let visCount = this.getVisibleEnableItems().length;
        const max = this.maxSelectedChoices;
        if (max > 0 && max < visCount)
            return false;
        return visCount > 0;
    }
    getVisibleEnableItems() {
        const res = new Array();
        const items = this.visibleChoices;
        for (let i = 0; i < items.length; i++) {
            const item = items[i];
            if (item.isEnabled && !this.isBuiltInChoice(item) && !item.isExclusive) {
                res.push(item);
            }
        }
        return res;
    }
    shouldCheckMaxSelectedChoices() {
        if (this.maxSelectedChoices < 1)
            return false;
        var val = this.value;
        var len = !Array.isArray(val) ? 0 : val.length;
        return len >= this.maxSelectedChoices;
    }
    checkMinSelectedChoicesUnreached() {
        if (this.minSelectedChoices < 1)
            return false;
        var val = this.value;
        var len = !Array.isArray(val) ? 0 : val.length;
        if (len === 1 && this.isNoneItemsSelected())
            return false;
        return len < this.minSelectedChoices;
    }
    getItemClassCore(item, options) {
        this.value; //trigger dependencies from koValue for knockout
        options.isSelectAllItem = item === this.selectAllItem;
        return new CssClassBuilder()
            .append(super.getItemClassCore(item, options))
            .append(this.cssClasses.itemSelectAll, options.isSelectAllItem)
            .toString();
    }
    updateValueFromSurvey(newValue, clearData) {
        super.updateValueFromSurvey(newValue, clearData);
        this.invisibleOldValues = {};
    }
    setDefaultValue() {
        super.setDefaultValue();
        const val = this.defaultValue;
        if (Array.isArray(val)) {
            for (var i = 0; i < val.length; i++) {
                const rVal = this.getRealValue(val[i]);
                if (this.canClearValueAnUnknown(rVal)) {
                    this.addIntoInvisibleOldValues(rVal);
                }
            }
        }
    }
    addIntoInvisibleOldValues(val) {
        this.invisibleOldValues[val] = val;
    }
    hasValueToClearIncorrectValues() {
        return super.hasValueToClearIncorrectValues() || !Helpers.isValueEmpty(this.invisibleOldValues);
    }
    setNewValue(newValue) {
        if (!this.isChangingValueOnClearIncorrect) {
            this.invisibleOldValues = {};
        }
        newValue = this.valueFromData(newValue);
        var value = this.value;
        if (!newValue)
            newValue = [];
        if (!value)
            value = [];
        if (this.isTwoValueEquals(value, newValue))
            return;
        this.removeNoneItemsValues(value, newValue);
        super.setNewValue(newValue);
    }
    getIsMultipleValue() {
        return true;
    }
    getCommentFromValue(newValue) {
        var ind = this.getFirstUnknownIndex(newValue);
        if (ind < 0)
            return "";
        return newValue[ind];
    }
    getStoreOthersAsComment() {
        if (!!this.valuePropertyName)
            return false;
        return super.getStoreOthersAsComment();
    }
    setOtherValueIntoValue(newValue) {
        var ind = this.getFirstUnknownIndex(newValue);
        if (ind < 0)
            return newValue;
        let otherVal = this.otherItem.value;
        const propName = this.valuePropertyName;
        if (propName) {
            const obj = {};
            obj[propName] = otherVal;
            otherVal = obj;
        }
        newValue.splice(ind, 1, otherVal);
        return newValue;
    }
    getFirstUnknownIndex(newValue) {
        if (!Array.isArray(newValue))
            return -1;
        for (var i = 0; i < newValue.length; i++) {
            if (this.hasUnknownValueItem(newValue[i], false, false))
                return i;
        }
        return -1;
    }
    removeNoneItemsValues(value, newValue) {
        const noneValues = this.getNoneItems().map(item => item.value);
        if (noneValues.length > 0) {
            const prevNone = this.noneIndexInArray(value, noneValues);
            const newNone = this.noneIndexInArray(newValue, noneValues);
            if (prevNone.index > -1) {
                if (prevNone.val === newNone.val) {
                    if (newValue.length > 0) {
                        newValue.splice(newNone.index, 1);
                    }
                }
                else {
                    const prevNewNone = this.noneIndexInArray(newValue, [prevNone.val]);
                    if (prevNewNone.index > -1 && prevNewNone.index < newValue.length - 1) {
                        newValue.splice(prevNewNone.index, 1);
                    }
                }
            }
            else {
                if (newNone.index > -1 && newValue.length > 1) {
                    const itemVal = this.convertValueToObject([newNone.val])[0];
                    newValue.splice(0, newValue.length, itemVal);
                }
            }
        }
    }
    noneIndexInArray(val, noneValues) {
        if (!Array.isArray(val))
            return { index: -1, val: undefined };
        for (var i = val.length - 1; i >= 0; i--) {
            const index = noneValues.indexOf(this.getRealValue(val[i]));
            if (index > -1)
                return { index: i, val: noneValues[index] };
        }
        return { index: -1, val: undefined };
    }
    supportSelectAll() {
        return this.isSupportProperty("showSelectAllItem");
    }
    addNonChoicesItems(dict, isAddAll) {
        super.addNonChoicesItems(dict, isAddAll);
        if (this.supportSelectAll()) {
            this.addNonChoiceItem(dict, this.selectAllItem, isAddAll, this.hasSelectAll, settings.specialChoicesOrder.selectAllItem);
        }
    }
    isBuiltInChoice(item) {
        return item === this.selectAllItem || super.isBuiltInChoice(item);
    }
    isItemInList(item) {
        if (item == this.selectAllItem)
            return this.hasSelectAll;
        return super.isItemInList(item);
    }
    getDisplayValueEmpty() {
        return ItemValue.getTextOrHtmlByValue(this.visibleChoices.filter(choice => choice != this.selectAllItemValue), undefined);
    }
    getDisplayValueCore(keysAsText, value) {
        if (!Array.isArray(value))
            return super.getDisplayValueCore(keysAsText, value);
        const valuePropName = this.valuePropertyName;
        const onGetValueCallback = (index) => {
            let val = value[index];
            if (!!valuePropName && !!val[valuePropName]) {
                val = val[valuePropName];
            }
            return val;
        };
        return this.getDisplayArrayValue(keysAsText, value, onGetValueCallback);
    }
    clearIncorrectValuesCore() {
        this.clearIncorrectAndDisabledValues(false);
    }
    clearDisabledValuesCore() {
        this.clearIncorrectAndDisabledValues(true);
    }
    clearIncorrectAndDisabledValues(clearDisabled) {
        var val = this.value;
        var hasChanged = false;
        var restoredValues = this.restoreValuesFromInvisible();
        if (!val && restoredValues.length == 0)
            return;
        if (!Array.isArray(val) || val.length == 0) {
            this.isChangingValueOnClearIncorrect = true;
            if (!clearDisabled) {
                if (this.hasComment) {
                    this.value = null;
                }
                else {
                    this.clearValue(true);
                }
            }
            this.isChangingValueOnClearIncorrect = false;
            if (restoredValues.length == 0)
                return;
            val = [];
        }
        var newValue = [];
        for (var i = 0; i < val.length; i++) {
            const rItemVal = this.getRealValue(val[i]);
            var isUnkown = this.canClearValueAnUnknown(rItemVal);
            if ((!clearDisabled && !isUnkown) ||
                (clearDisabled && !this.isValueDisabled(rItemVal))) {
                newValue.push(val[i]);
            }
            else {
                hasChanged = true;
                if (isUnkown) {
                    this.addIntoInvisibleOldValues(val[i]);
                }
            }
        }
        for (var i = 0; i < restoredValues.length; i++) {
            newValue.push(restoredValues[i]);
            hasChanged = true;
        }
        if (!hasChanged)
            return;
        this.isChangingValueOnClearIncorrect = true;
        if (newValue.length == 0) {
            this.clearValue(true);
        }
        else {
            this.value = newValue;
        }
        this.isChangingValueOnClearIncorrect = false;
    }
    restoreValuesFromInvisible() {
        var res = [];
        var visItems = this.visibleChoices;
        for (var i = 0; i < visItems.length; i++) {
            const item = visItems[i];
            if (item === this.selectAllItem)
                continue;
            var val = visItems[i].value;
            if (Helpers.isTwoValueEquals(val, this.invisibleOldValues[val])) {
                if (!this.isItemSelected(item)) {
                    res.push(val);
                }
                delete this.invisibleOldValues[val];
            }
        }
        return res;
    }
    getConditionJson(operator = null, path = null) {
        const json = super.getConditionJson(operator, path);
        if (operator == "contains" || operator == "notcontains") {
            json["type"] = "radiogroup";
        }
        json["maxSelectedChoices"] = 0;
        json["minSelectedChoices"] = 0;
        return json;
    }
    isAnswerCorrect() {
        return Helpers.isArrayContainsEqual(this.value, this.correctAnswer);
    }
    setDefaultValueWithOthers() {
        this.value = this.renderedValueFromDataCore(this.defaultValue);
    }
    getIsItemValue(val, item) {
        if (!val || !Array.isArray(val))
            return false;
        return val.indexOf(item.value) >= 0;
    }
    valueFromData(val) {
        if (!val)
            return val;
        if (!Array.isArray(val))
            return [super.valueFromData(val)];
        let value = [];
        for (let i = 0; i < val.length; i++) {
            let choiceitem = ItemValue.getItemByValue(this.visibleChoices, val[i]);
            if (!!choiceitem) {
                value.push(choiceitem.value);
            }
            else {
                value.push(val[i]);
            }
        }
        return value;
    }
    rendredValueFromData(val) {
        val = this.convertValueFromObject(val);
        return super.rendredValueFromData(val);
    }
    rendredValueToData(val) {
        val = super.rendredValueToData(val);
        return this.convertValueToObject(val);
    }
    convertValueFromObject(val) {
        if (!this.valuePropertyName)
            return val;
        return Helpers.convertArrayObjectToValue(val, this.valuePropertyName);
    }
    convertValueToObject(val) {
        if (!this.valuePropertyName)
            return val;
        let dest = undefined;
        if (!!this.survey && this.survey.questionsByValueName(this.getValueName()).length > 1) {
            dest = this.data.getValue(this.getValueName());
        }
        return Helpers.convertArrayValueToObject(val, this.valuePropertyName, dest);
    }
    renderedValueFromDataCore(val) {
        if (!val || !Array.isArray(val))
            val = [];
        if (!this.hasActiveChoices)
            return val;
        for (var i = 0; i < val.length; i++) {
            if (val[i] == this.otherItem.value)
                return val;
            if (this.hasUnknownValueItem(val[i], true, false)) {
                this.otherValue = val[i];
                var newVal = val.slice();
                newVal[i] = this.otherItem.value;
                return newVal;
            }
        }
        return val;
    }
    rendredValueToDataCore(val) {
        if (!val || !val.length)
            return val;
        for (var i = 0; i < val.length; i++) {
            if (val[i] == this.otherItem.value) {
                if (this.needConvertRenderedOtherToDataValue()) {
                    var newVal = val.slice();
                    newVal[i] = this.otherValue;
                    return newVal;
                }
            }
        }
        return val;
    }
    selectOtherValueFromComment(val) {
        var newVal = [];
        const rendVal = this.renderedValue;
        if (Array.isArray(rendVal)) {
            for (var i = 0; i < rendVal.length; i++) {
                if (rendVal[i] !== this.otherItem.value) {
                    newVal.push(rendVal[i]);
                }
            }
        }
        if (val) {
            newVal.push(this.otherItem.value);
        }
        this.value = newVal;
    }
    get checkBoxSvgPath() {
        return "M5,13l2-2l3,3l7-7l2,2l-9,9L5,13z";
    }
    //a11y
    get isNewA11yStructure() {
        return true;
    }
    get a11y_input_ariaRole() {
        return "group";
    }
    get a11y_input_ariaRequired() {
        return null;
    }
}
Serializer.addClass("checkboxitem", [{ name: "isExclusive:boolean", locationInTable: "detail" }], (value) => new CheckboxItem(value), "itemvalue");
Serializer.addClass("checkbox", [
    { name: "showSelectAllItem:boolean", alternativeName: "hasSelectAll" },
    { name: "separateSpecialChoices", visible: true },
    { name: "maxSelectedChoices:number", default: 0,
        onSettingValue: (obj, val) => {
            if (val <= 0)
                return 0;
            const min = obj.minSelectedChoices;
            return min > 0 && val < min ? min : val;
        }
    },
    { name: "minSelectedChoices:number", default: 0,
        onSettingValue: (obj, val) => {
            if (val <= 0)
                return 0;
            const max = obj.maxSelectedChoices;
            return max > 0 && val > max ? max : val;
        }
    },
    {
        name: "selectAllText",
        serializationProperty: "locSelectAllText",
        dependsOn: "showSelectAllItem",
        visibleIf: function (obj) {
            return obj.hasSelectAll;
        }
    },
    {
        name: "valuePropertyName",
        category: "data"
    },
    { name: "itemComponent", visible: false, default: "survey-checkbox-item" }
], function () {
    return new QuestionCheckboxModel("");
}, "checkboxbase");
Serializer.getProperty("checkbox", "choices").type = "checkboxitem[]";
QuestionFactory.Instance.registerQuestion("checkbox", (name) => {
    var q = new QuestionCheckboxModel(name);
    q.choices = QuestionFactory.DefaultChoices;
    return q;
});

class MultiSelectListModel extends ListModel {
    updateItemState() {
        this.actions.forEach(action => {
            const isSelected = this.isItemSelected(action);
            action.visible = this.hideSelectedItems ? !isSelected : true;
        });
    }
    constructor(options) {
        super(options);
        this.onItemClick = (item) => {
            if (this.isItemDisabled(item))
                return;
            this.isExpanded = false;
            if (this.isItemSelected(item)) {
                this.selectedItems.splice(this.selectedItems.indexOf(item), 1)[0];
                !!this.onSelectionChanged && (this.onSelectionChanged(item, "removed"));
            }
            else {
                this.selectedItems.push(item);
                !!this.onSelectionChanged && (this.onSelectionChanged(item, "added"));
            }
        };
        this.isItemDisabled = (itemValue) => {
            return itemValue.enabled !== undefined && !itemValue.enabled;
        };
        this.isItemSelected = (itemValue) => {
            return !!this.allowSelection && this.selectedItems.filter(item => this.areSameItems(item, itemValue)).length > 0;
        };
        this.setSelectedItems(options.selectedItems || []);
    }
    updateState() {
        this.updateItemState();
        this.isEmpty = this.renderedActions.filter(action => this.isItemVisible(action)).length === 0;
    }
    setSelectedItems(newItems) {
        this.selectedItems = newItems;
        this.updateState();
    }
    selectFocusedItem() {
        super.selectFocusedItem();
        if (this.hideSelectedItems) {
            this.focusNextVisibleItem();
        }
    }
}
__decorate([
    property()
], MultiSelectListModel.prototype, "hideSelectedItems", void 0);

class DropdownMultiSelectListModel extends DropdownListModel {
    get needRenderInput() {
        return !this.question.isInputReadOnly || !!this.filterStringPlaceholder;
    }
    locStrsChanged() {
        super.locStrsChanged();
        this.syncFilterStringPlaceholder();
    }
    updateListState() {
        this.listModel.updateState();
        this.updateCustomItemValue();
        this.syncFilterStringPlaceholder();
    }
    syncFilterStringPlaceholder() {
        const selectedActions = this.getSelectedActions();
        if (selectedActions.length || this.question.selectedItems.length || this.listModel.focusedItem) {
            this.filterStringPlaceholder = undefined;
        }
        else {
            this.filterStringPlaceholder = this.question.placeholder;
        }
    }
    getSelectedActions() {
        return this.listModel.actions.filter(item => item.selected);
    }
    getFocusFirstInputSelector() {
        if (this.listModel.hideSelectedItems && IsTouch && !this.isValueEmpty(this.question.value)) {
            return this.itemSelector;
        }
        else {
            return super.getFocusFirstInputSelector();
        }
    }
    getPopupCssClasses() { return "sv-multi-select-list"; }
    createListModel() {
        const visibleItems = this.getAvailableItems();
        let _onSelectionChanged = this.onSelectionChanged;
        if (!_onSelectionChanged) {
            _onSelectionChanged = (item, status) => {
                this.resetFilterString();
                if (item.id === "selectall") {
                    this.selectAllItems();
                }
                else if (status === "added" && item.value === settings.noneItemValue) {
                    this.selectNoneItem();
                }
                else if (status === "added") {
                    this.selectItem(item.value);
                }
                else if (status === "removed") {
                    this.deselectItem(item.value);
                }
                this.popupRecalculatePosition(false);
                if (this.closeOnSelect) {
                    this.popupModel.isVisible = false;
                }
            };
        }
        const listOptions = {
            items: visibleItems,
            onSelectionChanged: _onSelectionChanged,
            allowSelection: false,
            locOwner: this.question,
            elementId: this.listElementId
        };
        const res = new MultiSelectListModel(listOptions);
        this.setOnTextSearchCallbackForListModel(res);
        res.forceShowFilter = this.question.choicesLazyLoadEnabled;
        return res;
    }
    resetFilterString() {
        super.resetFilterString();
        this.inputString = null;
        this.hintString = "";
    }
    get shouldResetAfterCancel() {
        return IsTouch && !this.closeOnSelect;
    }
    createPopup() {
        super.createPopup();
        this.popupModel.onFooterActionsCreated.add((_, opt) => {
            opt.actions.push({
                id: "sv-dropdown-done-button",
                title: this.doneButtonCaption,
                innerCss: "sv-popup__button--done",
                needSpace: true,
                action: () => { this.popupModel.isVisible = false; },
                enabled: new ComputedUpdater(() => !this.isTwoValueEquals(this.question.renderedValue, this.previousValue))
            });
        });
        this.popupModel.onVisibilityChanged.add((_, opt) => {
            if (this.shouldResetAfterCancel && opt.isVisible) {
                this.previousValue = [].concat(this.question.renderedValue || []);
            }
        });
        this.popupModel.onCancel = () => {
            if (this.shouldResetAfterCancel) {
                this.question.renderedValue = this.previousValue;
                this.updateListState();
            }
        };
    }
    selectAllItems() {
        this.question.toggleSelectAll();
        if (this.question.isAllSelected && this.question.hideSelectedItems) {
            this.popupModel.hide();
        }
        this.updateListState();
    }
    selectNoneItem() {
        this.question.renderedValue = [settings.noneItemValue];
        this.updateListState();
    }
    selectItem(id) {
        let addedItem;
        if (this.allowCustomChoices && id === this.customItemValue.id) {
            const newChoice = this.createCustomItem();
            if (!!newChoice) {
                addedItem = newChoice.id;
            }
        }
        else {
            addedItem = id;
        }
        if (addedItem) {
            let newValue = [].concat(this.question.renderedValue || []);
            newValue.push(addedItem);
            this.question.renderedValue = newValue;
            this.updateListState();
        }
    }
    deselectItem(id) {
        let newValue = [].concat(this.question.renderedValue || []);
        newValue.splice(newValue.indexOf(id), 1);
        this.question.renderedValue = newValue;
        this.applyHintString();
        this.updateListState();
    }
    clear() {
        super.clear();
        this.syncFilterStringPlaceholder();
    }
    onClear(event) {
        super.onClear(event);
        this.updateListState();
    }
    setHideSelectedItems(newValue) {
        this.listModel.hideSelectedItems = newValue;
        this.updateListState();
    }
    removeLastSelectedItem() {
        this.deselectItem(this.question.renderedValue[this.question.renderedValue.length - 1]);
        this.popupRecalculatePosition(false);
    }
    constructor(question, onSelectionChanged) {
        super(question, onSelectionChanged);
        this.setHideSelectedItems(question.hideSelectedItems);
        this.syncFilterStringPlaceholder();
        this.closeOnSelect = question.closeOnSelect;
    }
    inputKeyHandler(event) {
        if (event.keyCode === 8 && !this.filterString) {
            this.removeLastSelectedItem();
            event.preventDefault();
            event.stopPropagation();
        }
    }
    setInputStringFromSelectedItem(newValue) {
        if (this.question.searchEnabled) {
            this.inputString = null;
        }
    }
    focusItemOnClickAndPopup() {
        return;
    }
    onEscape() {
        return;
    }
    beforeScrollToFocusedItem(focusedItem) {
        return;
    }
    afterScrollToFocusedItem() {
        var _a;
        if (!((_a = this.listModel.focusedItem) === null || _a === void 0 ? void 0 : _a.selected)) {
            this.applyHintString();
        }
        else {
            this.hintString = "";
        }
        this.syncFilterStringPlaceholder();
    }
    onPropertyChangedHandler(sender, options) {
        super.onPropertyChangedHandler(sender, options);
        if (options.name === "value" || options.name === "renderedValue" || options.name === "placeholder") {
            this.syncFilterStringPlaceholder();
        }
    }
}
__decorate([
    property({ defaultValue: "" })
], DropdownMultiSelectListModel.prototype, "filterStringPlaceholder", void 0);
__decorate([
    property({ defaultValue: true })
], DropdownMultiSelectListModel.prototype, "closeOnSelect", void 0);
__decorate([
    property()
], DropdownMultiSelectListModel.prototype, "previousValue", void 0);
__decorate([
    property({ localizable: { defaultStr: "tagboxDoneButtonCaption" } })
], DropdownMultiSelectListModel.prototype, "doneButtonCaption", void 0);

/**
 * A class that describes the Multi-Select Dropdown (Tag Box) question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/how-to-create-multiselect-tag-box/ (linkStyle))
 */
class QuestionTagboxModel extends QuestionCheckboxModel {
    constructor(name) {
        super(name);
        this.itemDisplayNameMap = {};
        this.onOpened = this.addEvent();
        this.createLocalizableString("placeholder", this, false, true);
        this.createLocalizableString("readOnlyText", this, true);
        this.deselectAllItemText = this.createLocalizableString("deselectAllText", this.selectAllItem, true, "deselectAllItemText");
        this.registerPropertyChangedHandlers(["value", "renderAs", "showOtherItem", "otherText", "placeholder", "choices", "visibleChoices"], () => {
            this.updateReadOnlyText();
        });
        this.updateReadOnlyText();
    }
    locStrsChanged() {
        var _a;
        super.locStrsChanged();
        this.updateReadOnlyText();
        (_a = this.dropdownListModelValue) === null || _a === void 0 ? void 0 : _a.locStrsChanged();
    }
    updateReadOnlyText() {
        this.readOnlyText = this.displayValue || this.placeholder;
    }
    getDefaultItemComponent() {
        return "";
    }
    get dropdownListModel() {
        if (!this.dropdownListModelValue) {
            this.dropdownListModelValue = new DropdownMultiSelectListModel(this);
        }
        return this.dropdownListModelValue;
    }
    set dropdownListModel(val) {
        this.dropdownListModelValue = val;
    }
    /**
     * A text displayed in the input field when it doesn't have a value.
     */
    get placeholder() {
        return this.getLocalizableStringText("placeholder");
    }
    set placeholder(val) {
        this.setLocalizableStringText("placeholder", val);
        if (!!this.dropdownListModelValue) {
            this.dropdownListModel.setInputPlaceholder(val);
        }
    }
    get locPlaceholder() {
        return this.getLocalizableString("placeholder");
    }
    get readOnlyText() {
        return this.getLocalizableStringText("readOnlyText");
    }
    set readOnlyText(val) {
        this.setLocalizableStringText("readOnlyText", val);
    }
    get locReadOnlyText() {
        return this.getLocalizableString("readOnlyText");
    }
    getType() {
        return "tagbox";
    }
    get a11yInputAriaRole() {
        return "combobox";
    }
    get popupModel() {
        return this.dropdownListModel.popupModel;
    }
    getControlClass() {
        return new CssClassBuilder()
            .append(this.cssClasses.control)
            .append(this.cssClasses.controlEmpty, this.isEmpty())
            .append(this.cssClasses.onError, this.hasCssError())
            .append(this.cssClasses.controlEditable, !this.isDisabledStyle && !this.isReadOnlyStyle && !this.isPreviewStyle)
            .append(this.cssClasses.controlDisabled, this.isDisabledStyle)
            .append(this.cssClasses.controlReadOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.controlPreview, this.isPreviewStyle)
            .toString();
    }
    updateCssClasses(res, css) {
        super.updateCssClasses(res, css);
        updateListCssValues(res, css);
    }
    calcCssClasses(css) {
        const classes = super.calcCssClasses(css);
        if (this.dropdownListModelValue) {
            this.dropdownListModel.updateCssClasses(classes.popup, classes.list);
        }
        return classes;
    }
    onOpenedCallBack() {
        this.onOpened.fire(this, { question: this, choices: this.choices });
    }
    hasUnknownValue(val, includeOther = false, isFilteredChoices = true, checkEmptyValue = false) {
        if (this.choicesLazyLoadEnabled)
            return false;
        return super.hasUnknownValue(val, includeOther, isFilteredChoices, checkEmptyValue);
    }
    needConvertRenderedOtherToDataValue() {
        var _a;
        const val = (_a = this.otherValue) === null || _a === void 0 ? void 0 : _a.trim();
        if (!val)
            return false;
        return super.hasUnknownValue(val, true, false);
    }
    onVisibleChoicesChanged() {
        super.onVisibleChoicesChanged();
        if (!!this.dropdownListModelValue) {
            this.dropdownListModel.updateItems();
        }
    }
    getItemIfChoicesNotContainThisValue(value, text) {
        if (this.choicesLazyLoadEnabled) {
            return this.createItemValue(value, text);
        }
        else {
            return super.getItemIfChoicesNotContainThisValue(value, text);
        }
    }
    validateItemValues(itemValues) {
        this.updateItemDisplayNameMap();
        const val = this.renderedValue;
        if (!!itemValues.length && itemValues.length === val.length)
            return itemValues;
        const selectedItemValues = this.selectedItemValues;
        if (!itemValues.length && !!selectedItemValues && !!selectedItemValues.length) {
            this.defaultSelectedItemValues = [].concat(selectedItemValues);
            return selectedItemValues;
        }
        const itemValueValues = itemValues.map(iV => iV.value);
        val.filter(item => { return itemValueValues.indexOf(item) === -1; }).forEach(item => {
            const newItem = this.getItemIfChoicesNotContainThisValue(item, this.itemDisplayNameMap[item]);
            if (newItem) {
                itemValues.push(newItem);
            }
        });
        itemValues.sort((a, b) => { return val.indexOf(a.value) - val.indexOf(b.value); });
        return itemValues;
    }
    updateItemDisplayNameMap() {
        const func = (item) => { this.itemDisplayNameMap[item.value] = item.text; };
        (this.defaultSelectedItemValues || []).forEach(func);
        (this.selectedItemValues || []).forEach(func);
        this.visibleChoices.forEach(func);
    }
    getIsQuestionReady() {
        return super.getIsQuestionReady() && !this.isChoicesLoading;
    }
    ensureQuestionIsReady() {
        super.ensureQuestionIsReady();
        if (!!this.dropdownListModel && this.choicesLazyLoadEnabled) {
            this.dropdownListModel.loadQuestionChoices();
        }
    }
    setIsChoicesLoading(value) {
        this.isChoicesLoading = value;
        this.updateIsReady();
    }
    canAddCustomChoices() {
        return this.allowCustomChoices;
    }
    getFirstInputElementId() {
        return this.inputId + (this.searchEnabled || this.allowCustomChoices ? "_0" : "");
    }
    getInputId() {
        return this.inputId + "_0";
    }
    supportEmptyValidation() { return true; }
    onBlurCore(event) {
        this.dropdownListModel.onBlur(event);
        super.onBlurCore(event);
    }
    onFocusCore(event) {
        this.dropdownListModel.onFocus(event);
        super.onFocusCore(event);
    }
    allElementsSelected() {
        const result = super.allElementsSelected();
        this.updateSelectAllItemText(result);
        return result;
    }
    updateSelectAllItemText(isAllSelected) {
        this.selectAllItem.setLocText(isAllSelected ? this.deselectAllItemText : this.selectAllItemText);
    }
    dispose() {
        super.dispose();
        if (!!this.dropdownListModelValue) {
            this.dropdownListModelValue.dispose();
            this.dropdownListModelValue = undefined;
        }
    }
    clearValue(keepComment) {
        var _a;
        super.clearValue(keepComment);
        (_a = this.dropdownListModelValue) === null || _a === void 0 ? void 0 : _a.clear();
    }
    get showClearButton() {
        return this.allowClear && !this.isEmpty();
    }
}
__decorate([
    property()
], QuestionTagboxModel.prototype, "searchMode", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            if (!!target.dropdownListModelValue) {
                target.dropdownListModel.setAllowCustomChoices(newValue);
            }
        }
    })
], QuestionTagboxModel.prototype, "allowCustomChoices", void 0);
__decorate([
    property()
], QuestionTagboxModel.prototype, "allowClear", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            if (!!target.dropdownListModelValue) {
                target.dropdownListModel.setSearchEnabled(newValue);
            }
        }
    })
], QuestionTagboxModel.prototype, "searchEnabled", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            if (!!target.dropdownListModelValue) {
                target.dropdownListModel.setHideSelectedItems(newValue);
            }
        }
    })
], QuestionTagboxModel.prototype, "hideSelectedItems", void 0);
__decorate([
    property({
        onSet: (newValue, target) => {
            if (!!target.dropdownListModelValue) {
                target.dropdownListModel.setChoicesLazyLoadEnabled(newValue);
            }
        }
    })
], QuestionTagboxModel.prototype, "choicesLazyLoadEnabled", void 0);
__decorate([
    property()
], QuestionTagboxModel.prototype, "choicesLazyLoadPageSize", void 0);
__decorate([
    property({ getDefaultValue: () => { return settings.tagboxCloseOnSelect; } })
], QuestionTagboxModel.prototype, "closeOnSelect", void 0);
__decorate([
    property()
], QuestionTagboxModel.prototype, "textWrapEnabled", void 0);
Serializer.addClass("tagbox", [
    { name: "placeholder", serializationProperty: "locPlaceholder" },
    { name: "allowClear:boolean", default: true },
    { name: "searchEnabled:boolean", default: true },
    {
        name: "allowCustomChoices:boolean", default: false,
        visibleIf: (obj) => !obj.choicesFromQuestion, dependsOn: "choicesFromQuestion"
    },
    { name: "textWrapEnabled:boolean", default: true },
    { name: "choicesLazyLoadEnabled:boolean", default: false, visible: false },
    { name: "choicesLazyLoadPageSize:number", default: 25, visible: false },
    { name: "hideSelectedItems:boolean", default: false },
    { name: "closeOnSelect:boolean" },
    { name: "itemComponent", visible: false, default: "" },
    { name: "searchMode", default: "contains", choices: ["contains", "startsWith"] }
], function () {
    return new QuestionTagboxModel("");
}, "checkbox");
QuestionFactory.Instance.registerQuestion("tagbox", (name) => {
    const q = new QuestionTagboxModel(name);
    q.choices = QuestionFactory.DefaultChoices;
    return q;
});

class DragDropChoices extends DragDropCore {
    constructor() {
        super(...arguments);
        this.doDragOver = () => {
            if (this.parentElement.getType() === "imagepicker")
                return;
            const node = this.domAdapter.draggedElementShortcut.querySelector(".svc-item-value-controls__button");
            node.style.cursor = "grabbing";
        };
        this.doBanDropHere = () => {
            if (this.parentElement.getType() === "imagepicker")
                return;
            const node = this.domAdapter.draggedElementShortcut.querySelector(".svc-item-value-controls__button");
            node.style.cursor = "not-allowed";
        };
    }
    get draggedElementType() {
        return "item-value";
    }
    createDraggedElementShortcut(text, draggedElementNode, event) {
        if (this.parentElement.getType() === "imagepicker") {
            return this.createImagePickerShortcut(this.draggedElement, text, draggedElementNode, event);
        }
        const draggedElementShortcut = DomDocumentHelper.createElement("div");
        if (!draggedElementShortcut)
            return;
        // draggedElementShortcut.innerText = text;
        draggedElementShortcut.className = "sv-drag-drop-choices-shortcut";
        const isDeepClone = true;
        const clone = (draggedElementNode
            .closest("[data-sv-drop-target-item-value]")
            .cloneNode(isDeepClone));
        clone.classList.add("sv-drag-drop-choices-shortcut__content");
        const dragIcon = clone.querySelector(".svc-item-value-controls__drag-icon");
        dragIcon.style.visibility = "visible";
        const removeIcon = clone.querySelector(".svc-item-value-controls__remove");
        removeIcon.style.backgroundColor = "transparent";
        clone.classList.remove("svc-item-value--moveup");
        clone.classList.remove("svc-item-value--movedown");
        this.draggedElement.isDragDropMoveDown = false;
        this.draggedElement.isDragDropMoveUp = false;
        draggedElementShortcut.appendChild(clone);
        const rect = draggedElementNode.getBoundingClientRect();
        draggedElementShortcut.shortcutXOffset = event.clientX - rect.x;
        draggedElementShortcut.shortcutYOffset = event.clientY - rect.y;
        this.isBottom = null;
        if (typeof this.onShortcutCreated === "function") {
            this.onShortcutCreated(draggedElementShortcut);
        }
        return draggedElementShortcut;
    }
    createImagePickerShortcut(item, text, draggedElementNode, event) {
        const draggedElementShortcut = DomDocumentHelper.createElement("div");
        if (!draggedElementShortcut)
            return;
        draggedElementShortcut.classList.add("sv-drag-drop-image-picker-shortcut");
        const itemValueNode = draggedElementNode.closest("[data-sv-drop-target-item-value]");
        this.imagepickerControlsNode = itemValueNode.querySelector(".svc-image-item-value-controls");
        const imageContainerNode = itemValueNode.querySelector(".sd-imagepicker__image-container");
        let imageNode = itemValueNode.querySelector(item.imageLink ? "img" : ".sd-imagepicker__no-image").cloneNode(true);
        if (!!this.imagepickerControlsNode) {
            this.imagepickerControlsNode.style.display = "none";
        }
        imageContainerNode.style.width = imageNode.width + "px";
        imageContainerNode.style.height = imageNode.height + "px";
        imageNode.style.objectFit = "cover";
        imageNode.style.borderRadius = "4px";
        draggedElementShortcut.appendChild(imageNode);
        return draggedElementShortcut;
    }
    getDropTargetByDataAttributeValue(dataAttributeValue) {
        let dragOverChoice;
        dragOverChoice = this.parentElement.choices.filter((choice) => "" + choice.value == dataAttributeValue)[0];
        return dragOverChoice;
    }
    getChoices() {
        const parent = this.parentElement;
        if (parent.getType() === "ranking") {
            if (parent.selectToRankEnabled) {
                return parent.unRankingChoices;
            }
            else {
                return parent.rankingChoices;
            }
        }
        return parent.visibleChoices;
    }
    isDropTargetValid(dropTarget, dropTargetNode) {
        const choices = this.getChoices();
        if (this.parentElement.getType() !== "imagepicker") {
            const dropTargetIndex = choices.indexOf(this.dropTarget);
            const draggedElementIndex = choices.indexOf(this.draggedElement);
            if (draggedElementIndex > dropTargetIndex && this.dropTarget.isDragDropMoveUp) {
                this.dropTarget.isDragDropMoveUp = false;
                return false;
            }
            if (draggedElementIndex < dropTargetIndex && this.dropTarget.isDragDropMoveDown) {
                this.dropTarget.isDragDropMoveDown = false;
                return false;
            }
        }
        // shouldn't allow to drop on "adorners" (selectall, none, other)
        if (choices.indexOf(dropTarget) === -1)
            return false;
        return true;
    }
    isDropTargetDoesntChanged(newIsBottom) {
        return (this.dropTarget === this.prevDropTarget && newIsBottom === this.isBottom);
    }
    calculateIsBottom(clientY, dropTargetNode) {
        const rect = dropTargetNode.getBoundingClientRect();
        return clientY >= rect.y + rect.height / 2;
    }
    afterDragOver(dropTargetNode) {
        //if (this.isDropTargetDoesntChanged(this.isBottom)) return;
        const choices = this.getChoices();
        const dropTargetIndex = choices.indexOf(this.dropTarget);
        const draggedElementIndex = choices.indexOf(this.draggedElement);
        if (draggedElementIndex < dropTargetIndex && this.isBottom === true) {
            // drag "down"
            choices.splice(draggedElementIndex, 1);
            choices.splice(dropTargetIndex, 0, this.draggedElement);
        }
        else if (draggedElementIndex > dropTargetIndex && this.isBottom === false) {
            // drag "up"
            choices.splice(dropTargetIndex, 1);
            choices.splice(draggedElementIndex, 0, this.dropTarget);
        }
        else {
            return;
        }
        if (this.parentElement.getType() === "imagepicker")
            return;
        if (draggedElementIndex !== dropTargetIndex) {
            dropTargetNode.classList.remove("svc-item-value--moveup");
            dropTargetNode.classList.remove("svc-item-value--movedown");
            this.dropTarget.isDragDropMoveDown = false;
            this.dropTarget.isDragDropMoveUp = false;
        }
        if (draggedElementIndex > dropTargetIndex) {
            this.dropTarget.isDragDropMoveDown = true;
        }
        if (draggedElementIndex < dropTargetIndex) {
            this.dropTarget.isDragDropMoveUp = true;
        }
        super.ghostPositionChanged();
    }
    doDrop() {
        const choices = this.parentElement.choices;
        const filteredChoices = this.getChoices().filter((item) => {
            return choices.indexOf(item) !== -1;
        });
        const oldIndex = choices.indexOf(this.draggedElement);
        let newIndex = filteredChoices.indexOf(this.draggedElement);
        choices.splice(oldIndex, 1);
        choices.splice(newIndex, 0, this.draggedElement);
        return this.parentElement;
    }
    clear() {
        if (!!this.parentElement) {
            this.updateVisibleChoices(this.parentElement);
        }
        if (!!this.imagepickerControlsNode) {
            this.imagepickerControlsNode.style.display = "flex";
            this.imagepickerControlsNode = null;
        }
        super.clear();
    }
    updateVisibleChoices(parent) {
        parent.getType() === "ranking" ?
            parent.updateRankingChoices() :
            parent["updateVisibleChoices"]();
    }
}

class DragDropRankingChoices extends DragDropChoices {
    constructor() {
        super(...arguments);
        this.isDragOverRootNode = false;
        this.doDragOver = () => {
            const node = this.domAdapter.draggedElementShortcut.querySelector(".sv-ranking-item");
            node.style.cursor = "grabbing";
        };
        this.reorderRankedItem = (questionModel, fromIndex, toIndex) => {
            if (fromIndex == toIndex)
                return;
            const rankingChoices = questionModel.rankingChoices;
            const item = rankingChoices[fromIndex];
            questionModel.isValueSetByUser = true;
            rankingChoices.splice(fromIndex, 1);
            rankingChoices.splice(toIndex, 0, item);
            this.updateDraggedElementShortcut(toIndex + 1);
        };
        this.doBanDropHere = () => {
            if (this.isDragOverRootNode) {
                this.allowDropHere = true;
                return;
            }
            const node = this.domAdapter.draggedElementShortcut.querySelector(".sv-ranking-item");
            node.style.cursor = "not-allowed";
            if (IsTouch) {
                this.parentElement.updateRankingChoices(true);
            }
        };
    }
    get draggedElementType() {
        return "ranking-item";
    }
    createDraggedElementShortcut(text, draggedElementNode, event) {
        const draggedElementShortcut = DomDocumentHelper.createElement("div");
        if (!draggedElementShortcut)
            return;
        draggedElementShortcut.className = this.shortcutClass + " sv-ranking-shortcut";
        const isDeepClone = true;
        const clone = draggedElementNode.cloneNode(isDeepClone);
        draggedElementShortcut.appendChild(clone);
        const rect = draggedElementNode.getBoundingClientRect();
        draggedElementShortcut.style.left = rect.x;
        draggedElementShortcut.style.top = rect.y;
        this.domAdapter.rootElement.append(draggedElementShortcut);
        const shortcutHeight = draggedElementShortcut.offsetHeight;
        let clientY = event.clientY;
        if (clientY > rect.y + shortcutHeight) {
            clientY = rect.y + shortcutHeight - 10; //TODO
        }
        draggedElementShortcut.shortcutXOffset = event.clientX - rect.x;
        draggedElementShortcut.shortcutYOffset = clientY - rect.y;
        if (this.parentElement && this.parentElement.useFullItemSizeForShortcut) {
            draggedElementShortcut.style.width = draggedElementNode.offsetWidth + "px";
            draggedElementShortcut.style.height = draggedElementNode.offsetHeight + "px";
        }
        return draggedElementShortcut;
    }
    get shortcutClass() {
        return new CssClassBuilder()
            .append(this.parentElement.cssClasses.root)
            .append(this.parentElement.cssClasses.rootMobileMod, IsMobile)
            .toString();
    }
    getDropTargetByDataAttributeValue(dataAttributeValue) {
        return this.parentElement.rankingChoices[dataAttributeValue];
    }
    findDropTargetNodeByDragOverNode(dragOverNode) {
        this.isDragOverRootNode = this.getIsDragOverRootNode(dragOverNode);
        return super.findDropTargetNodeByDragOverNode(dragOverNode);
    }
    getIsDragOverRootNode(dragOverNode) {
        // dragOverNode might be <path></path> for example and the className prop is obj
        return typeof dragOverNode.className === "string" &&
            dragOverNode.className.indexOf("sv-ranking") !== -1;
    }
    isDropTargetValid(dropTarget, dropTargetNode) {
        const choices = this.parentElement.rankingChoices;
        if (choices.indexOf(dropTarget) === -1)
            // shouldn't allow to drop on "adorners" (selectall, none, other)
            return false;
        return true;
    }
    calculateIsBottom(clientY, dropTargetNode) {
        if (this.dropTarget instanceof ItemValue && this.draggedElement !== this.dropTarget) {
            return super.calculateIsBottom(clientY, dropTargetNode);
        }
        return false;
    }
    getIndices(model, fromChoicesArray, toChoicesArray) {
        let fromIndex = fromChoicesArray.indexOf(this.draggedElement);
        let toIndex = toChoicesArray.indexOf(this.dropTarget);
        if (fromIndex < 0 && !!this.draggedElement) {
            this.draggedElement = ItemValue.getItemByValue(fromChoicesArray, this.draggedElement.value) || this.draggedElement;
            fromIndex = fromChoicesArray.indexOf(this.draggedElement);
        }
        if (toIndex === -1) {
            const length = model.value.length;
            toIndex = length;
        }
        else if (fromChoicesArray == toChoicesArray) {
            if (!this.isBottom && fromIndex < toIndex)
                toIndex--;
            if (this.isBottom && fromIndex > toIndex)
                toIndex++;
        }
        else if (fromChoicesArray != toChoicesArray) {
            if (this.isBottom)
                toIndex++;
        }
        return { fromIndex, toIndex };
    }
    afterDragOver(dropTargetNode) {
        const { fromIndex, toIndex } = this.getIndices(this.parentElement, this.parentElement.rankingChoices, this.parentElement.rankingChoices);
        this.reorderRankedItem(this.parentElement, fromIndex, toIndex);
    }
    updateDraggedElementShortcut(newIndex) {
        var _a;
        if ((_a = this.domAdapter) === null || _a === void 0 ? void 0 : _a.draggedElementShortcut) {
            const newIndexText = newIndex !== null ? newIndex + "" : "";
            // TODO should avoid direct DOM manipulation, do through the frameworks instead
            const indexNode = this.domAdapter.draggedElementShortcut.querySelector(".sv-ranking-item__index");
            indexNode.innerText = newIndexText;
        }
    }
    ghostPositionChanged() {
        this.parentElement.currentDropTarget = this.draggedElement;
        super.ghostPositionChanged();
    }
    doDrop() {
        this.parentElement.setValue();
        return this.parentElement;
    }
    clear() {
        if (!!this.parentElement) {
            this.parentElement.dropTargetNodeMove = null;
            this.parentElement.updateRankingChoices(true);
        }
        super.clear();
    }
}

class DragDropRankingSelectToRank extends DragDropRankingChoices {
    constructor() {
        super(...arguments);
        this.selectToRank = (questionModel, fromIndex, toIndex) => {
            const rankingChoices = [].concat(questionModel.rankingChoices);
            const unRankingChoices = questionModel.unRankingChoices;
            const item = unRankingChoices[fromIndex];
            rankingChoices.splice(toIndex, 0, item);
            this.updateChoices(questionModel, rankingChoices);
        };
        this.unselectFromRank = (questionModel, fromIndex, toIndex) => {
            const rankingChoices = [].concat(questionModel.rankingChoices);
            rankingChoices.splice(fromIndex, 1);
            this.updateChoices(questionModel, rankingChoices);
        };
    }
    findDropTargetNodeByDragOverNode(dragOverNode) {
        if (dragOverNode.dataset.ranking === "from-container" || dragOverNode.dataset.ranking === "to-container") {
            return dragOverNode;
        }
        let toContainer = dragOverNode.closest("[data-ranking='to-container']");
        let fromContainer = dragOverNode.closest("[data-ranking='from-container']");
        if (this.parentElement.unRankingChoices.length === 0 && fromContainer)
            return fromContainer;
        if (this.parentElement.rankingChoices.length === 0 && toContainer)
            return toContainer;
        return super.findDropTargetNodeByDragOverNode(dragOverNode);
    }
    getDropTargetByDataAttributeValue(dataAttributeValue) {
        return this.parentElement.rankingChoices[dataAttributeValue] || this.parentElement.unRankingChoices[dataAttributeValue];
    }
    getDropTargetByNode(dropTargetNode, event) {
        if (dropTargetNode.dataset.ranking === "to-container") {
            return "to-container";
        }
        if (dropTargetNode.dataset.ranking === "from-container" || dropTargetNode.closest("[data-ranking='from-container']")) {
            return "from-container";
        }
        return super.getDropTargetByNode(dropTargetNode, event);
    }
    isDropTargetValid(dropTarget, dropTargetNode) {
        if (dropTarget === "to-container" || dropTarget === "from-container") {
            return true;
        }
        else {
            return super.isDropTargetValid(dropTarget, dropTargetNode);
        }
    }
    afterDragOver(dropTargetNode) {
        const questionModel = this.parentElement;
        const rankingChoices = questionModel.rankingChoices;
        const unRankingChoices = questionModel.unRankingChoices;
        if (this.isDraggedElementUnranked && this.isDropTargetRanked) {
            this.doRankBetween(dropTargetNode, unRankingChoices, rankingChoices, this.selectToRank);
            return;
        }
        if (this.isDraggedElementRanked && this.isDropTargetRanked) {
            this.doRankBetween(dropTargetNode, rankingChoices, rankingChoices, this.reorderRankedItem);
            return;
        }
        if (this.isDraggedElementRanked && !this.isDropTargetRanked) {
            this.doRankBetween(dropTargetNode, rankingChoices, unRankingChoices, this.unselectFromRank);
            return;
        }
    }
    doRankBetween(dropTargetNode, fromChoicesArray, toChoicesArray, rankFunction) {
        const questionModel = this.parentElement;
        let { fromIndex, toIndex } = this.getIndices(questionModel, fromChoicesArray, toChoicesArray);
        rankFunction(questionModel, fromIndex, toIndex, dropTargetNode);
    }
    get isDraggedElementRanked() {
        return this.parentElement.rankingChoices.indexOf(this.draggedElement) !== -1;
    }
    get isDropTargetRanked() {
        if (this.dropTarget === "to-container")
            return true;
        return this.parentElement.rankingChoices.indexOf(this.dropTarget) !== -1;
    }
    get isDraggedElementUnranked() {
        return !this.isDraggedElementRanked;
    }
    updateChoices(questionModel, rankingChoices) {
        questionModel.isValueSetByUser = true;
        questionModel.rankingChoices = rankingChoices;
        questionModel.updateUnRankingChoices(rankingChoices);
    }
}

/**
 * A class that describes the Ranking question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-ranking/ (linkStyle))
 */
class QuestionRankingModel extends QuestionCheckboxModel {
    constructor(name) {
        super(name);
        this.domNode = null;
        this.onVisibleChoicesChanged = () => {
            super.onVisibleChoicesChanged();
            if (this.carryForwardStartUnranked && !this.isValueSetByUser && !this.selectToRankEnabled && !this.defaultValue) {
                this.value = [];
            }
            // ranking question with only one choice doesn't make sense
            if (this.visibleChoices.length === 1 && !this.selectToRankEnabled) {
                this.value = [];
                this.value.push(this.visibleChoices[0].value);
                this.updateRankingChoices();
                return;
            }
            if (this.isEmpty()) {
                this.updateRankingChoices();
                return;
            }
            if (this.selectToRankEnabled) {
                this.updateRankingChoices();
                return;
            }
            if (this.visibleChoices.length > this.value.length)
                this.addToValueByVisibleChoices();
            if (this.visibleChoices.length < this.value.length)
                this.removeFromValueByVisibleChoices();
            this.updateRankingChoices();
        };
        this.localeChanged = () => {
            super.localeChanged();
            this.updateRankingChoicesSync();
        };
        this._rankingChoicesAnimation = new AnimationGroup(this.getChoicesAnimationOptions(true), (val) => {
            this._renderedRankingChoices = val;
        }, () => this.renderedRankingChoices);
        this._unRankingChoicesAnimation = new AnimationGroup(this.getChoicesAnimationOptions(false), (val) => {
            this._renderedUnRankingChoices = val;
        }, () => this.renderedUnRankingChoices);
        this.rankingChoices = [];
        this.unRankingChoices = [];
        this._renderedRankingChoices = [];
        this._renderedUnRankingChoices = [];
        this.handlePointerDown = (event, choice, node) => {
            const target = event.target;
            if (!this.isDragStartNodeValid(target))
                return;
            if (this.isAllowStartDrag(target, choice)) {
                this.draggedChoiceValue = choice.value;
                this.draggedTargetNode = node;
                this.dragOrClickHelper.onPointerDown(event);
            }
        };
        this.startDrag = (event) => {
            const choice = ItemValue.getItemByValue(this.visibleChoices, this.draggedChoiceValue);
            this.dragDropRankingChoices.startDrag(event, choice, this, this.draggedTargetNode);
        };
        this.handlePointerUp = (event, choice, node) => {
            if (!this.selectToRankEnabled)
                return;
            const target = event.target;
            if (this.isAllowStartDrag(target, choice)) {
                this.handleKeydownSelectToRank(event, choice, " ", false);
            }
        };
        this.handleKeydown = (event, choice) => {
            if (this.isReadOnlyAttr)
                return;
            if (!this.isDesignMode) {
                const key = event.key;
                const index = this.rankingChoices.indexOf(choice);
                if (this.selectToRankEnabled) {
                    this.handleKeydownSelectToRank(event, choice);
                    return;
                }
                if ((key === "ArrowUp" && index) || (key === "ArrowDown" && index !== this.rankingChoices.length - 1)) {
                    const toIndex = key == "ArrowUp" ? index - 1 : index + 1;
                    this.dragDropRankingChoices.reorderRankedItem(this, index, toIndex);
                    this.setValueAfterKeydown(toIndex, "", true, event);
                }
            }
        };
        this.focusItem = (index, container) => {
            if (!this.domNode)
                return;
            if (this.selectToRankEnabled && container) {
                const containerSelector = "[data-ranking='" + container + "']";
                const itemsNodes = this.domNode.querySelectorAll(containerSelector + " " + "." + this.cssClasses.item);
                itemsNodes[index].focus();
            }
            else {
                const itemsNodes = this.domNode.querySelectorAll("." + this.cssClasses.item);
                itemsNodes[index].focus();
            }
        };
        this.isValueSetByUser = false;
        this.setValue = () => {
            const value = [];
            this.rankingChoices.forEach((choice) => {
                value.push(choice.value);
            });
            this.value = value;
            this.isValueSetByUser = true;
        };
        this.registerFunctionOnPropertyValueChanged("selectToRankEnabled", () => {
            this.clearValue(true);
            this.setDragDropRankingChoices();
            this.updateRankingChoicesSync();
        });
        this.dragOrClickHelper = new DragOrClickHelper(this.startDrag);
    }
    getType() {
        return "ranking";
    }
    getItemTabIndex(item) {
        if (this.isDesignMode || item.disabled)
            return undefined;
        return 0;
    }
    supportContainerQueries() {
        return this.selectToRankEnabled;
    }
    get rootClass() {
        return new CssClassBuilder()
            .append(this.cssClasses.root)
            .append(this.cssClasses.rootMobileMod, this.isMobileMode())
            .append(this.cssClasses.rootDisabled, this.isDisabledStyle)
            .append(this.cssClasses.rootReadOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.rootPreview, this.isPreviewStyle)
            .append(this.cssClasses.rootDesignMode, !!this.isDesignMode)
            .append(this.cssClasses.itemOnError, this.hasCssError())
            .append(this.cssClasses.rootDragHandleAreaIcon, settings.rankingDragHandleArea === "icon")
            .append(this.cssClasses.rootSelectToRankMod, this.selectToRankEnabled)
            .append(this.cssClasses.rootSelectToRankEmptyValueMod, this.isEmpty())
            .append(this.cssClasses.rootSelectToRankAlignHorizontal, this.selectToRankEnabled && this.renderedSelectToRankAreasLayout === "horizontal")
            .append(this.cssClasses.rootSelectToRankAlignVertical, this.selectToRankEnabled && this.renderedSelectToRankAreasLayout === "vertical")
            .append(this.cssClasses.rootSelectToRankSwapAreas, this.selectToRankEnabled && this.renderedSelectToRankAreasLayout === "horizontal" && this.selectToRankSwapAreas)
            .toString();
    }
    isItemSelectedCore(item) {
        if (this.selectToRankEnabled) {
            return super.isItemSelectedCore(item);
        }
        return true;
    }
    getItemClassCore(item, options) {
        return new CssClassBuilder()
            .append(super.getItemClassCore(item, options))
            .append(this.cssClasses.itemGhostMod, this.currentDropTarget === item)
            .toString();
    }
    getContainerClasses(containerType) {
        let isEmpty = false;
        const isToContainer = containerType === "to";
        const isFromContainer = containerType === "from";
        if (isToContainer) {
            isEmpty = this.renderedRankingChoices.length === 0;
        }
        else if (isFromContainer) {
            isEmpty = this.renderedUnRankingChoices.length === 0;
        }
        return new CssClassBuilder()
            .append(this.cssClasses.container)
            .append(this.cssClasses.containerToMode, isToContainer)
            .append(this.cssClasses.containerFromMode, isFromContainer)
            .append(this.cssClasses.containerEmptyMode, isEmpty)
            .toString();
    }
    isItemCurrentDropTarget(item) {
        return this.dragDropRankingChoices.dropTarget === item;
    }
    get ghostPositionCssClass() {
        if (this.ghostPosition === "top")
            return this.cssClasses.dragDropGhostPositionTop;
        if (this.ghostPosition === "bottom")
            return this.cssClasses.dragDropGhostPositionBottom;
        return "";
    }
    getItemIndexClasses(item) {
        let noNumber;
        if (this.selectToRankEnabled) {
            noNumber = this.unRankingChoices.indexOf(item) !== -1;
        }
        else {
            noNumber = this.isEmpty();
        }
        return new CssClassBuilder()
            .append(this.cssClasses.itemIndex)
            .append(this.cssClasses.itemIndexEmptyMode, noNumber)
            .toString();
    }
    getNumberByIndex(index) {
        return this.isEmpty() ? "" : index + 1 + "";
    }
    updateRankingChoicesSync() {
        this.blockAnimations();
        this.updateRankingChoices();
        this.releaseAnimations();
    }
    setSurveyImpl(value, isLight) {
        super.setSurveyImpl(value, isLight);
        this.setDragDropRankingChoices();
        this.updateRankingChoicesSync();
    }
    isAnswerCorrect() {
        return Helpers.isArraysEqual(this.value, this.correctAnswer, false);
    }
    get requireStrictCompare() { return true; }
    onSurveyValueChanged(newValue) {
        super.onSurveyValueChanged(newValue);
        if (this.isLoadingFromJson)
            return;
        this.updateRankingChoices();
    }
    onSurveyLoad() {
        this.blockAnimations();
        super.onSurveyLoad();
        this.updateRankingChoices();
        this.releaseAnimations();
    }
    updateValueFromSurvey(newValue, clearData) {
        super.updateValueFromSurvey(newValue, clearData);
        if (newValue)
            this.isValueSetByUser = true;
    }
    addToValueByVisibleChoices() {
        const newValue = this.value.slice();
        this.visibleChoices.forEach((choice) => {
            if (newValue.indexOf(choice.value) === -1) {
                newValue.push(choice.value);
            }
        });
        this.value = newValue;
    }
    removeFromValueByVisibleChoices() {
        const newValue = this.value.slice();
        const choices = this.visibleChoices;
        for (let i = this.value.length - 1; i >= 0; i--) {
            if (!ItemValue.getItemByValue(choices, this.value[i])) {
                newValue.splice(i, 1);
            }
        }
        this.value = newValue;
    }
    getChoicesAnimationOptions(isRankingChoices) {
        return {
            getKey(item) {
                return item.value;
            },
            getRerenderEvent: () => {
                return this.onElementRerendered;
            },
            isAnimationEnabled: () => this.animationAllowed && !this.isDesignMode && this.isVisible && !!this.domNode,
            getReorderOptions: (item, movedForward) => {
                let cssClass = "";
                if (item !== this.currentDropTarget) {
                    cssClass = movedForward ? "sv-dragdrop-movedown" : "sv-dragdrop-moveup";
                }
                return { cssClass };
            },
            getLeaveOptions: (item) => {
                const choices = isRankingChoices ? this.renderedRankingChoices : this.renderedUnRankingChoices;
                if (this.renderedSelectToRankAreasLayout == "vertical" && choices.length == 1 && choices.indexOf(item) >= 0) {
                    return { cssClass: "sv-ranking-item--animate-item-removing-empty" };
                }
                return { cssClass: "sv-ranking-item--animate-item-removing", onBeforeRunAnimation: (el) => {
                        el.style.setProperty("--animation-height", el.offsetHeight + "px");
                    } };
            },
            getEnterOptions: (item) => {
                const choices = isRankingChoices ? this.renderedRankingChoices : this.renderedUnRankingChoices;
                if (this.renderedSelectToRankAreasLayout == "vertical" && choices.length == 1 && choices.indexOf(item) >= 0) {
                    return { cssClass: "sv-ranking-item--animate-item-adding-empty" };
                }
                return { cssClass: "sv-ranking-item--animate-item-adding", onBeforeRunAnimation: (el) => {
                        el.style.setProperty("--animation-height", el.offsetHeight + "px");
                    } };
            },
            getAnimatedElement: (item) => {
                var _a;
                const cssClasses = this.cssClasses;
                let containerSelector = "";
                if (this.selectToRankEnabled) {
                    if (!isRankingChoices && cssClasses.containerFromMode) {
                        containerSelector = classesToSelector(cssClasses.containerFromMode);
                    }
                    else if (isRankingChoices && cssClasses.containerToMode) {
                        containerSelector = classesToSelector(cssClasses.containerToMode);
                    }
                }
                const index = isRankingChoices ? this.renderedRankingChoices.indexOf(item) : this.renderedUnRankingChoices.indexOf(item);
                return (_a = this.domNode) === null || _a === void 0 ? void 0 : _a.querySelector(`${containerSelector} [data-sv-drop-target-ranking-item='${index}']`);
            },
            allowSyncRemovalAddition: true
        };
    }
    get rankingChoicesAnimation() {
        return this._rankingChoicesAnimation;
    }
    get unRankingChoicesAnimation() {
        return this._unRankingChoicesAnimation;
    }
    get renderedRankingChoices() {
        return this._renderedRankingChoices;
    }
    set renderedRankingChoices(val) {
        this.rankingChoicesAnimation.sync(val);
    }
    get renderedUnRankingChoices() {
        return this._renderedUnRankingChoices;
    }
    set renderedUnRankingChoices(val) {
        this.unRankingChoicesAnimation.sync(val);
    }
    updateRenderedRankingChoices() {
        this.renderedRankingChoices = this.rankingChoices;
    }
    updateRenderedUnRankingChoices() {
        this.renderedUnRankingChoices = this.unRankingChoices;
    }
    updateRankingChoices(forceUpdate = false) {
        if (this.selectToRankEnabled) {
            this.updateRankingChoicesSelectToRankMode(forceUpdate);
            return;
        }
        const newRankingChoices = [];
        // ranking question with only one choice doesn't make sense
        // if (this.visibleChoices.length === 1) {
        //   this.setPropertyValue("rankingChoices", newRankingChoices);
        //   return;
        // }
        if (forceUpdate)
            this.rankingChoices = [];
        if (this.isEmpty()) {
            this.rankingChoices = this.visibleChoices;
            return;
        }
        this.value.forEach((valueItem) => {
            this.visibleChoices.forEach((choice) => {
                if (choice.value === valueItem)
                    newRankingChoices.push(choice);
            });
        });
        this.rankingChoices = newRankingChoices;
    }
    updateUnRankingChoices(newRankingChoices) {
        const unRankingChoices = [];
        this.visibleChoices.forEach((choice) => {
            unRankingChoices.push(choice);
        });
        newRankingChoices.forEach((rankingChoice) => {
            unRankingChoices.forEach((choice, index) => {
                if (choice.value === rankingChoice.value)
                    unRankingChoices.splice(index, 1);
            });
        });
        this.unRankingChoices = unRankingChoices;
    }
    updateRankingChoicesSelectToRankMode(forceUpdate) {
        const newRankingChoices = [];
        if (!this.isEmpty()) {
            this.value.forEach((valueItem) => {
                this.visibleChoices.forEach((choice) => {
                    if (choice.value === valueItem)
                        newRankingChoices.push(choice);
                });
            });
        }
        this.updateUnRankingChoices(newRankingChoices);
        this.rankingChoices = newRankingChoices;
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        this.setDragDropRankingChoices();
    }
    setDragDropRankingChoices() {
        this.dragDropRankingChoices = this.createDragDropRankingChoices();
    }
    createDragDropRankingChoices() {
        if (this.selectToRankEnabled)
            return new DragDropRankingSelectToRank(this.survey, null, this.longTap);
        return new DragDropRankingChoices(this.survey, null, this.longTap);
    }
    isDragStartNodeValid(target) {
        if (settings.rankingDragHandleArea === "icon") {
            return target.classList.contains(this.cssClasses.itemIconHoverMod);
        }
        return true;
    }
    isAllowStartDrag(target, choice) {
        return !this.isReadOnly &&
            !this.isDesignMode &&
            this.canStartDragDueMaxSelectedChoices(target) &&
            this.canStartDragDueItemEnabled(choice);
    }
    canStartDragDueMaxSelectedChoices(target) {
        if (!this.selectToRankEnabled)
            return true;
        let fromContainer = target.closest("[data-ranking='from-container']");
        if (fromContainer) {
            return this.checkMaxSelectedChoicesUnreached();
        }
        return true;
    }
    canStartDragDueItemEnabled(item) {
        return item.enabled;
    }
    checkMaxSelectedChoicesUnreached() {
        if (this.maxSelectedChoices < 1)
            return true;
        var val = this.value;
        var len = !Array.isArray(val) ? 0 : val.length;
        return len < this.maxSelectedChoices;
    }
    //cross framework initialization
    afterRenderQuestionElement(el) {
        this.domNode = el;
        super.afterRenderQuestionElement(el);
    }
    //cross framework destroy
    beforeDestroyQuestionElement(el) {
        this.domNode = undefined;
        super.beforeDestroyQuestionElement(el);
    }
    supportSelectAll() { return false; }
    supportOther() { return false; }
    supportNone() { return false; }
    supportRefuse() { return false; }
    supportDontKnow() { return false; }
    handleKeydownSelectToRank(event, movedElement, hardKey, isNeedFocus = true) {
        if (this.isDesignMode)
            return;
        let key = event.key;
        if (hardKey)
            key = hardKey;
        if (key !== " " && key !== "ArrowUp" && key !== "ArrowDown")
            return;
        const dnd = this.dragDropRankingChoices; //????
        const rankingChoices = this.rankingChoices;
        const isMovedElementRanked = rankingChoices.indexOf(movedElement) !== -1;
        const choices = isMovedElementRanked ? rankingChoices : this.unRankingChoices;
        const fromIndex = choices.indexOf(movedElement);
        if (fromIndex < 0)
            return;
        let toIndex;
        if (key === " " && !isMovedElementRanked) {
            if (!this.checkMaxSelectedChoicesUnreached() || !this.canStartDragDueItemEnabled(movedElement))
                return;
            toIndex = this.value.length;
            dnd.selectToRank(this, fromIndex, toIndex);
            this.setValueAfterKeydown(toIndex, "to-container", isNeedFocus, event);
            return;
        }
        if (!isMovedElementRanked)
            return;
        if (key === " ") {
            dnd.unselectFromRank(this, fromIndex);
            toIndex = this.unRankingChoices.indexOf(movedElement); //'this.' leads to actual array after the 'unselectFromRank' method
            this.setValueAfterKeydown(toIndex, "from-container", isNeedFocus, event);
            return;
        }
        const delta = key === "ArrowUp" ? -1 : (key === "ArrowDown" ? 1 : 0);
        if (delta === 0)
            return;
        toIndex = fromIndex + delta;
        if (toIndex < 0 || toIndex >= rankingChoices.length)
            return;
        dnd.reorderRankedItem(this, fromIndex, toIndex);
        this.setValueAfterKeydown(toIndex, "to-container", isNeedFocus, event);
    }
    setValueAfterKeydown(index, container, isNeedFocus = true, event) {
        this.setValue();
        if (isNeedFocus) {
            setTimeout(() => {
                this.focusItem(index, container);
            }, 1);
        }
        event && event.preventDefault();
    }
    getIconHoverCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.itemIcon)
            .append(this.cssClasses.itemIconHoverMod)
            .toString();
    }
    getIconFocusCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.itemIcon)
            .append(this.cssClasses.itemIconFocusMod)
            .toString();
    }
    /**
     * Specifies whether to use a long tap (press and hold) gesture to start dragging.
     *
     * Default value: `true`
     *
     * Disable this property if you want to start dragging when users perform a scroll gesture.
    */
    get longTap() {
        return this.getPropertyValue("longTap");
    }
    set longTap(val) {
        this.setPropertyValue("longTap", val);
    }
    getDefaultItemComponent() {
        return "sv-ranking-item";
    }
    /**
     * Specifies whether users can select choices they want to rank.
     *
     * When you enable this property, the Ranking question displays two areas for ranked and unranked choices. To order choices, users should first drag them from the unranked to the ranked area. Use this mode if you want to let users order only the choices they select.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/select-items-to-rank/ (linkStyle))
     * @see selectToRankAreasLayout
    */
    get selectToRankEnabled() {
        return this.getPropertyValue("selectToRankEnabled", false);
    }
    set selectToRankEnabled(val) {
        this.setPropertyValue("selectToRankEnabled", val);
    }
    get selectToRankSwapAreas() {
        return this.getPropertyValue("selectToRankSwapAreas", false);
    }
    set selectToRankSwapAreas(val) {
        this.setPropertyValue("selectToRankSwapAreas", val);
    }
    /**
     * Specifies the layout of the ranked and unranked areas. Applies when [`selectToRankEnabled`](https://surveyjs.io/form-library/documentation/api-reference/ranking-question-model#selectToRankEnabled) is `true`.
     *
     * Possible values:
     *
     * - `"horizontal"` (default) - The ranked and unranked areas are positioned next to each other. Users drag and drop choices between them in the horizontal direction.
     * - `"vertical"`- The ranked area is positioned above the unranked area. Users drag and drop choices between them in the vertical direction.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/select-items-to-rank/ (linkStyle))
     * @see selectToRankAreasLayout
    */
    get selectToRankAreasLayout() {
        return this.getPropertyValue("selectToRankAreasLayout");
    }
    set selectToRankAreasLayout(val) {
        this.setPropertyValue("selectToRankAreasLayout", val);
    }
    get renderedSelectToRankAreasLayout() {
        if (this.isMobileMode())
            return "vertical";
        return this.selectToRankAreasLayout;
    }
    isMobileMode() {
        return IsMobile;
    }
    get useFullItemSizeForShortcut() {
        return this.getPropertyValue("useFullItemSizeForShortcut");
    }
    set useFullItemSizeForShortcut(val) {
        this.setPropertyValue("useFullItemSizeForShortcut", val);
    }
    get dragDropSvgIcon() {
        return this.cssClasses.dragDropSvgIconId || "#icon-drag-24x24";
    }
    get arrowsSvgIcon() {
        return this.cssClasses.arrowsSvgIconId || "#icon-reorder-24x24";
    }
    get dashSvgIcon() {
        return this.cssClasses.dashSvgIconId || "#icon-rankingundefined-16x16";
    }
    //a11y
    get isNewA11yStructure() {
        return false;
    }
}
__decorate([
    propertyArray({
        onSet: (val, target) => target.updateRenderedRankingChoices(),
        onRemove: (_, _i, target) => target.updateRenderedRankingChoices(),
        onPush: (_, _i, target) => target.updateRenderedRankingChoices(),
    })
], QuestionRankingModel.prototype, "rankingChoices", void 0);
__decorate([
    propertyArray({ onSet: (val, target) => target.updateRenderedUnRankingChoices(),
        onRemove: (_, _i, target) => target.updateRenderedUnRankingChoices(),
        onPush: (_, _i, target) => target.updateRenderedUnRankingChoices(),
    })
], QuestionRankingModel.prototype, "unRankingChoices", void 0);
__decorate([
    propertyArray()
], QuestionRankingModel.prototype, "_renderedRankingChoices", void 0);
__decorate([
    propertyArray()
], QuestionRankingModel.prototype, "_renderedUnRankingChoices", void 0);
__decorate([
    property({ defaultValue: null })
], QuestionRankingModel.prototype, "currentDropTarget", void 0);
__decorate([
    property({ defaultValue: true })
], QuestionRankingModel.prototype, "carryForwardStartUnranked", void 0);
__decorate([
    property({ localizable: { defaultStr: "selectToRankEmptyRankedAreaText" } })
], QuestionRankingModel.prototype, "selectToRankEmptyRankedAreaText", void 0);
__decorate([
    property({ localizable: { defaultStr: "selectToRankEmptyUnrankedAreaText" } })
], QuestionRankingModel.prototype, "selectToRankEmptyUnrankedAreaText", void 0);
Serializer.addClass("ranking", [
    { name: "showOtherItem", visible: false, isSerializable: false },
    { name: "otherText", visible: false, isSerializable: false },
    { name: "otherErrorText", visible: false, isSerializable: false },
    { name: "storeOthersAsComment", visible: false, isSerializable: false },
    { name: "showNoneItem", visible: false, isSerializable: false },
    { name: "showRefuseItem", visible: false, isSerializable: false },
    { name: "showDontKnowItem", visible: false, isSerializable: false },
    { name: "noneText", visible: false, isSerializable: false },
    { name: "showSelectAllItem", visible: false, isSerializable: false },
    { name: "selectAllText", visible: false, isSerializable: false },
    { name: "colCount:number", visible: false, isSerializable: false },
    { name: "separateSpecialChoices", visible: false, isSerializable: false },
    {
        name: "longTap",
        default: true,
        visible: false,
        isSerializable: false,
    },
    {
        name: "selectToRankEnabled:switch",
        default: false,
        visible: true,
        isSerializable: true,
    },
    {
        name: "selectToRankSwapAreas:switch",
        default: false,
        visible: false,
        isSerializable: true,
        dependsOn: "selectToRankEnabled",
    },
    {
        name: "selectToRankAreasLayout",
        default: "horizontal",
        choices: ["horizontal", "vertical"],
        dependsOn: "selectToRankEnabled",
        visibleIf: (obj) => {
            return !!obj.selectToRankEnabled;
        },
        visible: true,
        isSerializable: true,
    },
    {
        name: "selectToRankEmptyRankedAreaText:text",
        serializationProperty: "locSelectToRankEmptyRankedAreaText",
        category: "general",
        dependsOn: "selectToRankEnabled",
        visibleIf: (obj) => {
            return !!obj.selectToRankEnabled;
        },
    },
    {
        name: "selectToRankEmptyUnrankedAreaText:text",
        serializationProperty: "locSelectToRankEmptyUnrankedAreaText",
        category: "general",
        dependsOn: "selectToRankEnabled",
        visibleIf: (obj) => {
            return !!obj.selectToRankEnabled;
        },
    },
    {
        name: "maxSelectedChoices:number",
        visible: true,
        default: 0,
        dependsOn: "selectToRankEnabled",
        visibleIf: (obj) => {
            return !!obj.selectToRankEnabled;
        },
        isSerializable: true
    },
    { name: "minSelectedChoices:number",
        visible: true,
        default: 0,
        dependsOn: "selectToRankEnabled",
        visibleIf: (obj) => {
            return !!obj.selectToRankEnabled;
        },
        isSerializable: true },
    { name: "itemComponent", visible: false, default: "sv-ranking-item" },
], function () {
    return new QuestionRankingModel("");
}, "checkbox");
QuestionFactory.Instance.registerQuestion("ranking", (name) => {
    const q = new QuestionRankingModel(name);
    q.choices = QuestionFactory.DefaultChoices;
    return q;
});

/**
 * A class that describes the Long Text question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-comment/ (linkStyle))
 */
class QuestionCommentModel extends QuestionTextBase {
    constructor(name) {
        super(name);
    }
    get textAreaModel() {
        if (!this.textAreaModelValue) {
            this.textAreaModelValue = new TextAreaModel(this.getTextAreaOptions());
        }
        return this.textAreaModelValue;
    }
    getTextAreaOptions() {
        const _this = this;
        const updateQuestionValue = (newValue) => {
            if (!Helpers.isTwoValueEquals(_this.value, newValue, false, true, false)) {
                _this.value = newValue;
            }
        };
        const options = {
            question: this,
            id: () => this.inputId,
            propertyNames: ["value"],
            className: () => this.className,
            placeholder: () => this.renderedPlaceholder,
            isDisabledAttr: () => this.isDisabledAttr,
            isReadOnlyAttr: () => this.isReadOnlyAttr,
            autoGrow: () => this.renderedAutoGrow,
            maxLength: () => this.getMaxLength(),
            rows: () => this.rows,
            cols: () => this.cols,
            ariaRequired: () => this.a11y_input_ariaRequired,
            ariaLabel: () => this.a11y_input_ariaLabel,
            ariaLabelledBy: () => this.a11y_input_ariaLabelledBy,
            ariaDescribedBy: () => this.a11y_input_ariaDescribedBy,
            ariaInvalid: () => this.a11y_input_ariaInvalid,
            ariaErrormessage: () => this.a11y_input_ariaErrormessage,
            getTextValue: () => { return this.value; },
            onTextAreaChange: (e) => { updateQuestionValue(e.target.value); },
            onTextAreaInput: (event) => { this.onInput(event); },
            onTextAreaKeyDown: (event) => { this.onKeyDown(event); },
            onTextAreaFocus: (event) => { this.onFocus(event); },
            onTextAreaBlur: (event) => { this.onBlur(event); }
        };
        return options;
    }
    /**
     * Specifies the visible height of the comment area, measured in lines.
     *
     * The value of this property is passed on to the `rows` attribute of the underlying `<textarea>` element.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-open-ended-question-to-a-form/ (linkStyle))
     */
    get rows() {
        return this.getPropertyValue("rows");
    }
    set rows(val) {
        this.setPropertyValue("rows", val);
    }
    get cols() {
        return this.getPropertyValue("cols");
    }
    set cols(val) {
        this.setPropertyValue("cols", val);
    }
    /**
     * Specifies whether the question allows line breaks.
     *
     * When this property is enabled, a user can press Enter to insert line breaks. They are saved as `\n` in survey results. The Comment question also recognizes and interprets the `\n` sequence as a line break when you set the question `value` in code.
     */
    get acceptCarriageReturn() {
        return this.getPropertyValue("acceptCarriageReturn");
    }
    set acceptCarriageReturn(val) {
        this.setPropertyValue("acceptCarriageReturn", val);
    }
    /**
     * Specifies whether the comment area automatically increases its height to accomodate multi-line content.
     *
     * Default value: `false` (inherited from `SurveyModel`'s [`autoGrowComment`](https://surveyjs.io/form-library/documentation/surveymodel#autoGrowComment) property)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-open-ended-question-to-a-form/ (linkStyle))
     * @see allowResize
     */
    get autoGrow() {
        return this.getPropertyValue("autoGrow");
    }
    set autoGrow(val) {
        this.setPropertyValue("autoGrow", val);
    }
    get renderedAutoGrow() {
        const autoGrow = this.autoGrow;
        return autoGrow === undefined && this.survey ? this.survey.autoGrowComment : !!autoGrow;
    }
    /**
     * Specifies whether to display a resize handle for the comment area.
     *
     * Default value: `true` (inherited from `SurveyModel`'s [`allowResizeComment`](https://surveyjs.io/form-library/documentation/surveymodel#allowResizeComment) property)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-open-ended-question-to-a-form/ (linkStyle))
     * @see autoGrow
     */
    get allowResize() {
        return this.getPropertyValue("allowResize");
    }
    set allowResize(val) {
        this.setPropertyValue("allowResize", val);
    }
    get renderedAllowResize() {
        const res = this.allowResize;
        if (res === undefined && this.survey) {
            return this.survey.allowResizeComment;
        }
        else {
            return !!res;
        }
    }
    get resizeStyle() {
        return this.renderedAllowResize ? "both" : "none";
    }
    getType() {
        return "comment";
    }
    afterRenderQuestionElement(el) {
        this.element = (el === null || el === void 0 ? void 0 : el.querySelector(`#${this.inputId}`)) || el;
        super.afterRenderQuestionElement(el);
    }
    beforeDestroyQuestionElement(el) {
        super.beforeDestroyQuestionElement(el);
        this.element = undefined;
    }
    onInput(event) {
        if (this.isInputTextUpdate)
            this.value = event.target.value;
        this.updateRemainingCharacterCounter(event.target.value);
    }
    onBlurCore(event) {
        super.onBlurCore(event);
    }
    onKeyDown(event) {
        this.onKeyDownPreprocess && this.onKeyDownPreprocess(event);
        if (!this.acceptCarriageReturn && (event.key === "Enter" || event.keyCode === 13)) {
            event.preventDefault();
            event.stopPropagation();
        }
    }
    setNewValue(newValue) {
        if (!this.acceptCarriageReturn && !!newValue) {
            // eslint-disable-next-line no-control-regex
            newValue = newValue.replace(new RegExp("(\r\n|\n|\r)", "gm"), "");
        }
        super.setNewValue(newValue);
    }
    getValueSeparator() { return "\n"; }
    notifyStateChanged(prevState) {
        super.notifyStateChanged(prevState);
        if (!this.isCollapsed) {
            this.textAreaModel.updateElement();
        }
    }
    get className() {
        return (this.cssClasses ? this.getControlClass() : "panel-comment-root") || undefined;
    }
}
Serializer.addClass("comment", [
    { name: "maxLength:number", default: -1 },
    { name: "cols:number", default: 50, visible: false, isSerializable: false },
    { name: "rows:number", default: 4 },
    { name: "placeholder",
        alternativeName: "placeHolder",
        serializationProperty: "locPlaceholder" },
    {
        name: "textUpdateMode",
        default: "default",
        choices: ["default", "onBlur", "onTyping"],
    },
    { name: "autoGrow:boolean", defaultFunc: () => undefined },
    { name: "allowResize:boolean", defaultFunc: () => undefined },
    { name: "acceptCarriageReturn:boolean", default: true, visible: false }
], function () {
    return new QuestionCommentModel("");
}, "textbase");
QuestionFactory.Instance.registerQuestion("comment", (name) => {
    return new QuestionCommentModel(name);
});

const envStr = "environment";
const userStr = "user";
class Camera {
    constructor() {
        this.canFlipValue = undefined;
    }
    static clear() {
        Camera.cameraList = undefined;
        Camera.cameraIndex = -1;
    }
    static setCameraList(list) {
        const getDeviceType = function (device) {
            const lbl = device.label.toLocaleLowerCase();
            if (lbl.indexOf(userStr) > -1)
                return userStr;
            if (lbl.indexOf(envStr) > -1)
                return envStr;
            if (lbl.indexOf("front") > -1)
                return userStr;
            if (lbl.indexOf("back") > -1)
                return envStr;
            return "";
        };
        Camera.clear();
        if (Array.isArray(list) && list.length > 0) {
            Camera.cameraIndex = -1;
            list.sort((a, b) => {
                if (a === b)
                    return 0;
                if (a.label !== b.label) {
                    const lblA = getDeviceType(a);
                    const lblB = getDeviceType(b);
                    if (lblA !== lblB) {
                        if (lblA === userStr)
                            return -1;
                        if (lblB === userStr)
                            return 1;
                        if (lblA === envStr)
                            return -1;
                        if (lblB === envStr)
                            return 1;
                    }
                }
                const iA = list.indexOf(a);
                const iB = list.indexOf(b);
                return iA < iB ? -1 : 1;
            });
        }
        Camera.cameraList = list;
    }
    hasCamera(callback) {
        if (Camera.cameraList !== undefined) {
            this.hasCameraCallback(callback);
            return;
        }
        if (Camera.mediaDevicesCallback) {
            const devicesCallback = (devices) => {
                this.setVideoInputs(devices);
                this.hasCameraCallback(callback);
            };
            Camera.mediaDevicesCallback(devicesCallback);
            return;
        }
        if (typeof navigator !== "undefined" && navigator.mediaDevices) {
            navigator.mediaDevices.enumerateDevices()
                .then(devices => {
                this.setVideoInputs(devices);
                this.hasCameraCallback(callback);
                this.updateCanFlipValue();
            })
                .catch(error => {
                Camera.cameraList = null;
                this.hasCameraCallback(callback);
            });
        }
        else {
            Camera.cameraList = null;
            this.hasCameraCallback(callback);
        }
    }
    getMediaConstraints(videoSize) {
        const devices = Camera.cameraList;
        if (!Array.isArray(devices) || devices.length < 1)
            return undefined;
        if (Camera.cameraIndex < 0)
            Camera.cameraIndex = 0;
        const selDevice = devices[Camera.cameraIndex];
        const videoConstraints = {};
        if (selDevice && selDevice.deviceId) {
            videoConstraints.deviceId = { exact: selDevice.deviceId };
        }
        else {
            videoConstraints.facingMode = Camera.cameraFacingMode;
        }
        if (videoSize) {
            if (videoSize === null || videoSize === void 0 ? void 0 : videoSize.height) {
                videoConstraints.height = { ideal: videoSize.height };
            }
            if (videoSize === null || videoSize === void 0 ? void 0 : videoSize.width) {
                videoConstraints.width = { ideal: videoSize.width };
            }
        }
        return {
            video: videoConstraints,
            audio: false
        };
    }
    startVideo(videoElement, callback, imageWidth, imageHeight) {
        if (!videoElement) {
            callback(undefined);
            return;
        }
        videoElement.style.width = "100%";
        videoElement.style.height = "auto";
        videoElement.style.height = "100%";
        videoElement.style.objectFit = "contain";
        const mediaConstraints = this.getMediaConstraints({ width: imageWidth, height: imageHeight });
        navigator.mediaDevices.getUserMedia(mediaConstraints).then(stream => {
            var _a;
            videoElement.srcObject = stream;
            if (!((_a = Camera.cameraList[Camera.cameraIndex]) === null || _a === void 0 ? void 0 : _a.deviceId) && !!stream.getTracks()[0].getCapabilities().facingMode) {
                Camera.canSwitchFacingMode = true;
                this.updateCanFlipValue();
            }
            videoElement.play();
            callback(stream);
        })
            .catch(error => {
            callback(undefined);
        });
    }
    getImageSize(videoEl) {
        return { width: videoEl.videoWidth, height: videoEl.videoHeight };
    }
    snap(videoElement, callback) {
        if (!videoElement)
            return false;
        if (!DomDocumentHelper.isAvailable())
            return false;
        const root = DomDocumentHelper.getDocument();
        const canvasEl = root.createElement("canvas");
        const imageSize = this.getImageSize(videoElement);
        canvasEl.height = imageSize.height;
        canvasEl.width = imageSize.width;
        let context = canvasEl.getContext("2d");
        /*
        if(this._facingMode == 'user'){
          context.translate(canvasEl.width, 0);
          context.scale(-1, 1);
        }
        */
        context.clearRect(0, 0, canvasEl.width, canvasEl.height);
        context.drawImage(videoElement, 0, 0, canvasEl.width, canvasEl.height);
        canvasEl.toBlob(callback, "image/png");
        return true;
    }
    updateCanFlipValue() {
        const list = Camera.cameraList;
        this.canFlipValue = Array.isArray(list) && list.length > 1 || Camera.canSwitchFacingMode;
        if (this.onCanFlipChangedCallback)
            this.onCanFlipChangedCallback(this.canFlipValue);
    }
    canFlip(onCanFlipChangedCallback) {
        if (this.canFlipValue === undefined) {
            this.updateCanFlipValue();
        }
        if (onCanFlipChangedCallback) {
            this.onCanFlipChangedCallback = onCanFlipChangedCallback;
        }
        return this.canFlipValue;
    }
    flip() {
        if (!this.canFlip())
            return;
        if (Camera.canSwitchFacingMode) {
            Camera.cameraFacingMode = Camera.cameraFacingMode === userStr ? "environment" : userStr;
        }
        else if (Camera.cameraIndex >= Camera.cameraList.length - 1) {
            Camera.cameraIndex = 0;
        }
        else {
            Camera.cameraIndex++;
        }
    }
    hasCameraCallback(callback) {
        callback(Array.isArray(Camera.cameraList));
    }
    setVideoInputs(devices) {
        const list = [];
        devices.forEach(device => {
            if (device.kind === "videoinput") {
                list.push(device);
            }
        });
        Camera.setCameraList(list.length > 0 ? list : null);
    }
}
Camera.cameraIndex = -1;
Camera.cameraFacingMode = userStr;
Camera.canSwitchFacingMode = false;

function dataUrl2File(dataUrl, fileName, type) {
    const str = atob(dataUrl.split(",")[1]);
    const buffer = new Uint8Array(str.split("").map(c => c.charCodeAt(0))).buffer;
    return new File([buffer], fileName, { type: type });
}
/**
 * A base class for question types that support file upload: `QuestionFileModel` and `QuestionSignaturePadModel`.
 */
class QuestionFileModelBase extends Question {
    constructor() {
        super(...arguments);
        this.isUploading = false;
        /**
         * An event that is raised after the upload state has changed.
         *
         * Parameters:
         *
         * - `sender`: `SurveyModel`\
         * A survey instance that raised the event.
         * - `options.state`: `string`\
         * The current upload state: `"empty"`, `"loading"`, `"loaded"`, or `"error"`.
         */
        this.onUploadStateChanged = this.addEvent();
        this.onStateChanged = this.addEvent();
    }
    stateChanged(state) {
        if (this.currentState == state) {
            return;
        }
        if (state === "loading") {
            this.isUploading = true;
        }
        if (state === "loaded") {
            this.isUploading = false;
        }
        if (state === "error") {
            this.isUploading = false;
        }
        this.currentState = state;
        this.onStateChanged.fire(this, { state: state });
        this.onUploadStateChanged.fire(this, { state: state });
    }
    get showLoadingIndicator() {
        return this.isUploading;
    }
    /**
     * Specifies whether to store file or signature content as text in `SurveyModel`'s [`data`](https://surveyjs.io/form-library/documentation/surveymodel#data) property.
     *
     * If you disable this property, implement `SurveyModel`'s [`onUploadFiles`](https://surveyjs.io/form-library/documentation/surveymodel#onUploadFiles) event handler to specify how to store file content.
     *
     * [File Upload Demo](https://surveyjs.io/form-library/examples/file-upload/ (linkStyle))
     *
     * [Signature Pad Demo](https://surveyjs.io/form-library/examples/upload-signature-pad-data-to-server/ (linkStyle))
     */
    get storeDataAsText() {
        return this.getPropertyValue("storeDataAsText");
    }
    set storeDataAsText(val) {
        this.setPropertyValue("storeDataAsText", val);
    }
    /**
     * Enable this property if you want to wait until files are uploaded to complete the survey.
     *
     * Default value: `false`
     *
     * [File Upload Demo](https://surveyjs.io/form-library/examples/file-upload/ (linkStyle))
     *
     * [Signature Pad Demo](https://surveyjs.io/form-library/examples/upload-signature-pad-data-to-server/ (linkStyle))
     */
    get waitForUpload() {
        return this.getPropertyValue("waitForUpload");
    }
    set waitForUpload(val) {
        this.setPropertyValue("waitForUpload", val);
    }
    clearValue(keepComment) {
        this.clearOnDeletingContainer();
        super.clearValue(keepComment);
    }
    clearOnDeletingContainer() {
        if (!this.survey)
            return;
        this.survey.clearFiles(this, this.name, this.value, null, () => { });
    }
    onCheckForErrors(errors, isOnValueChanged, fireCallback) {
        super.onCheckForErrors(errors, isOnValueChanged, fireCallback);
        if (this.isUploading && this.waitForUpload) {
            errors.push(new UploadingFileError(this.getLocalizationString("uploadingFile"), this));
        }
    }
    uploadFiles(files) {
        if (this.survey) {
            this.stateChanged("loading");
            this.survey.uploadFiles(this, this.name, files, (arg1, arg2) => {
                if (Array.isArray(arg1)) {
                    this.setValueFromResult(arg1);
                    if (Array.isArray(arg2)) {
                        arg2.forEach(error => this.errors.push(new UploadingFileError(error, this)));
                        this.stateChanged("error");
                    }
                }
                if (arg1 === "success" && Array.isArray(arg2)) {
                    this.setValueFromResult(arg2);
                }
                if (arg1 === "error") {
                    if (typeof (arg2) === "string") {
                        this.errors.push(new UploadingFileError(arg2, this));
                    }
                    if (Array.isArray(arg2) && arg2.length > 0) {
                        arg2.forEach(error => this.errors.push(new UploadingFileError(error, this)));
                    }
                    this.stateChanged("error");
                }
                this.stateChanged("loaded");
            });
        }
    }
    loadPreview(newValue) { }
    onChangeQuestionValue(newValue) {
        super.onChangeQuestionValue(newValue);
        this.stateChanged(this.isEmpty() ? "empty" : "loaded");
    }
    getIsQuestionReady() {
        return super.getIsQuestionReady() && !this.isFileLoading;
    }
    get isFileLoading() { return this.isFileLoadingValue; }
    set isFileLoading(val) {
        this.isFileLoadingValue = val;
        this.updateIsReady();
    }
}
__decorate([
    property()
], QuestionFileModelBase.prototype, "isUploading", void 0);
__decorate([
    property({ defaultValue: "empty" })
], QuestionFileModelBase.prototype, "currentState", void 0);
class QuestionFilePage extends Base {
    static getId() {
        return "sv_sfp_" + QuestionFilePage.pageCounter++;
    }
    constructor(question, index) {
        super();
        this.question = question;
        this.index = index;
        this.id = QuestionFilePage.getId();
    }
    get css() {
        return this.question.cssClasses.page;
    }
}
QuestionFilePage.pageCounter = 0;
__decorate([
    propertyArray({})
], QuestionFilePage.prototype, "items", void 0);
/**
 * A class that describes the File Upload question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/file-upload/ (linkStyle))
 */
class QuestionFileModel extends QuestionFileModelBase {
    get fileNavigatorVisible() {
        const isUploading = this.isUploading;
        const isPlayingVideo = this.isPlayingVideo;
        const containsMultipleFiles = this.containsMultiplyFiles;
        const needToShowFileNavigator = this.pageSize < this.previewValue.length;
        return !isUploading && !isPlayingVideo && containsMultipleFiles && needToShowFileNavigator;
    }
    get pagesCount() {
        return Math.ceil(this.previewValue.length / this.pageSize);
    }
    get actionsContainerVisible() {
        const isUploading = this.isUploading;
        const isPlayingVideo = this.isPlayingVideo;
        return !isUploading && !isPlayingVideo;
    }
    constructor(name) {
        super(name);
        this.isDragging = false;
        this.fileNavigator = new ActionContainer();
        this.canFlipCameraValue = undefined;
        this.prevPreviewLength = 0;
        this._renderedPages = [];
        this.pagesAnimation = new AnimationTab(this.getPagesAnimationOptions(), (val) => {
            this._renderedPages = val;
        }, () => this.renderedPages);
        this.calcAvailableItemsCount = (availableWidth, itemWidth, gap) => {
            let itemsCount = Math.floor(availableWidth / (itemWidth + gap));
            if ((itemsCount + 1) * (itemWidth + gap) - gap <= availableWidth)
                itemsCount++;
            return itemsCount;
        };
        this.dragCounter = 0;
        this.onDragEnter = (event) => {
            if (this.canDragDrop()) {
                event.preventDefault();
                this.isDragging = true;
                this.dragCounter++;
            }
        };
        this.onDragOver = (event) => {
            if (!this.canDragDrop()) {
                event.returnValue = false;
                return false;
            }
            event.dataTransfer.dropEffect = "copy";
            event.preventDefault();
        };
        this.onDrop = (event) => {
            if (this.canDragDrop()) {
                this.isDragging = false;
                this.dragCounter = 0;
                event.preventDefault();
                let src = event.dataTransfer;
                this.onChange(src);
            }
        };
        this.onDragLeave = (event) => {
            if (this.canDragDrop()) {
                this.dragCounter--;
                if (this.dragCounter === 0) {
                    this.isDragging = false;
                }
            }
        };
        this.doChange = (event) => {
            var src = event.target || event.srcElement;
            this.onChange(src);
        };
        this.doClean = () => {
            if (this.needConfirmRemoveFile) {
                confirmActionAsync({
                    message: this.confirmRemoveAllMessage,
                    funcOnYes: () => { this.clearFilesCore(); },
                    locale: this.getLocale(),
                    rootElement: this.survey.rootElement,
                    cssClass: this.cssClasses.confirmDialog
                });
                return;
            }
            this.clearFilesCore();
        };
        this.doDownloadFileFromContainer = (event) => {
            event.stopPropagation();
            const currentTarget = event.currentTarget;
            if (currentTarget && currentTarget.getElementsByTagName) {
                const link = currentTarget.getElementsByTagName("a")[0];
                link === null || link === void 0 ? void 0 : link.click();
            }
        };
        this.doDownloadFile = (event, data) => {
            event.stopPropagation();
            if (detectIEOrEdge()) {
                event.preventDefault();
                loadFileFromBase64(data.content, data.name);
            }
        };
        this.createLocalizableString("takePhotoCaption", this, false, true);
        this.createLocalizableString("clearCaption", this, false, true);
        this.actionsContainer = new ActionContainer();
        this.actionsContainer.locOwner = this;
        this.fileIndexAction = new Action({
            id: "fileIndex",
            title: this.getFileIndexCaption(),
            enabled: false
        });
        this.prevFileAction = new Action({
            id: "prevPage",
            iconSize: 16,
            action: () => {
                this.navigationDirection = "left";
                this.indexToShow = this.previewValue.length && ((this.indexToShow - 1 + this.pagesCount) % this.pagesCount) || 0;
                this.fileIndexAction.title = this.getFileIndexCaption();
            }
        });
        this.nextFileAction = new Action({
            id: "nextPage",
            iconSize: 16,
            action: () => {
                this.navigationDirection = "right";
                this.indexToShow = this.previewValue.length && ((this.indexToShow + 1) % this.pagesCount) || 0;
                this.fileIndexAction.title = this.getFileIndexCaption();
            }
        });
        this.takePictureAction = new Action({
            iconName: "icon-takepicture",
            id: "sv-file-take-picture",
            iconSize: "auto",
            innerCss: new ComputedUpdater(() => new CssClassBuilder().append(this.cssClasses.contextButton).append(this.cssClasses.takePictureButton).toString()),
            locTitle: this.locTakePhotoCaption,
            showTitle: false,
            action: () => {
                this.snapPicture();
            }
        });
        this.closeCameraAction = new Action({
            iconName: "icon-closecamera",
            id: "sv-file-close-camera",
            iconSize: "auto",
            innerCss: new ComputedUpdater(() => new CssClassBuilder().append(this.cssClasses.contextButton).append(this.cssClasses.closeCameraButton).toString()),
            action: () => {
                this.stopVideo();
            }
        });
        this.changeCameraAction = new Action({
            iconName: "icon-changecamera",
            id: "sv-file-change-camera",
            iconSize: "auto",
            innerCss: new ComputedUpdater(() => new CssClassBuilder().append(this.cssClasses.contextButton).append(this.cssClasses.changeCameraButton).toString()),
            visible: new ComputedUpdater(() => this.canFlipCamera()),
            action: () => {
                this.flipCamera();
            }
        });
        this.chooseFileAction = new Action({
            iconName: "icon-choosefile",
            id: "sv-file-choose-file",
            iconSize: "auto",
            data: { question: this },
            enabledIf: () => !this.isInputReadOnly,
            component: "sv-file-choose-btn"
        });
        this.startCameraAction = new Action({
            iconName: "icon-takepicture_24x24",
            id: "sv-file-start-camera",
            iconSize: "auto",
            locTitle: this.locTakePhotoCaption,
            showTitle: new ComputedUpdater(() => !this.isAnswered),
            enabledIf: () => !this.isInputReadOnly,
            action: () => {
                this.startVideo();
            }
        });
        this.cleanAction = new Action({
            iconName: "icon-clear",
            id: "sv-file-clean",
            iconSize: "auto",
            locTitle: this.locClearButtonCaption,
            showTitle: false,
            enabledIf: () => !this.isInputReadOnly,
            innerCss: new ComputedUpdater(() => this.cssClasses.removeButton),
            action: () => {
                this.doClean();
            }
        });
        [this.closeCameraAction, this.changeCameraAction, this.takePictureAction].forEach((action) => {
            action.cssClasses = {};
        });
        this.registerFunctionOnPropertiesValueChanged(["sourceType", "currentMode", "isAnswered"], () => {
            this.updateActionsVisibility();
        });
        this.actionsContainer.actions = [this.chooseFileAction, this.startCameraAction, this.cleanAction];
        this.fileNavigator.actions = [this.prevFileAction, this.fileIndexAction, this.nextFileAction];
    }
    get videoId() { return this.id + "_video"; }
    get hasVideoUI() { return this.currentMode !== "file"; }
    get hasFileUI() { return this.currentMode !== "camera"; }
    startVideo() {
        if (this.currentMode === "file" || this.isDesignMode || this.isPlayingVideo)
            return;
        this.setIsPlayingVideo(true);
        setTimeout(() => {
            this.startVideoInCamera();
        }, 0);
    }
    get videoHtmlElement() {
        var _a;
        return (_a = this.rootElement) === null || _a === void 0 ? void 0 : _a.querySelector(`#${this.videoId}`);
    }
    startVideoInCamera() {
        this.camera.startVideo(this.videoHtmlElement, (stream) => {
            this.videoStream = stream;
            if (!stream) {
                this.stopVideo();
            }
        }, getRenderedSize(this.imageWidth), getRenderedSize(this.imageHeight));
    }
    stopVideo() {
        this.setIsPlayingVideo(false);
        this.closeVideoStream();
    }
    snapPicture() {
        if (!this.isPlayingVideo)
            return;
        const blobCallback = (blob) => {
            if (blob) {
                const file = new File([blob], "snap_picture.png", { type: "image/png" });
                this.loadFiles([file]);
            }
        };
        this.camera.snap(this.videoHtmlElement, blobCallback);
        this.stopVideo();
    }
    canFlipCamera() {
        if (this.canFlipCameraValue === undefined) {
            this.canFlipCameraValue = this.camera.canFlip((res) => {
                this.canFlipCameraValue = res;
            });
        }
        return this.canFlipCameraValue;
    }
    flipCamera() {
        if (!this.canFlipCamera())
            return;
        this.closeVideoStream();
        this.camera.flip();
        this.startVideoInCamera();
    }
    closeVideoStream() {
        if (!!this.videoStream) {
            this.videoStream.getTracks().forEach(track => {
                track.stop();
            });
            this.videoStream = undefined;
        }
    }
    onHidingContent() {
        super.onHidingContent();
        this.stopVideo();
    }
    updateElementCssCore(cssClasses) {
        super.updateElementCssCore(cssClasses);
        this.prevFileAction.iconName = this.cssClasses.leftIconId;
        this.nextFileAction.iconName = this.cssClasses.rightIconId;
        this.updateCurrentMode();
    }
    getFileIndexCaption() {
        return this.getLocalizationFormatString("indexText", this.indexToShow + 1, this.pagesCount);
    }
    updateFileNavigator() {
        this.updatePages();
        this.navigationDirection = undefined;
        this.indexToShow = this.previewValue.length && ((this.indexToShow + this.pagesCount) % this.pagesCount) || 0;
        this.fileIndexAction.title = this.getFileIndexCaption();
    }
    updateRenderedPages() {
        if (this.pages && this.pages[this.indexToShow]) {
            this.renderedPages = [this.pages[this.indexToShow]];
        }
    }
    updatePages() {
        this.blockAnimations();
        let currentPage;
        this.pages = [];
        this.renderedPages = [];
        this.previewValue.forEach((val, index) => {
            if (index % this.pageSize == 0) {
                currentPage = new QuestionFilePage(this, this.pages.length);
                this.pages.push(currentPage);
            }
            currentPage.items.push(val);
        });
        this.releaseAnimations();
        this.updateRenderedPages();
    }
    previewValueChanged() {
        this.navigationDirection = undefined;
        if (this.previewValue.length !== this.prevPreviewLength) {
            if (this.previewValue.length > 0) {
                if (this.prevPreviewLength > this.previewValue.length) {
                    if (this.indexToShow >= this.pagesCount && this.indexToShow > 0) {
                        this.indexToShow = this.pagesCount - 1;
                        this.navigationDirection = "left-delete";
                    }
                }
                else {
                    this.indexToShow = Math.floor(this.prevPreviewLength / this.pageSize);
                }
            }
            else {
                this.indexToShow = 0;
            }
        }
        this.updatePages();
        this.fileIndexAction.title = this.getFileIndexCaption();
        this.containsMultiplyFiles = this.previewValue.length > 1;
        if (this.previewValue.length > 0 && !this.calculatedGapBetweenItems && !this.calculatedItemWidth) {
            setTimeout(() => {
                this.processResponsiveness(0, this._width);
            }, 1);
        }
        this.prevPreviewLength = this.previewValue.length;
    }
    getType() {
        return "file";
    }
    onChangeQuestionValue(newValue) {
        super.onChangeQuestionValue(newValue);
        if (!this.isLoadingFromJson) {
            this.loadPreview(newValue);
        }
    }
    /**
     * Disable this property only to implement a custom preview.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/file-custom-preview/ (linkStyle))
     * @see allowImagesPreview
     */
    get showPreview() {
        return this.getPropertyValue("showPreview");
    }
    set showPreview(val) {
        this.setPropertyValue("showPreview", val);
    }
    /**
     * Specifies whether users can upload multiple files.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/file-upload/ (linkStyle))
     */
    get allowMultiple() {
        return this.getPropertyValue("allowMultiple");
    }
    set allowMultiple(val) {
        this.setPropertyValue("allowMultiple", val);
    }
    /**
     * The height of the following images:
     *
     * - [Images in the preview](#allowImagesPreview)
     * - [Photos taken using the camera](#sourceType)
     * - Uploaded images in a [generated PDF form](https://surveyjs.io/pdf-generator/documentation/overview)
     *
     * > The sizes of previewed images are limited by the height and width of the preview area in single file upload mode or that of a thumbnail area in [multiple file upload mode](#allowMultiple).
     * @see imageWidth
     */
    get imageHeight() {
        return this.getPropertyValue("imageHeight");
    }
    set imageHeight(val) {
        this.setPropertyValue("imageHeight", val);
    }
    /**
     * The width of the following images:
     *
     * - [Images in the preview](#allowImagesPreview)
     * - [Photos taken using the camera](#sourceType)
     * - Uploaded images in a [generated PDF form](https://surveyjs.io/pdf-generator/documentation/overview)
     *
     * > The sizes of previewed images are limited by the height and width of the preview area in single file upload mode or that of a thumbnail area in [multiple file upload mode](#allowMultiple).
     * @see imageHeight
     */
    get imageWidth() {
        return this.getPropertyValue("imageWidth");
    }
    set imageWidth(val) {
        this.setPropertyValue("imageWidth", val);
    }
    /**
     * An [accept](https://www.w3schools.com/tags/att_input_accept.asp) attribute value for the underlying `<input>` element.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/store-file-names-in-survey-results/ (linkStyle))
     */
    get acceptedTypes() {
        return this.getPropertyValue("acceptedTypes");
    }
    set acceptedTypes(val) {
        this.setPropertyValue("acceptedTypes", val);
    }
    /**
     * Specifies whether to show a preview of image files.
     */
    get allowImagesPreview() {
        return this.getPropertyValue("allowImagesPreview");
    }
    set allowImagesPreview(val) {
        this.setPropertyValue("allowImagesPreview", val);
    }
    /**
     * Maximum allowed file size, measured in bytes.
     *
     * Default value: 0 (unlimited)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/file-upload/ (linkStyle))
     */
    get maxSize() {
        return this.getPropertyValue("maxSize");
    }
    set maxSize(val) {
        this.setPropertyValue("maxSize", val);
    }
    chooseFile(event) {
        if (!this.rootElement)
            return;
        const inputElement = this.rootElement.querySelector(`#${this.inputId}`);
        if (!inputElement)
            return;
        event.preventDefault();
        event.stopImmediatePropagation();
        if (inputElement) {
            if (this.survey) {
                this.survey.chooseFiles(inputElement, files => this.loadFiles(files), { element: this, elementType: this.getType(), propertyName: this.name });
            }
            else {
                inputElement.click();
            }
        }
    }
    /**
     * Specifies whether users should confirm file deletion.
     *
     * Default value: `false`
     */
    get needConfirmRemoveFile() {
        return this.getPropertyValue("needConfirmRemoveFile");
    }
    set needConfirmRemoveFile(val) {
        this.setPropertyValue("needConfirmRemoveFile", val);
    }
    getConfirmRemoveMessage(fileName) {
        return this.confirmRemoveMessage.format(fileName);
    }
    get takePhotoCaption() { return this.getLocalizableStringText("takePhotoCaption"); }
    set takePhotoCaption(val) { this.setLocalizableStringText("takePhotoCaption", val); }
    get locTakePhotoCaption() { return this.getLocalizableString("takePhotoCaption"); }
    get clearButtonCaption() {
        return this.getLocalizableStringText("clearCaption");
    }
    set clearButtonCaption(value) {
        this.setLocalizableStringText("clearCaption", value);
    }
    get locClearButtonCaption() {
        return this.getLocalizableString("clearCaption");
    }
    get locRenderedPlaceholder() {
        if (this.locRenderedPlaceholderValue === undefined) {
            this.locRenderedPlaceholderValue = (new ComputedUpdater(() => {
                const isReadOnly = this.isReadOnly;
                const hasFileUI = (!this.isDesignMode && this.hasFileUI) || (this.isDesignMode && this.sourceType != "camera");
                const hasVideoUI = (!this.isDesignMode && this.hasVideoUI) || (this.isDesignMode && this.sourceType != "file");
                let renderedPlaceholder;
                if (isReadOnly) {
                    renderedPlaceholder = this.locNoFileChosenCaption;
                }
                else if (hasFileUI && hasVideoUI) {
                    renderedPlaceholder = this.locFileOrPhotoPlaceholder;
                }
                else if (hasFileUI) {
                    renderedPlaceholder = this.locFilePlaceholder;
                }
                else {
                    renderedPlaceholder = this.locPhotoPlaceholder;
                }
                return renderedPlaceholder;
            }));
        }
        return this.locRenderedPlaceholderValue;
    }
    get currentMode() {
        return this.getPropertyValue("currentMode", this.sourceType);
    }
    get isPlayingVideo() {
        return this.getPropertyValue("isPlayingVideo", false);
    }
    setIsPlayingVideo(show) {
        this.setPropertyValue("isPlayingVideo", show);
    }
    updateCurrentMode() {
        if (!this.isDesignMode && this.survey) {
            if (this.sourceType !== "file") {
                this.camera.hasCamera((res) => {
                    this.setPropertyValue("currentMode", res ? this.sourceType : "file");
                });
            }
            else {
                this.setPropertyValue("currentMode", this.sourceType);
            }
        }
    }
    updateActionsVisibility() {
        const isDesignMode = this.isDesignMode;
        this.chooseFileAction.visible = (!isDesignMode && this.hasFileUI) || (isDesignMode && this.sourceType !== "camera");
        this.startCameraAction.visible = (!isDesignMode && this.hasVideoUI) || (isDesignMode && this.sourceType !== "file");
        this.cleanAction.visible = !!this.isAnswered;
    }
    get inputTitle() {
        if (this.isUploading)
            return this.loadingFileTitle;
        if (this.isEmpty())
            return this.chooseFileTitle;
        return " ";
    }
    get chooseButtonText() {
        return this.isEmpty() || this.allowMultiple ? this.chooseButtonCaption : this.replaceButtonCaption;
    }
    clear(doneCallback) {
        if (!this.survey)
            return;
        this.containsMultiplyFiles = false;
        this.survey.clearFiles(this, this.name, this.value, null, (status, data) => {
            if (status === "success") {
                this.value = undefined;
                this.errors = [];
                !!doneCallback && doneCallback();
                this.indexToShow = 0;
                this.fileIndexAction.title = this.getFileIndexCaption();
            }
        });
    }
    get renderCapture() {
        return this.allowCameraAccess ? "user" : undefined;
    }
    get multipleRendered() {
        return this.allowMultiple ? "multiple" : undefined;
    }
    get showFileDecorator() {
        const isPlayingVideo = this.isPlayingVideo;
        const showLoadingIndicator = this.showLoadingIndicator;
        return !isPlayingVideo && !showLoadingIndicator;
    }
    get showDragAreaPlaceholder() {
        return !this.isAnswered;
    }
    get allowShowPreview() {
        const isShowLoadingIndicator = this.showLoadingIndicator;
        const isPlayingVideo = this.isPlayingVideo;
        return !isShowLoadingIndicator && !isPlayingVideo;
    }
    get showPreviewContainer() {
        return this.previewValue && this.previewValue.length > 0;
    }
    defaultImage(data) {
        return !this.canPreviewImage(data) && !!this.cssClasses.defaultImage;
    }
    /**
     * Removes a file with a specified name.
     */
    removeFile(name) {
        this.removeFileByContent(this.value.filter((f) => f.name === name)[0]);
    }
    removeFileByContent(content) {
        if (!this.survey)
            return;
        this.survey.clearFiles(this, this.name, this.value, content.name, (status, data) => {
            if (status === "success") {
                var oldValue = this.value;
                if (Array.isArray(oldValue)) {
                    this.value = oldValue.filter((f) => !Helpers.isTwoValueEquals(f, content, true, false, false));
                }
                else {
                    this.value = undefined;
                }
            }
        });
    }
    setValueFromResult(arg) {
        this.value = (this.value || []).concat(arg.map((r) => {
            return {
                name: r.file.name,
                type: r.file.type,
                content: r.content,
            };
        }));
    }
    /**
     * Loads multiple files into the question.
     * @param files An array of [File](https://developer.mozilla.org/en-US/docs/Web/API/File) objects.
     */
    loadFiles(files) {
        if (!this.survey) {
            return;
        }
        this.errors = [];
        if (!this.allFilesOk(files)) {
            return;
        }
        var loadFilesProc = () => {
            this.stateChanged("loading");
            var content = [];
            if (this.storeDataAsText) {
                files.forEach((file) => {
                    let fileReader = new FileReader();
                    fileReader.onload = (e) => {
                        content = content.concat([
                            { name: file.name, type: file.type, content: fileReader.result },
                        ]);
                        if (content.length === files.length) {
                            this.value = (this.value || []).concat(content);
                        }
                    };
                    fileReader.readAsDataURL(file);
                });
            }
            else {
                this.uploadFiles(files);
            }
        };
        if (this.allowMultiple) {
            loadFilesProc();
        }
        else {
            this.clear(loadFilesProc);
        }
    }
    get camera() {
        if (!this.cameraValue) {
            this.cameraValue = new Camera();
        }
        return this.cameraValue;
    }
    canPreviewImage(fileItem) {
        return this.allowImagesPreview && !!fileItem && this.isFileImage(fileItem);
    }
    loadPreview(newValue) {
        if (this.showPreview && this.prevLoadedPreviewValue === newValue)
            return;
        this.previewValue.splice(0, this.previewValue.length);
        if (!this.showPreview || !newValue)
            return;
        this.prevLoadedPreviewValue = newValue;
        var newValues = Array.isArray(newValue)
            ? newValue
            : !!newValue
                ? [newValue]
                : [];
        if (this.storeDataAsText) {
            newValues.forEach((value) => {
                var content = value.content || value;
                this.previewValue.push({
                    name: value.name,
                    type: value.type,
                    content: content,
                });
            });
            this.previewValueChanged();
        }
        else {
            if (!!this._previewLoader) {
                this._previewLoader.dispose();
            }
            this.isFileLoading = true;
            this._previewLoader = new FileLoader(this, (status, loaded) => {
                if (status !== "error") {
                    loaded.forEach((val) => {
                        this.previewValue.push(val);
                    });
                    this.previewValueChanged();
                }
                this.isFileLoading = false;
                this._previewLoader.dispose();
                this._previewLoader = undefined;
            });
            this._previewLoader.load(newValues);
        }
    }
    allFilesOk(files) {
        var errorLength = this.errors ? this.errors.length : 0;
        (files || []).forEach((file) => {
            if (this.maxSize > 0 && file.size > this.maxSize) {
                this.errors.push(new ExceedSizeError(this.maxSize, this));
            }
        });
        return errorLength === this.errors.length;
    }
    isFileImage(file) {
        if (!file || !file.content || !file.content.substring)
            return false;
        const imagePrefix = "data:image";
        var subStr = file.content && file.content.substring(0, imagePrefix.length);
        subStr = subStr && subStr.toLowerCase();
        var result = subStr === imagePrefix ||
            (!!file.type && file.type.toLowerCase().indexOf("image/") === 0);
        return result;
    }
    getPlainData(options = {
        includeEmpty: true,
    }) {
        var questionPlainData = super.getPlainData(options);
        if (!!questionPlainData && !this.isEmpty()) {
            questionPlainData.isNode = false;
            var values = Array.isArray(this.value) ? this.value : [this.value];
            questionPlainData.data = values.map((dataValue, index) => {
                return {
                    name: index,
                    title: "File",
                    value: (dataValue.content && dataValue.content) || dataValue,
                    displayValue: (dataValue.name && dataValue.name) || dataValue,
                    getString: (val) => typeof val === "object" ? JSON.stringify(val) : val,
                    isNode: false,
                };
            });
        }
        return questionPlainData;
    }
    getImageWrapperCss(data) {
        return new CssClassBuilder().append(this.cssClasses.imageWrapper).append(this.cssClasses.imageWrapperDefaultImage, this.defaultImage(data)).toString();
    }
    getActionsContainerCss(css) {
        return new CssClassBuilder()
            .append(css.actionsContainer)
            .append(css.actionsContainerAnswered, this.isAnswered)
            .toString();
    }
    getRemoveButtonCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.removeFileButton)
            .append(this.cssClasses.contextButton)
            .toString();
    }
    getChooseFileCss() {
        const isAnswered = this.isAnswered;
        return new CssClassBuilder()
            .append(this.cssClasses.chooseFile)
            .append(this.cssClasses.controlDisabled, this.isReadOnly)
            .append(this.cssClasses.chooseFileAsText, !isAnswered)
            .append(this.cssClasses.chooseFileAsTextDisabled, !isAnswered && this.isInputReadOnly)
            .append(this.cssClasses.contextButton, isAnswered)
            .append(this.cssClasses.chooseFileAsIcon, isAnswered)
            .toString();
    }
    getReadOnlyFileCss() {
        return new CssClassBuilder()
            .append("form-control")
            .append(this.cssClasses.placeholderInput)
            .toString();
    }
    get fileRootCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.root)
            .append(this.cssClasses.rootDisabled, this.isDisabledStyle)
            .append(this.cssClasses.rootReadOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.rootPreview, this.isPreviewStyle)
            .append(this.cssClasses.rootDragging, this.isDragging)
            .append(this.cssClasses.rootAnswered, this.isAnswered)
            .append(this.cssClasses.single, !this.allowMultiple)
            .append(this.cssClasses.singleImage, !this.allowMultiple && this.isAnswered && this.canPreviewImage(this.value[0]))
            .append(this.cssClasses.mobile, this.isMobile)
            .toString();
    }
    getFileDecoratorCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.fileDecorator)
            .append(this.cssClasses.onError, this.hasCssError())
            .append(this.cssClasses.fileDecoratorDrag, this.isDragging)
            .toString();
    }
    onChange(src) {
        if (!DomWindowHelper.isFileReaderAvailable())
            return;
        if (!src || !src.files || src.files.length < 1)
            return;
        let files = [];
        let allowCount = this.allowMultiple ? src.files.length : 1;
        for (let i = 0; i < allowCount; i++) {
            files.push(src.files[i]);
        }
        src.value = "";
        this.loadFiles(files);
    }
    calcCssClasses(css) {
        const classes = super.calcCssClasses(css);
        this.actionsContainer.cssClasses = css.actionBar;
        this.actionsContainer.cssClasses.itemWithTitle = this.actionsContainer.cssClasses.item;
        this.actionsContainer.cssClasses.item = "";
        this.actionsContainer.cssClasses.itemAsIcon = classes.contextButton;
        this.actionsContainer.containerCss = classes.actionsContainer;
        return classes;
    }
    onSurveyLoad() {
        super.onSurveyLoad();
        this.updateCurrentMode();
        this.updateActionsVisibility();
        this.loadPreview(this.value);
    }
    needResponsiveness() {
        return this.supportResponsiveness();
    }
    supportResponsiveness() {
        return true;
    }
    getObservedElementSelector() {
        return classesToSelector(this.cssClasses.dragArea);
    }
    getFileListSelector() {
        return classesToSelector(this.cssClasses.fileList);
    }
    get renderedPages() {
        return this._renderedPages;
    }
    set renderedPages(val) {
        this.pagesAnimation.sync(val);
    }
    getPagesAnimationOptions() {
        return {
            getEnterOptions: (page) => {
                const pageClass = this.cssClasses.page;
                return { cssClass: pageClass ? new CssClassBuilder()
                        .append(`${pageClass}--enter-from-left`, this.navigationDirection == "left" || this.navigationDirection == "left-delete")
                        .append(`${pageClass}--enter-from-right`, this.navigationDirection == "right").toString() : ""
                };
            },
            getLeaveOptions: (page) => {
                const pageClass = this.cssClasses.page;
                return {
                    cssClass: pageClass ? new CssClassBuilder()
                        .append(`${pageClass}--leave-to-left`, this.navigationDirection == "right")
                        .append(`${pageClass}--leave-to-right`, this.navigationDirection == "left").toString() : ""
                };
            },
            getAnimatedElement: (page) => {
                var _a;
                return (_a = this.rootElement) === null || _a === void 0 ? void 0 : _a.querySelector(`#${page.id}`);
            },
            isAnimationEnabled: () => {
                return this.animationAllowed && !!this.rootElement;
            },
            getRerenderEvent: () => {
                return this.onElementRerendered;
            }
        };
    }
    triggerResponsiveness(hard) {
        if (hard) {
            this.calculatedGapBetweenItems = undefined;
            this.calculatedItemWidth = undefined;
        }
        super.triggerResponsiveness();
    }
    processResponsiveness(_, availableWidth) {
        this._width = availableWidth;
        if (this.rootElement) {
            if ((!this.calculatedGapBetweenItems || !this.calculatedItemWidth) && this.allowMultiple) {
                const fileListSelector = this.getFileListSelector();
                const fileListElement = fileListSelector ? this.rootElement.querySelector(this.getFileListSelector()) : undefined;
                if (fileListElement) {
                    const visiblePage = fileListElement.querySelector(classesToSelector(this.cssClasses.page));
                    if (visiblePage) {
                        const firstVisibleItem = visiblePage.querySelector(classesToSelector(this.cssClasses.previewItem));
                        this.calculatedGapBetweenItems = Math.ceil(Number.parseFloat(DomDocumentHelper.getComputedStyle(visiblePage).gap));
                        if (firstVisibleItem) {
                            this.calculatedItemWidth = Math.ceil(Number.parseFloat(DomDocumentHelper.getComputedStyle(firstVisibleItem).width));
                        }
                    }
                }
            }
        }
        if (this.calculatedGapBetweenItems && this.calculatedItemWidth) {
            this.pageSize = this.calcAvailableItemsCount(availableWidth, this.calculatedItemWidth, this.calculatedGapBetweenItems);
            return true;
        }
        return false;
    }
    canDragDrop() { return !this.isInputReadOnly && this.currentMode !== "camera" && !this.isPlayingVideo; }
    afterRenderQuestionElement(el) {
        this.rootElement = el;
    }
    beforeDestroyQuestionElement(el) {
        this.rootElement = undefined;
    }
    clearFilesCore() {
        if (this.rootElement) {
            const input = this.rootElement.querySelectorAll("input")[0];
            if (input) {
                input.value = "";
            }
        }
        this.clear();
    }
    doRemoveFile(data, event) {
        event.stopPropagation();
        if (this.needConfirmRemoveFile) {
            confirmActionAsync({
                message: this.getConfirmRemoveMessage(data.name),
                funcOnYes: () => { this.removeFileCore(data); },
                locale: this.getLocale(),
                rootElement: this.survey.rootElement,
                cssClass: this.cssClasses.confirmDialog
            });
            return;
        }
        this.removeFileCore(data);
    }
    removeFileCore(data) {
        const previewIndex = this.previewValue.indexOf(data);
        this.removeFileByContent(previewIndex === -1 ? data : this.value[previewIndex]);
    }
    //#endregion
    dispose() {
        this.cameraValue = undefined;
        this.closeVideoStream();
        super.dispose();
    }
}
__decorate([
    property()
], QuestionFileModel.prototype, "isDragging", void 0);
__decorate([
    propertyArray({})
], QuestionFileModel.prototype, "previewValue", void 0);
__decorate([
    propertyArray({})
], QuestionFileModel.prototype, "pages", void 0);
__decorate([
    property({ defaultValue: 0, onSet: (val, target) => {
            target.updateRenderedPages();
        } })
], QuestionFileModel.prototype, "indexToShow", void 0);
__decorate([
    property({
        defaultValue: 1, onSet: (_, target) => {
            target.updateFileNavigator();
        }
    })
], QuestionFileModel.prototype, "pageSize", void 0);
__decorate([
    property({ defaultValue: false })
], QuestionFileModel.prototype, "containsMultiplyFiles", void 0);
__decorate([
    property()
], QuestionFileModel.prototype, "allowCameraAccess", void 0);
__decorate([
    property({
        onSet: (val, obj) => {
            if (!obj.isLoadingFromJson) {
                obj.updateCurrentMode();
            }
        }
    })
], QuestionFileModel.prototype, "sourceType", void 0);
__decorate([
    property()
], QuestionFileModel.prototype, "canFlipCameraValue", void 0);
__decorate([
    property({ localizable: { defaultStr: "confirmRemoveFile" } })
], QuestionFileModel.prototype, "confirmRemoveMessage", void 0);
__decorate([
    property({ localizable: { defaultStr: "confirmRemoveAllFiles" } })
], QuestionFileModel.prototype, "confirmRemoveAllMessage", void 0);
__decorate([
    property({ localizable: { defaultStr: "noFileChosen" } })
], QuestionFileModel.prototype, "noFileChosenCaption", void 0);
__decorate([
    property({ localizable: { defaultStr: "chooseFileCaption" } })
], QuestionFileModel.prototype, "chooseButtonCaption", void 0);
__decorate([
    property({ localizable: { defaultStr: "replaceFileCaption" } })
], QuestionFileModel.prototype, "replaceButtonCaption", void 0);
__decorate([
    property({ localizable: { defaultStr: "removeFileCaption" } })
], QuestionFileModel.prototype, "removeFileCaption", void 0);
__decorate([
    property({ localizable: { defaultStr: "loadingFile" } })
], QuestionFileModel.prototype, "loadingFileTitle", void 0);
__decorate([
    property({ localizable: { defaultStr: "chooseFile" } })
], QuestionFileModel.prototype, "chooseFileTitle", void 0);
__decorate([
    property({ localizable: { defaultStr: "fileOrPhotoPlaceholder" } })
], QuestionFileModel.prototype, "fileOrPhotoPlaceholder", void 0);
__decorate([
    property({ localizable: { defaultStr: "photoPlaceholder" } })
], QuestionFileModel.prototype, "photoPlaceholder", void 0);
__decorate([
    property({ localizable: { defaultStr: "filePlaceholder" } })
], QuestionFileModel.prototype, "filePlaceholder", void 0);
__decorate([
    property()
], QuestionFileModel.prototype, "locRenderedPlaceholderValue", void 0);
__decorate([
    propertyArray()
], QuestionFileModel.prototype, "_renderedPages", void 0);
Serializer.addClass("file", [
    { name: "showCommentArea:switch", layout: "row", visible: true, category: "general" },
    { name: "showPreview:boolean", default: true, visible: false },
    "allowMultiple:boolean",
    {
        name: "allowImagesPreview:boolean",
        default: true,
        dependsOn: "showPreview",
        visibleIf: (obj) => {
            return !!obj.showPreview;
        },
    },
    "imageHeight",
    "imageWidth",
    "acceptedTypes",
    { name: "storeDataAsText:boolean", default: true },
    { name: "waitForUpload:boolean", default: false },
    { name: "maxSize:number", default: 0 },
    { name: "defaultValue", visible: false },
    { name: "correctAnswer", visible: false },
    { name: "validators", visible: false },
    { name: "needConfirmRemoveFile:boolean" },
    { name: "sourceType", choices: ["file", "camera", "file-camera"], default: "file", category: "general", visible: true },
    { name: "fileOrPhotoPlaceholder:text", serializationProperty: "locFileOrPhotoPlaceholder", category: "general" },
    { name: "photoPlaceholder:text", serializationProperty: "locPhotoPlaceholder", category: "general" },
    { name: "filePlaceholder:text", serializationProperty: "locFilePlaceholder", category: "general" },
    { name: "allowCameraAccess:switch", category: "general", visible: false },
], function () {
    return new QuestionFileModel("");
}, "question");
QuestionFactory.Instance.registerQuestion("file", (name) => {
    return new QuestionFileModel(name);
});
class FileLoader {
    constructor(fileQuestion, callback) {
        this.fileQuestion = fileQuestion;
        this.callback = callback;
        this.loaded = [];
    }
    load(files) {
        let downloadedCount = 0;
        this.loaded = new Array(files.length);
        files.forEach((value, index) => {
            if (this.fileQuestion.survey) {
                this.fileQuestion.survey.downloadFile(this.fileQuestion, this.fileQuestion.name, value, (status, data) => {
                    if (!this.fileQuestion || !this.callback) {
                        return;
                    }
                    if (status !== "error") {
                        this.loaded[index] = {
                            content: data,
                            name: value.name,
                            type: value.type,
                        };
                        downloadedCount++;
                        if (downloadedCount === files.length) {
                            this.callback(status, this.loaded);
                        }
                    }
                    else {
                        this.callback("error", this.loaded);
                    }
                });
            }
        });
    }
    dispose() {
        this.fileQuestion = undefined;
        this.callback = undefined;
    }
}

/**
  * A class that describes the HTML question type. Unlike other question types, HTML cannot have a title or value.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-html/ (linkStyle))
 */
class QuestionHtmlModel extends QuestionNonValue {
    constructor(name) {
        super(name);
        var locHtml = this.createLocalizableString("html", this);
        locHtml.onGetTextCallback = (str) => {
            return !!this.survey && !this.ignoreHtmlProgressing
                ? this.processHtml(str)
                : str;
        };
    }
    getType() {
        return "html";
    }
    get isCompositeQuestion() {
        return true;
    }
    getProcessedText(text) {
        if (this.ignoreHtmlProgressing)
            return text;
        return super.getProcessedText(text);
    }
    /**
     * HTML markup to display.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-html-form-field/ (linkStyle))
     *
     * > If you get the markup from a third party, ensure that it does not contain malicious code.
     */
    get html() {
        return this.getLocalizableStringText("html", "");
    }
    set html(val) {
        this.setLocalizableStringText("html", val);
    }
    get locHtml() {
        return this.getLocalizableString("html");
    }
    get processedHtml() {
        return this.processHtml(this.html);
    }
    processHtml(html) {
        return this.survey ? this.survey.processHtml(html, "html-question") : this.html;
    }
    get isNewA11yStructure() {
        return true;
    }
    get renderCssRoot() {
        return new CssClassBuilder().append(this.cssClasses.root).append(this.cssClasses.nested, this.getIsNested()).toString() || undefined;
    }
}
Serializer.addClass("html", [
    { name: "html:html", serializationProperty: "locHtml" },
    { name: "showNumber", visible: false },
    { name: "state", visible: false },
    { name: "titleLocation", visible: false },
    { name: "descriptionLocation", visible: false },
    { name: "errorLocation", visible: false },
    { name: "indent", visible: false },
    { name: "width", visible: false },
], function () {
    return new QuestionHtmlModel("");
}, "nonvalue");
QuestionFactory.Instance.registerQuestion("html", name => {
    return new QuestionHtmlModel(name);
});

/**
 * A class that describes the Radio Button Group question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-radiogroup/ (linkStyle))
 */
class QuestionRadiogroupModel extends QuestionCheckboxBase {
    constructor(name) {
        super(name);
    }
    getDefaultItemComponent() {
        return "survey-radiogroup-item";
    }
    getType() {
        return "radiogroup";
    }
    getFirstInputElementId() {
        return this.inputId + "_0";
    }
    /**
     * Returns the selected choice item. If no item is selected, returns `null`.
     */
    get selectedItem() { return this.getSingleSelectedItem(); }
    /**
     * Specifies whether to display a button that clears the question value.
     *
     * Default value: `false`
     */
    get allowClear() {
        return this.getPropertyValue("allowClear");
    }
    set allowClear(val) {
        this.setPropertyValue("allowClear", val);
    }
    /**
     * @deprecated Use the [`allowClear`](https://surveyjs.io/form-library/documentation/api-reference/radio-button-question-model#allowClear) property instead.
     */
    get showClearButton() {
        return this.allowClear;
    }
    set showClearButton(val) {
        this.allowClear = val;
    }
    get canShowClearButton() {
        return this.allowClear && !this.isReadOnly;
    }
    get clearButtonCaption() {
        return this.getLocalizationString("clearCaption");
    }
    supportAutoAdvance() {
        return this.isMouseDown === true && !this.isOtherSelected;
    }
    getConditionJson(operator = null, path = null) {
        const json = super.getConditionJson(operator, path);
        delete json["allowClear"];
        delete json["showClearButton"];
        return json;
    }
    setNewComment(newValue) {
        this.isMouseDown = true;
        super.setNewComment(newValue);
        this.isMouseDown = false;
    }
    clickItemHandler(item) {
        if (this.isReadOnlyAttr)
            return;
        this.renderedValue = item.value;
    }
    getDefaultTitleActions() {
        const actions = [];
        if (!this.isDesignMode) {
            const clearAction = new Action({
                locTitleName: "clearCaption",
                id: `sv-clr-btn-${this.id}`,
                action: () => { this.clearValue(true); },
                innerCss: this.cssClasses.clearButton,
                visible: new ComputedUpdater(() => this.canShowClearButton)
            });
            actions.push(clearAction);
        }
        return actions;
    }
    //a11y
    get isNewA11yStructure() {
        return true;
    }
    get a11y_input_ariaRole() {
        return "radiogroup";
    }
}
Serializer.addClass("radiogroup", [
    { name: "allowClear:boolean", alternativeName: "showClearButton" },
    { name: "separateSpecialChoices", visible: true },
    { name: "itemComponent", visible: false, default: "survey-radiogroup-item" }
], function () {
    return new QuestionRadiogroupModel("");
}, "checkboxbase");
QuestionFactory.Instance.registerQuestion("radiogroup", (name) => {
    var q = new QuestionRadiogroupModel(name);
    q.choices = QuestionFactory.DefaultChoices;
    return q;
});

class RenderedRatingItem extends Base {
    onStringChangedCallback() {
        this.text = this.itemValue.text;
    }
    get value() {
        return this.itemValue.getPropertyValue("value");
    }
    get locText() {
        return this.locString || this.itemValue.locText;
    }
    constructor(itemValue, locString = null) {
        super();
        this.itemValue = itemValue;
        this.locString = locString;
        this.locText.onStringChanged.add(this.onStringChangedCallback.bind(this));
        this.onStringChangedCallback();
    }
}
__decorate([
    property({ defaultValue: "" })
], RenderedRatingItem.prototype, "highlight", void 0);
__decorate([
    property({ defaultValue: "" })
], RenderedRatingItem.prototype, "text", void 0);
__decorate([
    property()
], RenderedRatingItem.prototype, "style", void 0);
class RatingItemValue extends ItemValue {
    constructor(value, text, description) {
        super(value, text);
        this.description = description;
    }
}
/**
 * A class that describes the Rating Scale question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/rating-scale/ (linkStyle))
 */
class QuestionRatingModel extends Question {
    constructor(name) {
        super(name);
        this.iCounter = 0;
        this.createItemValues("rateValues");
        this.createLocalizableString("ratingOptionsCaption", this, false, true);
        this.registerFunctionOnPropertiesValueChanged(["rateMin", "rateMax",
            "minRateDescription", "maxRateDescription", "rateStep", "displayRateDescriptionsAsExtremeItems"], () => this.resetRenderedItems());
        this.registerFunctionOnPropertiesValueChanged(["rateType"], () => {
            this.setIconsToRateValues();
            this.resetRenderedItems();
            this.updateRateCount();
        });
        this.registerFunctionOnPropertiesValueChanged(["rateValues"], () => {
            this.setIconsToRateValues();
            this.resetRenderedItems();
        });
        this.registerSychProperties(["rateValues"], () => {
            this.autoGenerate = this.rateValues.length == 0;
            this.setIconsToRateValues();
            this.resetRenderedItems();
        });
        this.registerFunctionOnPropertiesValueChanged(["rateColorMode", "scaleColorMode"], () => {
            this.updateColors(this.survey.themeVariables);
        });
        this.registerFunctionOnPropertiesValueChanged(["displayMode"], () => {
            this.updateRenderAsBasedOnDisplayMode(true);
        });
        this.registerSychProperties(["autoGenerate"], () => {
            if (!this.autoGenerate && this.rateValues.length === 0) {
                this.setPropertyValue("rateValues", this.visibleRateValues);
            }
            if (this.autoGenerate) {
                this.rateValues.splice(0, this.rateValues.length);
                this.updateRateMax();
            }
            this.resetRenderedItems();
        });
        this.createLocalizableString("minRateDescription", this, true)
            .onStringChanged.add((sender, options) => {
            this.setPropertyValue("hasMinRateDescription", !sender.isEmpty);
        });
        this.createLocalizableString("maxRateDescription", this, true)
            .onStringChanged.add((sender, options) => {
            this.setPropertyValue("hasMaxRateDescription", !sender.isEmpty);
        });
        this.createLocalizableString("readOnlyText", this, true);
        this.registerPropertyChangedHandlers(["value", "renderAs", "placeholder", "choices", "visibleChoices"], () => {
            this.updateReadOnlyText();
        });
        this.updateReadOnlyText();
        this.initPropertyDependencies();
    }
    setIconsToRateValues() {
        if (this.rateType == "smileys") {
            this.rateValues.map(item => item.icon = this.getItemSmiley(item));
        }
    }
    locStrsChanged() {
        var _a;
        super.locStrsChanged();
        this.updateReadOnlyText();
        (_a = this.dropdownListModelValue) === null || _a === void 0 ? void 0 : _a.locStrsChanged();
    }
    updateReadOnlyText() {
        this.readOnlyText = this.displayValue || this.placeholder;
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        if (this.jsonObj.rateMin !== undefined && this.jsonObj.rateCount !== undefined && this.jsonObj.rateMax === undefined) {
            this.updateRateMax();
        }
        if (this.jsonObj.rateMax !== undefined && this.jsonObj.rateCount !== undefined && this.jsonObj.rateMin === undefined) {
            this.updateRateMin();
        }
        if (this.jsonObj.autoGenerate === undefined && this.jsonObj.rateValues !== undefined)
            this.autoGenerate = !this.jsonObj.rateValues.length;
        this.updateRateCount();
        this.setIconsToRateValues();
    }
    useRateValues() {
        return !!this.rateValues.length && !this.autoGenerate;
    }
    updateRateMax() {
        this.rateMax = this.rateMin + this.rateStep * (this.rateCount - 1);
    }
    updateRateMin() {
        this.rateMin = this.rateMax - this.rateStep * (this.rateCount - 1);
    }
    updateRateCount() {
        let newCount = 0;
        if (this.useRateValues()) {
            newCount = this.rateValues.length;
        }
        else {
            newCount = Math.trunc((this.rateMax - this.rateMin) / (this.rateStep || 1)) + 1;
        }
        if (newCount > 10 && this.rateDisplayMode == "smileys") {
            newCount = 10;
        }
        this.rateCount = newCount;
        if (this.rateValues.length > newCount)
            this.rateValues.splice(newCount, this.rateValues.length - newCount);
    }
    initPropertyDependencies() {
        this.registerSychProperties(["rateCount"], () => {
            if (!this.useRateValues()) {
                this.rateMax = this.rateMin + this.rateStep * (this.rateCount - 1);
            }
            else {
                if (this.rateCount < this.rateValues.length) {
                    if (this.rateCount >= 10 && this.rateDisplayMode == "smileys")
                        return;
                    this.rateValues.splice(this.rateCount, this.rateValues.length - this.rateCount);
                }
                else {
                    for (let i = this.rateValues.length; i < this.rateCount; i++) {
                        this.rateValues.push(new ItemValue(getLocaleString("choices_Item") + (i + 1)));
                    }
                }
            }
        });
        this.registerSychProperties(["rateMin", "rateMax", "rateStep", "rateValues"], () => {
            this.updateRateCount();
        });
    }
    get showSelectedItemLocText() {
        return !this.readOnly && !this.inputHasValue && !!this.selectedItemLocText;
    }
    get selectedItemLocText() {
        var _a;
        return !this.readOnly && ((_a = this.visibleRateValues.filter(v => v.value == this.value)[0]) === null || _a === void 0 ? void 0 : _a.locText);
    }
    /**
     * A list of rate values.
     *
     * This property accepts an array of objects with the following structure:
     *
     * ```js
     * {
     *   "value": any, // A value to be saved in survey results
     *   "text": String, // A display text. This property supports Markdown. When `text` is undefined, `value` is used.
     *   "customProperty": any // Any property that you find useful.
     * }
     * ```
     *
     * If you add custom properties, refer to the following help topic to learn how to serialize them into JSON: [Add Custom Properties to Property Grid](https://surveyjs.io/survey-creator/documentation/property-grid#add-custom-properties-to-the-property-grid).
     *
     * To enable Markdown support for the `text` property, implement Markdown-to-HTML conversion in the [onTextMarkdown](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onTextMarkdown) event handler. For an example, refer to the following demo: [Convert Markdown to HTML with markdown-it](https://surveyjs.io/form-library/examples/edit-survey-questions-markdown/).
     *
     * If you need to specify only the `value` property, you can set the `rateValues` property to an array of numbers, for example, `[ 3, 6, 10 ]`. These values are both saved in survey results and used as display text.
     *
     * If you do not specify the `rateValues` property, rate values are generated automatically based upon the [`rateMin`](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model#rateMin), [`rateMax`](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model#rateMax), [`rateStep`](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model#rateStep), and [`rateCount`](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model#rateCount) property values.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/rating-scale/ (linkStyle))
     */
    get rateValues() {
        return this.getPropertyValue("rateValues");
    }
    set rateValues(val) {
        this.setPropertyValue("rateValues", val);
    }
    /**
     * Specifies the first rate value in the generated sequence of rate values. Applies if the [`rateValues`](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model#rateValues) array is empty.
     *
     * Default value: 1
     *
     * [View Demo](https://surveyjs.io/form-library/examples/rating-scale/ (linkStyle))
     * @see rateMax
     * @see rateStep
     * @see rateCount
     */
    get rateMin() {
        return this.getPropertyValue("rateMin");
    }
    set rateMin(val) {
        this.setPropertyValue("rateMin", val);
    }
    /**
     * Specifies the last rate value in the generated sequence of rate values. Applies if the [`rateValues`](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model#rateValues) array is empty.
     *
     * Default value: 5
     *
     * [View Demo](https://surveyjs.io/form-library/examples/rating-scale/ (linkStyle))
     * @see rateMin
     * @see rateStep
     * @see rateCount
     */
    get rateMax() {
        return this.getPropertyValue("rateMax");
    }
    set rateMax(val) {
        this.setPropertyValue("rateMax", val);
    }
    /**
     * Specifies a step with which to generate rate values. Applies if the [`rateValues`](https://surveyjs.io/form-library/documentation/api-reference/rating-scale-question-model#rateValues) array is empty.
     *
     * Default value: 1
     *
     * [View Demo](https://surveyjs.io/form-library/examples/rating-scale/ (linkStyle))
     * @see rateMin
     * @see rateMax
     * @see rateCount
     */
    get rateStep() {
        return this.getPropertyValue("rateStep");
    }
    set rateStep(val) {
        this.setPropertyValue("rateStep", val);
    }
    updateColors(themeVariables) {
        if (this.colorMode === "monochrome")
            return;
        if (!DomDocumentHelper.isAvailable())
            return;
        if (QuestionRatingModel.colorsCalculated)
            return;
        function getColorFromProperty(varName) {
            const style = getComputedStyle(DomDocumentHelper.getDocumentElement());
            return style.getPropertyValue && style.getPropertyValue(varName);
        }
        function getRGBColor(colorName, varName) {
            let str = !!themeVariables && themeVariables[colorName];
            if (!str)
                str = getColorFromProperty(varName);
            if (!str)
                return null;
            const canvasElement = DomDocumentHelper.createElement("canvas");
            if (!canvasElement)
                return null;
            var ctx = canvasElement.getContext("2d");
            ctx.fillStyle = str;
            if (ctx.fillStyle == "#000000") {
                ctx.fillStyle = getColorFromProperty(varName);
            }
            const newStr = ctx.fillStyle;
            if (newStr.startsWith("rgba")) {
                return newStr.substring(5, newStr.length - 1).split(",").map(c => +(c.trim()));
            }
            var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(newStr);
            return result ? [
                parseInt(result[1], 16),
                parseInt(result[2], 16),
                parseInt(result[3], 16),
                1
            ] : null;
        }
        QuestionRatingModel.badColor = getRGBColor("--sjs-special-red", "--sd-rating-bad-color");
        QuestionRatingModel.normalColor = getRGBColor("--sjs-special-yellow", "--sd-rating-normal-color");
        QuestionRatingModel.goodColor = getRGBColor("--sjs-special-green", "--sd-rating-good-color");
        QuestionRatingModel.badColorLight = getRGBColor("--sjs-special-red-light", "--sd-rating-bad-color-light");
        QuestionRatingModel.normalColorLight = getRGBColor("--sjs-special-yellow-light", "--sd-rating-normal-color-light");
        QuestionRatingModel.goodColorLight = getRGBColor("--sjs-special-green-light", "--sd-rating-good-color-light");
        this.colorsCalculated = true;
        this.resetRenderedItems();
    }
    getDisplayValueCore(keysAsText, value) {
        if (!this.useRateValues)
            return super.getDisplayValueCore(keysAsText, value);
        var res = ItemValue.getTextOrHtmlByValue(this.visibleRateValues, value);
        return !!res ? res : value;
    }
    get visibleRateValues() {
        return this.renderedRateItems.map(i => i.itemValue);
    }
    supportEmptyValidation() { return this.renderAs === "dropdown"; }
    itemValuePropertyChanged(item, name, oldValue, newValue) {
        if (!this.useRateValues() && newValue !== undefined)
            this.autoGenerate = false;
        super.itemValuePropertyChanged(item, name, oldValue, newValue);
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        this.runRateItesmCondition(values, properties);
    }
    runRateItesmCondition(values, properties) {
        var _a;
        if (!this.useRateValues())
            return;
        let isChanged = false;
        if ((_a = this.survey) === null || _a === void 0 ? void 0 : _a.areInvisibleElementsShowing) {
            this.rateValues.forEach(item => {
                isChanged = isChanged || !item.isVisible;
                item.setIsVisible(item, true);
            });
        }
        else {
            isChanged = ItemValue.runConditionsForItems(this.rateValues, undefined, undefined, values, properties, true);
        }
        if (isChanged) {
            this.resetRenderedItems();
            if (!this.isEmpty() && !this.isReadOnly) {
                const item = ItemValue.getItemByValue(this.rateValues, this.value);
                if (item && !item.isVisible) {
                    this.clearValue();
                }
            }
        }
    }
    getRateValuesCore() {
        if (!this.useRateValues())
            return this.createRateValues();
        const items = new Array();
        this.rateValues.forEach(item => {
            if (item.isVisible) {
                items.push(item);
            }
        });
        return items;
    }
    calculateRateValues() {
        let rateValues = this.getRateValuesCore();
        if (this.rateType == "smileys" && rateValues.length > 10)
            rateValues = rateValues.slice(0, 10);
        return rateValues;
    }
    calculateRenderedRateItems() {
        const rateValues = this.calculateRateValues();
        return rateValues.map((v, i) => {
            let renderedItem = null;
            if (this.displayRateDescriptionsAsExtremeItems) {
                if (i == 0)
                    renderedItem = new RenderedRatingItem(v, this.minRateDescription && this.locMinRateDescription || v.locText);
                if (i == rateValues.length - 1)
                    renderedItem = new RenderedRatingItem(v, this.maxRateDescription && this.locMaxRateDescription || v.locText);
            }
            if (!renderedItem)
                renderedItem = new RenderedRatingItem(v);
            return renderedItem;
        });
    }
    calculateVisibleChoices() {
        const rateValues = this.calculateRateValues();
        return rateValues.map((i, idx) => this.getRatingItemValue(i, idx));
    }
    resetRenderedItems() {
        if (this.autoGenerate) {
            const rateValues = this.getRateValuesCore();
            this.rateMax = rateValues[rateValues.length - 1].value;
        }
        if (Array.isArray(this.getPropertyValueWithoutDefault("renderedRateItems"))) {
            this.setArrayPropertyDirectly("renderedRateItems", this.calculateRenderedRateItems());
        }
        if (Array.isArray(this.getPropertyValueWithoutDefault("visibleChoices"))) {
            this.setArrayPropertyDirectly("visibleChoices", this.calculateVisibleChoices);
        }
    }
    get renderedRateItems() {
        return this.getPropertyValue("renderedRateItems", undefined, () => this.calculateRenderedRateItems());
    }
    get visibleChoices() {
        return this.getPropertyValue("visibleChoices", undefined, () => this.calculateVisibleChoices());
    }
    createRateValues() {
        var res = [];
        var value = this.rateMin;
        var step = this.rateStep;
        while (value <= this.rateMax &&
            res.length < settings.ratingMaximumRateValueCount) {
            let item = new ItemValue(value);
            item.locOwner = this;
            item.ownerPropertyName = "rateValues";
            res.push(item);
            value = this.correctValue(value + step, step);
        }
        return res;
    }
    getRatingItemValue(item, index) {
        if (!item)
            return null;
        const value = item.value;
        let description;
        if (index === 0) {
            description = this.minRateDescription && this.locMinRateDescription;
        }
        if (index === (this.rateCount - 1)) {
            description = this.maxRateDescription && this.locMaxRateDescription;
        }
        let newItem = new RatingItemValue(value, item.text, description);
        newItem.locOwner = item.locOwner;
        newItem.ownerPropertyName = item.ownerPropertyName;
        return newItem;
    }
    correctValue(value, step) {
        if (!value)
            return value;
        if (Math.round(value) == value)
            return value;
        var fr = 0;
        while (Math.round(step) != step) {
            step *= 10;
            fr++;
        }
        return parseFloat(value.toFixed(fr));
    }
    getType() {
        return "rating";
    }
    getFirstInputElementId() {
        return this.inputId + "_0";
    }
    getInputId(index) {
        return this.inputId + "_" + index;
    }
    get questionName() {
        return this.name + "_" + this.id;
    }
    supportAutoAdvance() {
        return this.isMouseDown === true || this.renderAs === "dropdown";
    }
    supportOther() {
        return false;
    }
    getPlainDataCalculatedValue(propName) {
        const res = super.getPlainDataCalculatedValue(propName);
        if (res !== undefined || !this.useRateValues || this.isEmpty())
            return res;
        const item = ItemValue.getItemByValue(this.visibleRateValues, this.value);
        return item ? item[propName] : undefined;
    }
    /**
     * Specifies a description for the minimum (first) rate value.
     * @see rateDescriptionLocation
     * @see displayRateDescriptionsAsExtremeItems
     * @see rateValues
     * @see rateMin
     */
    get minRateDescription() {
        return this.getLocalizableStringText("minRateDescription");
    }
    set minRateDescription(val) {
        this.setLocalizableStringText("minRateDescription", val);
    }
    get locMinRateDescription() {
        return this.getLocalizableString("minRateDescription");
    }
    /**
     * Specifies a description for the maximum (last) rate value.
     * @see rateDescriptionLocation
     * @see displayRateDescriptionsAsExtremeItems
     * @see rateValues
     * @see rateMax
     */
    get maxRateDescription() {
        return this.getLocalizableStringText("maxRateDescription");
    }
    set maxRateDescription(val) {
        this.setLocalizableStringText("maxRateDescription", val);
    }
    get locMaxRateDescription() {
        return this.getLocalizableString("maxRateDescription");
    }
    get hasMinRateDescription() {
        return this.getPropertyValue("hasMinRateDescription", undefined, () => !!this.minRateDescription);
    }
    get hasMaxRateDescription() {
        return this.getPropertyValue("hasMaxRateDescription", undefined, () => !!this.maxRateDescription);
    }
    get hasMinLabel() {
        return !this.displayRateDescriptionsAsExtremeItems && !!this.hasMinRateDescription;
    }
    get hasMaxLabel() {
        return !this.displayRateDescriptionsAsExtremeItems && !!this.hasMaxRateDescription;
    }
    updateRenderAsBasedOnDisplayMode(isOnChange) {
        if (this.isDesignMode) {
            if (isOnChange || this.renderAs === "dropdown") {
                this.renderAs = "default";
            }
        }
        else {
            if (isOnChange || this.displayMode !== "auto") {
                this.renderAs = this.displayMode === "dropdown" ? "dropdown" : "default";
            }
        }
    }
    onSurveyLoad() {
        super.onSurveyLoad();
        if (this.renderAs === "dropdown" && this.displayMode === "auto") {
            this.displayMode = this.renderAs;
        }
        else {
            this.updateRenderAsBasedOnDisplayMode();
        }
    }
    get rateDisplayMode() {
        return this.rateType;
    }
    set rateDisplayMode(val) {
        this.rateType = val;
    }
    get isStar() {
        return this.rateType == "stars";
    }
    get isSmiley() {
        return this.rateType == "smileys";
    }
    getDefaultItemComponent() {
        if (this.renderAs == "dropdown")
            return "sv-rating-dropdown-item";
        if (this.isStar)
            return "sv-rating-item-star";
        if (this.isSmiley)
            return "sv-rating-item-smiley";
        return "sv-rating-item";
    }
    /**
     * The name of a component used to render items.
     */
    get itemComponent() {
        return this.getPropertyValue("itemComponent", this.getDefaultItemComponent());
    }
    set itemComponent(value) {
        this.setPropertyValue("itemComponent", value);
    }
    valueToData(val) {
        if (this.useRateValues()) {
            var item = ItemValue.getItemByValue(this.rateValues, val);
            return !!item ? item.value : val;
        }
        return !isNaN(val) ? parseFloat(val) : val;
    }
    setValueFromClick(value) {
        if (this.isReadOnlyAttr)
            return;
        if (this.value === ((typeof (this.value) === "string") ? value : parseFloat(value))) {
            this.clearValue(true);
        }
        else {
            this.value = value;
        }
        for (let i = 0; i < this.renderedRateItems.length; i++) {
            this.renderedRateItems[i].highlight = "none";
        }
    }
    onItemMouseIn(item) {
        if (IsTouch)
            return;
        if (this.isReadOnly || !item.itemValue.isEnabled || this.isDesignMode)
            return;
        let high = true;
        let selected = this.value != null;
        if (this.rateType !== "stars") {
            item.highlight = "highlighted";
            return;
        }
        for (let i = 0; i < this.renderedRateItems.length; i++) {
            this.renderedRateItems[i].highlight = high && !selected && "highlighted" || !high && selected && "unhighlighted" || "none";
            if (this.renderedRateItems[i] == item)
                high = false;
            if (this.renderedRateItems[i].itemValue.value == this.value)
                selected = false;
        }
    }
    onItemMouseOut(item) {
        if (IsTouch)
            return;
        this.renderedRateItems.forEach(item => item.highlight = "none");
    }
    get itemSmallMode() {
        return !this.isSingleInputActive && this.inMatrixMode && settings.matrix.rateSize == "small";
    }
    get ratingRootCss() {
        const hasLabel = this.hasMaxLabel || this.hasMinLabel;
        return new CssClassBuilder()
            .append(this.cssClasses.root)
            .append(this.cssClasses.rootWrappable, this.displayMode == "buttons" || (!!this.survey && this.survey.isDesignMode) || (this.displayMode == "auto" && !this.supportResponsiveness()))
            .append(this.cssClasses.rootLabelsTop, hasLabel && this.rateDescriptionLocation == "top")
            .append(this.cssClasses.rootLabelsBottom, hasLabel && this.rateDescriptionLocation == "bottom")
            .append(this.cssClasses.rootLabelsDiagonal, hasLabel && this.rateDescriptionLocation == "topBottom")
            .append(this.cssClasses.itemSmall, this.itemSmallMode && this.rateType != "labels")
            .toString();
    }
    get itemStarIcon() {
        return this.itemSmallMode ? "icon-rating-star-small" : "icon-rating-star";
    }
    get itemStarIconAlt() {
        return this.itemStarIcon + "-2";
    }
    getItemSmiley(item) {
        const icons = ["terrible", "very-poor", "poor", "not-good", "average", "normal", "good", "very-good", "excellent", "perfect"];
        const priority = ["very-good", "not-good", "normal", "good", "average", "excellent", "poor", "perfect", "very-poor", "terrible"];
        const count = this.useRateValues() ? this.rateValues.length : this.rateMax - this.rateMin + 1;
        const selectedPriority = priority.slice(0, count);
        const selectedIcons = icons.filter(i => selectedPriority.indexOf(i) != -1);
        if (!this.useRateValues()) {
            return selectedIcons[item.value - this.rateMin];
        }
        else {
            return selectedIcons[this.rateValues.indexOf(item)];
        }
    }
    getItemSmileyIconName(item) {
        return "icon-" + this.getItemSmiley(item);
    }
    getItemClassByText(item, text) {
        return this.getItemClass(item);
    }
    getRenderedItemColor(index, light) {
        let startColor = light ? QuestionRatingModel.badColorLight : QuestionRatingModel.badColor;
        let endColor = light ? QuestionRatingModel.goodColorLight : QuestionRatingModel.goodColor;
        const normalIndex = (this.rateCount - 1) / 2.0;
        const middleColor = light ? QuestionRatingModel.normalColorLight : QuestionRatingModel.normalColor;
        if (index < normalIndex) {
            endColor = middleColor;
        }
        else {
            startColor = middleColor;
            index -= normalIndex;
        }
        if (!startColor || !endColor)
            return null;
        const curColor = [0, 0, 0, 0];
        for (let i = 0; i < 4; i++) {
            curColor[i] = startColor[i] + (endColor[i] - startColor[i]) * index / normalIndex;
            if (i < 3)
                curColor[i] = Math.trunc(curColor[i]);
        }
        return "rgba(" + curColor[0] + ", " + curColor[1] + ", " + curColor[2] + ", " + curColor[3] + ")";
    }
    getItemStyle(item, highlight = "none") {
        if (this.scaleColorMode === "monochrome" && this.rateColorMode == "default" ||
            this.isPreviewStyle ||
            this.isReadOnlyStyle)
            return {};
        const index = this.visibleRateValues.indexOf(item);
        const color = this.getRenderedItemColor(index, false);
        const colorLight = highlight == "highlighted" && this.scaleColorMode === "colored" && this.getRenderedItemColor(index, true);
        return colorLight ? { "--sd-rating-item-color": color, "--sd-rating-item-color-light": colorLight } : { "--sd-rating-item-color": color };
    }
    getItemClass(item, highlight = "none") {
        let isSelected = this.value == item.value;
        if (this.isStar) {
            if (!this.useRateValues()) {
                isSelected = this.value >= item.value;
            }
            else {
                isSelected = this.rateValues.indexOf(this.rateValues.filter(i => i.value == this.value)[0]) >= this.rateValues.indexOf(item);
            }
        }
        const isDisabled = this.isReadOnly || !item.isEnabled;
        const allowHover = !isDisabled && (this.value != item.value) && !(!!this.survey && this.survey.isDesignMode);
        const renderedItem = this.renderedRateItems.filter(i => i.itemValue == item)[0];
        const isHighlighted = this.isStar && (renderedItem === null || renderedItem === void 0 ? void 0 : renderedItem.highlight) == "highlighted";
        const isUnhighlighted = this.isStar && (renderedItem === null || renderedItem === void 0 ? void 0 : renderedItem.highlight) == "unhighlighted";
        let itemClass = this.cssClasses.item;
        let itemSelectedClass = this.cssClasses.selected;
        let itemDisabledClass = this.cssClasses.itemDisabled;
        let itemReadOnlyClass = this.cssClasses.itemReadOnly;
        let itemPreviewClass = this.cssClasses.itemPreview;
        let itemHoverClass = this.cssClasses.itemHover;
        let itemitemOnErrorClass = this.cssClasses.itemOnError;
        let itemHighlightedClass = null;
        let itemUnhighlightedClass = null;
        let itemScaleColoredClass = null;
        let itemRateColoredClass = null;
        let itemSmallClass = null;
        if (this.isStar) {
            itemClass = this.cssClasses.itemStar;
            itemSelectedClass = this.cssClasses.itemStarSelected;
            itemDisabledClass = this.cssClasses.itemStarDisabled;
            itemReadOnlyClass = this.cssClasses.itemStarReadOnly;
            itemPreviewClass = this.cssClasses.itemStarPreview;
            itemHoverClass = this.cssClasses.itemStarHover;
            itemitemOnErrorClass = this.cssClasses.itemStarOnError;
            itemHighlightedClass = this.cssClasses.itemStarHighlighted;
            itemUnhighlightedClass = this.cssClasses.itemStarUnhighlighted;
            itemSmallClass = this.cssClasses.itemStarSmall;
        }
        if (this.isSmiley) {
            itemClass = this.cssClasses.itemSmiley;
            itemSelectedClass = this.cssClasses.itemSmileySelected;
            itemDisabledClass = this.cssClasses.itemSmileyDisabled;
            itemReadOnlyClass = this.cssClasses.itemSmileyReadOnly;
            itemPreviewClass = this.cssClasses.itemSmileyPreview;
            itemHoverClass = this.cssClasses.itemSmileyHover;
            itemitemOnErrorClass = this.cssClasses.itemSmileyOnError;
            itemHighlightedClass = this.cssClasses.itemSmileyHighlighted;
            itemScaleColoredClass = this.cssClasses.itemSmileyScaleColored;
            itemRateColoredClass = this.cssClasses.itemSmileyRateColored;
            itemSmallClass = this.cssClasses.itemSmileySmall;
        }
        const hasFixedSize = !this.isStar &&
            !this.isSmiley &&
            (!this.displayRateDescriptionsAsExtremeItems ||
                this.useRateValues() && item != this.rateValues[0] && item != this.rateValues[this.rateValues.length - 1] ||
                !this.useRateValues() && item.value != this.rateMin && item.value != this.rateMax) &&
            item.locText.calculatedText.length <= 2 &&
            Number.isInteger(Number(item.locText.calculatedText));
        const options = { item: item, css: "" };
        options.css = new CssClassBuilder()
            .append(itemClass)
            .append(itemSelectedClass, isSelected)
            .append(itemDisabledClass, this.isDisabledStyle)
            .append(itemReadOnlyClass, this.isReadOnlyStyle)
            .append(itemPreviewClass, this.isPreviewStyle)
            .append(itemHoverClass, allowHover)
            .append(itemHighlightedClass, isHighlighted)
            .append(itemScaleColoredClass, this.scaleColorMode == "colored")
            .append(itemRateColoredClass, this.rateColorMode == "scale" && isSelected)
            .append(itemUnhighlightedClass, isUnhighlighted)
            .append(itemitemOnErrorClass, this.hasCssError())
            .append(itemSmallClass, this.itemSmallMode)
            .append(this.cssClasses.itemFixedSize, hasFixedSize)
            .toString();
        if (!!this.survey) {
            this.survey.updateChoiceItemCss(this, options);
        }
        return options.css;
    }
    //methods for mobile view
    getControlClass() {
        this.isEmpty();
        return new CssClassBuilder()
            .append(this.cssClasses.control)
            .append(this.cssClasses.controlEmpty, this.isEmpty())
            .append(this.cssClasses.onError, this.hasCssError())
            .append(this.cssClasses.controlDisabled, this.isDisabledStyle)
            .append(this.cssClasses.controlReadOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.controlPreview, this.isPreviewStyle)
            .toString();
    }
    get placeholder() {
        return this.getLocalizableStringText("ratingOptionsCaption");
    }
    set placeholder(val) {
        this.setLocalizableStringText("ratingOptionsCaption", val);
    }
    get locPlaceholder() {
        return this.getLocalizableString("ratingOptionsCaption");
    }
    get allowClear() {
        return true;
    }
    get searchEnabled() {
        return false;
    }
    get renderedValue() {
        return this.value;
    }
    set renderedValue(val) {
        this.value = val;
    }
    isItemSelected(item) {
        return item.value == this.value;
    }
    get readOnlyText() {
        return this.getLocalizableStringText("readOnlyText");
    }
    set readOnlyText(val) {
        this.setLocalizableStringText("readOnlyText", val);
    }
    get locReadOnlyText() {
        return this.getLocalizableString("readOnlyText");
    }
    get a11yInputAriaRole() {
        return this.renderAs === "dropdown" ? "combobox" : null;
    }
    needResponsiveWidth() {
        this.getPropertyValue("rateValues");
        const rateStep = this.getPropertyValue("rateStep");
        const rateMax = this.getPropertyValue("rateMax");
        const rateMin = this.getPropertyValue("rateMin");
        return this.displayMode != "dropdown" && !!(this.hasMinRateDescription ||
            this.hasMaxRateDescription ||
            (rateStep && (rateMax - rateMin) / rateStep > 9));
    }
    // TODO: return responsiveness after design improvement
    supportResponsiveness() {
        return !this.inMatrixMode;
    }
    onBeforeSetCompactRenderer() {
        if (!this.dropdownListModelValue) {
            this.dropdownListModelValue = new DropdownListModel(this);
        }
    }
    getCompactRenderAs() {
        return (this.displayMode == "buttons") ? "default" : "dropdown";
    }
    getDesktopRenderAs() {
        return (this.displayMode == "dropdown") ? "dropdown" : "default";
    }
    set dropdownListModel(val) {
        this.dropdownListModelValue = val;
        this.updateElementCss();
    }
    get dropdownListModel() {
        if (this.renderAs === "dropdown") {
            this.onBeforeSetCompactRenderer();
        }
        return this.dropdownListModelValue;
    }
    onBlurCore(event) {
        var _a;
        (_a = this.dropdownListModel) === null || _a === void 0 ? void 0 : _a.onBlur(event);
        super.onBlurCore(event);
    }
    updateCssClasses(res, css) {
        super.updateCssClasses(res, css);
        updateListCssValues(res, css);
    }
    calcCssClasses(css) {
        const classes = super.calcCssClasses(css);
        if (this.dropdownListModelValue) {
            this.dropdownListModelValue.updateCssClasses(classes.popup, classes.list);
        }
        return classes;
    }
    themeChanged(theme) {
        this.colorsCalculated = false;
        this.updateColors(theme.cssVariables);
    }
    setSurveyImpl(value, isLight) {
        super.setSurveyImpl(value, isLight);
        if (!this.survey)
            return;
        this.updateColors(this.survey.themeVariables);
        this.updateRenderAsBasedOnDisplayMode();
    }
    dispose() {
        super.dispose();
        if (!!this.dropdownListModelValue) {
            this.dropdownListModelValue.dispose();
            this.dropdownListModelValue = undefined;
        }
    }
}
QuestionRatingModel.colorsCalculated = false;
__decorate([
    property({ defaultValue: false })
], QuestionRatingModel.prototype, "inputHasValue", void 0);
__decorate([
    property()
], QuestionRatingModel.prototype, "autoGenerate", void 0);
__decorate([
    property()
], QuestionRatingModel.prototype, "rateCount", void 0);
__decorate([
    property()
], QuestionRatingModel.prototype, "displayRateDescriptionsAsExtremeItems", void 0);
__decorate([
    property()
], QuestionRatingModel.prototype, "displayMode", void 0);
__decorate([
    property()
], QuestionRatingModel.prototype, "rateDescriptionLocation", void 0);
__decorate([
    property()
], QuestionRatingModel.prototype, "rateType", void 0);
__decorate([
    property()
], QuestionRatingModel.prototype, "scaleColorMode", void 0);
__decorate([
    property()
], QuestionRatingModel.prototype, "rateColorMode", void 0);
Serializer.addClass("rating", [
    { name: "showCommentArea:switch", layout: "row", visible: true, category: "general" },
    {
        name: "rateType",
        alternativeName: "rateDisplayMode",
        default: "labels",
        category: "rateValues",
        choices: ["labels", "stars", "smileys"],
        visibleIndex: 1
    },
    {
        name: "scaleColorMode",
        category: "rateValues",
        default: "monochrome",
        choices: ["monochrome", "colored"],
        visibleIf: function (obj) {
            return obj.rateDisplayMode == "smileys";
        },
        visibleIndex: 2
    },
    {
        name: "rateColorMode",
        category: "rateValues",
        default: "scale",
        choices: ["default", "scale"],
        visibleIf: function (obj) {
            return obj.rateDisplayMode == "smileys" && obj.scaleColorMode == "monochrome";
        },
        visibleIndex: 3
    },
    {
        name: "autoGenerate",
        category: "rateValues",
        default: true,
        choices: [true, false],
        visibleIndex: 5
    },
    {
        name: "rateCount:number",
        default: 5,
        category: "rateValues",
        visibleIndex: 4,
        onSettingValue: (obj, val) => {
            if (val < 2)
                return 2;
            if (val > settings.ratingMaximumRateValueCount && val > obj.rateValues.length)
                return settings.ratingMaximumRateValueCount;
            if (val > 10 && obj.rateDisplayMode == "smileys")
                return 10;
            return val;
        },
    },
    {
        name: "rateValues:itemvalue[]",
        baseValue: function () {
            return getLocaleString("choices_Item");
        },
        category: "rateValues",
        visibleIf: function (obj) {
            return !obj.autoGenerate;
        },
        visibleIndex: 6
    },
    {
        name: "rateMin:number", default: 1,
        onSettingValue: (obj, val) => {
            return val > obj.rateMax - obj.rateStep ? obj.rateMax - obj.rateStep : val;
        },
        visibleIf: function (obj) {
            return !!obj.autoGenerate;
        },
        visibleIndex: 7
    },
    {
        name: "rateMax:number", default: 5,
        onSettingValue: (obj, val) => {
            return val < obj.rateMin + obj.rateStep ? obj.rateMin + obj.rateStep : val;
        },
        visibleIf: function (obj) {
            return !!obj.autoGenerate;
        },
        visibleIndex: 8
    },
    {
        name: "rateStep:number", default: 1, minValue: 0.1,
        onSettingValue: (obj, val) => {
            if (val <= 0)
                val = 1;
            if (val > obj.rateMax - obj.rateMin)
                val = obj.rateMax - obj.rateMin;
            return val;
        },
        visibleIf: function (obj) {
            return !!obj.autoGenerate;
        },
        visibleIndex: 9
    },
    {
        name: "minRateDescription",
        alternativeName: "mininumRateDescription",
        serializationProperty: "locMinRateDescription",
        visibleIndex: 18
    },
    {
        name: "maxRateDescription",
        alternativeName: "maximumRateDescription",
        serializationProperty: "locMaxRateDescription",
        visibleIndex: 19
    },
    {
        name: "displayRateDescriptionsAsExtremeItems:boolean",
        default: false,
        visibleIndex: 21,
        visibleIf: function (obj) {
            return obj.rateType == "labels";
        }
    },
    {
        name: "rateDescriptionLocation",
        default: "leftRight",
        choices: ["leftRight", "top", "bottom", "topBottom"],
        visibleIndex: 20
    },
    {
        name: "displayMode",
        default: "auto",
        choices: ["auto", "buttons", "dropdown"],
        visibleIndex: 0
    },
    { name: "itemComponent", visible: false,
        defaultFunc: (obj) => {
            if (!obj)
                return "sv-rating-item";
            if (!!obj.getOriginalObj)
                obj = obj.getOriginalObj();
            return obj.getDefaultItemComponent();
        } }
], function () {
    return new QuestionRatingModel("");
}, "question");
QuestionFactory.Instance.registerQuestion("rating", (name) => {
    return new QuestionRatingModel(name);
});

class SliderLabelItemValue extends ItemValue {
    getBaseType() {
        return "sliderlabel";
    }
    onGetText(text) {
        if (!!text || !this.locOwner)
            return super.onGetText(text);
        return this.locOwner.getTextByItem(this);
    }
    getCorrectValue(value) {
        if (typeof value === "number")
            return value;
        if (Helpers.isNumber(value)) {
            return parseFloat(value.toString());
        }
        return this.value || 0;
    }
}
/**
 * A class that describes the Slider question type.
 *
 * [View Slider Demo](https://surveyjs.io/form-library/examples/single-value-slider-input/ (linkStyle))
 *
 * [View Range Slider Demo](https://surveyjs.io/form-library/examples/dual-range-slider-input/ (linkStyle))
 */
class QuestionSliderModel extends Question {
    /**
     * Sets the interval between selectable scale values.
     *
     * Default value: 1
     *
     * [View Slider Demo](https://surveyjs.io/form-library/examples/single-value-slider-input/ (linkStyle))
     *
     * [View Range Slider Demo](https://surveyjs.io/form-library/examples/dual-range-slider-input/ (linkStyle))
     */
    get step() {
        // if (this.segmentCount) {
        //   return (this.renderedMax - this.renderedMin) / this.segmentCount;
        // }
        return this.getPropertyValue("step");
    }
    set step(val) {
        this.setPropertyValue("step", val);
    }
    /**
     * Defines how many auto-generated labels should be displayed along the slider scale. Ignored if the [`customLabels`](#customLabels) property is set.
     *
     * Default value: -1 (the number of labels is calculated automatically based on the [`min`](#min) and [`max`](#max) values)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/customize-slider-scale-labels/ (linkStyle))
     * @see showLabels
     * @see labelFormat
     */
    get labelCount() {
        if (this.customLabels.length > 0)
            return this.customLabels.length;
        if (this.tickSize) {
            return Math.round(100 / this.tickSize) + 2;
        }
        return this.getPropertyValue("labelCount");
    }
    set labelCount(val) {
        this.setPropertyValue("labelCount", val);
    }
    /**
     * Specifies custom scale labels. Overrides auto-generated labels if defined.
     *
     * This property accepts an array of numbers or objects with the following fields:
     *
     * - `value`: `number`\
     * The scale value where the label should appear.
     *
     * - `text`: `string`\
     * The label text to display.
     *
     * Numbers and objects can be combined in the same array. For instance, the following slider configuration specifies textual labels for extreme scale points and adds numeric labels between them.
     *
     * ```js
     * const surveyJson = {
     *   "elements": [
     *     {
     *       "type": "slider",
     *       // ...
     *       "customLabels": [
     *         { value: 0, text: "Lowest" },
     *         20,
     *         40
     *         60
     *         80,
     *         { value: 100, text: "Highest" },
     *       ]
     *     }
     *   ]
     * };
     * ```
     *
     * [View Demo](https://surveyjs.io/form-library/examples/customize-slider-scale-labels/ (linkStyle))
     * @see showLabels
     * @see labelCount
     * @see labelFormat
     */
    get customLabels() {
        return this.getPropertyValue("customLabels");
    }
    set customLabels(val) {
        this.setPropertyValue("customLabels", val);
    }
    /**
     * Allows the start and end thumbs to cross over each other. If `false`, the thumbs cannot be swapped. Applies only if [`sliderType`](#sliderType) is `"range"`.
     *
     * Default value: `false` if [`minRangeLength`](#minRangeLength) is defined, `true` otherwise.
     */
    get allowSwap() {
        if (this.minRangeLength)
            return false;
        return this.getPropertyValue("allowSwap", true);
    }
    set allowSwap(val) {
        this.setPropertyValue("allowSwap", val);
    }
    constructor(name) {
        super(name);
        this.getThumbContainerCss = (thumbNumber) => {
            return new CssClassBuilder()
                .append(this.cssClasses.thumbContainer)
                .append(this.cssClasses.thumbContainerIndeterminateMode, !!this.isIndeterminate)
                .append(this.cssClasses.thumbContainerFocusedMode, thumbNumber === this.focusedThumb)
                .toString();
        };
        this.getLabelCss = (locText) => {
            return new CssClassBuilder()
                .append(this.cssClasses.label)
                .append(this.cssClasses.labelLongMod, locText.renderedHtml.length > 10)
                .toString();
        };
        this.isIndeterminate = false;
        this.getTrackPercentLeft = () => {
            const { renderedValue, sliderType, renderedMin: min } = this;
            let result;
            if (sliderType === "single") {
                if (renderedValue[0] > 0) {
                    result = this.getPercent(Math.max(0, min));
                }
                else {
                    result = this.getPercent(renderedValue[0]);
                }
            }
            else {
                result = this.getPercent(Math.min(...renderedValue));
            }
            return result;
        };
        this.getTrackPercentRight = () => {
            const { renderedValue, sliderType, renderedMax: max } = this;
            let result;
            if (sliderType === "single") {
                if (renderedValue[0] > 0) {
                    result = this.getPercent(renderedValue[0]);
                }
                else {
                    result = this.getPercent(Math.min(0, max));
                }
            }
            else {
                result = this.getPercent(Math.max(...renderedValue));
            }
            return 100 - result;
        };
        this.getPercent = (value) => {
            const { renderedMax: max, renderedMin: min } = this;
            const fullRange = max - min;
            return (Math.abs(value - min) / fullRange) * 100;
        };
        this.ensureMaxRangeBorders = (newValue, inputNumber) => {
            const { renderedMaxRangeLength, renderedValue } = this;
            const value = renderedValue.slice();
            const oldValue = value[inputNumber];
            let isOutOfRange = false;
            value[inputNumber] = newValue;
            for (let i = 0; i < value.length - 1; i++) {
                if (Math.abs(value[i] - value[i + 1]) > renderedMaxRangeLength) {
                    isOutOfRange = true;
                    break;
                }
            }
            return isOutOfRange ? oldValue : newValue;
        };
        this.ensureMinRangeBorders = (newValue, inputNumber) => {
            const { renderedMinRangeLength, renderedValue, allowSwap, renderedMin: min, renderedMax: max } = this;
            const value = renderedValue.slice();
            const oldValue = value[inputNumber];
            let isOutOfRange = false;
            value[inputNumber] = newValue;
            for (let i = 0; i < value.length - 1; i++) {
                if (Math.abs(value[i] - value[i + 1]) < renderedMinRangeLength) {
                    isOutOfRange = true;
                    break;
                }
            }
            if (!allowSwap) {
                const prevValue = inputNumber > 0 ? value[inputNumber - 1] : min;
                const nextValue = inputNumber < value.length - 1 ? value[inputNumber + 1] : max;
                if (newValue <= prevValue || newValue >= nextValue) {
                    isOutOfRange = true;
                }
            }
            return isOutOfRange ? oldValue : newValue;
        };
        this.getClosestToStepValue = (value) => {
            const { step, renderedMin: min, renderedMax: max } = this;
            const maxByStep = min + Math.trunc((max - min) / step) * step;
            let result = min + Math.round((value - min) / step) * step;
            result = Math.min(maxByStep, result);
            return result;
        };
        this.handleRangeOnChange = (event) => {
            if (!this.isRangeMoving)
                return;
            const { renderedMax: max, renderedMin: min, renderedValue, ensureMaxRangeBorders, ensureMinRangeBorders } = this;
            const inputNode = event.target;
            const diff = this.oldInputValue - +inputNode.value;
            this.oldInputValue = +inputNode.value;
            let borderArrived = false;
            for (let i = 0; i < renderedValue.length; i++) {
                let newVal = renderedValue[i] - diff;
                newVal = ensureMaxRangeBorders(newVal, i);
                newVal = ensureMinRangeBorders(newVal, i);
                if (newVal <= max && newVal >= min) {
                    renderedValue.splice(i, 1, newVal);
                }
                else {
                    borderArrived = true;
                }
            }
            if (borderArrived) {
                borderArrived = false;
                return;
            }
        };
        this.prepareInputRangeForMoving = (event, rootNode) => {
            const { renderedMax: max, renderedMin: min } = this;
            this.isRangeMoving = true;
            this.animatedThumb = false;
            //const inputNode = this.rangeInputRef.current;
            const inputNode = event.target;
            inputNode.style.setProperty("--sjs-range-slider-range-input-thumb-width", "20px");
            inputNode.style.setProperty("--sjs-range-slider-range-input-thumb-left", "initial");
            inputNode.style.setProperty("--sjs-range-slider-range-input-thumb-position", "static");
            const leftPercent = ((event.clientX - rootNode.getBoundingClientRect().x) / rootNode.getBoundingClientRect().width) * 100;
            const newInputValue = leftPercent / 100 * (max - min) + min;
            inputNode.value = "" + newInputValue;
            this.oldInputValue = newInputValue;
        };
        this.handleRangePointerDown = (event, rootNode) => {
            const { dragOrClickHelper, allowDragRange, step, prepareInputRangeForMoving } = this;
            const inputNode = event.target;
            if (step) {
                inputNode.step = "0.1";
            }
            if (allowDragRange) {
                dragOrClickHelper.dragHandler = () => { prepareInputRangeForMoving.call(this, event, rootNode); };
                dragOrClickHelper.onPointerDown(event);
            }
        };
        this.handleRangePointerUp = (event, rootNode) => {
            const { step, renderedValue, getClosestToStepValue } = this;
            const inputNode = event.target;
            if (this.isRangeMoving) {
                this.refreshInputRange();
                this.isRangeMoving = false;
                if (step) {
                    // const input = this.rangeInputRef.current as HTMLInputElement; //TODO
                    inputNode.step = "" + step;
                    for (let i = 0; i < renderedValue.length; i++) {
                        renderedValue[i] = getClosestToStepValue(renderedValue[i]);
                    }
                    this.setSliderValue(renderedValue);
                }
                return;
            }
            // const inputNode = this.rangeInputRef.current;
            inputNode.style.setProperty("--sjs-range-slider-range-input-thumb-width", "0px");
            inputNode.style.setProperty("--sjs-range-slider-range-input-thumb-left", "initial");
            inputNode.style.setProperty("--sjs-range-slider-range-input-thumb-position", "static");
            this.setValueByClickOnPath(event, rootNode);
        };
        this.refreshInputRange = (inputRef) => {
            const { allowDragRange, renderedValue, getPercent } = this;
            if (!allowDragRange)
                return;
            //if (!this.rangeInputRef.current) return;
            const input = inputRef || DomDocumentHelper.getDocument().getElementById("sjs-slider-input-range-input"); //TODO
            if (!input)
                return;
            const percentLastValue = getPercent(renderedValue[renderedValue.length - 1]);
            const percentFirstValue = getPercent(renderedValue[0]);
            let percent = percentLastValue - percentFirstValue;
            //const inputNode = this.rangeInputRef.current;
            input.style.setProperty("--sjs-range-slider-range-input-thumb-width", `calc(${percent}% - 20px - 20px)`); //TODO 20px is thumb width remove hardcode
            input.style.setProperty("--sjs-range-slider-range-input-thumb-left", `calc(${percentFirstValue}% + 20px)`);
            input.style.setProperty("--sjs-range-slider-range-input-thumb-position", "absolute");
        };
        this.setSliderValue = (newValue) => {
            if (!this.isReadOnly && !this.isDisabledAttr && !this.isPreviewStyle && !this.isDisabledStyle) {
                let result;
                if (this.sliderType === "single") {
                    result = Array.isArray(newValue) ? newValue[0] : newValue;
                }
                else if (this.sliderType === "range") {
                    result = newValue;
                }
                this.value = result;
                this.resetPropertyValue("renderedValue");
            }
        };
        this.setValueByClickOnPath = (event, rootNode) => {
            const { renderedMax: max, renderedMin: min } = this;
            let isRtl = DomDocumentHelper.getComputedStyle(DomDocumentHelper.getBody()).direction == "rtl";
            let percent = ((event.clientX - rootNode.getBoundingClientRect().x) / rootNode.getBoundingClientRect().width) * 100;
            if (isRtl)
                percent = 100 - percent;
            let newValue = percent / 100 * (max - min) + min;
            this.setValueByClick(newValue, event.target);
        };
        this.setValueByClick = (newValue, inputNode) => {
            const { step, getClosestToStepValue, ensureMaxRangeBorders, ensureMinRangeBorders, renderedValue, refreshInputRange, setSliderValue } = this;
            this.animatedThumb = true;
            const value = renderedValue.slice();
            let thumbIndex = 0;
            for (let i = 0; i < value.length; i++) {
                const currentMinValueDiff = Math.abs(value[thumbIndex] - newValue);
                const newMinValueDiff = Math.abs(value[i] - newValue);
                if (newMinValueDiff < currentMinValueDiff) {
                    thumbIndex = i;
                }
            }
            if (value.length > 1) {
                newValue = ensureMaxRangeBorders(newValue, thumbIndex);
                newValue = ensureMinRangeBorders(newValue, thumbIndex);
            }
            value[thumbIndex] = newValue;
            if (step) {
                const currentValue = renderedValue.slice();
                for (let i = 0; i < value.length; i++) {
                    const currentValueStep = currentValue[i] / step;
                    const newValueStep = value[i] / step;
                    const newValueRound = Math.round(newValueStep);
                    if (newValueRound === currentValueStep) {
                        if (newValueStep > currentValueStep) {
                            value[i] = value[i] + step;
                        }
                        else if (newValueStep < currentValueStep) {
                            value[i] = value[i] - step;
                        }
                    }
                    value[i] = getClosestToStepValue(value[i]);
                }
            }
            setSliderValue(value);
            //refreshInputRange(this.rangeInputRef.current);
            refreshInputRange();
        };
        this.handleOnChange = (event, inputNumber) => {
            if (this.oldValue === null)
                return; // Firefox raise one more OnChange after PointerUp and break the value
            const { allowSwap, ensureMaxRangeBorders, ensureMinRangeBorders, renderedValue } = this;
            const inputNode = event.target;
            let newValue = +inputNode.value;
            if (renderedValue.length > 1) {
                newValue = ensureMaxRangeBorders(newValue, inputNumber);
                if (!allowSwap) {
                    newValue = ensureMinRangeBorders(newValue, inputNumber);
                }
            }
            renderedValue.splice(inputNumber, 1, newValue);
        };
        this.handlePointerDown = (e) => {
            const { step, renderedValue } = this;
            if (step) {
                for (let i = 0; i < renderedValue.length; i++) {
                    const input = DomDocumentHelper.getDocument().getElementById(`sjs-slider-input-${i}`); //TODO
                    input.step = 0.1;
                }
            }
            this.oldValue = this.renderedValue;
            this.animatedThumb = false;
        };
        this.handlePointerUp = (event) => {
            event.stopPropagation();
            const { step, focusedThumb, renderedValue, allowSwap, renderedMinRangeLength, getClosestToStepValue, refreshInputRange, setSliderValue } = this;
            const focusedThumbValue = renderedValue[focusedThumb];
            event.target;
            renderedValue.sort((a, b) => a - b);
            this.focusedThumb = renderedValue.indexOf(focusedThumbValue);
            if (step) {
                for (let i = 0; i < renderedValue.length; i++) {
                    renderedValue[i] = getClosestToStepValue(renderedValue[i]);
                    const input = DomDocumentHelper.getDocument().getElementById(`sjs-slider-input-${i}`); //TODO
                    input.step = step;
                }
            }
            if (allowSwap) {
                for (let i = 0; i < renderedValue.length - 1; i++) {
                    if (Math.abs(renderedValue[i] - renderedValue[i + 1]) < renderedMinRangeLength) {
                        this.setPropertyValue("renderedValue", this.oldValue);
                        break;
                    }
                }
            }
            setSliderValue(renderedValue);
            refreshInputRange();
            this.oldValue = null;
        };
        this.handleKeyDown = (event) => {
            this.oldValue = this.renderedValue;
            this.animatedThumb = true;
        };
        this.handleKeyUp = (event) => {
            this.oldValue = null;
            this.setSliderValue(this.renderedValue);
        };
        this.handleOnFocus = (inputNumber) => {
            this.focusedThumb = inputNumber;
        };
        this.handleOnBlur = () => {
            this.focusedThumb = null;
        };
        this.handleLabelPointerUp = (event, newValue) => {
            const inputNode = event.target;
            if (isNaN(newValue))
                return;
            this.setValueByClick(newValue, inputNode);
        };
        this.getTooltipValue = (tooltipNumber) => {
            const { step, getClosestToStepValue, renderedValue, tooltipFormat, formatNumber } = this;
            let value = renderedValue[tooltipNumber];
            value = step ? getClosestToStepValue(value) : value;
            value = formatNumber(value);
            return tooltipFormat.replace("{0}", "" + value);
        };
        this.getLabelText = (labelNumber) => {
            const { step, renderedMax: max, renderedMin: min, renderedLabelCount: labelCount, formatNumber } = this;
            const fullRange = max - min;
            const isDecimal = step % 1 != 0;
            const count = labelCount - 1;
            let labelStep = count === 0 ? 0 : labelNumber * fullRange / count;
            return isDecimal ? "" + formatNumber(labelStep + min) : "" + Math.round(labelStep + min);
        };
        this.getLabelPosition = (labelNumber) => {
            const { max, min, renderedLabelCount: labelCount, customLabels } = this;
            const count = labelCount - 1;
            if (count === 0)
                return 0;
            const fullRange = max - min;
            const labelStep = min + labelNumber * fullRange / count;
            return labelStep;
        };
        this.isRangeMoving = false;
        this.oldInputValue = null;
        this.oldValue = null;
        this.calcRenderedValue = () => {
            const { renderedMax: max, renderedMin: min, renderedMaxRangeLength, getClosestToStepValue, sliderType } = this;
            let result;
            if (sliderType === "single") {
                result = this.ensureValueRespectMinMax(this.value);
                if (typeof result === "undefined" || result === null || result.length === 0) {
                    this.isIndeterminate = true;
                    return this.isNegativeScale ? [Math.min(max, 0)] : [min];
                }
                else {
                    return Array.isArray(result) ? [result[0]] : [result];
                }
            }
            result = Array.isArray(this.value) ? this.value.slice() : [];
            if (result.length === 0) {
                const fullRange = max - min;
                this.isIndeterminate = true;
                if (Math.abs(fullRange) > renderedMaxRangeLength) {
                    const range = (fullRange - renderedMaxRangeLength) / 2;
                    return [getClosestToStepValue(min + range), getClosestToStepValue(max - range)];
                }
                return [min, max]; // TODO support several values 3 and more
            }
            return result.map(v => this.ensureValueRespectMinMax(v));
        };
        this.createItemValues("customLabels");
        this.dragOrClickHelper = new DragOrClickHelper(null, false);
        this.initPropertyDependencies();
    }
    get generatedLabels() {
        return this.getPropertyValue("generatedLabels", undefined, () => this.calcGeneratedLabels());
    }
    get tooltipVisibilityPG() {
        return this.tooltipVisibility === "auto";
    }
    set tooltipVisibilityPG(newValue) {
        this.tooltipVisibility = newValue ? "auto" : "never";
    }
    get renderedValue() {
        return this.getPropertyValue("renderedValue", undefined, () => this.calcRenderedValue());
    }
    set renderedValue(val) {
        this.setPropertyValue("renderedValue", val);
    }
    getType() {
        return "slider";
    }
    get rootCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.root)
            .append(this.cssClasses.rootSingleMode, this.sliderType === "single")
            .append(this.cssClasses.rootNegativeScaleMode, !!this.isNegativeScale)
            .append(this.cssClasses.rootDesignMode, !!this.isDesignMode)
            .append(this.cssClasses.rootAnimatedThumbMode, !!this.animatedThumb)
            .toString();
    }
    get tooltipCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.tooltip)
            .append(this.cssClasses.tooltipOnHoverMode, this.tooltipVisibility === "auto")
            .toString();
    }
    get renderedLabelCount() {
        return this.labelCount < 0 ? 6 : this.labelCount;
    }
    get renderedMax() {
        return this.max; // TODO
    }
    get renderedMin() {
        return this.min; // TODO
    }
    get renderedMaxRangeLength() {
        var _a;
        return (_a = this.maxRangeLength) !== null && _a !== void 0 ? _a : this.renderedMax - this.renderedMin;
    }
    get renderedMinRangeLength() {
        var _a;
        return (_a = this.minRangeLength) !== null && _a !== void 0 ? _a : this.step;
    }
    get renderedLabels() {
        const generatedLabels = this.generatedLabels; // need this const due to observability reasons
        const customLabels = this.customLabels; // need this const due to observability reasons
        if (this.autoGenerate)
            return generatedLabels;
        return customLabels;
    }
    get isNegativeScale() {
        return this.renderedMin < 0;
    }
    getTextByItem(item) {
        const res = item.value.toString();
        return this.labelFormat.replace("{0}", "" + res);
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        if (this.jsonObj.customLabels !== undefined) {
            this.autoGenerate = false;
        }
        if (!this.isDesignMode && this.sliderType === "range") {
            this.createNewArray("value");
        }
    }
    updateValueFromSurvey(newValue, clearData) {
        newValue = this.ensureValueRespectMinMax(newValue);
        super.updateValueFromSurvey(newValue, clearData);
        if (this.isIndeterminate) {
            this.isIndeterminate = false;
        }
        this.resetPropertyValue("renderedValue");
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        if (this.maxValueExpression) {
            let maxRunner = this.getDefaultRunner(this.defaultExpressionRunner, this.maxValueExpression);
            if (!!maxRunner && maxRunner.canRun) {
                maxRunner.onRunComplete = (res) => {
                    this.max = res !== null && res !== void 0 ? res : this.renderedMax;
                };
                maxRunner.run(values, properties);
            }
        }
        if (this.minValueExpression) {
            let minRunner = this.getDefaultRunner(this.defaultExpressionRunner, this.minValueExpression);
            if (!!minRunner && minRunner.canRun) {
                minRunner.onRunComplete = (res) => {
                    this.min = res !== null && res !== void 0 ? res : this.renderedMin;
                };
                minRunner.run(values, properties);
            }
        }
    }
    initPropertyDependencies() {
        // this.registerSychProperties(["segmentCount"],
        //   () => {
        //     if (this.segmentCount) {
        //       this.step = (this.renderedMax - this.renderedMin) / this.segmentCount;
        //     }
        //   }
        // );
        // this.registerSychProperties(["step"],
        //   () => {
        //     if (this.step) {
        //       this.segmentCount = (this.renderedMax - this.renderedMin) / this.step;
        //     }
        //   }
        // );
        this.registerFunctionOnPropertiesValueChanged(["min", "max", "step", "autoGenerate", "labelFormat", "labelCount"], () => {
            this.resetPropertyValue("generatedLabels");
            this.locStrsChanged();
        });
        this.registerSychProperties(["autoGenerate"], () => {
            if (!this.autoGenerate && this.customLabels.length === 0) {
                this.setPropertyValue("customLabels", this.calcGeneratedLabels());
            }
            if (this.autoGenerate) {
                this.customLabels.splice(0, this.customLabels.length);
            }
        });
        this.registerFunctionOnPropertiesValueChanged(["min", "max", "step", "maxRangeLength", "minRangeLength", "sliderType"], () => {
            this.resetPropertyValue("renderedValue");
        });
    }
    setNewValue(newValue) {
        newValue = this.ensureValueRespectMinMax(newValue);
        super.setNewValue(newValue);
        if (this.isIndeterminate) {
            this.isIndeterminate = false;
        }
        this.resetPropertyValue("renderedValue");
    }
    setDefaultValue() {
        super.setDefaultValue();
        const val = this.defaultValue;
        if (this.sliderType === "single" && Array.isArray(val)) {
            this.setSliderValue(val);
        }
        this.resetPropertyValue("renderedValue");
    }
    getDefaultTitleActions() {
        const actions = [];
        if (!this.isDesignMode) {
            const clearAction = new Action({
                locTitleName: "clearCaption",
                id: `sv-clr-btn-${this.id}`,
                action: () => { this.clearValue(true); },
                innerCss: this.cssClasses.clearButton,
                visible: new ComputedUpdater(() => this.allowClear && !this.isReadOnly)
            });
            actions.push(clearAction);
        }
        return actions;
    }
    getItemValueType() {
        return "sliderlabel";
    }
    createLabelItem(value) {
        const res = new SliderLabelItemValue(value);
        res.locOwner = this;
        return res;
    }
    calcGeneratedLabels() {
        const labels = [];
        for (let i = 0; i < this.renderedLabelCount; i++) {
            labels.push(this.createLabelItem(this.getLabelPosition(i)));
        }
        return labels;
    }
    formatNumber(number) {
        return parseFloat(number.toFixed(4));
    }
    ensureValueRespectMinMax(value) {
        if (!Array.isArray(value)) {
            if (value < this.min)
                value = this.min;
            if (value > this.max)
                value = this.max;
        }
        else {
            value.forEach((el, i, array) => {
                if (el < this.min)
                    value[i] = this.min;
                if (el > this.max)
                    value[i] = this.max;
                if (i === 0) {
                    if (typeof el === "undefined" || el === null)
                        value[i] = this.min;
                }
                else if (i === array.length - 1) {
                    if (typeof el === "undefined" || el === null)
                        value[i] = this.max;
                }
            });
        }
        return value;
    }
}
__decorate([
    property({ defaultValue: "single" })
], QuestionSliderModel.prototype, "sliderType", void 0);
__decorate([
    property({ defaultValue: 100 })
], QuestionSliderModel.prototype, "max", void 0);
__decorate([
    property({ defaultValue: 0 })
], QuestionSliderModel.prototype, "min", void 0);
__decorate([
    property({ defaultValue: null })
], QuestionSliderModel.prototype, "maxValueExpression", void 0);
__decorate([
    property({ defaultValue: null })
], QuestionSliderModel.prototype, "minValueExpression", void 0);
__decorate([
    property({ defaultValue: null })
], QuestionSliderModel.prototype, "maxRangeLength", void 0);
__decorate([
    property({ defaultValue: null })
], QuestionSliderModel.prototype, "minRangeLength", void 0);
__decorate([
    property({ defaultValue: "{0}" })
], QuestionSliderModel.prototype, "tooltipFormat", void 0);
__decorate([
    property({ defaultValue: "{0}" })
], QuestionSliderModel.prototype, "labelFormat", void 0);
__decorate([
    property({ defaultValue: "auto" })
], QuestionSliderModel.prototype, "tooltipVisibility", void 0);
__decorate([
    property({ defaultValue: true })
], QuestionSliderModel.prototype, "showLabels", void 0);
__decorate([
    property({ defaultValue: true })
], QuestionSliderModel.prototype, "autoGenerate", void 0);
__decorate([
    property({ defaultValue: true })
], QuestionSliderModel.prototype, "allowDragRange", void 0);
__decorate([
    property({ defaultValue: null })
], QuestionSliderModel.prototype, "tickSize", void 0);
__decorate([
    property({ defaultValue: false })
], QuestionSliderModel.prototype, "allowClear", void 0);
__decorate([
    property({ defaultValue: null })
], QuestionSliderModel.prototype, "focusedThumb", void 0);
__decorate([
    property({ defaultValue: null })
], QuestionSliderModel.prototype, "animatedThumb", void 0);
function getCorrectMinMax(min, max, isMax, step) {
    let val = isMax ? max : min;
    if (min >= max)
        return isMax ? min + step : max - step;
    return val;
}
Serializer.addClass("sliderlabel", [
    { name: "!value:number" },
    { name: "visibleIf", visible: false },
    { name: "enableIf", visible: false }
], (value) => new SliderLabelItemValue(value), "itemvalue");
Serializer.addClass("slider", [
    {
        name: "sliderType",
        default: "single",
        choices: ["single", "range"],
    },
    {
        name: "autoGenerate",
        default: true,
        isSerializable: false,
        choices: [true, false]
    },
    {
        name: "min:number",
        default: 0,
        onSettingValue: (obj, val) => {
            return getCorrectMinMax(val, obj.max, false, obj.step);
        },
    },
    {
        name: "max:number",
        default: 100,
        onSettingValue: (obj, val) => {
            return getCorrectMinMax(obj.min, val, true, obj.step);
        },
    },
    {
        name: "step:number",
        default: 1,
        // visibleIf: function (obj: any) {
        //   return obj.autoGenerate;
        // },
    },
    // {
    //   name: "segmentCount:number",
    //   // visibleIf: function (obj: any) {
    //   //   return obj.autoGenerate;
    //   // },
    // },
    {
        name: "minValueExpression",
        type: "expression"
    },
    {
        name: "maxValueExpression",
        type: "expression"
    },
    {
        name: "minRangeLength:number",
        visibleIf: function (obj) {
            return obj.sliderType === "range";
        },
    },
    {
        name: "maxRangeLength:number",
        visibleIf: function (obj) {
            return obj.sliderType === "range";
        }
    },
    {
        name: "customLabels:sliderlabel[]",
        visibleIf: function (obj) {
            return !obj.autoGenerate;
        },
    },
    {
        name: "showLabels:boolean",
        default: true,
    },
    {
        name: "tooltipVisibility:string",
        default: "auto",
        visible: false,
        choices: ["auto", "never"]
    },
    {
        name: "tooltipVisibilityPG:boolean",
        default: true,
        isSerializable: false,
    },
    {
        name: "labelFormat:string",
        default: "{0}"
    },
    {
        name: "tooltipFormat:string",
        default: "{0}"
    },
    {
        name: "allowDragRange:boolean",
        default: true,
        visible: false,
        visibleIf: function (obj) {
            return obj.sliderType === "range";
        },
    },
    {
        name: "allowSwap:boolean",
        default: true,
        visibleIf: function (obj) {
            return obj.sliderType === "range";
        },
    },
    {
        name: "labelCount:number",
        default: -1,
        visibleIf: function (obj) {
            return obj.autoGenerate;
        },
    },
    {
        name: "allowClear:boolean",
        default: false,
    },
], function () {
    return new QuestionSliderModel("");
}, "question");
QuestionFactory.Instance.registerQuestion("slider", (name) => {
    return new QuestionSliderModel(name);
});

/**
 * A class that describes the Yes/No (Boolean) question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-boolean/ (linkStyle))
 */
class QuestionBooleanModel extends Question {
    constructor(name) {
        super(name);
        this.createLocalizableString("labelFalse", this, true, "booleanUncheckedLabel");
        this.createLocalizableString("labelTrue", this, true, "booleanCheckedLabel");
    }
    getType() {
        return "boolean";
    }
    isLayoutTypeSupported(layoutType) {
        return true;
    }
    supportAutoAdvance() {
        return this.renderAs !== "checkbox";
    }
    get isIndeterminate() {
        return this.isEmpty();
    }
    get hasTitle() {
        return true;
    }
    /**
     * Gets or sets the question value as a Boolean value.
     *
     * If you set the `valueTrue` and `valueFalse` properties, the `value` property contains their values instead of Boolean values. This may be inconvenient when you operate the question value in code. To access the standard Boolean values, use the `booleanValue` property.
     * @see valueTrue
     * @see valueFalse
     */
    get booleanValue() {
        if (this.isEmpty())
            return null;
        return this.value == this.getValueTrue();
    }
    set booleanValue(val) {
        if (this.isReadOnly || this.isDesignMode) {
            return;
        }
        this.setBooleanValue(val);
    }
    get checkedValue() { return this.booleanValue; }
    set checkedValue(val) { this.booleanValue = val; }
    setBooleanValue(val) {
        if (this.isValueEmpty(val)) {
            this.value = undefined;
            this.booleanValueRendered = undefined;
        }
        else {
            this.value = val == true ? this.getValueTrue() : this.getValueFalse();
            this.booleanValueRendered = val;
        }
    }
    get defaultValue() {
        return this.getPropertyValue("defaultValue");
    }
    set defaultValue(val) {
        if (val === true)
            val = "true";
        if (val === false)
            val = "false";
        this.setPropertyValue("defaultValue", val);
        this.updateValueWithDefaults();
    }
    getDefaultValue() {
        const val = this.defaultValue;
        if (val === "indeterminate" || val === undefined || val === null)
            return undefined;
        return val == "true" ? this.getValueTrue() : this.getValueFalse();
    }
    get locTitle() {
        const original = this.getLocalizableString("title");
        if ((this.isLabelRendered && !this.showTitle || this.isValueEmpty(original.text)) && !this.isValueEmpty(this.locLabel.text))
            return this.locLabel;
        return original;
    }
    get labelRenderedAriaID() {
        return this.isLabelRendered ? this.ariaTitleId : null;
    }
    beforeDestroyQuestionElement(el) {
        super.beforeDestroyQuestionElement(el);
        this.leftAnswerElement = undefined;
    }
    get isLabelRendered() {
        return this.titleLocation === "hidden" && this.useTitleAsLabel;
    }
    get canRenderLabelDescription() {
        return this.isLabelRendered && this.hasDescription && (this.hasDescriptionUnderTitle || this.hasDescriptionUnderInput);
    }
    /**
     * Gets or sets a text label that corresponds to a positive answer.
     *
     * Default value: "Yes"
     *
     * [View Demo](https://surveyjs.io/form-library/examples/yes-no-question/ (linkStyle))
     * @see valueTrue
     * @see valueFalse
     */
    get labelTrue() {
        return this.getLocalizableStringText("labelTrue");
    }
    set labelTrue(val) {
        this.setLocalizableStringText("labelTrue", val);
    }
    get locLabelTrue() {
        return this.getLocalizableString("labelTrue");
    }
    get isDeterminated() {
        return this.booleanValue !== null && this.booleanValue !== undefined;
    }
    get locLabelLeft() {
        return this.swapOrder ? this.getLocalizableString("labelTrue") : this.getLocalizableString("labelFalse");
    }
    get locLabelRight() {
        return this.swapOrder ? this.getLocalizableString("labelFalse") : this.getLocalizableString("labelTrue");
    }
    /**
     * Gets or sets a text label that corresponds to a negative answer.
     *
     * Default value: "No"
     *
     * [View Demo](https://surveyjs.io/form-library/examples/yes-no-question/ (linkStyle))
     * @see valueTrue
     * @see valueFalse
     */
    get labelFalse() {
        return this.getLocalizableStringText("labelFalse");
    }
    set labelFalse(val) {
        this.setLocalizableStringText("labelFalse", val);
    }
    get locLabelFalse() {
        return this.getLocalizableString("labelFalse");
    }
    getValueTrue() {
        return this.valueTrue !== undefined ? this.valueTrue : true;
    }
    getValueFalse() {
        return this.valueFalse !== undefined ? this.valueFalse : false;
    }
    setDefaultValue() {
        if (this.isDefaultValueSet("true", this.valueTrue))
            this.setBooleanValue(true);
        if (this.isDefaultValueSet("false", this.valueFalse))
            this.setBooleanValue(false);
        const val = this.defaultValue;
        if (val === "indeterminate" || val === null || val === undefined)
            this.setBooleanValue(undefined);
    }
    isDefaultValueSet(defaultValueCheck, valueTrueOrFalse) {
        return this.defaultValue == defaultValueCheck || (valueTrueOrFalse !== undefined && this.defaultValue === valueTrueOrFalse);
    }
    getDisplayValueCore(keysAsText, value) {
        if (value == this.getValueTrue())
            return this.locLabelTrue.textOrHtml;
        return this.locLabelFalse.textOrHtml;
    }
    getItemCssValue(css) {
        return new CssClassBuilder()
            .append(css.item)
            .append(css.itemOnError, this.hasCssError())
            .append(css.itemDisabled, this.isDisabledStyle)
            .append(css.itemReadOnly, this.isReadOnlyStyle)
            .append(css.itemPreview, this.isPreviewStyle)
            .append(css.itemHover, !this.isDesignMode)
            .append(css.itemChecked, !!this.booleanValue)
            .append(css.itemExchanged, !!this.swapOrder)
            .append(css.itemIndeterminate, !this.isDeterminated)
            .toString();
    }
    getItemCss() {
        return this.getItemCssValue(this.cssClasses);
    }
    getCheckboxItemCss() {
        return this.getItemCssValue({
            item: this.cssClasses.checkboxItem,
            itemOnError: this.cssClasses.checkboxItemOnError,
            itemDisabled: this.cssClasses.checkboxItemDisabled,
            itemDisable: this.cssClasses.checkboxItemDisabled,
            itemReadOnly: this.cssClasses.checkboxItemReadOnly,
            itemPreview: this.cssClasses.checkboxItemPreview,
            itemChecked: this.cssClasses.checkboxItemChecked,
            itemIndeterminate: this.cssClasses.checkboxItemIndeterminate
        });
    }
    getLabelCss(checked) {
        return new CssClassBuilder()
            .append(this.cssClasses.label)
            .append(this.cssClasses.disabledLabel, this.booleanValue === !checked || this.isDisabledStyle)
            .append(this.cssClasses.labelReadOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.labelPreview, this.isPreviewStyle)
            .append(this.cssClasses.labelTrue, !this.isIndeterminate && checked === !this.swapOrder)
            .append(this.cssClasses.labelFalse, !this.isIndeterminate && checked === this.swapOrder)
            .toString();
    }
    updateValueFromSurvey(newValue, clearData = false) {
        super.updateValueFromSurvey(newValue, clearData);
    }
    onValueChanged() {
        super.onValueChanged();
    }
    get svgIcon() {
        if (this.booleanValue && this.cssClasses.svgIconCheckedId)
            return this.cssClasses.svgIconCheckedId;
        if (!this.isDeterminated && this.cssClasses.svgIconIndId)
            return this.cssClasses.svgIconIndId;
        if (!this.booleanValue && this.cssClasses.svgIconUncheckedId)
            return this.cssClasses.svgIconUncheckedId;
        return this.cssClasses.svgIconId;
    }
    get itemSvgIcon() {
        if (this.isPreviewStyle && this.cssClasses.itemPreviewSvgIconId) {
            return this.cssClasses.itemPreviewSvgIconId;
        }
        return this.cssClasses.itemSvgIconId;
    }
    get allowClick() {
        return this.isIndeterminate && !this.isInputReadOnly;
    }
    getCheckedLabel() {
        if (this.booleanValue === true) {
            return this.locLabelTrue;
        }
        else if (this.booleanValue === false) {
            return this.locLabelFalse;
        }
    }
    setQuestionValue(newValue, updateIsAnswered = true) {
        if (newValue === "true" && this.valueTrue !== "true")
            newValue = true;
        if (newValue === "false" && this.valueFalse !== "false")
            newValue = false;
        if (newValue === "indeterminate" || newValue === null)
            newValue = undefined;
        super.setQuestionValue(newValue, updateIsAnswered);
    }
    /* #region web-based methods */
    onLabelClick(event, value) {
        if (this.allowClick) {
            preventDefaults(event);
            this.booleanValue = value;
        }
        return true;
    }
    calculateBooleanValueByEvent(event, isRightClick) {
        let isRtl = false;
        if (DomDocumentHelper.isAvailable()) {
            isRtl = DomDocumentHelper.getComputedStyle(event.target).direction == "rtl";
        }
        this.booleanValue = isRtl ? !isRightClick : isRightClick;
    }
    onSwitchClickModel(event) {
        if (this.allowClick) {
            preventDefaults(event);
            var isRightClick = event.offsetX / event.target.offsetWidth > 0.5;
            this.calculateBooleanValueByEvent(event, isRightClick);
            return;
        }
        return true;
    }
    onKeyDownCore(event) {
        if (event.key === "ArrowLeft" || event.key === "ArrowRight") {
            event.stopPropagation();
            this.calculateBooleanValueByEvent(event, event.key === "ArrowRight");
        }
        return true;
    }
    /* #endregion */
    getRadioItemClass(css, value) {
        let className = undefined;
        if (css.radioItem) {
            className = css.radioItem;
        }
        if (css.radioItemChecked && value === this.booleanValue) {
            className = (className ? className + " " : "") + css.radioItemChecked;
        }
        if (this.isDisabledStyle) {
            className += " " + css.radioItemDisabled;
        }
        if (this.isReadOnlyStyle) {
            className += " " + css.radioItemReadOnly;
        }
        if (this.isPreviewStyle) {
            className += " " + css.radioItemPreview;
        }
        return className;
    }
    supportResponsiveness() {
        return true;
    }
    getCompactRenderAs() {
        return "radio";
    }
    createActionContainer(allowAdaptiveActions) {
        return super.createActionContainer(this.renderAs !== "checkbox");
    }
    //a11y
    get isNewA11yStructure() {
        return true;
    }
    get a11y_input_ariaRole() {
        return "switch";
    }
}
__decorate([
    property()
], QuestionBooleanModel.prototype, "booleanValueRendered", void 0);
__decorate([
    property({ localizable: true })
], QuestionBooleanModel.prototype, "label", void 0);
__decorate([
    property({ defaultValue: true })
], QuestionBooleanModel.prototype, "useTitleAsLabel", void 0);
__decorate([
    property({ defaultValue: false })
], QuestionBooleanModel.prototype, "swapOrder", void 0);
__decorate([
    property()
], QuestionBooleanModel.prototype, "valueTrue", void 0);
__decorate([
    property()
], QuestionBooleanModel.prototype, "valueFalse", void 0);
Serializer.addClass("boolean", [
    { name: "showCommentArea:switch", layout: "row", visible: true, category: "general" },
    { name: "label:text", serializationProperty: "locLabel", isSerializable: false, visible: false },
    {
        name: "labelTrue:text",
        serializationProperty: "locLabelTrue",
    },
    {
        name: "labelFalse:text",
        serializationProperty: "locLabelFalse",
    },
    "valueTrue",
    "valueFalse",
    { name: "swapOrder:boolean", category: "general" },
    { name: "renderAs", default: "default", visible: false },
], function () {
    return new QuestionBooleanModel("");
}, "question");
QuestionFactory.Instance.registerQuestion("boolean", (name) => {
    return new QuestionBooleanModel(name);
});

class ImageItemValue extends ItemValue {
    constructor(value, text, typeName) {
        super(value, text, typeName);
        this.typeName = typeName;
        this.createLocalizableString("imageLink", this, false);
    }
    getBaseType() { return "imageitemvalue"; }
    /**
     * The image or video link property.
     */
    get imageLink() {
        return this.getLocalizableStringText("imageLink");
    }
    set imageLink(val) {
        this.setLocalizableStringText("imageLink", val);
        this.imageNotLoaded = false;
        this.videoNotLoaded = false;
    }
    get locImageLink() {
        return this.getLocalizableString("imageLink");
    }
    getLocale() {
        return !!this.locOwner ? this.locOwner.getLocale() : "";
    }
    getMarkdownHtml(text, name, item) {
        return !!this.locOwner ? this.locOwner.getMarkdownHtml(text, name, item) : undefined;
    }
    getRenderer(name) {
        return !!this.locOwner ? this.locOwner.getRenderer(name) : null;
    }
    getRendererContext(locStr) {
        return !!this.locOwner ? this.locOwner.getRendererContext(locStr) : locStr;
    }
    getProcessedText(text) {
        return !!this.locOwner ? this.locOwner.getProcessedText(text) : text;
    }
    onErrorHandler() {
        this.contentNotLoaded = true;
    }
    set contentNotLoaded(val) {
        if (this.locOwner instanceof QuestionImagePickerModel && this.locOwner.contentMode == "video") {
            this.videoNotLoaded = val;
        }
        else {
            this.imageNotLoaded = val;
        }
    }
    get contentNotLoaded() {
        return this.locOwner instanceof QuestionImagePickerModel && this.locOwner.contentMode == "video" ? this.videoNotLoaded : this.imageNotLoaded;
    }
}
__decorate([
    property({ defaultValue: false })
], ImageItemValue.prototype, "videoNotLoaded", void 0);
__decorate([
    property({ defaultValue: false })
], ImageItemValue.prototype, "imageNotLoaded", void 0);
/**
  * A class that describes the Image Picker question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/image-picker-question/ (linkStyle))
 */
class QuestionImagePickerModel extends QuestionCheckboxBase {
    constructor(name) {
        super(name);
        //responsive mode
        this.isResponsiveValue = false;
        this.onContentLoaded = (item, event) => {
            item.contentNotLoaded = false;
            const content = event.target;
            if (this.contentMode == "video") {
                item["aspectRatio"] = content.videoWidth / content.videoHeight;
            }
            else {
                item["aspectRatio"] = content.naturalWidth / content.naturalHeight;
            }
            this._width && this.processResponsiveness(0, this._width);
        };
        this.gridColCount = undefined;
        this.colCount = 0;
        this.registerPropertyChangedHandlers(["minImageWidth", "maxImageWidth", "minImageHeight", "maxImageHeight", "visibleChoices", "colCount", "isResponsiveValue"], () => {
            if (!!this._width) {
                this.processResponsiveness(0, this._width);
            }
        });
        this.registerPropertyChangedHandlers(["imageWidth", "imageHeight"], () => {
            this.calcIsResponsive();
        });
        this.calcIsResponsive();
    }
    getType() {
        return "imagepicker";
    }
    supportAutoAdvance() {
        return !this.multiSelect;
    }
    get hasSingleInput() {
        return false;
    }
    getItemValueType() {
        return "imageitemvalue";
    }
    get isCompositeQuestion() {
        return true;
    }
    get itemFlowDirection() {
        return "row";
    }
    supportOther() { return false; }
    supportNone() { return false; }
    supportRefuse() { return false; }
    supportDontKnow() { return false; }
    isAnswerCorrect() {
        if (!this.multiSelect)
            return super.isAnswerCorrect();
        return Helpers.isArrayContainsEqual(this.value, this.correctAnswer);
    }
    /**
     * Specifies whether users can select multiple images or videos.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/image-picker-question/ (linkStyle))
     */
    get multiSelect() {
        return this.getPropertyValue("multiSelect");
    }
    set multiSelect(newValue) {
        this.setPropertyValue("multiSelect", newValue);
    }
    isItemSelected(item) {
        var val = this.value;
        const imageItemValue = item;
        if (this.isValueEmpty(val))
            return false;
        if (!imageItemValue.imageLink || imageItemValue.contentNotLoaded)
            return false;
        if (!this.multiSelect)
            return this.isTwoValueEquals(val, item.value);
        if (!Array.isArray(val))
            return false;
        for (var i = 0; i < val.length; i++) {
            if (this.isTwoValueEquals(val[i], item.value))
                return true;
        }
        return false;
    }
    getItemEnabled(item) {
        const imageItemValue = item;
        if (!imageItemValue.imageLink || imageItemValue.contentNotLoaded)
            return false;
        return super.getItemEnabled(item);
    }
    clearIncorrectValues() {
        if (this.multiSelect) {
            var val = this.value;
            if (!val)
                return;
            if (!Array.isArray(val) || val.length == 0) {
                this.clearValue(true);
                return;
            }
            var newValue = [];
            for (var i = 0; i < val.length; i++) {
                if (!this.hasUnknownValue(val[i], true)) {
                    newValue.push(val[i]);
                }
            }
            if (newValue.length == val.length)
                return;
            if (newValue.length == 0) {
                this.clearValue(true);
            }
            else {
                this.value = newValue;
            }
        }
        else {
            super.clearIncorrectValues();
        }
    }
    getDisplayValueCore(keysAsText, value) {
        if (!this.multiSelect && !Array.isArray(value))
            return super.getDisplayValueCore(keysAsText, value);
        return this.getDisplayArrayValue(keysAsText, value);
    }
    /**
     * Specifies whether to display labels under images or videos. Labels text are taken from the `text` property of each object in the [`choices`](#choices) array.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/image-picker-question/ (linkStyle))
     */
    get showLabel() {
        return this.getPropertyValue("showLabel");
    }
    set showLabel(newValue) {
        this.setPropertyValue("showLabel", newValue);
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        if (!this.isDesignMode && this.multiSelect) {
            this.createNewArray("renderedValue");
            this.createNewArray("value");
        }
        this.calcIsResponsive();
    }
    getValueCore() {
        var value = super.getValueCore();
        if (value !== undefined) {
            return value;
        }
        if (this.multiSelect) {
            return [];
        }
        return value;
    }
    convertValToArrayForMultSelect(val) {
        if (!this.multiSelect)
            return val;
        if (this.isValueEmpty(val) || Array.isArray(val))
            return val;
        return [val];
    }
    renderedValueFromDataCore(val) {
        return this.convertValToArrayForMultSelect(val);
    }
    rendredValueToDataCore(val) {
        return this.convertValToArrayForMultSelect(val);
    }
    /**
     * Specifies the height of containers for images or videos. Accepts positive numbers and CSS values.
     *
     * Default value: `auto`
     *
     * This property allows you to specify the exact image height. If you do not set it, the height will be calculated automatically based on the [`minImageHeight`](#minImageHeight) and [`maxImageHeight`](#maxImageHeight) values and available screen height.
     *
     * Use the [`imageFit`](#imageFit) property to specify how to fit the images or videos into their containers.
     * @see imageWidth
     */
    get imageHeight() {
        return this.getPropertyValue("imageHeight");
    }
    set imageHeight(val) {
        this.setPropertyValue("imageHeight", val);
    }
    get imageScale() {
        return this.survey ? this.survey["widthScale"] / 100 : 1;
    }
    get renderedImageHeight() {
        const height = this.isResponsive ? Math.floor(this.responsiveImageHeight) : this.imageHeight * this.imageScale;
        return (height ? height : 150 * this.imageScale);
    }
    /**
     * Specifies the width of containers for images or videos. Accepts positive numbers and CSS values.
     *
     * Default value: `auto`
     *
     * This property allows you to specify the exact image width. If you do not set it, the width will be calculated automatically based on the [`minImageWidth`](#minImageWidth) and [`maxImageWidth`](#maxImageWidth) values and available screen width.
     *
     * Use the [`imageFit`](#imageFit) property to specify how to fit the images or videos into their containers.
     * @see imageHeight
     */
    get imageWidth() {
        return this.getPropertyValue("imageWidth");
    }
    set imageWidth(val) {
        this.setPropertyValue("imageWidth", val);
    }
    get renderedImageWidth() {
        const width = this.isResponsive ? Math.floor(this.responsiveImageWidth) : this.imageWidth * this.imageScale;
        return (width ? width : 200 * this.imageScale);
    }
    /**
     * Specifies how to resize images or videos to fit them into their containers.
     *
     * Refer to the [`object-fit`](https://developer.mozilla.org/en-US/docs/Web/CSS/object-fit) CSS property description for information on accepted values.
     * @see imageHeight
     * @see imageWidth
     */
    get imageFit() {
        return this.getPropertyValue("imageFit");
    }
    set imageFit(val) {
        this.setPropertyValue("imageFit", val);
    }
    /**
     * Specifies the type of content that choice items display.
     *
     * Possible values:
     *
     * - `"image"` (default) - Images in one of the following formats: JPEG, GIF, PNG, APNG, SVG, BMP, ICO.
     * - `"video"` - Videos in one of the following formats: MP4, MOV, WMV, FLV, AVI, MKV.
     */
    get contentMode() {
        return this.getPropertyValue("contentMode");
    }
    set contentMode(val) {
        this.setPropertyValue("contentMode", val);
        if (val === "video") {
            this.showLabel = true;
        }
    }
    convertDefaultValue(val) {
        return val;
    }
    get inputType() {
        return this.multiSelect ? "checkbox" : "radio";
    }
    isBuiltInChoice(item) {
        return false;
    }
    addToVisibleChoices(items, isAddAll) {
        this.addNewItemToVisibleChoices(items, isAddAll);
    }
    getSelectBaseRootCss() {
        const isResponsive = this.isResponsive;
        return new CssClassBuilder()
            .append(super.getSelectBaseRootCss())
            .append(this.cssClasses.rootResponsive, isResponsive)
            .append(this.cssClasses.rootStatic, !isResponsive)
            .append(this.cssClasses.rootColumn, this.getCurrentColCount() == 1)
            .toString();
    }
    get isResponsive() {
        return this.isResponsiveValue;
    }
    get exactSizesAreEmpty() {
        return !(["imageHeight", "imageWidth"].some(propName => this[propName] !== undefined && this[propName] !== null));
    }
    calcIsResponsive() {
        this.isResponsiveValue = this.exactSizesAreEmpty;
    }
    getObservedElementSelector() {
        return classesToSelector(this.cssClasses.root);
    }
    supportResponsiveness() {
        return true;
    }
    needResponsiveness() {
        return this.supportResponsiveness();
    }
    needResponsiveWidth() {
        return this.colCount > 2;
    }
    getCurrentColCount() {
        if (this.responsiveColCount === undefined || this.colCount === 0) {
            return this.colCount;
        }
        return this.responsiveColCount;
    }
    getContainerStyle() {
        if (!this.isResponsive)
            return {};
        return {
            gridAutoFlow: !this.gridColCount ? "column" : null,
            gridTemplateColumns: this.gridColCount ? `repeat(${this.gridColCount}, 1fr)` : null
        };
    }
    processResponsiveness(_, availableWidth) {
        this._width = availableWidth = Math.floor(availableWidth);
        const calcAvailableColumnsCount = (availableWidth, minWidth, gap) => {
            let itemsInRow = Math.floor(availableWidth / (minWidth + gap));
            if ((itemsInRow + 1) * (minWidth + gap) - gap <= availableWidth)
                itemsInRow++;
            return itemsInRow;
        };
        if (this.isResponsive) {
            const itemsCount = this.choices.length + (this.isDesignMode ? 1 : 0);
            const gap = (this.gapBetweenItems || 0) * this.imageScale;
            const minWidth = this.minImageWidth * this.imageScale;
            const maxWidth = this.maxImageWidth * this.imageScale;
            const maxHeight = this.maxImageHeight * this.imageScale;
            const minHeight = this.minImageHeight * this.imageScale;
            let colCount = this.colCount;
            let width;
            const availableColumnsCount = calcAvailableColumnsCount(availableWidth, minWidth, gap);
            if (colCount === 0) {
                if ((gap + minWidth) * itemsCount - gap > availableWidth) {
                    width = Math.floor((availableWidth - gap * (availableColumnsCount - 1)) / availableColumnsCount);
                }
                else {
                    width = Math.floor(((availableWidth - gap * (itemsCount - 1)) / itemsCount));
                }
                this.gridColCount = Math.max(Math.min(itemsCount, availableColumnsCount), 1);
            }
            else {
                if (availableColumnsCount < colCount) {
                    this.responsiveColCount = Math.max(availableColumnsCount, 1);
                    colCount = this.responsiveColCount;
                }
                else {
                    this.responsiveColCount = colCount;
                }
                this.gridColCount = this.responsiveColCount;
                width = Math.floor((availableWidth - gap * (colCount - 1)) / colCount);
            }
            width = Math.max(minWidth, Math.min(width, maxWidth));
            let height = Number.MIN_VALUE;
            this.choices.forEach((item) => {
                const tempHeight = width / item["aspectRatio"];
                height = tempHeight > height ? tempHeight : height;
            });
            if (height > maxHeight) {
                height = maxHeight;
            }
            else if (height < minHeight) {
                height = minHeight;
            }
            const oldResponsiveImageWidth = this.responsiveImageWidth;
            const oldResponsiveImageHeight = this.responsiveImageHeight;
            this.responsiveImageWidth = width;
            this.responsiveImageHeight = height;
            return oldResponsiveImageWidth !== this.responsiveImageWidth || oldResponsiveImageHeight !== this.responsiveImageHeight;
        }
        return false;
    }
    triggerResponsiveness(hard = true) {
        if (hard && this.reCalcGapBetweenItemsCallback) {
            this.reCalcGapBetweenItemsCallback();
        }
        super.triggerResponsiveness(hard);
    }
    afterRender(el) {
        super.afterRender(el);
        const selector = this.getObservedElementSelector();
        const observedElement = el && selector ? el.querySelector(selector) : undefined;
        if (!!observedElement) {
            this.reCalcGapBetweenItemsCallback = () => {
                this.gapBetweenItems = Math.ceil(Number.parseFloat(DomDocumentHelper.getComputedStyle(observedElement).gap)) || 16;
            };
            this.reCalcGapBetweenItemsCallback();
        }
    }
}
__decorate([
    property({})
], QuestionImagePickerModel.prototype, "responsiveImageHeight", void 0);
__decorate([
    property({})
], QuestionImagePickerModel.prototype, "responsiveImageWidth", void 0);
__decorate([
    property({})
], QuestionImagePickerModel.prototype, "isResponsiveValue", void 0);
__decorate([
    property({})
], QuestionImagePickerModel.prototype, "maxImageWidth", void 0);
__decorate([
    property({})
], QuestionImagePickerModel.prototype, "minImageWidth", void 0);
__decorate([
    property({})
], QuestionImagePickerModel.prototype, "maxImageHeight", void 0);
__decorate([
    property({})
], QuestionImagePickerModel.prototype, "minImageHeight", void 0);
__decorate([
    property({})
], QuestionImagePickerModel.prototype, "responsiveColCount", void 0);
__decorate([
    property()
], QuestionImagePickerModel.prototype, "gridColCount", void 0);
Serializer.addClass("imageitemvalue", [{ name: "imageLink:file", serializationProperty: "locImageLink" }], (value) => new ImageItemValue(value), "itemvalue");
Serializer.addClass("responsiveImageSize", [], undefined, "number");
Serializer.addClass("imagepicker", [
    { name: "showOtherItem", visible: false },
    { name: "otherText", visible: false },
    { name: "showNoneItem", visible: false },
    { name: "showRefuseItem", visible: false },
    { name: "showDontKnowItem", visible: false },
    { name: "noneText", visible: false },
    { name: "optionsCaption", visible: false },
    { name: "otherErrorText", visible: false },
    { name: "storeOthersAsComment", visible: false },
    {
        name: "contentMode",
        default: "image",
        choices: ["image", "video"],
    },
    {
        name: "imageFit",
        default: "contain",
        choices: ["none", "contain", "cover", "fill"],
    },
    { name: "imageHeight:number", minValue: 0 },
    { name: "imageWidth:number", minValue: 0 },
    { name: "minImageWidth:responsiveImageSize", default: 200, minValue: 0 },
    { name: "minImageHeight:responsiveImageSize", default: 133, minValue: 0 },
    { name: "maxImageWidth:responsiveImageSize", default: 3000, minValue: 0 },
    { name: "maxImageHeight:responsiveImageSize", default: 3000, minValue: 0 },
    "showLabel:boolean",
    { name: "colCount:number", default: 0, choices: [0, 1, 2, 3, 4, 5] },
    "multiSelect:boolean"
], function () {
    return new QuestionImagePickerModel("");
}, "checkboxbase");
Serializer.getProperty("imagepicker", "choices").type = "imageitemvalue[]";
QuestionFactory.Instance.registerQuestion("imagepicker", (name) => {
    var q = new QuestionImagePickerModel(name);
    //q.choices = QuestionFactory.DefaultChoices;
    return q;
});

const videoSuffics = [".mp4", ".mov", ".wmv", ".flv", ".avi", ".mkv"];
const youtubeUrl = "https://www.youtube.com/";
const youtubeEmbed = "embed";
/**
  * A class that describes the Image question type. Unlike other question types, Image cannot have a title or value.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/questiontype-image/ (linkStyle))
 */
class QuestionImageModel extends QuestionNonValue {
    constructor(name) {
        super(name);
        const locImageLink = this.createLocalizableString("imageLink", this, false);
        locImageLink.onGetTextCallback = (text) => {
            return getCorrectImageLink(text, this.contentMode == "youtube");
        };
        this.createLocalizableString("altText", this, false);
        this.registerPropertyChangedHandlers(["contentMode", "imageLink"], () => this.calculateRenderedMode());
    }
    getType() {
        return "image";
    }
    get isCompositeQuestion() {
        return false;
    }
    onSurveyLoad() {
        super.onSurveyLoad();
        this.calculateRenderedMode();
    }
    /**
     * Specifies an image or video URL.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-image-and-video-to-survey/ (linkStyle))
     * @see contentMode
     */
    get imageLink() {
        return this.getLocalizableStringText("imageLink");
    }
    set imageLink(val) {
        this.setLocalizableStringText("imageLink", val);
    }
    get locImageLink() {
        return this.getLocalizableString("imageLink");
    }
    /**
     * Specifies a value for the `alt` attribute of the underlying `<img>` element.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-image-and-video-to-survey/ (linkStyle))
     */
    get altText() {
        return this.getLocalizableStringText("altText");
    }
    set altText(val) {
        this.setLocalizableStringText("altText", val);
    }
    get locAltText() {
        return this.getLocalizableString("altText");
    }
    /**
     * Specifies the height of a container for the image or video. Accepts positive numbers and CSS values.
     *
     * Default value: 150
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-image-and-video-to-survey/ (linkStyle))
     *
     * > Use the [`imageFit`](#imageFit) property to specify how to fit the image or video into the container.
     * @see imageWidth
     */
    get imageHeight() {
        return this.getPropertyValue("imageHeight");
    }
    set imageHeight(val) {
        this.setPropertyValue("imageHeight", val);
    }
    get renderedStyleHeight() {
        return this.imageHeight ? getRenderedStyleSize(this.imageHeight) : undefined;
    }
    get renderedHeight() {
        return this.imageHeight ? getRenderedSize(this.imageHeight) : undefined;
    }
    /**
     * Specifies the width of a container for the image or video. Accepts positive numbers and CSS values.
     *
     * Default value: 200
     *
     * [View Demo](https://surveyjs.io/form-library/examples/add-image-and-video-to-survey/ (linkStyle))
     *
     * > Use the [`imageFit`](#imageFit) property to specify how to fit the image or video into the container.
     * @see imageHeight
     */
    get imageWidth() {
        return this.getPropertyValue("imageWidth");
    }
    set imageWidth(val) {
        this.setPropertyValue("imageWidth", val);
    }
    get renderedStyleWidth() {
        return this.imageWidth ? getRenderedStyleSize(this.imageWidth) : undefined;
    }
    get renderedWidth() {
        return this.imageWidth ? getRenderedSize(this.imageWidth) : undefined;
    }
    /**
     * Specifies how to resize the image or video to fit it into its container.
     *
     * Refer to the [`object-fit`](https://developer.mozilla.org/en-US/docs/Web/CSS/object-fit) CSS property description for information on accepted values.
     * @see imageHeight
     * @see imageWidth
     */
    get imageFit() {
        return this.getPropertyValue("imageFit");
    }
    set imageFit(val) {
        this.setPropertyValue("imageFit", val);
    }
    /**
     * Specifies the type of content that the Image question displays.
     *
     * Possible values:
     *
     * - `"image"` - An image in one of the following formats: JPEG, GIF, PNG, APNG, SVG, BMP, ICO.
     * - `"video"` - A video in one of the following formats: MP4, MOV, WMV, FLV, AVI, MKV.
     * - `"youtube"` - A link to a YouTube video.
     * - `"auto"` (default) - Selects one of the above based on the [`imageLink`](https://surveyjs.io/form-library/documentation/questionimagemodel#imageLink) property.
     */
    get contentMode() {
        return this.getPropertyValue("contentMode");
    }
    set contentMode(val) {
        this.setPropertyValue("contentMode", val);
        if (val === "video") {
            this.showLabel = true;
        }
    }
    /**
     * Returns the type of content that the Image question displays: `"image"`, `"video"`, or `"youtube"`.
     * @see contentMode
     */
    get renderedMode() {
        return this.getPropertyValue("renderedMode", "image");
    }
    get ariaInvalid() {
        return null;
    }
    get ariaLabel() {
        return null;
    }
    get renderedAltText() {
        return this.altText || this.title;
    }
    getImageCss() {
        const imageHeightProperty = this.getPropertyByName("imageHeight");
        const imageWidthProperty = this.getPropertyByName("imageWidth");
        const isDefaultSize = imageHeightProperty.isDefaultValue(this.imageHeight) && imageWidthProperty.isDefaultValue(this.imageWidth);
        return new CssClassBuilder()
            .append(this.cssClasses.image)
            .append(this.cssClasses.adaptive, isDefaultSize)
            .toString();
    }
    onLoadHandler() {
        this.contentNotLoaded = false;
    }
    onErrorHandler() {
        this.contentNotLoaded = true;
    }
    setRenderedMode(val) {
        this.setPropertyValue("renderedMode", val);
    }
    calculateRenderedMode() {
        if (this.contentMode !== "auto") {
            this.setRenderedMode(this.contentMode);
        }
        else {
            if (this.isYoutubeVideo()) {
                this.setRenderedMode("youtube");
            }
            else if (this.isVideo()) {
                this.setRenderedMode("video");
            }
            else {
                this.setRenderedMode("image");
            }
        }
    }
    isYoutubeVideo() {
        return Helpers.isUrlYoutubeVideo(this.imageLink);
    }
    isVideo() {
        let link = this.imageLink;
        if (!link)
            return false;
        link = link.toLowerCase();
        for (let i = 0; i < videoSuffics.length; i++) {
            if (link.endsWith(videoSuffics[i]))
                return true;
        }
        return false;
    }
}
__decorate([
    property({ defaultValue: false })
], QuestionImageModel.prototype, "contentNotLoaded", void 0);
function getCorrectImageLink(val, isYouTube) {
    if (!val || !Helpers.isUrlYoutubeVideo(val))
        return isYouTube ? "" : val;
    let res = val.toLocaleLowerCase();
    if (res.indexOf(youtubeEmbed) > -1)
        return val;
    let id = "";
    for (var i = val.length - 1; i >= 0; i--) {
        if (val[i] === "=" || val[i] === "/")
            break;
        id = val[i] + id;
    }
    return youtubeUrl + youtubeEmbed + "/" + id;
}
Serializer.addClass("image", [
    { name: "imageLink:file", serializationProperty: "locImageLink" },
    { name: "altText", serializationProperty: "locAltText", alternativeName: "text", category: "general" },
    {
        name: "contentMode",
        default: "auto",
        choices: ["auto", "image", "video", "youtube"],
    },
    {
        name: "imageFit",
        default: "contain",
        choices: ["none", "contain", "cover", "fill"],
    },
    { name: "imageHeight", default: "150" },
    { name: "imageWidth", default: "200" },
], function () {
    return new QuestionImageModel("");
}, "nonvalue");
QuestionFactory.Instance.registerQuestion("image", (name) => {
    return new QuestionImageModel(name);
});

/*!
 * Signature Pad v4.2.0 | https://github.com/szimek/signature_pad
 * (c) 2024 Szymon Nowak | Released under the MIT license
 */

class Point {
    constructor(x, y, pressure, time) {
        if (isNaN(x) || isNaN(y)) {
            throw new Error(`Point is invalid: (${x}, ${y})`);
        }
        this.x = +x;
        this.y = +y;
        this.pressure = pressure || 0;
        this.time = time || Date.now();
    }
    distanceTo(start) {
        return Math.sqrt(Math.pow(this.x - start.x, 2) + Math.pow(this.y - start.y, 2));
    }
    equals(other) {
        return (this.x === other.x &&
            this.y === other.y &&
            this.pressure === other.pressure &&
            this.time === other.time);
    }
    velocityFrom(start) {
        return this.time !== start.time
            ? this.distanceTo(start) / (this.time - start.time)
            : 0;
    }
}

class Bezier {
    static fromPoints(points, widths) {
        const c2 = this.calculateControlPoints(points[0], points[1], points[2]).c2;
        const c3 = this.calculateControlPoints(points[1], points[2], points[3]).c1;
        return new Bezier(points[1], c2, c3, points[2], widths.start, widths.end);
    }
    static calculateControlPoints(s1, s2, s3) {
        const dx1 = s1.x - s2.x;
        const dy1 = s1.y - s2.y;
        const dx2 = s2.x - s3.x;
        const dy2 = s2.y - s3.y;
        const m1 = { x: (s1.x + s2.x) / 2.0, y: (s1.y + s2.y) / 2.0 };
        const m2 = { x: (s2.x + s3.x) / 2.0, y: (s2.y + s3.y) / 2.0 };
        const l1 = Math.sqrt(dx1 * dx1 + dy1 * dy1);
        const l2 = Math.sqrt(dx2 * dx2 + dy2 * dy2);
        const dxm = m1.x - m2.x;
        const dym = m1.y - m2.y;
        const k = l2 / (l1 + l2);
        const cm = { x: m2.x + dxm * k, y: m2.y + dym * k };
        const tx = s2.x - cm.x;
        const ty = s2.y - cm.y;
        return {
            c1: new Point(m1.x + tx, m1.y + ty),
            c2: new Point(m2.x + tx, m2.y + ty),
        };
    }
    constructor(startPoint, control2, control1, endPoint, startWidth, endWidth) {
        this.startPoint = startPoint;
        this.control2 = control2;
        this.control1 = control1;
        this.endPoint = endPoint;
        this.startWidth = startWidth;
        this.endWidth = endWidth;
    }
    length() {
        const steps = 10;
        let length = 0;
        let px;
        let py;
        for (let i = 0; i <= steps; i += 1) {
            const t = i / steps;
            const cx = this.point(t, this.startPoint.x, this.control1.x, this.control2.x, this.endPoint.x);
            const cy = this.point(t, this.startPoint.y, this.control1.y, this.control2.y, this.endPoint.y);
            if (i > 0) {
                const xdiff = cx - px;
                const ydiff = cy - py;
                length += Math.sqrt(xdiff * xdiff + ydiff * ydiff);
            }
            px = cx;
            py = cy;
        }
        return length;
    }
    point(t, start, c1, c2, end) {
        return (start * (1.0 - t) * (1.0 - t) * (1.0 - t))
            + (3.0 * c1 * (1.0 - t) * (1.0 - t) * t)
            + (3.0 * c2 * (1.0 - t) * t * t)
            + (end * t * t * t);
    }
}

class SignatureEventTarget {
    constructor() {
        try {
            this._et = new EventTarget();
        }
        catch (error) {
            this._et = document;
        }
    }
    addEventListener(type, listener, options) {
        this._et.addEventListener(type, listener, options);
    }
    dispatchEvent(event) {
        return this._et.dispatchEvent(event);
    }
    removeEventListener(type, callback, options) {
        this._et.removeEventListener(type, callback, options);
    }
}

function throttle(fn, wait = 250) {
    let previous = 0;
    let timeout = null;
    let result;
    let storedContext;
    let storedArgs;
    const later = () => {
        previous = Date.now();
        timeout = null;
        result = fn.apply(storedContext, storedArgs);
        if (!timeout) {
            storedContext = null;
            storedArgs = [];
        }
    };
    return function wrapper(...args) {
        const now = Date.now();
        const remaining = wait - (now - previous);
        storedContext = this;
        storedArgs = args;
        if (remaining <= 0 || remaining > wait) {
            if (timeout) {
                clearTimeout(timeout);
                timeout = null;
            }
            previous = now;
            result = fn.apply(storedContext, storedArgs);
            if (!timeout) {
                storedContext = null;
                storedArgs = [];
            }
        }
        else if (!timeout) {
            timeout = window.setTimeout(later, remaining);
        }
        return result;
    };
}

class SignaturePad extends SignatureEventTarget {
    constructor(canvas, options = {}) {
        super();
        this.canvas = canvas;
        this._drawingStroke = false;
        this._isEmpty = true;
        this._lastPoints = [];
        this._data = [];
        this._lastVelocity = 0;
        this._lastWidth = 0;
        this._handleMouseDown = (event) => {
            if (event.buttons === 1) {
                this._strokeBegin(event);
            }
        };
        this._handleMouseMove = (event) => {
            this._strokeMoveUpdate(event);
        };
        this._handleMouseUp = (event) => {
            if (event.buttons === 1) {
                this._strokeEnd(event);
            }
        };
        this._handleTouchStart = (event) => {
            if (event.cancelable) {
                event.preventDefault();
            }
            if (event.targetTouches.length === 1) {
                const touch = event.changedTouches[0];
                this._strokeBegin(touch);
            }
        };
        this._handleTouchMove = (event) => {
            if (event.cancelable) {
                event.preventDefault();
            }
            const touch = event.targetTouches[0];
            this._strokeMoveUpdate(touch);
        };
        this._handleTouchEnd = (event) => {
            const wasCanvasTouched = event.target === this.canvas;
            if (wasCanvasTouched) {
                if (event.cancelable) {
                    event.preventDefault();
                }
                const touch = event.changedTouches[0];
                this._strokeEnd(touch);
            }
        };
        this._handlePointerStart = (event) => {
            event.preventDefault();
            this._strokeBegin(event);
        };
        this._handlePointerMove = (event) => {
            this._strokeMoveUpdate(event);
        };
        this._handlePointerEnd = (event) => {
            if (this._drawingStroke) {
                event.preventDefault();
                this._strokeEnd(event);
            }
        };
        this.velocityFilterWeight = options.velocityFilterWeight || 0.7;
        this.minWidth = options.minWidth || 0.5;
        this.maxWidth = options.maxWidth || 2.5;
        this.throttle = ('throttle' in options ? options.throttle : 16);
        this.minDistance = ('minDistance' in options ? options.minDistance : 5);
        this.dotSize = options.dotSize || 0;
        this.penColor = options.penColor || 'black';
        this.backgroundColor = options.backgroundColor || 'rgba(0,0,0,0)';
        this.compositeOperation = options.compositeOperation || 'source-over';
        this.canvasContextOptions = ('canvasContextOptions' in options ? options.canvasContextOptions : {});
        this._strokeMoveUpdate = this.throttle
            ? throttle(SignaturePad.prototype._strokeUpdate, this.throttle)
            : SignaturePad.prototype._strokeUpdate;
        this._ctx = canvas.getContext('2d', this.canvasContextOptions);
        this.clear();
        this.on();
    }
    clear() {
        const { _ctx: ctx, canvas } = this;
        ctx.fillStyle = this.backgroundColor;
        ctx.clearRect(0, 0, canvas.width, canvas.height);
        ctx.fillRect(0, 0, canvas.width, canvas.height);
        this._data = [];
        this._reset(this._getPointGroupOptions());
        this._isEmpty = true;
    }
    fromDataURL(dataUrl, options = {}) {
        return new Promise((resolve, reject) => {
            const image = new Image();
            const ratio = options.ratio || window.devicePixelRatio || 1;
            const width = options.width || this.canvas.width / ratio;
            const height = options.height || this.canvas.height / ratio;
            const xOffset = options.xOffset || 0;
            const yOffset = options.yOffset || 0;
            this._reset(this._getPointGroupOptions());
            image.onload = () => {
                this._ctx.drawImage(image, xOffset, yOffset, width, height);
                resolve();
            };
            image.onerror = (error) => {
                reject(error);
            };
            image.crossOrigin = 'anonymous';
            image.src = dataUrl;
            this._isEmpty = false;
        });
    }
    toDataURL(type = 'image/png', encoderOptions) {
        switch (type) {
            case 'image/svg+xml':
                if (typeof encoderOptions !== 'object') {
                    encoderOptions = undefined;
                }
                return `data:image/svg+xml;base64,${btoa(this.toSVG(encoderOptions))}`;
            default:
                if (typeof encoderOptions !== 'number') {
                    encoderOptions = undefined;
                }
                return this.canvas.toDataURL(type, encoderOptions);
        }
    }
    on() {
        this.canvas.style.touchAction = 'none';
        this.canvas.style.msTouchAction = 'none';
        this.canvas.style.userSelect = 'none';
        const isIOS = /Macintosh/.test(navigator.userAgent) && 'ontouchstart' in document;
        if (window.PointerEvent && !isIOS) {
            this._handlePointerEvents();
        }
        else {
            this._handleMouseEvents();
            if ('ontouchstart' in window) {
                this._handleTouchEvents();
            }
        }
    }
    off() {
        this.canvas.style.touchAction = 'auto';
        this.canvas.style.msTouchAction = 'auto';
        this.canvas.style.userSelect = 'auto';
        this.canvas.removeEventListener('pointerdown', this._handlePointerStart);
        this.canvas.removeEventListener('pointermove', this._handlePointerMove);
        this.canvas.ownerDocument.removeEventListener('pointerup', this._handlePointerEnd);
        this.canvas.removeEventListener('mousedown', this._handleMouseDown);
        this.canvas.removeEventListener('mousemove', this._handleMouseMove);
        this.canvas.ownerDocument.removeEventListener('mouseup', this._handleMouseUp);
        this.canvas.removeEventListener('touchstart', this._handleTouchStart);
        this.canvas.removeEventListener('touchmove', this._handleTouchMove);
        this.canvas.removeEventListener('touchend', this._handleTouchEnd);
    }
    isEmpty() {
        return this._isEmpty;
    }
    fromData(pointGroups, { clear = true } = {}) {
        if (clear) {
            this.clear();
        }
        this._fromData(pointGroups, this._drawCurve.bind(this), this._drawDot.bind(this));
        this._data = this._data.concat(pointGroups);
    }
    toData() {
        return this._data;
    }
    _getPointGroupOptions(group) {
        return {
            penColor: group && 'penColor' in group ? group.penColor : this.penColor,
            dotSize: group && 'dotSize' in group ? group.dotSize : this.dotSize,
            minWidth: group && 'minWidth' in group ? group.minWidth : this.minWidth,
            maxWidth: group && 'maxWidth' in group ? group.maxWidth : this.maxWidth,
            velocityFilterWeight: group && 'velocityFilterWeight' in group
                ? group.velocityFilterWeight
                : this.velocityFilterWeight,
            compositeOperation: group && 'compositeOperation' in group
                ? group.compositeOperation
                : this.compositeOperation,
        };
    }
    _strokeBegin(event) {
        const cancelled = !this.dispatchEvent(new CustomEvent('beginStroke', { detail: event, cancelable: true }));
        if (cancelled) {
            return;
        }
        this._drawingStroke = true;
        const pointGroupOptions = this._getPointGroupOptions();
        const newPointGroup = Object.assign(Object.assign({}, pointGroupOptions), { points: [] });
        this._data.push(newPointGroup);
        this._reset(pointGroupOptions);
        this._strokeUpdate(event);
    }
    _strokeUpdate(event) {
        if (!this._drawingStroke) {
            return;
        }
        if (this._data.length === 0) {
            this._strokeBegin(event);
            return;
        }
        this.dispatchEvent(new CustomEvent('beforeUpdateStroke', { detail: event }));
        const x = event.clientX;
        const y = event.clientY;
        const pressure = event.pressure !== undefined
            ? event.pressure
            : event.force !== undefined
                ? event.force
                : 0;
        const point = this._createPoint(x, y, pressure);
        const lastPointGroup = this._data[this._data.length - 1];
        const lastPoints = lastPointGroup.points;
        const lastPoint = lastPoints.length > 0 && lastPoints[lastPoints.length - 1];
        const isLastPointTooClose = lastPoint
            ? point.distanceTo(lastPoint) <= this.minDistance
            : false;
        const pointGroupOptions = this._getPointGroupOptions(lastPointGroup);
        if (!lastPoint || !(lastPoint && isLastPointTooClose)) {
            const curve = this._addPoint(point, pointGroupOptions);
            if (!lastPoint) {
                this._drawDot(point, pointGroupOptions);
            }
            else if (curve) {
                this._drawCurve(curve, pointGroupOptions);
            }
            lastPoints.push({
                time: point.time,
                x: point.x,
                y: point.y,
                pressure: point.pressure,
            });
        }
        this.dispatchEvent(new CustomEvent('afterUpdateStroke', { detail: event }));
    }
    _strokeEnd(event) {
        if (!this._drawingStroke) {
            return;
        }
        this._strokeUpdate(event);
        this._drawingStroke = false;
        this.dispatchEvent(new CustomEvent('endStroke', { detail: event }));
    }
    _handlePointerEvents() {
        this._drawingStroke = false;
        this.canvas.addEventListener('pointerdown', this._handlePointerStart);
        this.canvas.addEventListener('pointermove', this._handlePointerMove);
        this.canvas.ownerDocument.addEventListener('pointerup', this._handlePointerEnd);
    }
    _handleMouseEvents() {
        this._drawingStroke = false;
        this.canvas.addEventListener('mousedown', this._handleMouseDown);
        this.canvas.addEventListener('mousemove', this._handleMouseMove);
        this.canvas.ownerDocument.addEventListener('mouseup', this._handleMouseUp);
    }
    _handleTouchEvents() {
        this.canvas.addEventListener('touchstart', this._handleTouchStart);
        this.canvas.addEventListener('touchmove', this._handleTouchMove);
        this.canvas.addEventListener('touchend', this._handleTouchEnd);
    }
    _reset(options) {
        this._lastPoints = [];
        this._lastVelocity = 0;
        this._lastWidth = (options.minWidth + options.maxWidth) / 2;
        this._ctx.fillStyle = options.penColor;
        this._ctx.globalCompositeOperation = options.compositeOperation;
    }
    _createPoint(x, y, pressure) {
        const rect = this.canvas.getBoundingClientRect();
        return new Point(x - rect.left, y - rect.top, pressure, new Date().getTime());
    }
    _addPoint(point, options) {
        const { _lastPoints } = this;
        _lastPoints.push(point);
        if (_lastPoints.length > 2) {
            if (_lastPoints.length === 3) {
                _lastPoints.unshift(_lastPoints[0]);
            }
            const widths = this._calculateCurveWidths(_lastPoints[1], _lastPoints[2], options);
            const curve = Bezier.fromPoints(_lastPoints, widths);
            _lastPoints.shift();
            return curve;
        }
        return null;
    }
    _calculateCurveWidths(startPoint, endPoint, options) {
        const velocity = options.velocityFilterWeight * endPoint.velocityFrom(startPoint) +
            (1 - options.velocityFilterWeight) * this._lastVelocity;
        const newWidth = this._strokeWidth(velocity, options);
        const widths = {
            end: newWidth,
            start: this._lastWidth,
        };
        this._lastVelocity = velocity;
        this._lastWidth = newWidth;
        return widths;
    }
    _strokeWidth(velocity, options) {
        return Math.max(options.maxWidth / (velocity + 1), options.minWidth);
    }
    _drawCurveSegment(x, y, width) {
        const ctx = this._ctx;
        ctx.moveTo(x, y);
        ctx.arc(x, y, width, 0, 2 * Math.PI, false);
        this._isEmpty = false;
    }
    _drawCurve(curve, options) {
        const ctx = this._ctx;
        const widthDelta = curve.endWidth - curve.startWidth;
        const drawSteps = Math.ceil(curve.length()) * 2;
        ctx.beginPath();
        ctx.fillStyle = options.penColor;
        for (let i = 0; i < drawSteps; i += 1) {
            const t = i / drawSteps;
            const tt = t * t;
            const ttt = tt * t;
            const u = 1 - t;
            const uu = u * u;
            const uuu = uu * u;
            let x = uuu * curve.startPoint.x;
            x += 3 * uu * t * curve.control1.x;
            x += 3 * u * tt * curve.control2.x;
            x += ttt * curve.endPoint.x;
            let y = uuu * curve.startPoint.y;
            y += 3 * uu * t * curve.control1.y;
            y += 3 * u * tt * curve.control2.y;
            y += ttt * curve.endPoint.y;
            const width = Math.min(curve.startWidth + ttt * widthDelta, options.maxWidth);
            this._drawCurveSegment(x, y, width);
        }
        ctx.closePath();
        ctx.fill();
    }
    _drawDot(point, options) {
        const ctx = this._ctx;
        const width = options.dotSize > 0
            ? options.dotSize
            : (options.minWidth + options.maxWidth) / 2;
        ctx.beginPath();
        this._drawCurveSegment(point.x, point.y, width);
        ctx.closePath();
        ctx.fillStyle = options.penColor;
        ctx.fill();
    }
    _fromData(pointGroups, drawCurve, drawDot) {
        for (const group of pointGroups) {
            const { points } = group;
            const pointGroupOptions = this._getPointGroupOptions(group);
            if (points.length > 1) {
                for (let j = 0; j < points.length; j += 1) {
                    const basicPoint = points[j];
                    const point = new Point(basicPoint.x, basicPoint.y, basicPoint.pressure, basicPoint.time);
                    if (j === 0) {
                        this._reset(pointGroupOptions);
                    }
                    const curve = this._addPoint(point, pointGroupOptions);
                    if (curve) {
                        drawCurve(curve, pointGroupOptions);
                    }
                }
            }
            else {
                this._reset(pointGroupOptions);
                drawDot(points[0], pointGroupOptions);
            }
        }
    }
    toSVG({ includeBackgroundColor = false } = {}) {
        const pointGroups = this._data;
        const ratio = Math.max(window.devicePixelRatio || 1, 1);
        const minX = 0;
        const minY = 0;
        const maxX = this.canvas.width / ratio;
        const maxY = this.canvas.height / ratio;
        const svg = document.createElementNS('http://www.w3.org/2000/svg', 'svg');
        svg.setAttribute('xmlns', 'http://www.w3.org/2000/svg');
        svg.setAttribute('xmlns:xlink', 'http://www.w3.org/1999/xlink');
        svg.setAttribute('viewBox', `${minX} ${minY} ${maxX} ${maxY}`);
        svg.setAttribute('width', maxX.toString());
        svg.setAttribute('height', maxY.toString());
        if (includeBackgroundColor && this.backgroundColor) {
            const rect = document.createElement('rect');
            rect.setAttribute('width', '100%');
            rect.setAttribute('height', '100%');
            rect.setAttribute('fill', this.backgroundColor);
            svg.appendChild(rect);
        }
        this._fromData(pointGroups, (curve, { penColor }) => {
            const path = document.createElement('path');
            if (!isNaN(curve.control1.x) &&
                !isNaN(curve.control1.y) &&
                !isNaN(curve.control2.x) &&
                !isNaN(curve.control2.y)) {
                const attr = `M ${curve.startPoint.x.toFixed(3)},${curve.startPoint.y.toFixed(3)} ` +
                    `C ${curve.control1.x.toFixed(3)},${curve.control1.y.toFixed(3)} ` +
                    `${curve.control2.x.toFixed(3)},${curve.control2.y.toFixed(3)} ` +
                    `${curve.endPoint.x.toFixed(3)},${curve.endPoint.y.toFixed(3)}`;
                path.setAttribute('d', attr);
                path.setAttribute('stroke-width', (curve.endWidth * 2.25).toFixed(3));
                path.setAttribute('stroke', penColor);
                path.setAttribute('fill', 'none');
                path.setAttribute('stroke-linecap', 'round');
                svg.appendChild(path);
            }
        }, (point, { penColor, dotSize, minWidth, maxWidth }) => {
            const circle = document.createElement('circle');
            const size = dotSize > 0 ? dotSize : (minWidth + maxWidth) / 2;
            circle.setAttribute('r', size.toString());
            circle.setAttribute('cx', point.x.toString());
            circle.setAttribute('cy', point.y.toString());
            circle.setAttribute('fill', penColor);
            svg.appendChild(circle);
        });
        return svg.outerHTML;
    }
}

var defaultWidth = 300;
var defaultHeight = 200;
/**
 * A class that describes the Signature question type.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/signature-pad-widget-javascript/ (linkStyle))
 */
class QuestionSignaturePadModel extends QuestionFileModelBase {
    getPenColorFromTheme() {
        const _survey = this.survey;
        return !!_survey && !!_survey.themeVariables && _survey.themeVariables["--sjs-primary-backcolor"];
    }
    updateColors(signaturePad) {
        const penColorFromTheme = this.getPenColorFromTheme();
        const penColorProperty = this.getPropertyByName("penColor");
        signaturePad.penColor = this.penColor || penColorFromTheme || penColorProperty.defaultValue || "#1ab394";
        const backgroundColorProperty = this.getPropertyByName("backgroundColor");
        const backgroundColorFromTheme = penColorFromTheme ? "transparent" : undefined;
        const background = !!this.backgroundImage ? "transparent" : this.backgroundColor;
        signaturePad.backgroundColor = background || backgroundColorFromTheme || backgroundColorProperty.defaultValue || "#ffffff";
    }
    getCssRoot(cssClasses) {
        return new CssClassBuilder()
            .append(super.getCssRoot(cssClasses))
            .append(cssClasses.small, this.signatureWidth.toString() === "300")
            .toString();
    }
    getFormat() {
        return this.dataFormat === "jpeg" ? "image/jpeg" :
            (this.dataFormat === "svg" ? "image/svg+xml" : "");
    }
    updateValue() {
        if (this.signaturePad) {
            var data = this.signaturePad.toDataURL(this.getFormat());
            this.valueIsUpdatingInternally = true;
            this.value = data;
            this.valueIsUpdatingInternally = false;
        }
    }
    constructor(name) {
        super(name);
        this.valueIsUpdatingInternally = false;
        this._loadedData = undefined;
        this.updateValueHandler = () => {
            this._loadedData = undefined;
            this.scaleCanvas(true, true);
        };
    }
    getType() {
        return "signaturepad";
    }
    afterRenderQuestionElement(el) {
        if (DomWindowHelper.isAvailable()) {
            if (!!el) {
                if (!this.isDesignMode) {
                    this.initSignaturePad(el);
                }
                this.element = el;
            }
        }
        super.afterRenderQuestionElement(el);
    }
    beforeDestroyQuestionElement(el) {
        if (!!el) {
            this.destroySignaturePad(el);
        }
    }
    themeChanged(theme) {
        if (!!this.signaturePad) {
            this.updateColors(this.signaturePad);
        }
    }
    resizeCanvas() {
        this.canvas.width = this.containerWidth;
        this.canvas.height = this.containerHeight;
    }
    scaleCanvas(refresh = true, resize = false) {
        const canvas = this.canvas;
        const scale = canvas.offsetWidth / this.containerWidth;
        if (this.scale != scale || resize) {
            this.scale = scale;
            canvas.style.width = this.renderedCanvasWidth;
            this.resizeCanvas();
            this.signaturePad.minWidth = this.penMinWidth * scale;
            this.signaturePad.maxWidth = this.penMaxWidth * scale;
            canvas.getContext("2d").scale(1 / scale, 1 / scale);
            if (refresh) {
                this.loadPreview(this.value);
            }
        }
    }
    fromUrl(url) {
        this.isFileLoading = true;
        if (isBase64URL(url)) {
            this.fromDataUrl(url);
            this.isFileLoading = false;
        }
        else {
            const img = new Image();
            img.crossOrigin = "anonymous";
            img.src = url;
            img.onload = () => {
                if (!!this.canvas) {
                    const canvas = DomDocumentHelper.createElement("canvas");
                    canvas.width = this.containerWidth;
                    canvas.height = this.containerHeight;
                    const ctx = canvas.getContext("2d");
                    ctx.drawImage(img, 0, 0);
                    var dataURL = canvas.toDataURL(this.getFormat());
                    this.fromDataUrl(dataURL);
                }
                this.isFileLoading = false;
            };
            img.onerror = () => {
                this.isFileLoading = false;
            };
        }
    }
    fromDataUrl(data) {
        this._loadedData = data;
        if (this.signaturePad) {
            let ratio = 1;
            let scale = this.scale;
            if (this.dataFormat === "svg") {
                const devicePixelRatio = DomWindowHelper.getDevicePixelRatio();
                ratio = devicePixelRatio || 1;
                scale = 1;
            }
            const options = {
                width: this.canvas.width * scale / ratio,
                height: this.canvas.height * scale / ratio
            };
            this.signaturePad.fromDataURL(data, options);
        }
    }
    get loadedData() {
        return this._loadedData;
    }
    loadPreview(newValue) {
        if (!newValue) {
            if (this.signaturePad && this.canvas) {
                this.canvas.getContext("2d").clearRect(0, 0, this.canvas.width * this.scale, this.canvas.height * this.scale);
                this.signaturePad.clear();
            }
            this.valueWasChangedFromLastUpload = false;
            return;
        }
        if (this.storeDataAsText) {
            this.fromDataUrl(newValue);
        }
        else {
            if (this.loadedData) {
                this.fromDataUrl(this.loadedData);
            }
            else {
                var newValues = !!newValue ? [newValue] : [];
                if (!!this._previewLoader) {
                    this._previewLoader.dispose();
                }
                this.isFileLoading = true;
                this._previewLoader = new FileLoader(this, (status, loaded) => {
                    if (status === "success" && loaded && loaded.length > 0 && loaded[0].content) {
                        this.fromDataUrl(loaded[0].content);
                        this.isFileLoading = false;
                    }
                    else if (status === "skipped") {
                        this.fromUrl(newValue);
                    }
                    this._previewLoader.dispose();
                    this._previewLoader = undefined;
                });
                this._previewLoader.load(newValues);
            }
        }
    }
    onChangeQuestionValue(newValue) {
        super.onChangeQuestionValue(newValue);
        if (!this.isLoadingFromJson) {
            this._loadedData = undefined;
            this.loadPreview(newValue);
        }
    }
    onSurveyLoad() {
        super.onSurveyLoad();
        this.loadPreview(this.value);
    }
    initSignaturePad(el) {
        var canvas = el.getElementsByTagName("canvas")[0];
        this.canvas = canvas;
        this.resizeCanvas();
        var signaturePad = new SignaturePad(canvas, { backgroundColor: "#ffffff" });
        this.signaturePad = signaturePad;
        if (this.isInputReadOnly) {
            signaturePad.off();
        }
        this.readOnlyChangedCallback = () => {
            if (this.isInputReadOnly) {
                signaturePad.off();
            }
            else {
                signaturePad.on();
            }
        };
        this.updateColors(signaturePad);
        signaturePad.addEventListener("beginStroke", () => {
            this.scaleCanvas();
            this.isDrawingValue = true;
            canvas.focus();
        }, { once: false });
        signaturePad.addEventListener("endStroke", () => {
            this.isDrawingValue = false;
            if (this.storeDataAsText) {
                this.updateValue();
            }
            else {
                this.valueWasChangedFromLastUpload = true;
            }
        }, { once: false });
        this.updateValueHandler();
        this.readOnlyChangedCallback();
        var propertyChangedHandler = (sender, options) => {
            if (options.name === "signatureWidth" || options.name === "signatureHeight") {
                if (!this.valueIsUpdatingInternally)
                    this.updateValueHandler();
            }
        };
        this.onPropertyChanged.add(propertyChangedHandler);
        this.signaturePad.propertyChangedHandler = propertyChangedHandler;
    }
    destroySignaturePad(el) {
        if (this.signaturePad) {
            this.onPropertyChanged.remove(this.signaturePad.propertyChangedHandler);
            this.signaturePad.off();
        }
        this.readOnlyChangedCallback = null;
        this.signaturePad = null;
    }
    /**
     * Specifies the format in which to store the signature image.
     *
     * Possible values:
     *
     * - `"png"` (default)
     * - `"jpeg"`
     * - `"svg"`
     */
    get dataFormat() {
        return this.getPropertyValue("dataFormat");
    }
    set dataFormat(val) {
        this.setPropertyValue("dataFormat", correctFormatData(val));
    }
    /**
     * Specifies the width of the signature area. Accepts positive integer numbers.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/signature-pad-widget-javascript/ (linkStyle))
     */
    get signatureWidth() {
        return this.getPropertyValue("signatureWidth");
    }
    set signatureWidth(val) {
        this.setPropertyValue("signatureWidth", val);
    }
    /**
     * Specifies the height of the signature area. Accepts positive integer numbers.
     */
    get signatureHeight() {
        return this.getPropertyValue("signatureHeight");
    }
    set signatureHeight(val) {
        this.setPropertyValue("signatureHeight", val);
    }
    get containerHeight() {
        return this.signatureHeight || defaultHeight;
    }
    get containerWidth() {
        return this.signatureWidth || defaultWidth;
    }
    get renderedCanvasWidth() {
        return this.signatureAutoScaleEnabled ? "100%" : this.containerWidth + "px";
    }
    //todo: need to remove this property
    get height() {
        return this.getPropertyValue("height");
    }
    set height(val) {
        this.setPropertyValue("height", val);
    }
    /**
     * Specifies whether to display a button that clears the signature area.
     *
     * Default value: `true`
     */
    get allowClear() {
        return this.getPropertyValue("allowClear");
    }
    set allowClear(val) {
        this.setPropertyValue("allowClear", val);
    }
    get canShowClearButton() {
        const hasSignature = !this.nothingIsDrawn();
        const isUploading = this.isUploading;
        return !this.isInputReadOnly && this.allowClear && hasSignature && !isUploading;
    }
    /**
     * Specifies a color for the pen.
     *
     * This property accepts color values in the following formats:
     *
     * - Hexadecimal colors (`"#FF0000"`)
     * - RGB colors (`"rgb(255,0,0)"`)
     * - Color names (`"red"`)
     *
     * [View Demo](https://surveyjs.io/form-library/examples/upload-signature-pad-data-to-server/ (linkStyle))
     * @see backgroundColor
     */
    get penColor() {
        return this.getPropertyValue("penColor");
    }
    set penColor(val) {
        this.setPropertyValue("penColor", val);
        !!this.signaturePad && this.updateColors(this.signaturePad);
    }
    /**
     * Specifies a color for the signature area background. Ignored if [`backgroundImage`](#backgroundImage) is set.
     *
     * This property accepts color values in the following formats:
     *
     * - Hexadecimal colors (`"#FF0000"`)
     * - RGB colors (`"rgb(255,0,0)"`)
     * - Color names (`"red"`)
     * @see penColor
     */
    get backgroundColor() {
        return this.getPropertyValue("backgroundColor");
    }
    set backgroundColor(val) {
        this.setPropertyValue("backgroundColor", val);
        !!this.signaturePad && this.updateColors(this.signaturePad);
    }
    /**
     * An image to display in the background of the signature area. Accepts a base64 or URL string value.
     * @see backgroundColor
     */
    get backgroundImage() {
        return this.getPropertyValue("backgroundImage");
    }
    set backgroundImage(val) {
        this.setPropertyValue("backgroundImage", val);
        !!this.signaturePad && this.updateColors(this.signaturePad);
    }
    get clearButtonCaption() {
        return this.getLocalizationString("clearCaption");
    }
    get locRenderedPlaceholder() {
        return this.isReadOnly ? this.locPlaceholderReadOnly : this.locPlaceholder;
    }
    nothingIsDrawn() {
        const isDrawing = this.isDrawingValue;
        const isEmpty = this.isEmpty();
        const isUploading = this.isUploading;
        const valueWasChangedFromLastUpload = this.valueWasChangedFromLastUpload;
        return !isDrawing && isEmpty && !isUploading && !valueWasChangedFromLastUpload;
    }
    needShowPlaceholder() {
        return this.showPlaceholder && this.nothingIsDrawn();
    }
    onBlurCore(event) {
        super.onBlurCore(event);
        if (!this.storeDataAsText) {
            if (!this.element.contains(event.relatedTarget)) {
                if (!this.valueWasChangedFromLastUpload)
                    return;
                this.uploadFiles([dataUrl2File(this.signaturePad.toDataURL(this.getFormat()), this.name + "." + correctFormatData(this.dataFormat), this.getFormat())]);
                this.valueWasChangedFromLastUpload = false;
            }
        }
    }
    uploadResultItemToValue(r) {
        return r.content;
    }
    setValueFromResult(arg) {
        this.valueIsUpdatingInternally = true;
        this.value = (arg === null || arg === void 0 ? void 0 : arg.length) ? arg.map((r) => r.content)[0] : undefined;
        this.valueIsUpdatingInternally = false;
    }
    clearValue(keepComment) {
        this.valueWasChangedFromLastUpload = false;
        super.clearValue(keepComment);
        this._loadedData = undefined;
        this.loadPreview(this.value);
    }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        //todo: need to remove this code
        if (this.signatureWidth === 300 && !!this.width && typeof this.width === "number" && this.width) {
            ConsoleWarnings.warn("Use signatureWidth property to set width for the signature pad");
            this.signatureWidth = this.width;
            this.width = undefined;
        }
        if (this.signatureHeight === 200 && !!this.height) {
            ConsoleWarnings.warn("Use signatureHeight property to set width for the signature pad");
            this.signatureHeight = this.height;
            this.height = undefined;
        }
    }
}
__decorate([
    property({ defaultValue: false })
], QuestionSignaturePadModel.prototype, "isDrawingValue", void 0);
__decorate([
    property({ defaultValue: false })
], QuestionSignaturePadModel.prototype, "isReadyForUpload", void 0);
__decorate([
    property({ defaultValue: false })
], QuestionSignaturePadModel.prototype, "valueWasChangedFromLastUpload", void 0);
__decorate([
    property()
], QuestionSignaturePadModel.prototype, "signatureAutoScaleEnabled", void 0);
__decorate([
    property()
], QuestionSignaturePadModel.prototype, "penMinWidth", void 0);
__decorate([
    property()
], QuestionSignaturePadModel.prototype, "penMaxWidth", void 0);
__decorate([
    property({})
], QuestionSignaturePadModel.prototype, "showPlaceholder", void 0);
__decorate([
    property({ localizable: { defaultStr: "signaturePlaceHolder" } })
], QuestionSignaturePadModel.prototype, "placeholder", void 0);
__decorate([
    property({ localizable: { defaultStr: "signaturePlaceHolderReadOnly" } })
], QuestionSignaturePadModel.prototype, "placeholderReadOnly", void 0);
function correctFormatData(val) {
    if (!val)
        val = "png";
    val = val.replace("image/", "").replace("+xml", "");
    if (val !== "jpeg" && val !== "svg")
        val = "png";
    return val;
}
Serializer.addClass("signaturepad", [
    {
        name: "signatureWidth:number",
        category: "general",
        default: 300,
    },
    {
        name: "signatureHeight:number",
        category: "general",
        default: 200,
    },
    {
        name: "signatureAutoScaleEnabled:boolean",
        category: "general",
        default: false,
    },
    {
        name: "penMinWidth:number",
        category: "general",
        default: 0.5,
    },
    {
        name: "penMaxWidth:number",
        category: "general",
        default: 2.5,
    },
    //need to remove this property
    {
        name: "height:number",
        category: "general",
        visible: false
    },
    {
        name: "allowClear:boolean",
        category: "general",
        default: true,
    },
    { name: "showPlaceholder:boolean", category: "general", default: true },
    {
        name: "placeholder:text",
        serializationProperty: "locPlaceholder",
        category: "general",
        dependsOn: "showPlaceholder",
        visibleIf: (obj) => obj.showPlaceholder
    },
    {
        name: "placeholderReadOnly:text",
        serializationProperty: "locPlaceholderReadOnly",
        category: "general",
        dependsOn: "showPlaceholder",
        visibleIf: (obj) => obj.showPlaceholder
    },
    {
        name: "backgroundImage:file",
        category: "general",
    },
    {
        name: "penColor:color",
        category: "general",
    },
    {
        name: "backgroundColor:color",
        category: "general",
    },
    {
        name: "dataFormat",
        category: "general",
        default: "png",
        choices: [
            { value: "png", text: "PNG" },
            { value: "jpeg", text: "JPEG" },
            { value: "svg", text: "SVG" },
        ],
        onSettingValue: (obj, val) => {
            return correctFormatData(val);
        }
    },
    { name: "defaultValue", visible: false },
    { name: "correctAnswer", visible: false },
    { name: "storeDataAsText:boolean", default: true },
    { name: "waitForUpload:boolean", default: false },
], function () {
    return new QuestionSignaturePadModel("");
}, "question");
QuestionFactory.Instance.registerQuestion("signaturepad", (name) => {
    return new QuestionSignaturePadModel(name);
});

class QuestionPanelDynamicItemTextProcessor extends QuestionTextProcessor {
    constructor(data, panelItem, variableName) {
        super(variableName);
        this.data = data;
        this.panelItem = panelItem;
        this.variableName = variableName;
        this.sharedQuestions = {};
    }
    get survey() {
        return this.panelItem.getSurvey();
    }
    get panel() {
        return this.panelItem.panel;
    }
    get panelIndex() {
        return !!this.data ? this.data.getItemIndex(this.panelItem) : -1;
    }
    get visiblePanelIndex() {
        return !!this.data ? this.data.getVisibleItemIndex(this.panelItem) : -1;
    }
    getValues() {
        return this.panelItem.getAllValues();
    }
    getQuestionByName(name) {
        var res = super.getQuestionByName(name);
        if (!!res)
            return res;
        const index = this.panelIndex;
        res = index > -1 ? this.data.getSharedQuestionFromArray(name, index) : undefined;
        const qName = !!res ? res.name : name;
        this.sharedQuestions[qName] = name;
        return res;
    }
    getQuestionDisplayText(question) {
        const name = this.sharedQuestions[question.name];
        if (!name)
            return super.getQuestionDisplayText(question);
        const val = this.panelItem.getValue(name);
        return question.getDisplayValue(true, val);
    }
    onCustomProcessText(textValue) {
        if (textValue.name == QuestionPanelDynamicItem.IndexVariableName) {
            var index = this.panelIndex;
            if (index > -1) {
                textValue.isExists = true;
                textValue.value = index + 1;
                return true;
            }
        }
        if (textValue.name == QuestionPanelDynamicItem.VisibleIndexVariableName) {
            var index = this.visiblePanelIndex;
            if (index > -1) {
                textValue.isExists = true;
                textValue.value = index + 1;
                return true;
            }
        }
        if (textValue.name.toLowerCase().indexOf(QuestionPanelDynamicItem.ParentItemVariableName + ".") == 0) {
            var q = this.data;
            if (!!q && !!q.parentQuestion && !!q.parent && !!q.parent.data) {
                var processor = new QuestionPanelDynamicItemTextProcessor(q.parentQuestion, q.parent.data, QuestionPanelDynamicItem.ItemVariableName);
                var text = QuestionPanelDynamicItem.ItemVariableName +
                    textValue.name.substring(QuestionPanelDynamicItem.ParentItemVariableName.length);
                var res = processor.processValue(text, textValue.returnDisplayValue);
                textValue.isExists = res.isExists;
                textValue.value = res.value;
            }
            return true;
        }
        return false;
    }
}
class PanelDynamicTabbedMenuItem extends Action {
    constructor(innerItem) {
        super(innerItem);
    }
}
class QuestionPanelDynamicItem {
    constructor(data, panel) {
        this.data = data;
        this.panelValue = panel;
        this.textPreProcessor = new QuestionPanelDynamicItemTextProcessor(data, this, QuestionPanelDynamicItem.ItemVariableName);
        this.setSurveyImpl();
    }
    get panel() {
        return this.panelValue;
    }
    setSurveyImpl() {
        this.panel.setSurveyImpl(this);
    }
    getValue(name) {
        var values = this.getAllValues();
        return values[name];
    }
    setValue(name, newValue) {
        const oldItemData = this.data.getPanelItemData(this);
        const oldValue = !!oldItemData ? oldItemData[name] : undefined;
        if (Helpers.isTwoValueEquals(newValue, oldValue, false, true, false))
            return;
        this.data.setPanelItemData(this, name, Helpers.getUnbindValue(newValue));
        const questions = this.panel.questions;
        for (var i = 0; i < questions.length; i++) {
            const q = questions[i];
            if (q.getValueName() !== name) {
                q.checkBindings(name, newValue);
            }
            const suffix = settings.commentSuffix;
            if (name.endsWith(suffix)) {
                name = name.substring(0, name.length - suffix.length);
                const cQ = this.panel.getQuestionByName(name);
                if (!!cQ) {
                    newValue = cQ.value;
                }
            }
            const triggerName = QuestionPanelDynamicItem.ItemVariableName + "." + name;
            q.runTriggers(triggerName, newValue);
        }
    }
    getVariable(name) {
        return undefined;
    }
    setVariable(name, newValue) { }
    getComment(name) {
        var result = this.getValue(name + settings.commentSuffix);
        return result ? result : "";
    }
    setComment(name, newValue, locNotification) {
        this.setValue(name + settings.commentSuffix, newValue);
    }
    findQuestionByName(name) {
        if (!name)
            return undefined;
        const prefix = QuestionPanelDynamicItem.ItemVariableName + ".";
        if (name.indexOf(prefix) === 0) {
            return this.panel.getQuestionByName(name.substring(prefix.length));
        }
        const survey = this.getSurvey();
        return !!survey ? survey.getQuestionByName(name) : null;
    }
    getEditingSurveyElement() { return undefined; }
    getAllValues() {
        return this.data.getPanelItemData(this);
    }
    getFilteredValues() {
        var values = {};
        var surveyValues = !!this.data && !!this.data.getRootData()
            ? this.data.getRootData().getFilteredValues()
            : {};
        for (var key in surveyValues) {
            values[key] = surveyValues[key];
        }
        values[QuestionPanelDynamicItem.ItemVariableName] = this.getAllValues();
        if (!!this.data) {
            const indexStr = QuestionPanelDynamicItem.IndexVariableName;
            const visibleIndexStr = QuestionPanelDynamicItem.VisibleIndexVariableName;
            delete values[indexStr];
            delete values[visibleIndexStr];
            values[indexStr.toLowerCase()] = this.data.getItemIndex(this);
            values[visibleIndexStr.toLowerCase()] = this.data.getVisibleItemIndex(this);
            const q = this.data;
            if (!!q && !!q.parentQuestion && !!q.parent) {
                values[QuestionPanelDynamicItem.ParentItemVariableName] = q.parent.getValue();
            }
        }
        return values;
    }
    getFilteredProperties() {
        if (!!this.data && !!this.data.getRootData())
            return this.data.getRootData().getFilteredProperties();
        return { survey: this.getSurvey() };
    }
    getSurveyData() {
        return this;
    }
    getSurvey() {
        return this.data ? this.data.getSurvey() : null;
    }
    getTextProcessor() {
        return this.textPreProcessor;
    }
}
QuestionPanelDynamicItem.ItemVariableName = "panel";
QuestionPanelDynamicItem.ParentItemVariableName = "parentpanel";
QuestionPanelDynamicItem.IndexVariableName = "panelIndex";
QuestionPanelDynamicItem.VisibleIndexVariableName = "visiblePanelIndex";
class QuestionPanelDynamicTemplateSurveyImpl {
    constructor(data) {
        this.data = data;
    }
    getSurveyData() {
        return null;
    }
    getSurvey() {
        return this.data.getSurvey();
    }
    getTextProcessor() {
        return null;
    }
}
/**
  * A class that describes the Dynamic Panel question type.
  *
  * Dynamic Panel allows respondents to add panels based on a panel template and delete them. Specify the [`templateElements`](https://surveyjs.io/form-library/documentation/questionpaneldynamicmodel#templateElements) property to configure panel template elements.
  *
  * [View Demo](https://surveyjs.io/form-library/examples/questiontype-paneldynamic/ (linkStyle))
  */
class QuestionPanelDynamicModel extends Question {
    constructor(name) {
        super(name);
        this._renderedPanels = [];
        this.isPanelsAnimationRunning = false;
        this.isAddingNewPanels = false;
        this.isSetPanelItemData = {};
        this.createNewArray("panels", (panel) => { this.onPanelAdded(panel); }, (panel) => { this.onPanelRemoved(panel); });
        this.createNewArray("visiblePanels");
        this.templateValue = this.createAndSetupNewPanelObject();
        this.template.renderWidth = "100%";
        this.template.selectedElementInDesign = this;
        this.template.addElementCallback = (element) => {
            this.addOnPropertyChangedCallback(element);
            this.rebuildPanels();
        };
        this.template.removeElementCallback = () => {
            this.rebuildPanels();
        };
        this.createLocalizableString("confirmDeleteText", this, false, "confirmDelete");
        this.createLocalizableString("keyDuplicationError", this, false, true);
        this.createLocalizableString("addPanelText", this, false, "addPanel");
        this.createLocalizableString("removePanelText", this, false, "removePanel");
        this.createLocalizableString("prevPanelText", this, false, "pagePrevText");
        this.createLocalizableString("nextPanelText", this, false, "pageNextText");
        this.createLocalizableString("noEntriesText", this, false, "noEntriesText");
        this.createLocalizableString("editPanelText", this, false, "editText");
        this.createLocalizableString("templateTabTitle", this, true, "panelDynamicTabTextFormat");
        this.createLocalizableString("tabTitlePlaceholder", this, true, "tabTitlePlaceholder");
        this.registerPropertyChangedHandlers(["panelsState"], () => {
            this.setPanelsState();
        });
        this.registerPropertyChangedHandlers(["newPanelPosition", "displayMode", "showProgressBar"], () => {
            this.updateFooterActions();
        });
        this.registerPropertyChangedHandlers(["allowAddPanel"], () => { this.updateNoEntriesTextDefaultLoc(); });
        this.registerPropertyChangedHandlers(["minPanelCount"], () => { this.onMinPanelCountChanged(); });
        this.registerPropertyChangedHandlers(["maxPanelCount"], () => { this.onMaxPanelCountChanged(); });
        this.registerPropertyChangedHandlers(["templateQuestionTitleLocation", "templateQuestionTitleWidth"], () => {
            const panels = this.visiblePanelsCore;
            if (panels)
                panels.forEach((panel) => { panel.updateElementCss(true); });
        });
    }
    get isCompositeQuestion() { return true; }
    get hasSingleInput() { return false; }
    get isContainer() { return true; }
    getFirstQuestionToFocus(withError) {
        for (var i = 0; i < this.visiblePanelsCore.length; i++) {
            const res = this.visiblePanelsCore[i].getFirstQuestionToFocus(withError);
            if (!!res)
                return res;
        }
        if (this.showAddPanelButton && (!withError || this.currentErrorCount > 0))
            return this;
        return null;
    }
    getFirstInputElementId() {
        if (this.showAddPanelButton)
            return this.addButtonId;
        return super.getFirstInputElementId();
    }
    getFirstErrorInputElementId() {
        const question = this.getFirstQuestionToFocus(true);
        return question ? question.inputId : super.getFirstErrorInputElementId();
    }
    setSurveyImpl(value, isLight) {
        super.setSurveyImpl(value, isLight);
        this.setTemplatePanelSurveyImpl();
        this.setPanelsSurveyImpl();
    }
    assignOnPropertyChangedToTemplate() {
        var elements = this.template.elements;
        for (var i = 0; i < elements.length; i++) {
            this.addOnPropertyChangedCallback(elements[i]);
        }
    }
    addOnPropertyChangedCallback(element) {
        if (element.isQuestion) {
            element.setParentQuestion(this);
        }
        element.onPropertyChanged.add((element, options) => {
            this.onTemplateElementPropertyChanged(element, options);
        });
        if (element.isPanel) {
            element.addElementCallback = (element) => {
                this.addOnPropertyChangedCallback(element);
            };
        }
    }
    onTemplateElementPropertyChanged(element, options) {
        if (this.isLoadingFromJson || this.useTemplatePanel || this.panelsCore.length == 0)
            return;
        var property = Serializer.findProperty(element.getType(), options.name);
        if (!property)
            return;
        var panels = this.panelsCore;
        for (var i = 0; i < panels.length; i++) {
            var question = panels[i].getQuestionByName(element.name);
            if (!!question && question[options.name] !== options.newValue) {
                question[options.name] = options.newValue;
            }
        }
    }
    get useTemplatePanel() {
        return this.isDesignMode && !this.isContentElement;
    }
    getType() {
        return "paneldynamic";
    }
    clearOnDeletingContainer() {
        this.panelsCore.forEach((panel) => {
            panel.clearOnDeletingContainer();
        });
    }
    get isAllowTitleLeft() {
        return false;
    }
    removeElement(element) {
        return this.template.removeElement(element);
    }
    /**
     * A `PanelModel` object used as a template to create dynamic panels.
     * @see PanelModel
     * @see templateElements
     * @see templateTitle
     * @see panels
     * @see panelCount
     */
    get template() {
        return this.templateValue;
    }
    getPanel() {
        return this.template;
    }
    /**
     * An array of questions and panels included in a panel template.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/duplicate-group-of-fields-in-form/ (linkStyle))
     * @see template
     * @see panels
     * @see panelCount
     */
    get templateElements() {
        return this.template.elements;
    }
    /**
     * A template for panel titles.
     *
     * The template can contain the following placeholders:
     *
     * - `{panelIndex}` - A panel index within the collection of all panels. Starts with 1.
     * - `{visiblePanelIndex}` - A panel index within the collection of visible panels. Starts with 1.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/breakable-loop/ (linkStyle))
     * @see template
     * @see templateDescription
     * @see templateElements
     * @see panels
     * @see panelCount
     */
    get templateTitle() {
        return this.template.title;
    }
    set templateTitle(newValue) {
        this.template.title = newValue;
    }
    get locTemplateTitle() {
        return this.template.locTitle;
    }
    /**
     * A template for tab titles. Applies when [`displayMode`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#displayMode) is `"tab"`.
     *
     * The template can contain the following placeholders:
     *
     * - `{panelIndex}` - A panel index within the collection of all panels. Starts with 1.
     * - `{visiblePanelIndex}` - A panel index within the collection of visible panels. Starts with 1.
     *
     * If you want to customize individual tab titles, handle `SurveyModel`'s [`onGetDynamicPanelTabTitle`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#onGetDynamicPanelTabTitle) event.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/tabbed-interface-for-duplicate-group-option/ (linkStyle))
     * @see templateTitle
     * @see tabTitlePlaceholder
     * @see displayMode
     */
    get templateTabTitle() {
        return this.locTemplateTabTitle.text;
    }
    set templateTabTitle(newValue) {
        this.locTemplateTabTitle.text = newValue;
    }
    get locTemplateTabTitle() {
        return this.getLocalizableString("templateTabTitle");
    }
    /**
     * A placeholder for tab titles that applies when the [`templateTabTitle`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#templateTabTitle) expression doesn't produce a meaningful value.
     *
     * Default value: `"New Panel"` (taken from a [localization dictionary](https://github.com/surveyjs/survey-library/tree/01bd8abd0c574719956d4d579d48c8010cd389d4/packages/survey-core/src/localization))
     */
    get tabTitlePlaceholder() {
        return this.locTabTitlePlaceholder.text;
    }
    set tabTitlePlaceholder(newValue) {
        this.locTabTitlePlaceholder.text = newValue;
    }
    get locTabTitlePlaceholder() {
        return this.getLocalizableString("tabTitlePlaceholder");
    }
    /**
     * A template for panel descriptions.
     * @see template
     * @see templateTitle
     * @see templateElements
     * @see panels
     * @see panelCount
     */
    get templateDescription() {
        return this.template.description;
    }
    set templateDescription(newValue) {
        this.template.description = newValue;
    }
    get locTemplateDescription() {
        return this.template.locDescription;
    }
    /**
     * A Boolean expression that is evaluated against each panel. If the expression evaluates to `false`, the panel becomes hidden.
     *
     * A survey parses and runs all expressions on startup. If any values used in the expression change, the survey re-evaluates it.
     *
     * Use the `{panel}` placeholder to reference the current panel in the expression.
     *
     * Refer to the following help topic for more information: [Conditional Visibility](https://surveyjs.io/form-library/documentation/design-survey/conditional-logic#conditional-visibility).
     * @see visibleIf
     * @see visiblePanels
     */
    get templateVisibleIf() {
        return this.getPropertyValue("templateVisibleIf");
    }
    set templateVisibleIf(val) {
        this.setPropertyValue("templateVisibleIf", val);
        this.template.visibleIf = val;
    }
    get items() {
        var res = [];
        for (var i = 0; i < this.panelsCore.length; i++) {
            res.push(this.panelsCore[i].data);
        }
        return res;
    }
    /**
     * An array of `PanelModel` objects created based on a panel template.
     * @see PanelModel
     * @see template
     * @see panelCount
     */
    get panels() {
        this.buildPanelsFirstTime(this.canBuildPanels);
        return this.panelsCore;
    }
    /**
     * An array of currently visible panels ([`PanelModel`](https://surveyjs.io/form-library/documentation/api-reference/panel-model) objects).
     * @see templateVisibleIf
     */
    get visiblePanels() {
        this.buildPanelsFirstTime(this.canBuildPanels);
        return this.visiblePanelsCore;
    }
    get panelsCore() {
        return this.getPropertyValue("panels");
    }
    get visiblePanelsCore() {
        return this.getPropertyValue("visiblePanels");
    }
    onPanelAdded(panel) {
        this.onPanelRemovedCore(panel);
        if (!panel.visible)
            return;
        let index = 0;
        const panels = this.panelsCore;
        for (var i = 0; i < panels.length; i++) {
            if (panels[i] === panel)
                break;
            if (panels[i].visible)
                index++;
        }
        this.visiblePanelsCore.splice(index, 0, panel);
        this.addTabFromToolbar(panel, index);
        if (!this.currentPanel) {
            this.currentPanel = panel;
        }
        this.updateRenderedPanels();
    }
    onPanelRemoved(panel) {
        let index = this.onPanelRemovedCore(panel);
        if (this.currentPanel === panel) {
            const visPanels = this.visiblePanelsCore;
            if (index >= visPanels.length)
                index = visPanels.length - 1;
            this.currentPanel = index >= 0 ? visPanels[index] : null;
        }
        this.updateRenderedPanels();
    }
    onPanelRemovedCore(panel) {
        const visPanels = this.visiblePanelsCore;
        let index = visPanels.indexOf(panel);
        if (index > -1) {
            visPanels.splice(index, 1);
            this.removeTabFromToolbar(panel);
        }
        return index;
    }
    /**
     * A zero-based index of the currently displayed panel.
     *
     * When `displayMode` is `"list"` or Dynamic Panel is empty (`panelCount` is 0), this property contains -1.
     * @see currentPanel
     * @see panels
     * @see panelCount
     * @see displayMode
     */
    get currentIndex() {
        if (this.isRenderModeList)
            return -1;
        if (this.useTemplatePanel)
            return 0;
        return this.visiblePanelsCore.indexOf(this.currentPanel);
    }
    set currentIndex(val) {
        if (val < 0 || this.visiblePanelCount < 1)
            return;
        if (val >= this.visiblePanelCount)
            val = this.visiblePanelCount - 1;
        this.currentPanel = this.visiblePanelsCore[val];
    }
    /**
     * A `PanelModel` object that is the currently displayed panel.
     *
     * When `displayMode` is `"list"` or Dynamic Panel is empty (`panelCount` is 0), this property contains `null`.
     * @see currentIndex
     * @see panels
     * @see panelCount
     * @see displayMode
     */
    get currentPanel() {
        if (this.isDesignMode)
            return this.template;
        if (this.isRenderModeList || this.useTemplatePanel)
            return null;
        let res = this.getPropertyValue("currentPanel", null);
        if (!res && this.visiblePanelCount > 0) {
            res = this.visiblePanelsCore[0];
            this.currentPanel = res;
        }
        return res;
    }
    set currentPanel(val) {
        if (this.isRenderModeList || this.useTemplatePanel)
            return;
        const curPanel = this.getPropertyValue("currentPanel");
        const index = !!val ? this.visiblePanelsCore.indexOf(val) : -1;
        if (!!val && index < 0 || val === curPanel)
            return;
        if (curPanel) {
            curPanel.onHidingContent();
        }
        this.setPropertyValue("currentPanel", val);
        this.updateRenderedPanels();
        this.updateFooterActions();
        this.updateTabToolbarItemsPressedState();
        this.fireCallback(this.currentIndexChangedCallback);
        if (index > -1 && this.survey) {
            const options = {
                panel: val,
                visiblePanelIndex: index
            };
            this.survey.dynamicPanelCurrentIndexChanged(this, options);
        }
    }
    updateRenderedPanels() {
        if (this.isRenderModeList) {
            this.renderedPanels = [].concat(this.visiblePanels);
        }
        else if (this.currentPanel) {
            this.renderedPanels = [this.currentPanel];
        }
        else {
            this.renderedPanels = [];
        }
    }
    set renderedPanels(val) {
        if (this.renderedPanels.length == 0 || val.length == 0) {
            this.blockAnimations();
            this.panelsAnimation.sync(val);
            this.releaseAnimations();
        }
        else {
            this.isPanelsAnimationRunning = true;
            this.panelsAnimation.sync(val);
        }
    }
    get renderedPanels() {
        return this._renderedPanels;
    }
    getPanelsAnimationOptions() {
        const getDirectionCssClass = () => {
            if (this.isRenderModeList)
                return "";
            let cssClass = new CssClassBuilder();
            let isRemoving = false;
            const leavingPanel = this.renderedPanels.filter(el => el !== this.currentPanel)[0];
            let leavingPanelIndex = this.visiblePanels.indexOf(leavingPanel);
            if (leavingPanelIndex < 0) {
                isRemoving = true;
                leavingPanelIndex = this.removedPanelIndex;
            }
            return cssClass
                .append("sv-pd-animation-adding", !!this.focusNewPanelCallback)
                .append("sv-pd-animation-removing", isRemoving)
                .append("sv-pd-animation-left", leavingPanelIndex <= this.currentIndex)
                .append("sv-pd-animation-right", leavingPanelIndex > this.currentIndex)
                .toString();
        };
        return {
            getRerenderEvent: () => this.onElementRerendered,
            getAnimatedElement: (panel) => {
                var _a, _b;
                if (panel && this.cssContent) {
                    const contentSelector = classesToSelector(this.cssContent);
                    return (_b = (_a = this.getWrapperElement()) === null || _a === void 0 ? void 0 : _a.querySelector(`:scope ${contentSelector} #${panel.id}`)) === null || _b === void 0 ? void 0 : _b.parentElement;
                }
            },
            getEnterOptions: () => {
                const cssClass = new CssClassBuilder().append(this.cssClasses.panelWrapperEnter).append(getDirectionCssClass()).toString();
                return {
                    onBeforeRunAnimation: (el) => {
                        if (this.focusNewPanelCallback) {
                            const scolledElement = this.isRenderModeList ? el : el.parentElement;
                            SurveyElement.ScrollElementToViewCore(scolledElement, false, false, { behavior: "smooth" });
                        }
                        if (!this.isRenderModeList && el.parentElement) {
                            setPropertiesOnElementForAnimation(el.parentElement, { heightTo: el.offsetHeight + "px" });
                        }
                        else {
                            prepareElementForVerticalAnimation(el);
                        }
                    },
                    onAfterRunAnimation: (el) => {
                        cleanHtmlElementAfterAnimation(el);
                        if (el.parentElement) {
                            cleanHtmlElementAfterAnimation(el.parentElement);
                        }
                    },
                    cssClass: cssClass
                };
            },
            getLeaveOptions: () => {
                const cssClass = new CssClassBuilder().append(this.cssClasses.panelWrapperLeave).append(getDirectionCssClass()).toString();
                return {
                    onBeforeRunAnimation: (el) => {
                        if (!this.isRenderModeList && el.parentElement) {
                            setPropertiesOnElementForAnimation(el.parentElement, { heightFrom: el.offsetHeight + "px" });
                        }
                        else {
                            prepareElementForVerticalAnimation(el);
                        }
                    },
                    onAfterRunAnimation: (el) => {
                        cleanHtmlElementAfterAnimation(el);
                        if (el.parentElement) {
                            cleanHtmlElementAfterAnimation(el.parentElement);
                        }
                    },
                    cssClass: cssClass
                };
            },
            isAnimationEnabled: () => {
                return this.animationAllowed && !!this.getWrapperElement();
            },
        };
    }
    disablePanelsAnimations() {
        this.panelsCore.forEach((panel) => {
            panel.blockAnimations();
        });
    }
    enablePanelsAnimations() {
        this.panelsCore.forEach((panel) => {
            panel.releaseAnimations();
        });
    }
    updatePanelsAnimation() {
        this._panelsAnimations = new (this.isRenderModeList ? AnimationGroup : AnimationTab)(this.getPanelsAnimationOptions(), (val, isTempUpdate) => {
            this._renderedPanels = val;
            if (!isTempUpdate) {
                this.isPanelsAnimationRunning = false;
                this.focusNewPanel();
            }
        }, () => this._renderedPanels);
    }
    get panelsAnimation() {
        if (!this._panelsAnimations) {
            this.updatePanelsAnimation();
        }
        return this._panelsAnimations;
    }
    onHidingContent() {
        super.onHidingContent();
        if (this.currentPanel) {
            this.currentPanel.onHidingContent();
        }
        else {
            this.visiblePanelsCore.forEach(panel => panel.onHidingContent());
        }
    }
    /**
     * Specifies whether to display a confirmation dialog when a respondent wants to delete a panel.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/duplicate-group-of-fields-in-form/ (linkStyle))
     * @see confirmDeleteText
     */
    get confirmDelete() {
        return this.getPropertyValue("confirmDelete");
    }
    set confirmDelete(val) {
        this.setPropertyValue("confirmDelete", val);
    }
    /**
     * Specifies a key question. Set this property to the name of a question used in the template, and Dynamic Panel will display `keyDuplicationError` if a user tries to enter a duplicate value in this question.
     * @see keyDuplicationError
     */
    get keyName() {
        return this.getPropertyValue("keyName", "");
    }
    set keyName(val) {
        this.setPropertyValue("keyName", val);
    }
    /**
     * A message displayed in a confirmation dialog that appears when a respondent wants to delete a panel.
     * @see confirmDelete
     */
    get confirmDeleteText() {
        return this.getLocalizableStringText("confirmDeleteText");
    }
    set confirmDeleteText(val) {
        this.setLocalizableStringText("confirmDeleteText", val);
    }
    get locConfirmDeleteText() {
        return this.getLocalizableString("confirmDeleteText");
    }
    /**
     * An error message displayed when users enter a duplicate value into a question that accepts only unique values (`isUnique` is set to `true` or `keyName` is specified).
     *
     * A default value for this property is taken from a [localization dictionary](https://github.com/surveyjs/survey-library/tree/01bd8abd0c574719956d4d579d48c8010cd389d4/packages/survey-core/src/localization). Refer to the following help topic for more information: [Localization & Globalization](https://surveyjs.io/form-library/documentation/localization).
     * @see keyName
     */
    get keyDuplicationError() {
        return this.getLocalizableStringText("keyDuplicationError");
    }
    set keyDuplicationError(val) {
        this.setLocalizableStringText("keyDuplicationError", val);
    }
    get locKeyDuplicationError() {
        return this.getLocalizableString("keyDuplicationError");
    }
    /**
     * A caption for the Previous button. Applies only if `displayMode` is different from `"list"`.
     * @see displayMode
     * @see isPrevButtonVisible
     */
    get prevPanelText() { return this.getLocalizableStringText("prevPanelText"); }
    set prevPanelText(val) { this.setLocalizableStringText("prevPanelText", val); }
    get locPrevPanelText() { return this.getLocalizableString("prevPanelText"); }
    /**
     * @deprecated Use the [`prevPanelText`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#prevPanelText) property instead.
     */
    get panelPrevText() { return this.prevPanelText; }
    set panelPrevText(val) { this.prevPanelText = val; }
    get locPanelPrevText() { return this.locPrevPanelText; }
    /**
     * A caption for the Next button. Applies only if `displayMode` is different from `"list"`.
     * @see displayMode
     * @see isNextButtonVisible
     */
    get nextPanelText() { return this.getLocalizableStringText("nextPanelText"); }
    set nextPanelText(val) { this.setLocalizableStringText("nextPanelText", val); }
    get locNextPanelText() { return this.getLocalizableString("nextPanelText"); }
    /**
     * @deprecated Use the [`nextPanelText`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#nextPanelText) property instead.
     */
    get panelNextText() { return this.nextPanelText; }
    set panelNextText(val) { this.nextPanelText = val; }
    get locPanelNextText() { return this.locNextPanelText; }
    /**
     * A caption for the Add Panel button.
     */
    get addPanelText() { return this.getLocalizableStringText("addPanelText"); }
    set addPanelText(value) { this.setLocalizableStringText("addPanelText", value); }
    get locAddPanelText() { return this.getLocalizableString("addPanelText"); }
    /**
     * @deprecated Use the [`addPanelText`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#addPanelText) property instead.
     */
    get panelAddText() { return this.addPanelText; }
    set panelAddText(value) { this.addPanelText = value; }
    get locPanelAddText() { return this.locAddPanelText; }
    /**
     * A caption for the Remove Panel button.
     * @see removePanelButtonLocation
     */
    get removePanelText() { return this.getLocalizableStringText("removePanelText"); }
    set removePanelText(val) { this.setLocalizableStringText("removePanelText", val); }
    get locRemovePanelText() { return this.getLocalizableString("removePanelText"); }
    /**
     * @deprecated Use the [`removePanelText`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#removePanelText) property instead.
     */
    get panelRemoveText() { return this.removePanelText; }
    set panelRemoveText(val) { this.removePanelText = val; }
    get locPanelRemoveText() { return this.locRemovePanelText; }
    get isProgressTopShowing() {
        return this.displayMode == "carousel" && (this.progressBarLocation === "top" || this.progressBarLocation === "topBottom");
    }
    get isProgressBottomShowing() {
        return this.displayMode == "carousel" && (this.progressBarLocation === "bottom" || this.progressBarLocation === "topBottom");
    }
    /**
     * Indicates whether the Previous button is visible.
     * @see currentIndex
     * @see currentPanel
     * @see prevPanelText
     */
    get isPrevButtonVisible() { return this.currentIndex > 0; }
    get isPrevButtonShowing() { return this.isPrevButtonVisible; }
    /**
     * Indicates whether the Next button is visible.
     * @see currentIndex
     * @see currentPanel
     * @see nextPanelText
     */
    get isNextButtonVisible() {
        return this.currentIndex >= 0 && this.currentIndex < this.visiblePanelCount - 1;
    }
    get isNextButtonShowing() { return this.isNextButtonVisible; }
    get isRangeShowing() {
        return (this.showProgressBar && this.currentIndex >= 0 && this.visiblePanelCount > 1);
    }
    getElementsInDesign(includeHidden = false) {
        return includeHidden ? [this.template] : this.templateElements;
    }
    prepareValueForPanelCreating() {
        this.addingNewPanelsValue = this.value;
        this.isAddingNewPanels = true;
        this.isNewPanelsValueChanged = false;
    }
    setValueAfterPanelsCreating() {
        this.isAddingNewPanels = false;
        if (this.isNewPanelsValueChanged) {
            this.isValueChangingInternally = true;
            this.value = this.addingNewPanelsValue;
            this.isValueChangingInternally = false;
        }
    }
    getValueCore() {
        return this.isAddingNewPanels
            ? this.addingNewPanelsValue
            : super.getValueCore();
    }
    setValueCore(newValue) {
        if (this.isAddingNewPanels) {
            this.isNewPanelsValueChanged = true;
            this.addingNewPanelsValue = newValue;
        }
        else {
            super.setValueCore(newValue);
        }
    }
    setIsMobile(val) {
        super.setIsMobile(val);
        (this.panelsCore || []).forEach(panel => panel.getQuestions(true).forEach(question => {
            question.setIsMobile(val);
        }));
    }
    themeChanged(theme) {
        super.themeChanged(theme);
        (this.panelsCore || []).forEach(panel => panel.getQuestions(true).forEach(question => {
            question.themeChanged(theme);
        }));
    }
    /**
     * The number of panels in Dynamic Panel.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/duplicate-group-of-fields-in-form/ (linkStyle))
     * @see minPanelCount
     * @see maxPanelCount
     */
    get panelCount() {
        return !this.canBuildPanels || this.wasNotRenderedInSurvey
            ? this.getPropertyValue("panelCount")
            : this.panelsCore.length;
    }
    set panelCount(val) {
        if (val < 0)
            return;
        if (!this.isLoadingFromJson && this.isDesignMode) {
            const min = this.minPanelCount;
            if (val < min) {
                val = min;
            }
            const max = this.maxPanelCount;
            if (max > 0 && val > max) {
                val = max;
            }
        }
        if (!this.canBuildPanels || this.wasNotRenderedInSurvey) {
            this.setPropertyValue("panelCount", val);
            this.updateFooterActions();
            return;
        }
        if (val == this.panelsCore.length || this.useTemplatePanel)
            return;
        this.updateBindings("panelCount", val);
        this.prepareValueForPanelCreating();
        const isAddingOnePanel = val - this.panelCount === 1;
        for (let i = this.panelCount; i < val; i++) {
            const panel = this.createNewPanel();
            this.panelsCore.push(panel);
            if (this.displayMode == "list" && this.panelsState != "default") {
                if (this.panelsState === "expanded") {
                    panel.expand();
                }
                else {
                    if (!!panel.title) {
                        panel.collapse();
                    }
                }
            }
        }
        if (isAddingOnePanel) {
            this.singleInputOnAddItem(this.settingPanelCountBasedOnValue);
        }
        if (val < this.panelCount) {
            this.panelsCore.splice(val, this.panelCount - val);
        }
        this.disablePanelsAnimations();
        this.setValueAfterPanelsCreating();
        this.setValueBasedOnPanelCount();
        this.reRunCondition();
        this.updateFooterActions();
        this.fireCallback(this.panelCountChangedCallback);
        this.enablePanelsAnimations();
    }
    /**
     * Returns the number of visible panels in Dynamic Panel.
     * @see templateVisibleIf
     */
    get visiblePanelCount() { return this.visiblePanels.length; }
    /**
     * Specifies whether users can expand and collapse panels. Applies if `displayMode` is `"list"` and the `templateTitle` property is specified.
     *
     * Possible values:
     *
     * - `"default"` (default) - All panels are displayed in full and cannot be collapsed.
     * - `"expanded"` - All panels are displayed in full and can be collapsed in the UI.
     * - `"collapsed"` - All panels display only their titles and descriptions and can be expanded in the UI.
     * - `"firstExpanded"` - Only the first panel is displayed in full; other panels are collapsed and can be expanded in the UI.
     * @see displayMode
     * @see templateTitle
     */
    get panelsState() {
        return this.getPropertyValue("panelsState");
    }
    set panelsState(val) {
        this.setPropertyValue("panelsState", val);
    }
    setTemplatePanelSurveyImpl() {
        this.template.setSurveyImpl(this.useTemplatePanel
            ? this.surveyImpl
            : new QuestionPanelDynamicTemplateSurveyImpl(this));
    }
    setPanelsSurveyImpl() {
        for (var i = 0; i < this.panelsCore.length; i++) {
            var panel = this.panelsCore[i];
            if (panel == this.template)
                continue;
            panel.setSurveyImpl(panel.data);
        }
    }
    setPanelsState() {
        if (this.useTemplatePanel || this.displayMode != "list" || !this.templateTitle)
            return;
        for (var i = 0; i < this.panelsCore.length; i++) {
            var state = this.panelsState;
            if (state === "firstExpanded") {
                state = i === 0 ? "expanded" : "collapsed";
            }
            this.panelsCore[i].state = state;
        }
    }
    setValueBasedOnPanelCount() {
        var value = this.value;
        if (!value || !Array.isArray(value))
            value = [];
        if (value.length == this.panelCount)
            return;
        for (var i = value.length; i < this.panelCount; i++) {
            const panelValue = this.panels[i].getValue();
            const val = !Helpers.isValueEmpty(panelValue) ? panelValue : {};
            value.push(val);
        }
        if (value.length > this.panelCount) {
            value.splice(this.panelCount, value.length - this.panelCount);
        }
        this.isValueChangingInternally = true;
        this.value = value;
        this.isValueChangingInternally = false;
    }
    /**
     * A minimum number of panels in Dynamic Panel. Users cannot delete panels if `panelCount` equals `minPanelCount`.
     *
     * Default value: 0
     * @see panelCount
     * @see maxPanelCount
     * @see allowRemovePanel
     */
    get minPanelCount() {
        return this.getPropertyValue("minPanelCount");
    }
    set minPanelCount(val) {
        if (val < 0)
            val = 0;
        this.setPropertyValue("minPanelCount", val);
    }
    onMinPanelCountChanged() {
        const val = this.minPanelCount;
        if (val > this.maxPanelCount)
            this.maxPanelCount = val;
        if (this.panelCount < val)
            this.panelCount = val;
    }
    /**
     * A maximum number of panels in Dynamic Panel. Users cannot add new panels if `panelCount` equals `maxPanelCount`.
     *
     * Default value: 100 (inherited from [`settings.panel.maxPanelCount`](https://surveyjs.io/form-library/documentation/settings#panelMaximumPanelCount))
     *
     * [View Demo](https://surveyjs.io/form-library/examples/duplicate-group-of-fields-in-form/ (linkStyle))
     * @see panelCount
     * @see minPanelCount
     * @see allowAddPanel
     */
    get maxPanelCount() {
        return this.getPropertyValue("maxPanelCount");
    }
    set maxPanelCount(val) {
        if (val <= 0)
            return;
        if (val > settings.panel.maxPanelCount)
            val = settings.panel.maxPanelCount;
        this.setPropertyValue("maxPanelCount", val);
        this.updateFooterActions();
    }
    onMaxPanelCountChanged() {
        const val = this.maxPanelCount;
        if (val < this.minPanelCount)
            this.minPanelCount = val;
        if (this.panelCount > val)
            this.panelCount = val;
        this.updateFooterActions();
    }
    /**
     * Specifies whether users are allowed to add new panels.
     *
     * Default value: `true`
     *
     * By default, users add new panels to the end. If you want to let users insert a new panel after the current panel, set the [`newPanelPosition`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#newPanelPosition) property to `"next"`.
     * @see canAddPanel
     * @see allowRemovePanel
     */
    get allowAddPanel() {
        return this.getPropertyValue("allowAddPanel");
    }
    set allowAddPanel(val) {
        this.setPropertyValue("allowAddPanel", val);
    }
    get addButtonId() {
        return this.id + "addPanel";
    }
    /**
     * Specifies the position of newly added panels.
     *
     * Possible values:
     *
     * - `"last"` (default) - New panels are added to the end.
     * - `"next"` - New panels are inserted after the current panel.
     * @see allowAddPanel
     * @see addPanel
     */
    get newPanelPosition() {
        return this.getPropertyValue("newPanelPosition");
    }
    set newPanelPosition(val) {
        this.setPropertyValue("newPanelPosition", val);
    }
    /**
     * Specifies whether users are allowed to delete panels.
     *
     * Default value: `true`
     * @see canRemovePanel
     * @see allowAddPanel
     */
    get allowRemovePanel() {
        return this.getPropertyValue("allowRemovePanel");
    }
    set allowRemovePanel(val) {
        this.setPropertyValue("allowRemovePanel", val);
    }
    /**
     * Gets or sets the location of question titles relative to their input fields.
     *
     * - `"default"` (default) - Inherits the setting from the Dynamic Panel's `titleLocation` property, which in turn inherits the [`questionTitleLocation`](https://surveyjs.io/form-library/documentation/surveymodel#questionTitleLocation) property value specified for the Dynamic Panel's container (page or survey).
     * - `"top"` - Displays question titles above input fields.
     * - `"bottom"` - Displays question titles below input fields.
     * - `"left"` - Displays question titles to the left of input fields.
     * - `"hidden"` - Hides question titles.
     * @see titleLocation
     */
    get templateQuestionTitleLocation() {
        return this.getPropertyValue("templateQuestionTitleLocation");
    }
    set templateQuestionTitleLocation(val) {
        this.setPropertyValue("templateQuestionTitleLocation", val);
    }
    /**
     * @deprecated Use the [`templateQuestionTitleLocation`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#templateQuestionTitleLocation) property instead.
     */
    get templateTitleLocation() {
        return this.templateQuestionTitleLocation;
    }
    set templateTitleLocation(val) {
        this.templateQuestionTitleLocation = val;
    }
    /**
     * Sets consistent width for question titles in CSS values. Applies only when [`templateQuestionTitleLocation`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#templateQuestionTitleLocation) evaluates to `"left"`.
     *
     * Default value: `undefined` (inherits the actual value from the [`questionTitleWidth`](https://surveyjs.io/form-library/documentation/api-reference/page-model#questionTitleWidth) property of the parent panel or page.
     */
    get templateQuestionTitleWidth() {
        return this.template.questionTitleWidth;
    }
    set templateQuestionTitleWidth(val) {
        this.template.questionTitleWidth = val;
    }
    /**
     * Specifies the error message position.
     *
     * Possible values:
     *
     * - `"default"` (default) - Inherits the setting from the [`errorLocation`](#errorLocation) property.
     * - `"top"` - Displays error messages above questions.
     * - `"bottom"` - Displays error messages below questions.
     */
    get templateErrorLocation() {
        return this.getPropertyValue("templateErrorLocation");
    }
    set templateErrorLocation(value) {
        this.setPropertyValue("templateErrorLocation", value.toLowerCase());
    }
    resetSingleInput() {
        super.resetSingleInput();
        this.locTemplateTitle.onGetTextCallback = null;
    }
    getSingleInputQuestionsCore(question, checkDynamic) {
        this.onFirstRendering();
        const res = new Array();
        const panels = this.visiblePanels;
        if (checkDynamic) {
            for (let i = 0; i < panels.length; i++) {
                const panel = panels[i];
                if (!panel.hasValueAnyQuestion(true) || panel.hasErrors(false, false)) {
                    this.fillSingleInputQuestionsByPanel(res, panel);
                }
            }
        }
        return this.getSingleInputQuestionsForDynamic(question, res);
    }
    fillSingleInputQuestionsInContainer(res, innerQuestion) {
        const panel = this.getPanelByQuestion(innerQuestion);
        this.fillSingleInputQuestionsByPanel(res, panel);
    }
    fillSingleInputQuestionsByPanel(res, panel) {
        if (panel) {
            panel.questions.forEach(q => q.addNestedQuestion(res, true, false, false));
        }
    }
    getSingleQuestionLocTitleCore() {
        const res = this.locTemplateTitle;
        res.onGetTextCallback = (text) => {
            const q = this.singleInputQuestion;
            if (!q)
                return text;
            return this.processSingleInputTitle(text, this.getPanelByQuestion(q));
        };
        return res;
    }
    processSingleInputTitle(text, panel) {
        if (!text)
            text = this.getSingleInputTitleTemplate();
        if (!panel)
            return text;
        return panel.getProcessedText(text);
    }
    getSingleInputTitleTemplate() {
        return this.getLocalizationString("panelDynamicTabTextFormat");
    }
    getPanelByQuestion(question) {
        let parent = question.parent;
        while (!!parent && !!parent.parent) {
            parent = parent.parent;
        }
        return parent;
    }
    getSingleInputAddTextCore() {
        if (!this.canAddPanel)
            return undefined;
        return this.panelAddText;
    }
    singleInputAddItemCore() {
        this.addPanelUI();
    }
    singleInputRemoveItemCore(question) {
        const panel = this.getPanelByQuestion(question);
        const index = this.visiblePanelsCore.indexOf(panel);
        this.removePanelUI(index);
    }
    getSingleQuestionOnChange(index) {
        const panels = this.visiblePanelsCore;
        if (panels.length > 0) {
            if (index < 0 || index >= panels.length)
                index = panels.length - 1;
            const row = panels[index];
            const vQs = row.visibleQuestions;
            if (vQs.length > 0) {
                return vQs[0];
            }
        }
        return null;
    }
    createSingleInputSummary() {
        const res = new QuestionSingleInputSummary(this, this.locNoEntriesText);
        const items = new Array();
        this.visiblePanels.forEach((panel) => {
            const locText = new LocalizableString(this, true, undefined, this.locTemplateTitle.localizationName);
            locText.setJson(this.locTemplateTitle.getJson());
            locText.onGetTextCallback = (text) => {
                return this.processSingleInputTitle(this.templateTitle, panel);
            };
            const bntEdit = new Action({ locTitle: this.getLocalizableString("editPanelText"), action: () => { this.singInputEditPanel(panel); } });
            const btnRemove = this.canRemovePanel ? new Action({ locTitle: this.locPanelRemoveText, action: () => { this.removePanelUI(panel); } }) : undefined;
            items.push(new QuestionSingleInputSummaryItem(locText, bntEdit, btnRemove));
        });
        res.items = items;
        return res;
    }
    singleInputMoveToFirstCore() {
        var _a;
        let panel = (_a = this.singleInputQuestion) === null || _a === void 0 ? void 0 : _a.parent;
        while (!!panel && !!panel.parent) {
            panel = panel.parent;
        }
        this.singInputEditPanel(panel);
    }
    singInputEditPanel(panel) {
        if (!panel)
            return;
        const qs = panel.visibleQuestions;
        if (qs.length > 0) {
            this.setSingleInputQuestion(qs[0]);
        }
    }
    /**
     * Specifies whether to display survey element numbers within the dynamic panel and how to calculate them.
     *
     * Possible values:
     *
     * - `"onSurvey"` - Continues numbering across the entire survey.
     * - `"onPanel"` - Starts numbering within the dynamic panel from scratch.
     * - `"off"` (default) - Hides question numbers.
     */
    get showQuestionNumbers() {
        return this.getPropertyValue("showQuestionNumbers");
    }
    set showQuestionNumbers(val) {
        this.setPropertyValue("showQuestionNumbers", val);
        if (!this.isLoadingFromJson && this.survey) {
            this.survey.questionVisibilityChanged(this, this.visible, true);
        }
    }
    notifySurveyOnChildrenVisibilityChanged() { return this.showQuestionNumbers === "onSurvey"; }
    /**
     * Specifies the location of the Remove Panel button relative to panel content.
     *
     * Possible values:
     *
     * - `"bottom"` (default) - Displays the Remove Panel button below panel content.
     * - `"right"` - Displays the Remove Panel button to the right of panel content.
     * @see removePanelText
     */
    get removePanelButtonLocation() {
        return this.getPropertyValue("removePanelButtonLocation");
    }
    set removePanelButtonLocation(val) {
        this.setPropertyValue("removePanelButtonLocation", val);
    }
    /**
     * @deprecated Use the [`removePanelButtonLocation`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#removePanelButtonLocation) property instead.
     */
    get panelRemoveButtonLocation() { return this.removePanelButtonLocation; }
    set panelRemoveButtonLocation(val) { this.removePanelButtonLocation = val; }
    /**
     * @deprecated Use the [`showProgressBar`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#showProgressBar) property instead.
     */
    get showRangeInProgress() {
        return this.showProgressBar;
    }
    set showRangeInProgress(val) {
        this.showProgressBar = val;
    }
    /**
     * @deprecated Use the [`displayMode`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#displayMode) property instead.
     */
    get renderMode() {
        let displayMode = this.displayMode;
        if (displayMode == "carousel") {
            const progressBarLocation = this.progressBarLocation;
            if (progressBarLocation == "top") {
                return "progressTop";
            }
            else if (progressBarLocation == "bottom") {
                return "progressBottom";
            }
            else if (progressBarLocation == "topBottom") {
                return "progressTopBottom";
            }
        }
        return displayMode;
    }
    set renderMode(val) {
        if ((val || "").startsWith("progress")) {
            if (val == "progressTop") {
                this.progressBarLocation = "top";
            }
            else if (val == "progressBottom") {
                this.progressBarLocation = "bottom";
            }
            else if (val == "progressTopBottom") {
                this.progressBarLocation = "topBottom";
            }
            this.displayMode = "carousel";
        }
        else {
            this.displayMode = val;
        }
        // this.updatePanelView();
    }
    updatePanelView() {
        this.blockAnimations();
        this.updateRenderedPanels();
        this.releaseAnimations();
        this.updatePanelsAnimation();
    }
    get tabAlign() {
        return this.getPropertyValue("tabAlign");
    }
    set tabAlign(val) {
        this.setPropertyValue("tabAlign", val);
        if (this.isRenderModeTab) {
            this.tabbedMenu.containerCss = this.getTabbedMenuCss();
        }
    }
    get isRenderModeList() {
        return this.displayMode === "list" || this.isSingleInputActive;
    }
    get isRenderModeTab() {
        return this.displayMode === "tab" && !this.isSingleInputActive;
    }
    setVisibleIndex(value) {
        if (!this.isVisible)
            return 0;
        const onSurveyNumbering = this.showQuestionNumbers === "onSurvey";
        let startIndex = onSurveyNumbering ? value : 0;
        const panels = this.isDesignMode ? [this.template] : this.visiblePanelsCore;
        for (let i = 0; i < panels.length; i++) {
            let counter = this.setPanelVisibleIndex(panels[i], startIndex, this.showQuestionNumbers != "off");
            if (onSurveyNumbering) {
                startIndex += counter;
            }
        }
        super.setVisibleIndex(!onSurveyNumbering ? value : -1);
        return !onSurveyNumbering ? 1 : startIndex - value;
    }
    setPanelVisibleIndex(panel, index, showIndex) {
        if (!showIndex) {
            panel.setVisibleIndex(-1);
            return 0;
        }
        return panel.setVisibleIndex(index);
    }
    /**
     * Indicates whether it is possible to add a new panel.
     *
     * This property returns `true` when all of the following conditions apply:
     *
     * - Users are allowed to add new panels (`allowAddPanel` is `true`).
     * - Dynamic Panel or its parent survey is not in read-only state.
     * - `panelCount` is less than `maxPanelCount`.
     * @see allowAddPanel
     * @see isReadOnly
     * @see panelCount
     * @see maxPanelCount
     * @see canRemovePanel
     */
    get canAddPanel() {
        if (this.isDesignMode)
            return false;
        if (!this.legacyNavigation && !this.isRenderModeList &&
            (this.currentIndex < this.visiblePanelCount - 1 && this.newPanelPosition !== "next")) {
            return false;
        }
        return (this.allowAddPanel &&
            !this.isReadOnly &&
            this.panelCount < this.maxPanelCount);
    }
    /**
     * Indicates whether it is possible to delete panels.
     *
     * This property returns `true` when all of the following conditions apply:
     *
     * - Users are allowed to delete panels (`allowRemovePanel` is `true`).
     * - Dynamic Panel or its parent survey is not in read-only state.
     * - `panelCount` exceeds `minPanelCount`.
     * @see allowRemovePanel
     * @see isReadOnly
     * @see panelCount
     * @see minPanelCount
     * @see canAddPanel
     */
    get canRemovePanel() {
        if (this.isDesignMode)
            return false;
        return (this.allowRemovePanel &&
            !this.isReadOnly &&
            this.panelCount > this.minPanelCount);
    }
    rebuildPanels() {
        if (this.isLoadingFromJson)
            return;
        this.prepareValueForPanelCreating();
        var panels = [];
        if (this.useTemplatePanel) {
            new QuestionPanelDynamicItem(this, this.template);
            panels.push(this.template);
        }
        else {
            for (var i = 0; i < this.panelCount; i++) {
                this.createNewPanel();
                panels.push(this.createNewPanel());
            }
        }
        this.panelsCore.splice(0, this.panelsCore.length, ...panels);
        this.setValueAfterPanelsCreating();
        this.setPanelsState();
        this.reRunCondition();
        this.updateFooterActions();
        this.fireCallback(this.panelCountChangedCallback);
        this.updateTabToolbar();
    }
    /**
     * If it is not empty, then this value is set to every new panel, including panels created initially, unless the defaultValue is not empty
     * @see defaultValue
     * @see copyDefaultValueFromLastEntry
     */
    get defaultPanelValue() {
        return this.getPropertyValue("defaultPanelValue");
    }
    set defaultPanelValue(val) {
        this.setPropertyValue("defaultPanelValue", val);
    }
    /**
     * Specifies whether default values for a new panel should be copied from the last panel.
     *
     * If you also specify `defaultValue`, it will be merged with the copied values.
     * @see defaultValue
     */
    get copyDefaultValueFromLastEntry() {
        return this.getPropertyValue("copyDefaultValueFromLastEntry");
    }
    set copyDefaultValueFromLastEntry(val) {
        this.setPropertyValue("copyDefaultValueFromLastEntry", val);
    }
    /**
     * @deprecated Use the [`copyDefaultValueFromLastEntry`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#copyDefaultValueFromLastEntry) property instead.
     */
    get defaultValueFromLastPanel() {
        return this.copyDefaultValueFromLastEntry;
    }
    set defaultValueFromLastPanel(val) {
        this.copyDefaultValueFromLastEntry = val;
    }
    isDefaultValueEmpty() {
        return (super.isDefaultValueEmpty() && this.isValueEmpty(this.defaultPanelValue));
    }
    setDefaultValue() {
        if (this.isValueEmpty(this.defaultPanelValue) ||
            !this.isValueEmpty(this.defaultValue)) {
            super.setDefaultValue();
            return;
        }
        if (!this.isEmpty() || this.panelCount == 0)
            return;
        var newValue = [];
        for (var i = 0; i < this.panelCount; i++) {
            newValue.push(this.defaultPanelValue);
        }
        this.value = newValue;
    }
    get isValueArray() { return true; }
    isEmpty() {
        var val = this.value;
        if (!val || !Array.isArray(val))
            return true;
        for (var i = 0; i < val.length; i++) {
            if (!this.isRowEmpty(val[i]))
                return false;
        }
        return true;
    }
    getProgressInfo() {
        return SurveyElement.getProgressInfoByElements(this.visiblePanelsCore, this.isRequired);
    }
    isRowEmpty(val) {
        for (var prop in val) {
            if (val.hasOwnProperty(prop))
                return false;
        }
        return true;
    }
    /**
     * @deprecated Call the [`addPanel(undefined, true)`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#addPanel) method instead.
     */
    addPanelUI() {
        return this.addPanel(undefined, true);
    }
    /**
     * Adds a new panel based on the [template](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#template).
     * @param index *(Optional)* An index at which to insert the new panel. `undefined` adds the panel to the end or inserts it after the current panel if [`displayMode`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#renderMode) is `"tab"`. A negative index (for instance, -1) adds the panel to the end in all cases, regardless of the `displayMode` value.
     * @param runAdditionalActions *(Optional)* Pass `true` if you want to perform additional actions: check whether a new panel [can be added](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#canAddPanel), expand and focus the new panel, and run animated effects. Default value: `false` (the listed actions are skipped).
     * @see panelCount
     * @see panels
     * @see allowAddPanel
     * @see newPanelPosition
     */
    addPanel(index, runAdditionalActions) {
        const isUI = runAdditionalActions === true;
        if (isUI) {
            if (!this.canAddPanel)
                return null;
            if (!this.canLeaveCurrentPanel())
                return null;
        }
        const newPanel = this.addPanelCore(index);
        if (isUI) {
            if (this.displayMode === "list" && this.panelsState !== "default") {
                newPanel.expand();
            }
            this.focusNewPanelCallback = () => {
                newPanel.focusFirstQuestion();
            };
            if (!this.isPanelsAnimationRunning) {
                this.focusNewPanel();
            }
        }
        return newPanel;
    }
    addPanelCore(index) {
        const curIndex = this.currentIndex;
        if (index === undefined) {
            index = curIndex < 0 ? this.panelCount : curIndex + 1;
        }
        if (index < 0 || index > this.panelCount) {
            index = this.panelCount;
        }
        this.updateValueOnAddingPanel(curIndex < 0 ? this.panelCount - 1 : curIndex, index);
        if (!this.isRenderModeList) {
            this.currentIndex = index;
        }
        this.notifyOnPanelAddedRemoved(true, index);
        return this.panelsCore[index];
    }
    focusNewPanel() {
        if (this.focusNewPanelCallback) {
            this.focusNewPanelCallback();
            this.focusNewPanelCallback = undefined;
        }
    }
    updateValueOnAddingPanel(prevIndex, index) {
        this.panelCount++;
        let newValue = this.value;
        if (!Array.isArray(newValue) || newValue.length !== this.panelCount)
            return;
        let hasModified = false;
        const lastIndex = this.panelCount - 1;
        if (index < lastIndex) {
            hasModified = true;
            const rec = newValue[lastIndex];
            newValue.splice(lastIndex, 1);
            newValue.splice(index, 0, rec);
        }
        if (!this.isValueEmpty(this.defaultPanelValue)) {
            hasModified = true;
            this.copyValue(newValue[index], this.defaultPanelValue);
        }
        if (this.copyDefaultValueFromLastEntry && newValue.length > 1) {
            const fromIndex = prevIndex > -1 && prevIndex <= lastIndex ? prevIndex : lastIndex;
            hasModified = true;
            this.copyValue(newValue[index], newValue[fromIndex]);
        }
        if (hasModified) {
            this.value = newValue;
        }
    }
    canLeaveCurrentPanel() {
        return !(this.displayMode !== "list" && this.currentPanel && this.currentPanel.hasErrors(true, true));
    }
    copyValue(dest, src) {
        for (var key in src) {
            dest[key] = src[key];
        }
    }
    getPanelRemoveButtonId(panel) {
        return panel.id + "_remove_button";
    }
    isRequireConfirmOnDelete(val) {
        if (!this.confirmDelete)
            return false;
        const index = this.getVisualPanelIndex(val);
        if (index < 0 || index >= this.visiblePanelCount)
            return false;
        const panelValue = this.visiblePanelsCore[index].getValue();
        return !this.isValueEmpty(panelValue) &&
            (this.isValueEmpty(this.defaultPanelValue) || !this.isTwoValueEquals(panelValue, this.defaultPanelValue));
    }
    /**
     * Switches Dynamic Panel to the next panel. Returns `true` in case of success, or `false` if `displayMode` is `"list"` or the current panel contains validation errors.
     * @see displayMode
     */
    goToNextPanel() {
        if (this.currentIndex < 0)
            return false;
        if (!this.canLeaveCurrentPanel())
            return false;
        this.currentIndex++;
        return true;
    }
    /**
     * Switches Dynamic Panel to the previous panel.
     */
    goToPrevPanel() {
        if (this.currentIndex < 0)
            return;
        this.currentIndex--;
    }
    /**
     * @deprecated Call the [`removePanel(value, true)`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#removePanel) method instead.
     */
    removePanelUI(value) {
        this.removePanel(value, this.isRequireConfirmOnDelete(value));
    }
    /**
     * Deletes a panel from the [`panels`](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#panels) array.
     * @param value A `PanelModel` instance or zero-based panel index.
     * @param confirmDelete *(Optional)* Pass `true` if you want to perform additional actions: check whether the panel [can be removed](https://surveyjs.io/form-library/documentation/api-reference/dynamic-panel-model#canRemovePanel) and display a confirmation dialog.
     * @see addPanel
     */
    removePanel(value, confirmDelete) {
        const visIndex = this.getVisualPanelIndex(value);
        if (visIndex < 0 || visIndex >= this.visiblePanelCount)
            return;
        const isUI = confirmDelete !== undefined;
        if (isUI) {
            if (!this.canRemovePanel)
                return;
            const removePanel = () => {
                var _a;
                this.removePanelCore(visIndex);
                const pnlCount = this.visiblePanelCount;
                const nextIndex = visIndex >= pnlCount ? pnlCount - 1 : visIndex;
                let id = pnlCount === 0 ? this.addButtonId : (nextIndex > -1 ? this.getPanelRemoveButtonId(this.visiblePanels[nextIndex]) : "");
                if (!!id) {
                    SurveyElement.FocusElement(id, true, (_a = this.survey) === null || _a === void 0 ? void 0 : _a.rootElement);
                }
            };
            if (confirmDelete) {
                confirmActionAsync({
                    message: this.confirmDeleteText,
                    funcOnYes: () => { removePanel(); },
                    locale: this.getLocale(),
                    rootElement: this.survey.rootElement,
                    cssClass: this.cssClasses.confirmDialog
                });
            }
            else {
                removePanel();
            }
        }
        else {
            this.removePanelCore(visIndex);
        }
    }
    removePanelCore(visIndex) {
        this.removedPanelIndex = visIndex;
        const panel = this.visiblePanelsCore[visIndex];
        const index = this.panelsCore.indexOf(panel);
        if (index < 0)
            return;
        if (this.survey && !this.survey.dynamicPanelRemoving(this, index, panel))
            return;
        this.panelsCore.splice(index, 1);
        this.updateBindings("panelCount", this.panelCount);
        this.singleInputOnRemoveItem(visIndex);
        var value = this.value;
        if (!value || !Array.isArray(value) || index >= value.length) {
            this.updateFooterActions();
        }
        else {
            this.isValueChangingInternally = true;
            value.splice(index, 1);
            this.value = value;
            this.updateFooterActions();
            this.fireCallback(this.panelCountChangedCallback);
            this.notifyOnPanelAddedRemoved(false, index, panel);
            this.isValueChangingInternally = false;
        }
    }
    notifyOnPanelAddedRemoved(isAdded, index, panel) {
        if (!panel) {
            panel = this.panelsCore[index];
        }
        if (this.survey) {
            const updateIndeces = this.showQuestionNumbers === "onSurvey";
            if (isAdded) {
                this.survey.dynamicPanelAdded(this, index, panel, updateIndeces);
            }
            else {
                this.survey.dynamicPanelRemoved(this, index, panel, updateIndeces);
            }
        }
        if (isAdded && !!panel && this.showQuestionNumbers === "onPanel") {
            panel.setVisibleIndex(0);
        }
    }
    getVisualPanelIndex(val) {
        if (Helpers.isNumber(val))
            return val;
        const visPanels = this.visiblePanelsCore;
        for (var i = 0; i < visPanels.length; i++) {
            if (visPanels[i] === val || visPanels[i].data === val)
                return i;
        }
        return -1;
    }
    getPanelVisibleIndexById(id) {
        const visPanels = this.visiblePanelsCore;
        for (var i = 0; i < visPanels.length; i++) {
            if (visPanels[i].id === id)
                return i;
        }
        return -1;
    }
    locStrsChanged() {
        super.locStrsChanged();
        this.locTemplateTitle.strChanged();
        var panels = this.panelsCore;
        for (var i = 0; i < panels.length; i++) {
            panels[i].locStrsChanged();
        }
        if (this.tabbedMenu) {
            this.tabbedMenu.locStrsChanged();
        }
    }
    clearIncorrectValues() {
        for (var i = 0; i < this.panelsCore.length; i++) {
            this.clearIncorrectValuesInPanel(i);
        }
    }
    clearErrors() {
        super.clearErrors();
        for (var i = 0; i < this.panelsCore.length; i++) {
            this.panelsCore[i].clearErrors();
        }
    }
    getQuestionFromArray(name, index) {
        if (index < 0 || index >= this.panelsCore.length)
            return null;
        return this.panelsCore[index].getQuestionByName(name);
    }
    clearIncorrectValuesInPanel(index) {
        var panel = this.panelsCore[index];
        panel.clearIncorrectValues();
        var val = this.value;
        var values = !!val && index < val.length ? val[index] : null;
        if (!values)
            return;
        var isChanged = false;
        for (var key in values) {
            if (this.getSharedQuestionFromArray(key, index))
                continue;
            var q = panel.getQuestionByName(key);
            if (!!q)
                continue;
            if (this.iscorrectValueWithPostPrefix(panel, key, settings.commentSuffix) ||
                this.iscorrectValueWithPostPrefix(panel, key, settings.matrix.totalsSuffix))
                continue;
            delete values[key];
            isChanged = true;
        }
        if (isChanged) {
            val[index] = values;
            this.value = val;
        }
    }
    iscorrectValueWithPostPrefix(panel, key, postPrefix) {
        if (key.indexOf(postPrefix) !== key.length - postPrefix.length)
            return false;
        return !!panel.getQuestionByName(key.substring(0, key.indexOf(postPrefix)));
    }
    getSharedQuestionFromArray(name, panelIndex) {
        return !!this.survey && !!this.valueName ? (this.survey.getQuestionByValueNameFromArray(this.valueName, name, panelIndex)) : null;
    }
    addConditionObjectsByContext(objects, context) {
        const contextQ = !!(context === null || context === void 0 ? void 0 : context.isValidator) ? context.errorOwner : context;
        const hasContext = !!context && (context === true || this.template.questions.indexOf(contextQ) > -1);
        const panelObjs = new Array();
        const questions = this.template.questions;
        for (var i = 0; i < questions.length; i++) {
            questions[i].addConditionObjectsByContext(panelObjs, context);
        }
        for (var index = 0; index < settings.panel.maxPanelCountInCondition; index++) {
            const indexStr = "[" + index + "].";
            const prefixName = this.getValueName() + indexStr;
            const prefixText = this.processedTitle + indexStr;
            for (var i = 0; i < panelObjs.length; i++) {
                if (!!panelObjs[i].context) {
                    objects.push(panelObjs[i]);
                }
                else {
                    objects.push({
                        name: prefixName + panelObjs[i].name,
                        text: prefixText + panelObjs[i].text,
                        question: panelObjs[i].question,
                    });
                }
            }
        }
        if (hasContext) {
            const prefixName = context === true ? this.getValueName() + "." : "";
            const prefixText = context === true ? this.processedTitle + "." : "";
            for (var i = 0; i < panelObjs.length; i++) {
                if (panelObjs[i].question == context)
                    continue;
                const obj = {
                    name: prefixName + QuestionPanelDynamicItem.ItemVariableName + "." + panelObjs[i].name,
                    text: prefixText + QuestionPanelDynamicItem.ItemVariableName + "." + panelObjs[i].text,
                    question: panelObjs[i].question
                };
                obj.context = this;
                objects.push(obj);
            }
        }
    }
    collectNestedQuestionsCore(questions, visibleOnly, includeNested, includeItSelf) {
        if (includeItSelf) {
            questions.push(this);
        }
        const panels = visibleOnly ? this.visiblePanelsCore : this.panelsCore;
        if (!Array.isArray(panels))
            return;
        panels.forEach(panel => {
            panel.questions.forEach(q => q.addNestedQuestion(questions, visibleOnly, includeNested, includeItSelf));
        });
    }
    getConditionJson(operator = null, path = null) {
        if (!path)
            return super.getConditionJson(operator);
        var questionName = path;
        var pos = path.indexOf(".");
        if (pos > -1) {
            questionName = path.substring(0, pos);
            path = path.substring(pos + 1);
        }
        var question = this.template.getQuestionByName(questionName);
        if (!question)
            return null;
        return question.getConditionJson(operator, path);
    }
    onReadOnlyChanged() {
        var readOnly = this.isReadOnly;
        this.template.readOnly = readOnly;
        for (var i = 0; i < this.panelsCore.length; i++) {
            this.panelsCore[i].readOnly = readOnly;
        }
        this.updateNoEntriesTextDefaultLoc();
        this.updateFooterActions();
        super.onReadOnlyChanged();
    }
    updateNoEntriesTextDefaultLoc() {
        const loc = this.getLocalizableString("noEntriesText");
        if (!loc)
            return;
        loc.localizationName = (this.isReadOnly || !this.allowAddPanel) ? "noEntriesReadonlyText" : "noEntriesText";
    }
    onSurveyLoad() {
        this.template.readOnly = this.isReadOnly;
        this.template.onSurveyLoad();
        if (this.panelCount < this.minPanelCount) {
            this.panelCount = this.minPanelCount;
        }
        if (this.panelCount > this.maxPanelCount) {
            this.panelCount = this.maxPanelCount;
        }
        this.buildPanelsFirstTime();
        super.onSurveyLoad();
    }
    buildPanelsFirstTime(force = false) {
        if (this.hasPanelBuildFirstTime)
            return;
        if (!force && this.wasNotRenderedInSurvey)
            return;
        this.blockAnimations();
        this.hasPanelBuildFirstTime = true;
        this.isBuildingPanelsFirstTime = true;
        if (this.getPropertyValue("panelCount") > 0) {
            this.panelCount = this.getPropertyValue("panelCount");
        }
        if (this.useTemplatePanel) {
            this.rebuildPanels();
        }
        this.setPanelsSurveyImpl();
        this.setPanelsState();
        this.assignOnPropertyChangedToTemplate();
        if (this.data && this.isValueChangedWithoutPanels) {
            this.isValueChangedWithoutPanels = false;
            this.runTriggersOnBuildPanelsFirstTime();
        }
        if (!!this.survey) {
            for (var i = 0; i < this.panelCount; i++) {
                this.notifyOnPanelAddedRemoved(true, i);
            }
        }
        this.updateIsReady();
        if (!this.showAddPanelButton) {
            this.updateNoEntriesTextDefaultLoc();
        }
        this.updateFooterActions();
        this.isBuildingPanelsFirstTime = false;
        this.releaseAnimations();
    }
    runTriggersOnBuildPanelsFirstTime() {
        this.value;
        this.visiblePanelsCore.forEach(p => {
            const panelValue = this.getPanelItemData(p.data);
            if (!Helpers.isValueEmpty(panelValue)) {
                const triggeredValue = Helpers.createCopyWithPrefix(panelValue, QuestionPanelDynamicItem.ItemVariableName + ".");
                p.questions.forEach(q => q.runTriggers("", undefined, triggeredValue));
            }
        });
    }
    get showAddPanelButton() { return this.allowAddPanel && !this.isReadOnly; }
    get wasNotRenderedInSurvey() {
        return !this.hasPanelBuildFirstTime && !this.wasRendered && !!this.survey;
    }
    get canBuildPanels() {
        return !this.isLoadingFromJson && !this.useTemplatePanel;
    }
    onFirstRenderingCore() {
        super.onFirstRenderingCore();
        this.buildPanelsFirstTime();
        this.template.onFirstRendering();
        for (var i = 0; i < this.panelsCore.length; i++) {
            this.panelsCore[i].onFirstRendering();
        }
    }
    localeChanged() {
        super.localeChanged();
        for (var i = 0; i < this.panelsCore.length; i++) {
            this.panelsCore[i].localeChanged();
        }
    }
    runConditionCore(values, properties) {
        super.runConditionCore(values, properties);
        this.runPanelsCondition(this.panelsCore, values, properties);
    }
    runTriggers(name, value, keys) {
        super.runTriggers(name, value, keys);
        this.visiblePanelsCore.forEach(p => {
            p.questions.forEach(q => q.runTriggers(name, value, keys));
        });
    }
    reRunCondition() {
        if (!this.data)
            return;
        this.runCondition(this.getDataFilteredValues(), this.getDataFilteredProperties());
    }
    runPanelsCondition(panels, values, properties) {
        var cachedValues = {};
        if (values && values instanceof Object) {
            cachedValues = JSON.parse(JSON.stringify(values));
        }
        if (!!this.parentQuestion && !!this.parent) {
            cachedValues[QuestionPanelDynamicItem.ParentItemVariableName] = this.parent.getValue();
        }
        this.isValueChangingInternally = true;
        let visibleIndex = 0;
        for (var i = 0; i < panels.length; i++) {
            const panel = panels[i];
            var panelValues = this.getPanelItemData(panel.data);
            //Should be unique for every panel due async expression support
            const newValues = Helpers.createCopy(cachedValues);
            const panelName = QuestionPanelDynamicItem.ItemVariableName;
            newValues[panelName] = panelValues;
            newValues[QuestionPanelDynamicItem.IndexVariableName.toLowerCase()] = i;
            newValues[QuestionPanelDynamicItem.VisibleIndexVariableName.toLowerCase()] = visibleIndex;
            const newProps = Helpers.createCopy(properties);
            newProps[panelName] = panel;
            panel.runCondition(newValues, newProps);
            if (panel.isVisible) {
                visibleIndex++;
            }
        }
        this.isValueChangingInternally = false;
    }
    onAnyValueChanged(name, questionName) {
        super.onAnyValueChanged(name, questionName);
        if (!this.hasPanelBuildFirstTime && name === this.getValueName()) {
            this.isValueChangedWithoutPanels = true;
        }
        for (var i = 0; i < this.panelsCore.length; i++) {
            this.panelsCore[i].onAnyValueChanged(name, questionName);
            this.panelsCore[i].onAnyValueChanged(QuestionPanelDynamicItem.ItemVariableName, "");
        }
    }
    hasKeysDuplicated(fireCallback, rec = null) {
        var keyValues = [];
        var res;
        for (var i = 0; i < this.panelsCore.length; i++) {
            res =
                this.isValueDuplicated(this.panelsCore[i], keyValues, rec, fireCallback) ||
                    res;
        }
        return res;
    }
    updatePanelsContainsErrors() {
        var question = this.changingValueQuestion;
        var parent = question.parent;
        while (!!parent) {
            parent.updateContainsErrors();
            parent = parent.parent;
        }
        this.updateContainsErrors();
    }
    hasErrors(fireCallback = true, rec = null) {
        if (this.isValueChangingInternally || this.isBuildingPanelsFirstTime)
            return false;
        var res = false;
        if (!!this.changingValueQuestion) {
            var res = this.changingValueQuestion.hasErrors(fireCallback, rec);
            res = this.hasKeysDuplicated(fireCallback, rec) || res;
            this.updatePanelsContainsErrors();
        }
        else {
            res = this.hasErrorInPanels(fireCallback, rec);
        }
        return super.hasErrors(fireCallback, rec) || res;
    }
    getContainsErrors() {
        var res = super.getContainsErrors();
        if (res)
            return res;
        var panels = this.panelsCore;
        for (var i = 0; i < panels.length; i++) {
            if (panels[i].containsErrors)
                return true;
        }
        return false;
    }
    getIsAnswered() {
        if (!super.getIsAnswered())
            return false;
        var panels = this.visiblePanelsCore;
        for (var i = 0; i < panels.length; i++) {
            var visibleQuestions = [];
            panels[i].addQuestionsToList(visibleQuestions, true);
            for (var j = 0; j < visibleQuestions.length; j++) {
                if (!visibleQuestions[j].isAnswered)
                    return false;
            }
        }
        return true;
    }
    clearValueOnHidding(isClearOnHidden) {
        if (!isClearOnHidden) {
            if (!!this.survey && this.survey.getQuestionClearIfInvisible("onHidden") === "none")
                return;
            this.clearValueInPanelsIfInvisible("onHiddenContainer");
        }
        super.clearValueOnHidding(isClearOnHidden);
    }
    clearValueIfInvisible(reason = "onHidden") {
        const panelReason = reason === "onHidden" ? "onHiddenContainer" : reason;
        this.clearValueInPanelsIfInvisible(panelReason);
        super.clearValueIfInvisible(reason);
    }
    clearValueInPanelsIfInvisible(reason) {
        for (var i = 0; i < this.panelsCore.length; i++) {
            const panel = this.panelsCore[i];
            var questions = panel.questions;
            this.isSetPanelItemData = {};
            for (var j = 0; j < questions.length; j++) {
                const q = questions[j];
                if (q.visible && !panel.isVisible)
                    continue;
                q.clearValueIfInvisible(reason);
                this.isSetPanelItemData[q.getValueName()] = this.maxCheckCount + 1;
            }
        }
        this.isSetPanelItemData = {};
    }
    getIsRunningValidators() {
        if (super.getIsRunningValidators())
            return true;
        for (var i = 0; i < this.panelsCore.length; i++) {
            var questions = this.panelsCore[i].questions;
            for (var j = 0; j < questions.length; j++) {
                if (questions[j].isRunningValidators)
                    return true;
            }
        }
        return false;
    }
    getAllErrors() {
        var result = super.getAllErrors();
        const panels = this.visiblePanelsCore;
        for (var i = 0; i < panels.length; i++) {
            var questions = panels[i].questions;
            for (var j = 0; j < questions.length; j++) {
                var errors = questions[j].getAllErrors();
                if (errors && errors.length > 0) {
                    result = result.concat(errors);
                }
            }
        }
        return result;
    }
    getDisplayValueCore(keysAsText, value) {
        var values = this.getUnbindValue(value);
        if (!values || !Array.isArray(values))
            return values;
        for (var i = 0; i < this.panelsCore.length && i < values.length; i++) {
            var val = values[i];
            if (!val)
                continue;
            values[i] = this.getPanelDisplayValue(i, val, keysAsText);
        }
        return values;
    }
    getPanelDisplayValue(panelIndex, val, keysAsText) {
        if (!val)
            return val;
        var panel = this.panelsCore[panelIndex];
        var keys = Object.keys(val);
        for (var i = 0; i < keys.length; i++) {
            var key = keys[i];
            var question = panel.getQuestionByValueName(key);
            if (!question) {
                question = this.getSharedQuestionFromArray(key, panelIndex);
            }
            if (!!question) {
                var qValue = question.getDisplayValue(keysAsText, val[key]);
                val[key] = qValue;
                if (keysAsText && !!question.title && question.title !== key) {
                    val[question.title] = qValue;
                    delete val[key];
                }
            }
        }
        return val;
    }
    hasErrorInPanels(fireCallback, rec) {
        var res = false;
        var panels = this.visiblePanels;
        var keyValues = [];
        for (var i = 0; i < panels.length; i++) {
            this.setOnCompleteAsyncInPanel(panels[i]);
        }
        const focusOnError = !!rec && rec.focusOnFirstError;
        for (let i = 0; i < panels.length; i++) {
            let pnlError = panels[i].hasErrors(fireCallback, focusOnError, rec);
            pnlError = this.isValueDuplicated(panels[i], keyValues, rec, fireCallback) || pnlError;
            if (!this.isRenderModeList && pnlError && !res && focusOnError) {
                this.currentIndex = i;
            }
            res = pnlError || res;
        }
        return res;
    }
    setOnCompleteAsyncInPanel(panel) {
        var questions = panel.questions;
        for (var i = 0; i < questions.length; i++) {
            questions[i].onCompletedAsyncValidators = (hasErrors) => {
                this.raiseOnCompletedAsyncValidators();
            };
        }
    }
    isValueDuplicated(panel, keyValues, rec, fireCallback) {
        if (!this.keyName)
            return false;
        var question = panel.getQuestionByValueName(this.keyName);
        if (!question || question.isEmpty())
            return false;
        var value = question.value;
        if (!!this.changingValueQuestion &&
            question != this.changingValueQuestion) {
            question.hasErrors(fireCallback, rec);
        }
        for (var i = 0; i < keyValues.length; i++) {
            if (value == keyValues[i]) {
                if (fireCallback) {
                    question.addError(new KeyDuplicationError(this.keyDuplicationError, this));
                }
                if (!!rec && !rec.firstErrorQuestion) {
                    rec.firstErrorQuestion = question;
                }
                return true;
            }
        }
        keyValues.push(value);
        return false;
    }
    getPanelActions(panel) {
        let actions = panel.footerActions;
        if (this.removePanelButtonLocation !== "right") {
            actions.push(new Action({
                id: `remove-panel-${panel.id}`,
                component: "sv-paneldynamic-remove-btn",
                visible: new ComputedUpdater(() => [this.canRenderRemovePanel(panel, "bottom")].every((val) => val === true)),
                data: { question: this, panel: panel }
            }));
        }
        if (!!this.survey) {
            actions = this.survey.getUpdatedPanelFooterActions(panel, actions, this);
        }
        return actions;
    }
    canRenderRemovePanelOnRight(panel) {
        return this.canRenderRemovePanel(panel, "right");
    }
    canRenderRemovePanel(panel, side) {
        const canRemove = this.canRemovePanel;
        const notCollpased = panel.state !== "collapsed";
        return this.removePanelButtonLocation === side && canRemove && notCollpased;
    }
    createNewPanel() {
        var panel = this.createAndSetupNewPanelObject();
        var json = this.template.toJSON();
        new JsonObject().toObject(json, panel);
        panel.renderWidth = "100%";
        panel.updateCustomWidgets();
        new QuestionPanelDynamicItem(this, panel);
        if (!this.isDesignMode && !this.isReadOnly && !this.isValueEmpty(panel.getValue())) {
            this.runPanelsCondition([panel], this.getDataFilteredValues(), this.getDataFilteredProperties());
        }
        var questions = panel.questions;
        for (var i = 0; i < questions.length; i++) {
            questions[i].setParentQuestion(this);
        }
        if (this.wasRendered) {
            panel.onFirstRendering();
            panel.locStrsChanged();
        }
        panel.onGetFooterActionsCallback = () => {
            return this.getPanelActions(panel);
        };
        panel.onGetFooterToolbarCssCallback = () => { return this.cssClasses.panelFooter; };
        panel.registerPropertyChangedHandlers(["visible"], () => {
            if (panel.visible)
                this.onPanelAdded(panel);
            else
                this.onPanelRemoved(panel);
            this.updateFooterActions();
        });
        return panel;
    }
    createAndSetupNewPanelObject() {
        var panel = this.createNewPanelObject();
        panel.isInteractiveDesignElement = false;
        panel.setParentQuestion(this);
        panel.onGetQuestionTitleLocation = () => this.getTemplateQuestionTitleLocation();
        panel.onGetQuestionTitleWidth = () => this.templateQuestionTitleWidth;
        return panel;
    }
    getTemplateQuestionTitleLocation() {
        return this.templateQuestionTitleLocation != "default"
            ? this.templateQuestionTitleLocation
            : this.getTitleLocationCore();
    }
    getChildErrorLocation(child) {
        if (this.templateErrorLocation !== "default")
            return this.templateErrorLocation;
        return super.getChildErrorLocation(child);
    }
    createNewPanelObject() {
        return Serializer.createClass("panel");
    }
    setPanelCountBasedOnValue() {
        if (this.isValueChangingInternally || this.useTemplatePanel)
            return;
        var val = this.value;
        var newPanelCount = val && Array.isArray(val) ? val.length : 0;
        if (newPanelCount == 0 && this.getPropertyValue("panelCount") > 0) {
            newPanelCount = this.getPropertyValue("panelCount");
        }
        this.settingPanelCountBasedOnValue = true;
        this.panelCount = newPanelCount;
        this.settingPanelCountBasedOnValue = false;
    }
    setQuestionValue(newValue) {
        if (this.settingPanelCountBasedOnValue)
            return;
        super.setQuestionValue(newValue, false);
        this.setPanelCountBasedOnValue();
        for (var i = 0; i < this.panelsCore.length; i++) {
            this.panelUpdateValueFromSurvey(this.panelsCore[i]);
        }
        this.updateIsAnswered();
    }
    onSurveyValueChanged(newValue) {
        if (newValue === undefined && this.isAllPanelsEmpty())
            return;
        super.onSurveyValueChanged(newValue);
        for (var i = 0; i < this.panelsCore.length; i++) {
            this.panelSurveyValueChanged(this.panelsCore[i]);
        }
        if (newValue === undefined) {
            this.setValueBasedOnPanelCount();
        }
        this.updateIsReady();
    }
    isAllPanelsEmpty() {
        for (var i = 0; i < this.panelsCore.length; i++) {
            if (!Helpers.isValueEmpty(this.panelsCore[i].getValue()))
                return false;
        }
        return true;
    }
    panelUpdateValueFromSurvey(panel) {
        const questions = panel.questions;
        var values = this.getPanelItemData(panel.data);
        for (var i = 0; i < questions.length; i++) {
            const q = questions[i];
            q.updateValueFromSurvey(values[q.getValueName()]);
            q.updateCommentFromSurvey(values[q.getValueName() + settings.commentSuffix]);
            q.initDataUI();
        }
    }
    panelSurveyValueChanged(panel) {
        var questions = panel.questions;
        var values = this.getPanelItemData(panel.data);
        for (var i = 0; i < questions.length; i++) {
            var q = questions[i];
            q.onSurveyValueChanged(values[q.getValueName()]);
        }
    }
    onSetData() {
        super.onSetData();
        if (!this.isLoadingFromJson && this.useTemplatePanel) {
            this.setTemplatePanelSurveyImpl();
            this.rebuildPanels();
        }
    }
    isNewValueCorrect(val) {
        return Array.isArray(val);
    }
    //IQuestionPanelDynamicData
    getItemIndex(item) {
        var res = this.items.indexOf(item);
        return res > -1 ? res : this.items.length;
    }
    getVisibleItemIndex(item) {
        const visPanels = this.visiblePanelsCore;
        for (var i = 0; i < visPanels.length; i++) {
            if (visPanels[i].data === item)
                return i;
        }
        return visPanels.length;
    }
    getPanelItemData(item) {
        var items = this.items;
        var index = items.indexOf(item);
        var qValue = this.value;
        if (index < 0 && Array.isArray(qValue) && qValue.length > items.length) {
            index = items.length;
        }
        if (index < 0)
            return {};
        if (!qValue || !Array.isArray(qValue) || qValue.length <= index)
            return {};
        return qValue[index];
    }
    setPanelItemData(item, name, val) {
        if (this.isSetPanelItemData[name] > this.maxCheckCount)
            return;
        if (!this.isSetPanelItemData[name]) {
            this.isSetPanelItemData[name] = 0;
        }
        this.isSetPanelItemData[name]++;
        var items = this.items;
        var index = items.indexOf(item);
        if (index < 0)
            index = items.length;
        var qValue = this.getUnbindValue(this.value);
        if (!qValue || !Array.isArray(qValue)) {
            qValue = [];
        }
        if (qValue.length <= index) {
            for (var i = qValue.length; i <= index; i++) {
                qValue.push({});
            }
        }
        if (!qValue[index])
            qValue[index] = {};
        const oldVal = qValue[index][name];
        if (!this.isValueEmpty(val)) {
            qValue[index][name] = val;
        }
        else {
            delete qValue[index][name];
        }
        if (index >= 0 && index < this.panelsCore.length) {
            this.changingValueQuestion = this.panelsCore[index].getQuestionByValueName(name);
        }
        const options = {
            panel: item.panel,
            name: name,
            panelIndex: index,
            panelData: qValue[index],
            value: val,
            oldValue: oldVal
        };
        if (this.survey) {
            this.survey.dynamicPanelItemValueChanging(this, options);
        }
        this.value = qValue;
        this.changingValueQuestion = null;
        if (this.survey) {
            this.survey.dynamicPanelItemValueChanged(this, options);
        }
        this.isSetPanelItemData[name]--;
        if (this.isSetPanelItemData[name] - 1) {
            delete this.isSetPanelItemData[name];
        }
    }
    getRootData() {
        return this.data;
    }
    getPlainData(options = { includeEmpty: true }) {
        var questionPlainData = super.getPlainData(options);
        if (!!questionPlainData) {
            questionPlainData.isNode = true;
            const prevData = Array.isArray(questionPlainData.data) ? [].concat(questionPlainData.data) : [];
            questionPlainData.data = this.panels.map((panel, index) => {
                var panelDataItem = {
                    name: panel.name || index,
                    title: panel.title || "Panel",
                    value: panel.getValue(),
                    displayValue: panel.getValue(),
                    getString: (val) => typeof val === "object" ? JSON.stringify(val) : val,
                    isNode: true,
                    data: panel.questions
                        .map((question) => question.getPlainData(options))
                        .filter((d) => !!d),
                };
                (options.calculations || []).forEach((calculation) => {
                    panelDataItem[calculation.propertyName] = panel[calculation.propertyName];
                });
                return panelDataItem;
            });
            questionPlainData.data = questionPlainData.data.concat(prevData);
        }
        return questionPlainData;
    }
    updateElementCss(reNew) {
        super.updateElementCss(reNew);
        for (var i = 0; i < this.panelsCore.length; i++) {
            var el = this.panelsCore[i];
            el.updateElementCss(reNew);
        }
    }
    get progressText() {
        var rangeMax = this.visiblePanelCount;
        return this.getLocalizationFormatString("panelDynamicProgressText", this.currentIndex + 1, rangeMax);
    }
    get progress() {
        return ((this.currentIndex + 1) / this.visiblePanelCount) * 100 + "%";
    }
    get progressBarAriaLabel() {
        return getLocaleString("progressbar", this.getLocale());
    }
    getRootCss() {
        return new CssClassBuilder().append(super.getRootCss()).append(this.cssClasses.empty, this.getShowNoEntriesPlaceholder()).toString();
    }
    get cssHeader() {
        const showTab = this.isRenderModeTab && !!this.visiblePanelCount;
        return new CssClassBuilder()
            .append(super.getCssHeader(this.cssClasses))
            .append(this.cssClasses.headerTab, this.hasTitleOnTop && showTab)
            .toString();
    }
    getTabsContainerCss() {
        return new CssClassBuilder().append(this.cssClasses.tabsContainer).append(this.cssClasses.tabsContainerWithHeader, this.hasTitleOnTop).toString();
    }
    getPanelWrapperCss(panel) {
        return new CssClassBuilder()
            .append(this.cssClasses.panelWrapper, !panel || panel.visible)
            .append(this.cssClasses.panelWrapperList, this.isRenderModeList)
            .append(this.cssClasses.panelWrapperInRow, this.removePanelButtonLocation === "right")
            .toString();
    }
    getPanelRemoveButtonCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.button)
            .append(this.cssClasses.buttonRemove)
            .append(this.cssClasses.buttonRemoveRight, this.removePanelButtonLocation === "right")
            .toString();
    }
    getAddButtonCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.button)
            .append(this.cssClasses.buttonAdd)
            .append(this.cssClasses.buttonAdd + "--list-mode", this.displayMode === "list")
            .toString();
    }
    getPrevButtonCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.buttonPrev)
            .append(this.cssClasses.buttonPrevDisabled, !this.isPrevButtonVisible)
            .toString();
    }
    getNextButtonCss() {
        return new CssClassBuilder()
            .append(this.cssClasses.buttonNext)
            .append(this.cssClasses.buttonNextDisabled, !this.isNextButtonVisible)
            .toString();
    }
    /**
     * A text displayed when Dynamic Panel contains no entries.
     */
    get noEntriesText() {
        return this.getLocalizableStringText("noEntriesText");
    }
    set noEntriesText(val) {
        this.setLocalizableStringText("noEntriesText", val);
    }
    get locNoEntriesText() {
        return this.getLocalizableString("noEntriesText");
    }
    getShowNoEntriesPlaceholder() {
        return !!this.cssClasses.noEntriesPlaceholder && !this.isDesignMode && this.visiblePanelCount === 0;
    }
    needResponsiveWidth() {
        const panel = this.getPanel();
        if (!!panel && panel.needResponsiveWidth())
            return true;
        return false;
    }
    get hasTabbedMenu() {
        return this.isRenderModeTab && this.visiblePanels.length > 0;
    }
    get tabbedMenu() {
        if (!this.isRenderModeTab)
            return null;
        if (!this.tabbedMenuValue) {
            this.tabbedMenuValue = new AdaptiveActionContainer();
            this.tabbedMenuValue.dotsItem.popupModel.showPointer = false;
            this.tabbedMenuValue.dotsItem.popupModel.verticalPosition = "bottom";
            this.tabbedMenuValue.dotsItem.popupModel.horizontalPosition = "center";
            this.updateElementCss(false);
        }
        return this.tabbedMenuValue;
    }
    get footerToolbar() {
        if (!this.footerToolbarValue) {
            this.initFooterToolbar();
        }
        return this.footerToolbarValue;
    }
    get ariaRole() {
        return "group";
    }
    get ariaRequired() {
        return null;
    }
    get ariaInvalid() {
        return null;
    }
    updateFooterActions() {
        if (!!this.updateFooterActionsCallback) {
            this.updateFooterActionsCallback();
        }
    }
    initFooterToolbar() {
        this.footerToolbarValue = this.createActionContainer();
        const items = [];
        const prevTextBtn = new Action({
            id: "sv-pd-prev-btn",
            title: this.prevPanelText,
            action: () => {
                this.goToPrevPanel();
            }
        });
        const nextTextBtn = new Action({
            id: "sv-pd-next-btn",
            title: this.nextPanelText,
            action: () => {
                this.goToNextPanel();
            }
        });
        const addBtn = new Action({
            id: "sv-pd-add-btn",
            component: "sv-paneldynamic-add-btn",
            data: { question: this }
        });
        const prevBtnIcon = new Action({
            id: "sv-prev-btn-icon",
            component: "sv-paneldynamic-prev-btn",
            data: { question: this }
        });
        const progressText = new Action({
            id: "sv-pd-progress-text",
            component: "sv-paneldynamic-progress-text",
            data: { question: this }
        });
        const nextBtnIcon = new Action({
            id: "sv-pd-next-btn-icon",
            component: "sv-paneldynamic-next-btn",
            data: { question: this }
        });
        items.push(prevTextBtn, nextTextBtn, addBtn, prevBtnIcon, progressText, nextBtnIcon);
        this.updateFooterActionsCallback = () => {
            const isLegacyNavigation = this.legacyNavigation;
            const isRenderModeList = this.isRenderModeList;
            const isMobile = this.isMobile;
            const showNavigation = !isLegacyNavigation && !isRenderModeList;
            prevTextBtn.visible = showNavigation && this.currentIndex > 0;
            nextTextBtn.visible = showNavigation && this.currentIndex < this.visiblePanelCount - 1;
            nextTextBtn.needSpace = isMobile && nextTextBtn.visible && prevTextBtn.visible;
            addBtn.visible = this.canAddPanel;
            addBtn.needSpace = this.isMobile && !nextTextBtn.visible && prevTextBtn.visible;
            progressText.visible = !this.isRenderModeList && !isMobile;
            progressText.needSpace = !isLegacyNavigation && !this.isMobile;
            const showLegacyNavigation = isLegacyNavigation && !isRenderModeList;
            prevBtnIcon.visible = showLegacyNavigation;
            nextBtnIcon.visible = showLegacyNavigation;
            prevBtnIcon.needSpace = showLegacyNavigation;
        };
        this.updateFooterActionsCallback();
        this.footerToolbarValue.setItems(items);
    }
    createTabByPanel(panel, visPanelIndex) {
        if (!this.isRenderModeTab)
            return;
        const locTitle = new LocalizableString(panel, true);
        locTitle.onGetTextCallback = (str) => {
            if (!str) {
                str = this.locTabTitlePlaceholder.renderedHtml;
            }
            if (!this.survey)
                return str;
            const options = {
                title: str,
                panel: panel,
                visiblePanelIndex: visPanelIndex
            };
            this.survey.dynamicPanelGetTabTitle(this, options);
            return options.title;
        };
        locTitle.sharedData = this.locTemplateTabTitle;
        const panelId = panel.id;
        const isActive = this.getPanelVisibleIndexById(panelId) === this.currentIndex;
        const newItem = new PanelDynamicTabbedMenuItem({
            id: `${this.id}_tab_${panelId}`,
            panelId: panelId,
            pressed: isActive,
            locTitle: locTitle,
            disableHide: isActive,
            action: () => {
                this.currentIndex = this.getPanelVisibleIndexById(panelId);
            }
        });
        return newItem;
    }
    getTabbedMenuCss(cssClasses) {
        const css = cssClasses !== null && cssClasses !== void 0 ? cssClasses : this.cssClasses;
        return new CssClassBuilder()
            .append(css.tabsRoot)
            .append(css.tabsLeft, this.tabAlign === "left")
            .append(css.tabsRight, this.tabAlign === "right")
            .append(css.tabsCenter, this.tabAlign === "center")
            .toString();
    }
    updateTabToolbarItemsPressedState() {
        if (!this.isRenderModeTab)
            return;
        if (this.currentIndex < 0 || this.currentIndex >= this.visiblePanelCount)
            return;
        const panel = this.visiblePanelsCore[this.currentIndex];
        this.tabbedMenu.renderedActions.forEach(action => {
            const isActive = action.panelId === panel.id;
            action.pressed = isActive;
            action.disableHide = isActive;
            //should raise update if dimensions are not changed but action is active now
            if (action.mode === "popup" && action.disableHide) {
                action["raiseUpdate"]();
            }
        });
    }
    updateTabToolbar() {
        if (!this.isRenderModeTab)
            return;
        const items = [];
        const visPanels = this.visiblePanelsCore;
        for (let i = 0; i < visPanels.length; i++) {
            this.visiblePanelsCore.forEach(panel => items.push(this.createTabByPanel(visPanels[i], i)));
        }
        this.tabbedMenu.setItems(items);
    }
    addTabFromToolbar(panel, index) {
        if (!this.isRenderModeTab)
            return;
        const newItem = this.createTabByPanel(panel, index);
        this.tabbedMenu.actions.splice(index, 0, newItem);
        this.updateTabToolbarItemsPressedState();
    }
    removeTabFromToolbar(panel) {
        if (!this.isRenderModeTab)
            return;
        const removedItem = this.tabbedMenu.actions.find(a => a.panelId == panel.id);
        if (!removedItem)
            return;
        this.tabbedMenu.actions.splice(this.tabbedMenu.actions.indexOf(removedItem), 1);
        this.updateTabToolbarItemsPressedState();
    }
    get showNavigation() {
        if (this.isReadOnly && this.visiblePanelCount == 1)
            return false;
        return this.visiblePanelCount > 0 && !!this.cssClasses.footer;
    }
    showSeparator(index) {
        return this.isRenderModeList && index < this.renderedPanels.length - 1;
    }
    calcCssClasses(css) {
        const classes = super.calcCssClasses(css);
        const tabbedMenu = this.tabbedMenu;
        if (!!tabbedMenu) {
            tabbedMenu.containerCss = this.getTabbedMenuCss(classes);
            tabbedMenu.cssClasses = classes.tabs;
            tabbedMenu.dotsItem.cssClasses = classes.tabs;
            tabbedMenu.dotsItem.popupModel.contentComponentData.model.cssClasses = css.list;
        }
        return classes;
    }
    onMobileChanged() {
        super.onMobileChanged();
        this.updateFooterActions();
    }
}
QuestionPanelDynamicModel.maxCheckCount = 3;
__decorate([
    propertyArray({})
], QuestionPanelDynamicModel.prototype, "_renderedPanels", void 0);
__decorate([
    property({
        onSet: (val, target) => {
            target.fireCallback(target.renderModeChangedCallback);
            target.updatePanelView();
        }
    })
], QuestionPanelDynamicModel.prototype, "displayMode", void 0);
__decorate([
    property({
        onSet: (val, target) => {
            target.fireCallback(target.currentIndexChangedCallback);
        }
    })
], QuestionPanelDynamicModel.prototype, "showProgressBar", void 0);
__decorate([
    property({
        onSet: (val, target) => {
            // target.updatePanelView();
        }
    })
], QuestionPanelDynamicModel.prototype, "progressBarLocation", void 0);
__decorate([
    property({ defaultValue: false, onSet: (_, target) => { target.updateFooterActions(); } })
], QuestionPanelDynamicModel.prototype, "legacyNavigation", void 0);
Serializer.addClass("paneldynamic", [
    { name: "showCommentArea:switch", layout: "row", visible: true, category: "general" },
    {
        name: "templateElements",
        alternativeName: "questions",
        baseClassName: "question",
        visible: false,
        isLightSerializable: false
    },
    { name: "templateTitle:text", serializationProperty: "locTemplateTitle" },
    {
        name: "templateTabTitle", serializationProperty: "locTemplateTabTitle",
        visibleIf: (obj) => { return obj.displayMode === "tab"; }
    },
    {
        name: "tabTitlePlaceholder", serializationProperty: "locTabTitlePlaceholder",
        visibleIf: (obj) => { return obj.displayMode === "tab"; }
    },
    {
        name: "templateDescription:text",
        serializationProperty: "locTemplateDescription",
    },
    { name: "minWidth", defaultFunc: () => "auto" },
    { name: "noEntriesText:text", serializationProperty: "locNoEntriesText" },
    { name: "allowAddPanel:boolean", default: true },
    { name: "allowRemovePanel:boolean", default: true },
    { name: "newPanelPosition", choices: ["next", "last"], default: "last", category: "layout" },
    {
        name: "panelCount:number",
        isBindable: true,
        default: 0,
        choices: [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
    },
    { name: "minPanelCount:number", default: 0, minValue: 0 },
    {
        name: "maxPanelCount:number",
        defaultFunc: () => settings.panel.maxPanelCount,
    },
    "defaultPanelValue:panelvalue",
    { name: "copyDefaultValueFromLastEntry:boolean", alternativeName: "defaultValueFromLastPanel" },
    {
        name: "panelsState",
        default: "default",
        choices: ["default", "collapsed", "expanded", "firstExpanded"],
        visibleIf: (obj) => { return obj.displayMode === "list"; }
    },
    { name: "keyName" },
    {
        name: "keyDuplicationError",
        serializationProperty: "locKeyDuplicationError",
    },
    { name: "confirmDelete:boolean" },
    {
        name: "confirmDeleteText",
        serializationProperty: "locConfirmDeleteText",
        visibleIf: (obj) => { return obj.confirmDelete; }
    },
    {
        name: "addPanelText", alternativeName: "panelAddText",
        serializationProperty: "locAddPanelText",
        visibleIf: (obj) => { return obj.allowAddPanel; }
    },
    {
        name: "removePanelText", alternativeName: "panelRemoveText",
        serializationProperty: "locRemovePanelText",
        visibleIf: (obj) => { return obj.allowRemovePanel; }
    },
    {
        name: "prevPanelText", alternativeName: "panelPrevText",
        serializationProperty: "locPrevPanelText",
        visibleIf: (obj) => { return obj.displayMode !== "list"; }
    },
    {
        name: "nextPanelText", alternativeName: "panelNextText",
        serializationProperty: "locNextPanelText",
        visibleIf: (obj) => { return obj.displayMode !== "list"; }
    },
    {
        name: "showQuestionNumbers",
        default: "off",
        choices: ["off", "onPanel", "onSurvey"],
    },
    { name: "renderMode", visible: false, isSerializable: false },
    { name: "displayMode", default: "list", choices: ["list", "carousel", "tab"] },
    {
        name: "showProgressBar:boolean", alternativeName: "showRangeInProgress",
        default: true,
        visibleIf: (obj) => { return obj.displayMode === "carousel"; }
    },
    {
        name: "progressBarLocation",
        default: "top",
        choices: ["top", "bottom", "topBottom"],
        visibleIf: (obj) => { return obj.showProgressBar && obj.displayMode === "carousel"; }
    },
    {
        name: "tabAlign", default: "center", choices: ["left", "center", "right"],
        visibleIf: (obj) => { return obj.displayMode === "tab"; }
    },
    {
        name: "templateQuestionTitleLocation", alternativeName: "questionTitleLocation",
        default: "default",
        choices: ["default", "top", "bottom", "left"],
    },
    {
        name: "templateQuestionTitleWidth",
        visibleIf: function (obj) {
            return !!obj && obj.template.availableQuestionTitleWidth();
        }
    },
    { name: "templateErrorLocation", default: "default", choices: ["default", "top", "bottom"] },
    {
        name: "templateVisibleIf:expression",
        category: "logic"
    },
    {
        name: "removePanelButtonLocation", alternativeName: "panelRemoveButtonLocation",
        default: "bottom",
        choices: ["bottom", "right"],
        visibleIf: (obj) => { return obj.allowRemovePanel; }
    },
], function () {
    return new QuestionPanelDynamicModel("");
}, "question");
QuestionFactory.Instance.registerQuestion("paneldynamic", (name) => {
    return new QuestionPanelDynamicModel(name);
});

class SurveyProgressModel {
    static getProgressTextInBarCss(css) {
        return new CssClassBuilder()
            .append(css.progressText)
            .append(css.progressTextInBar)
            .toString();
    }
    static getProgressTextUnderBarCss(css) {
        return new CssClassBuilder()
            .append(css.progressText)
            .append(css.progressTextUnderBar)
            .toString();
    }
}

/**
 * A base class for all triggers.
 * A trigger calls a method when the expression change the result: from false to true or from true to false.
 * Please note, it runs only one changing the expression result.
 */
class Trigger extends Base {
    static get operators() {
        if (Trigger.operatorsValue != null)
            return Trigger.operatorsValue;
        Trigger.operatorsValue = {
            empty: function (value, expectedValue) {
                return !value;
            },
            notempty: function (value, expectedValue) {
                return !!value;
            },
            equal: function (value, expectedValue) {
                return value == expectedValue;
            },
            notequal: function (value, expectedValue) {
                return value != expectedValue;
            },
            contains: function (value, expectedValue) {
                return value && value["indexOf"] && value.indexOf(expectedValue) > -1;
            },
            notcontains: function (value, expectedValue) {
                return (!value || !value["indexOf"] || value.indexOf(expectedValue) == -1);
            },
            greater: function (value, expectedValue) {
                return value > expectedValue;
            },
            less: function (value, expectedValue) {
                return value < expectedValue;
            },
            greaterorequal: function (value, expectedValue) {
                return value >= expectedValue;
            },
            lessorequal: function (value, expectedValue) {
                return value <= expectedValue;
            },
        };
        return Trigger.operatorsValue;
    }
    constructor() {
        super();
        this.idValue = (Trigger.idCounter++);
        this.registerPropertyChangedHandlers(["operator", "value", "name"], () => {
            this.oldPropertiesChanged();
        });
        this.registerPropertyChangedHandlers(["expression"], () => { this.onExpressionChanged(); });
    }
    get id() { return this.idValue; }
    getType() {
        return "triggerbase";
    }
    toString() {
        var res = this.getType().replace("trigger", "");
        var exp = !!this.expression ? this.expression : this.buildExpression();
        if (exp) {
            res += ", " + exp;
        }
        return res;
    }
    get isInternal() {
        return this.isGhost === true;
    }
    get operator() {
        return this.getPropertyValue("operator", "equal");
    }
    set operator(value) {
        if (!value)
            return;
        value = value.toLowerCase();
        if (!Trigger.operators[value])
            return;
        this.setPropertyValue("operator", value);
    }
    get value() {
        return this.getPropertyValue("value", null);
    }
    set value(val) {
        this.setPropertyValue("value", val);
    }
    get name() {
        return this.getPropertyValue("name", "");
    }
    set name(val) {
        this.setPropertyValue("name", val);
    }
    get expression() {
        return this.getPropertyValue("expression", "");
    }
    set expression(val) {
        this.setPropertyValue("expression", val);
    }
    canBeExecuted(isOnNextPage) {
        return true;
    }
    canBeExecutedOnComplete() {
        return false;
    }
    checkExpression(options) {
        this.isExecutingOnNextPage = options.isOnNextPage;
        this.isExecutingOnNavigation = options.isOnNavigation || options.isOnNextPage;
        if (!this.canBeExecuted(options.isOnNextPage))
            return;
        if (options.isOnComplete && !this.canBeExecutedOnComplete())
            return;
        if (!this.isCheckRequired(options.keys))
            return;
        if (!!this.conditionRunner) {
            this.perform(options.values, options.properties || null);
        }
        else {
            if (this.canSuccessOnEmptyExpression()) {
                this.triggerResult(true, options.values, options.properties || null);
            }
        }
    }
    canSuccessOnEmptyExpression() { return false; }
    check(value) {
        var triggerResult = Trigger.operators[this.operator](value, this.value);
        if (triggerResult) {
            this.onSuccess({}, null);
        }
        else {
            this.onFailure();
        }
    }
    get requireValidQuestion() { return false; }
    perform(values, properties) {
        this.conditionRunner.onRunComplete = (res) => {
            this.triggerResult(res, values, properties);
        };
        this.conditionRunner.run(values, properties);
    }
    triggerResult(res, values, properties) {
        if (res) {
            this.onSuccess(values, properties);
            this.onSuccessExecuted();
        }
        else {
            this.onFailure();
        }
    }
    onSuccess(values, properties) { }
    onFailure() { }
    onSuccessExecuted() { }
    endLoadingFromJson() {
        super.endLoadingFromJson();
        this.oldPropertiesChanged();
    }
    oldPropertiesChanged() {
        this.onExpressionChanged();
    }
    onExpressionChanged() {
        this.conditionRunner = null;
    }
    buildExpression() {
        if (!this.name)
            return "";
        if (this.isValueEmpty(this.value) && this.isRequireValue)
            return "";
        return ("{" +
            this.name +
            "} " +
            this.operator +
            " " +
            OperandMaker.toOperandString(this.value));
    }
    isCheckRequired(keys) {
        if (!keys)
            return false;
        this.createConditionRunner();
        if (this.conditionRunner && this.conditionRunner.hasFunction() === true)
            return true;
        return new ProcessValue().isAnyKeyChanged(keys, this.getUsedVariables());
    }
    getUsedVariables() {
        if (!this.conditionRunner)
            return [];
        const res = this.conditionRunner.getVariables();
        if (Array.isArray(res)) {
            const unw = "-unwrapped";
            for (let i = res.length - 1; i >= 0; i--) {
                const s = res[i];
                if (s.endsWith(unw)) {
                    res.push(s.substring(0, s.length - unw.length));
                }
            }
        }
        return res;
    }
    createConditionRunner() {
        if (!!this.conditionRunner)
            return;
        var expression = this.expression;
        if (!expression) {
            expression = this.buildExpression();
        }
        if (!expression)
            return;
        this.conditionRunner = new ConditionRunner(expression);
    }
    get isRequireValue() {
        return this.operator !== "empty" && this.operator != "notempty";
    }
}
Trigger.idCounter = 1;
Trigger.operatorsValue = null;
/**
 * It extends the Trigger base class and add properties required for SurveyJS classes.
 */
class SurveyTrigger extends Trigger {
    constructor() {
        super();
        this.ownerValue = null;
    }
    get owner() {
        return this.ownerValue;
    }
    setOwner(owner) {
        this.ownerValue = owner;
    }
    getSurvey(live = false) {
        return !!this.owner && !!this.owner["getSurvey"]
            ? this.owner.getSurvey()
            : null;
    }
    isRealExecution() {
        return true;
    }
    onSuccessExecuted() {
        if (!!this.owner && this.isRealExecution()) {
            this.owner.triggerExecuted(this);
        }
    }
}
/**
 * If expression returns true, it makes questions/pages visible.
 * Ohterwise it makes them invisible.
 */
class SurveyTriggerVisible extends SurveyTrigger {
    constructor() {
        super();
        this.pages = [];
        this.questions = [];
    }
    getType() {
        return "visibletrigger";
    }
    onSuccess(values, properties) {
        this.onTrigger(this.onItemSuccess);
    }
    onFailure() {
        this.onTrigger(this.onItemFailure);
    }
    onTrigger(func) {
        if (!this.owner)
            return;
        var objects = this.owner.getObjects(this.pages, this.questions);
        for (var i = 0; i < objects.length; i++) {
            func(objects[i]);
        }
    }
    onItemSuccess(item) {
        item.visible = true;
    }
    onItemFailure(item) {
        item.visible = false;
    }
}
/**
 * If expression returns true, it completes the survey.
 */
class SurveyTriggerComplete extends SurveyTrigger {
    constructor() {
        super();
    }
    getType() {
        return "completetrigger";
    }
    get requireValidQuestion() { return true; }
    isRealExecution() {
        return !settings.triggers.executeCompleteOnValueChanged === this.isExecutingOnNavigation;
    }
    onSuccess(values, properties) {
        if (!this.owner)
            return;
        if (this.isRealExecution()) {
            this.owner.setCompleted(this);
        }
        else {
            this.owner.canBeCompleted(this, true);
        }
    }
    onFailure() {
        this.owner.canBeCompleted(this, false);
    }
}
/**
 * If expression returns true, the value from property **setValue** will be set to **setToName**
 */
class SurveyTriggerSetValue extends SurveyTrigger {
    constructor() {
        super();
    }
    getType() {
        return "setvaluetrigger";
    }
    canBeExecuted(isOnNextPage) {
        return !isOnNextPage && !!this.setToName;
    }
    onPropertyValueChanged(name, oldValue, newValue) {
        super.onPropertyValueChanged(name, oldValue, newValue);
        if (name !== "setToName")
            return;
        var survey = this.getSurvey();
        if (survey && !survey.isLoadingFromJson && survey.isDesignMode) {
            this.setValue = undefined;
        }
    }
    get setToName() {
        return this.getPropertyValue("setToName", "");
    }
    set setToName(val) {
        this.setPropertyValue("setToName", val);
    }
    get setValue() {
        return this.getPropertyValue("setValue");
    }
    set setValue(val) {
        this.setPropertyValue("setValue", val);
    }
    get isVariable() {
        return this.getPropertyValue("isVariable");
    }
    set isVariable(val) {
        this.setPropertyValue("isVariable", val);
    }
    onSuccess(values, properties) {
        if (!this.setToName || !this.owner)
            return;
        this.owner.setTriggerValue(this.setToName, Helpers.getUnbindValue(this.setValue), this.isVariable);
    }
}
/**
 * If expression returns true, the survey go to question **gotoName** and focus it.
 */
class SurveyTriggerSkip extends SurveyTrigger {
    constructor() {
        super();
    }
    getType() {
        return "skiptrigger";
    }
    get requireValidQuestion() { return this.canBeExecuted(false); }
    get gotoName() {
        return this.getPropertyValue("gotoName", "");
    }
    set gotoName(val) {
        this.setPropertyValue("gotoName", val);
    }
    canBeExecuted(isOnNextPage) {
        return isOnNextPage === !settings.triggers.executeSkipOnValueChanged;
    }
    onSuccess(values, properties) {
        if (!this.gotoName || !this.owner)
            return;
        this.owner.focusQuestion(this.gotoName);
    }
}
/**
 * If expression returns true, the **runExpression** will be run. If **setToName** property is not empty then the result of **runExpression** will be set to it.
 */
class SurveyTriggerRunExpression extends SurveyTrigger {
    constructor() {
        super();
    }
    getType() {
        return "runexpressiontrigger";
    }
    get setToName() {
        return this.getPropertyValue("setToName", "");
    }
    set setToName(val) {
        this.setPropertyValue("setToName", val);
    }
    get runExpression() {
        return this.getPropertyValue("runExpression", "");
    }
    set runExpression(val) {
        this.setPropertyValue("runExpression", val);
    }
    canBeExecuted(isOnNextPage) {
        return !isOnNextPage;
    }
    onSuccess(values, properties) {
        if (!this.owner || !this.runExpression)
            return;
        var expression = new ExpressionRunner(this.runExpression);
        if (expression.canRun) {
            expression.onRunComplete = (res) => {
                this.onCompleteRunExpression(res);
            };
            expression.run(values, properties);
        }
    }
    onCompleteRunExpression(newValue) {
        if (!!this.setToName && newValue !== undefined) {
            this.owner.setTriggerValue(this.setToName, Helpers.convertValToQuestionVal(newValue), false);
        }
    }
}
/**
 * If expression returns true, the value from question **fromName** will be set into **setToName**.
 */
class SurveyTriggerCopyValue extends SurveyTrigger {
    constructor() {
        super();
    }
    canBeExecuted(isOnNextPage) {
        return !isOnNextPage && !!this.setToName && !!this.fromName;
    }
    get setToName() {
        return this.getPropertyValue("setToName", "");
    }
    set setToName(val) {
        this.setPropertyValue("setToName", val);
    }
    get fromName() {
        return this.getPropertyValue("fromName", "");
    }
    set fromName(val) {
        this.setPropertyValue("fromName", val);
    }
    get copyDisplayValue() {
        return this.getPropertyValue("copyDisplayValue");
    }
    set copyDisplayValue(val) {
        this.setPropertyValue("copyDisplayValue", val);
    }
    getType() {
        return "copyvaluetrigger";
    }
    onSuccess(values, properties) {
        if (!this.setToName || !this.owner)
            return;
        this.owner.copyTriggerValue(this.setToName, this.fromName, this.copyDisplayValue);
    }
    canSuccessOnEmptyExpression() { return true; }
    getUsedVariables() {
        const res = super.getUsedVariables();
        if (res.length === 0 && !!this.fromName) {
            res.push(this.fromName);
        }
        return res;
    }
}
Serializer.addClass("trigger", [
    { name: "operator", default: "equal", visible: false },
    { name: "value", visible: false },
    "expression:condition",
]);
Serializer.addClass("surveytrigger", [{ name: "name", visible: false }], null, "trigger");
Serializer.addClass("visibletrigger", ["pages:pages", "questions:questions"], function () {
    return new SurveyTriggerVisible();
}, "surveytrigger");
Serializer.addClass("completetrigger", [], function () {
    return new SurveyTriggerComplete();
}, "surveytrigger");
Serializer.addClass("setvaluetrigger", [
    { name: "!setToName:questionvalue" },
    {
        name: "setValue:triggervalue",
        dependsOn: "setToName",
        visibleIf: function (obj) {
            return !!obj && !!obj["setToName"];
        },
    },
    { name: "isVariable:boolean", visible: false },
], function () {
    return new SurveyTriggerSetValue();
}, "surveytrigger");
Serializer.addClass("copyvaluetrigger", [{ name: "!fromName:questionvalue" }, { name: "!setToName:questionvalue" },
    { name: "copyDisplayValue:boolean", visible: false }], function () {
    return new SurveyTriggerCopyValue();
}, "surveytrigger");
Serializer.addClass("skiptrigger", [{ name: "!gotoName:question" }], function () {
    return new SurveyTriggerSkip();
}, "surveytrigger");
Serializer.addClass("runexpressiontrigger", [{ name: "setToName:questionvalue" }, "runExpression:expression"], function () {
    return new SurveyTriggerRunExpression();
}, "surveytrigger");

/**
 * A class that renders a survey in a pop-up window.
 *
 * [View Demo](https://surveyjs.io/form-library/examples/popup-survey/ (linkStyle))
 */
class PopupSurveyModel extends Base {
    constructor(jsonObj, initialModel = null) {
        super();
        /**
         * Specifies how many seconds the pop-up window should remain open after users complete the survey.
         *
         * Default value: 0 (the window is closed immediately)
         *
         * Set this property to a negative value (for instance, -1) to keep the pop-up window open without a time limit.
         *
         * [View Demo](https://surveyjs.io/form-library/examples/popup-survey/ (linkStyle))
         */
        this.closeOnCompleteTimeout = 0;
        if (initialModel) {
            this.surveyValue = initialModel;
        }
        else {
            this.surveyValue = this.createSurvey(jsonObj);
        }
        this.surveyValue.fitToContainer = true;
        this.windowElement = DomDocumentHelper.createElement("div");
        this.survey.onComplete.add((survey, options) => {
            this.onSurveyComplete();
        });
        this.registerPropertyChangedHandlers(["isShowing"], () => {
            if (!!this.showingChangedCallback)
                this.showingChangedCallback();
        });
        this.registerPropertyChangedHandlers(["isExpanded"], () => {
            this.onExpandedChanged();
        });
        this.width = new ComputedUpdater(() => this.survey.width);
        this.width = this.survey.width;
        this.updateCss();
        this.onCreating();
    }
    onCreating() { }
    getType() {
        return "popupsurvey";
    }
    /**
     * A [`SurveyModel`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model) instance rendered in the pop-up window.
     */
    get survey() {
        return this.surveyValue;
    }
    /**
     * Indicates whether the pop-up survey appears on the page, regardless of its [expand state](#isExpanded).
     *
     * You can set this property to `true` or `false` to control visibility of the pop-up survey. Alternatively, you can use the [`show()`](#show) and [`hide()`](#hide) methods.
     */
    get isShowing() {
        return this.getPropertyValue("isShowing", false);
    }
    set isShowing(val) {
        this.setPropertyValue("isShowing", val);
    }
    get isFullScreen() {
        return this.getPropertyValue("isFullScreen", false);
    }
    set isFullScreen(val) {
        if (!this.isExpanded && !!val) {
            this.isExpanded = true;
        }
        this.setPropertyValue("isFullScreen", val);
        this.setCssRoot();
    }
    /**
     * Shows the pop-up survey. The survey may appear [expanded or collapsed](#isExpanded).
     *
     * As an alternative to this method, you can set the [`isShowing`](#isShowing) property to `true`.
     * @see hide
     */
    show() {
        this.isShowing = true;
    }
    /**
     * Hides the pop-up survey.
     *
     * As an alternative to this method, you can set the [`isShowing`](#isShowing) property to `false`.
     * @see show
     * @see expand
     * @see collapse
     */
    hide() {
        this.isShowing = false;
    }
    toggleFullScreen() {
        this.isFullScreen = !this.isFullScreen;
    }
    /**
     * Indicates whether the pop-up window is expanded or collapsed.
     *
     * [View Demo](https://surveyjs.io/form-library/examples/popup-survey/ (linkStyle))
     *
     * You can set this property to `true` or `false` to control the expand state of the pop-up survey. Alternatively, you can use the [`expand()`](#expand) and [`collapse()`](#collapse) methods.
     */
    get isExpanded() {
        return this.getPropertyValue("isExpanded", false);
    }
    set isExpanded(val) {
        if (!!this.isFullScreen && !val) {
            this.isFullScreen = false;
        }
        this.setPropertyValue("isExpanded", val);
    }
    get isCollapsed() {
        return !this.isExpanded;
    }
    onExpandedChanged() {
        if (!!this.expandedChangedCallback) {
            this.expandedChangedCallback();
        }
        this.updateCssButton();
    }
    /**
     * A title for the pop-up window. If this property is undefined, the title is taken from [`SurveyModel`](#survey)'s [`title`](https://surveyjs.io/form-library/documentation/api-reference/survey-data-model#title) property.
     */
    get title() {
        return this.survey.title;
    }
    set title(value) {
        this.survey.title = value;
    }
    get locTitle() {
        if (this.survey.locTitle.isEmpty)
            return null;
        return this.survey.locTitle;
    }
    get locDescription() {
        if (this.survey.locTitle.isEmpty)
            return null;
        return this.survey.locDescription;
    }
    /**
     * Expands the pop-up window.
     *
     * As an alternative to this method, you can set the [`isExpanded`](#isExpanded) property to `true`.
     * @see collapse
     */
    expand() {
        this.isExpanded = true;
    }
    /**
     * Collapses the pop-up window, leaving only the survey title visible.
     *
     * As an alternative to this method, you can set the [`isExpanded`](#isExpanded) property to `false`.
     * @see expand
     */
    collapse() {
        this.isExpanded = false;
    }
    changeExpandCollapse() {
        this.isExpanded = !this.isExpanded;
    }
    /**
     * Specifies whether to display a button that closes the pop-up window.
     *
     * Default value: `false`
     *
     * [View Demo](https://surveyjs.io/form-library/examples/popup-survey/ (linkStyle))
     *
     * If you allow users to close the pop-up window, make sure to implement a UI element that opens it. This element should call the [`show()`](#show) method or enable the [`isShowing`](#isShowing) property.
     * @see expand
     * @see collapse
     * @see hide
     */
    get allowClose() {
        return this.getPropertyValue("allowClose", false);
    }
    set allowClose(val) {
        this.setPropertyValue("allowClose", val);
    }
    /**
     * Specifies whether to display a button that allows respondents to show the pop-up survey in full screen mode.
     *
     * Default value: `false`
     */
    get allowFullScreen() {
        return this.getPropertyValue("allowFullScreen", false);
    }
    set allowFullScreen(val) {
        this.setPropertyValue("allowFullScreen", val);
    }
    get css() {
        return this.survey.css;
    }
    get cssButton() {
        return this.getPropertyValue("cssButton", "");
    }
    get cssRoot() {
        let result = this.getPropertyValue("cssRoot", "");
        if (this.isCollapsed)
            result += " " + this.getPropertyValue("cssRootCollapsedMod", "");
        return result;
    }
    get cssRootCollapsedMod() {
        return this.getPropertyValue("cssRootCollapsedMod");
    }
    get cssRootContent() {
        return this.getPropertyValue("cssRootContent");
    }
    get cssBody() {
        return this.getPropertyValue("cssBody", "");
    }
    get cssHeaderRoot() {
        return this.getPropertyValue("cssHeaderRoot", "");
    }
    get cssHeaderTitleCollapsed() {
        return this.getPropertyValue("cssHeaderTitleCollapsed", "");
    }
    get cssHeaderButtonsContainer() {
        return this.getPropertyValue("cssHeaderButtonsContainer", "");
    }
    get cssHeaderCollapseButton() {
        return this.getPropertyValue("cssHeaderCollapseButton", "");
    }
    get cssHeaderCloseButton() {
        return this.getPropertyValue("cssHeaderCloseButton", "");
    }
    get cssHeaderFullScreenButton() {
        return this.getPropertyValue("cssHeaderFullScreenButton", "");
    }
    get renderedWidth() {
        let width = this.getPropertyValue("width", "60%");
        if (width && !isNaN(width))
            width = width + "px";
        return width;
    }
    updateCss() {
        if (!this.css || !this.css.window)
            return;
        const cssWindow = this.css.window;
        this.setCssRoot();
        this.setPropertyValue("cssRootCollapsedMod", cssWindow.rootCollapsedMod);
        this.setPropertyValue("cssRootContent", cssWindow.rootContent);
        this.setPropertyValue("cssBody", cssWindow.body);
        const cssHeader = cssWindow.header;
        if (!cssHeader)
            return;
        this.setPropertyValue("cssHeaderRoot", cssHeader.root);
        this.setPropertyValue("cssHeaderTitleCollapsed", cssHeader.titleCollapsed);
        this.setPropertyValue("cssHeaderButtonsContainer", cssHeader.buttonsContainer);
        this.setPropertyValue("cssHeaderCollapseButton", cssHeader.collapseButton);
        this.setPropertyValue("cssHeaderCloseButton", cssHeader.closeButton);
        this.setPropertyValue("cssHeaderFullScreenButton", cssHeader.fullScreenButton);
        this.updateCssButton();
    }
    setCssRoot() {
        const cssWindow = this.css.window;
        if (this.isFullScreen) {
            this.setPropertyValue("cssRoot", cssWindow.root + " " + cssWindow.rootFullScreenMode);
        }
        else {
            this.setPropertyValue("cssRoot", cssWindow.root);
        }
    }
    updateCssButton() {
        const cssHeader = !!this.css.window ? this.css.window.header : null;
        if (!cssHeader)
            return;
        this.setCssButton(this.isExpanded ? cssHeader.buttonExpanded : cssHeader.buttonCollapsed);
    }
    setCssButton(val) {
        if (!val)
            return;
        this.setPropertyValue("cssButton", val);
    }
    createSurvey(jsonObj) {
        return new SurveyModel(jsonObj);
    }
    onSurveyComplete() {
        if (this.closeOnCompleteTimeout < 0)
            return;
        if (this.closeOnCompleteTimeout == 0) {
            this.hide();
        }
        else {
            var self = this;
            var timerId = null;
            var func = function () {
                self.hide();
                clearInterval(timerId);
            };
            timerId = setInterval(func, this.closeOnCompleteTimeout * 1000);
        }
    }
    onScroll() {
        this.survey.onScroll();
    }
}
__decorate([
    property()
], PopupSurveyModel.prototype, "width", void 0);
/**
 * @deprecated Use `PopupSurveyModel` instead.
 */
class SurveyWindowModel extends PopupSurveyModel {
}

class ScrollViewModel {
    constructor() {
        this._lockScroll = false;
    }
    setRootElement(element) {
        this._containerElementValue = element === null || element === void 0 ? void 0 : element.querySelector(".sv-scroll__scroller");
        this._scrollbarElement = element === null || element === void 0 ? void 0 : element.querySelector(".sv-scroll__scrollbar");
        this._scrollbarSizerElement = element === null || element === void 0 ? void 0 : element.querySelector(".sv-scroll__scrollbar-sizer");
        this._containerBodyElement = element === null || element === void 0 ? void 0 : element.querySelector(".sv-scroll__container");
        if (!element || !DomWindowHelper.isAvailable())
            return;
        this._containerBodyResizeObserver = new ResizeObserver(entries => {
            for (let entry of entries) {
                const height = entry.contentBoxSize
                    ? entry.contentBoxSize[0].blockSize
                    : entry.contentRect.width;
                this._scrollbarSizerElement.style.height = height + "px";
            }
            this.onInnerHeightChanged && this.onInnerHeightChanged(this._containerBodyElement.clientHeight > this._containerElementValue.clientHeight);
        });
        this._containerBodyResizeObserver.observe(this._containerBodyElement);
    }
    onScrollContainer() {
        this._lockScroll = true;
        this._scrollbarElement.scrollTop = this._containerElementValue.scrollTop;
    }
    onScrollScrollbar() {
        if (this._lockScroll) {
            this._lockScroll = false;
            return;
        }
        this._containerElementValue.scrollTop = this._scrollbarElement.scrollTop;
    }
    unsubscribeRootElement() {
        if (!!this._containerBodyResizeObserver) {
            this._containerBodyResizeObserver.disconnect();
            this._containerBodyResizeObserver = undefined;
        }
    }
}

const FOCUS_INPUT_SELECTOR = "input:not(:disabled):not([readonly]):not([type=hidden]),select:not(:disabled):not([readonly]),textarea:not(:disabled):not([readonly]), button:not(:disabled):not([readonly]), [tabindex]:not([tabindex^=\"-\"])";
class PopupBaseViewModel extends Base {
    updateIsVisible(val) {
        this._isVisible = val;
        this.onVisibilityChanged.fire(this, { isVisible: val });
    }
    updateBeforeShowing() {
        this.model.onShow();
    }
    updateAfterHiding() {
        this.model.onHiding();
    }
    getLeaveOptions() {
        return { cssClass: "sv-popup--leave",
            onBeforeRunAnimation: (el) => {
                el.setAttribute("inert", "");
            },
            onAfterRunAnimation: (el) => el.removeAttribute("inert")
        };
    }
    getEnterOptions() {
        return { cssClass: "sv-popup--enter" };
    }
    getAnimatedElement() {
        return this.getAnimationContainer();
    }
    isAnimationEnabled() {
        return this.model.displayMode !== "overlay" && settings.animationEnabled;
    }
    getRerenderEvent() { return this.onElementRerendered; }
    getAnimationContainer() {
        var _a;
        return (_a = this.container) === null || _a === void 0 ? void 0 : _a.querySelector(this.fixedPopupContainer);
    }
    get isVisible() {
        return this._isVisible;
    }
    set isVisible(val) {
        this.visibilityAnimation.sync(val);
    }
    get container() {
        return this.containerElement || this.createdContainer;
    }
    getLocale() {
        if (!!this.locale)
            return this.locale;
        return super.getLocale();
    }
    hidePopup() {
        this.model.isVisible = false;
    }
    getStyleClass() {
        return new CssClassBuilder()
            .append(this.model.cssClass);
        // .append(`sv-popup--${this.model.displayMode}`, this.isOverlay);
    }
    getShowFooter() {
        return this.isOverlay;
    }
    getShowHeader() {
        return false;
    }
    getPopupHeaderTemplate() {
        return undefined;
    }
    createFooterActionBar() {
        this.footerToolbarValue = new ActionContainer();
    }
    resetDimensionsAndPositionStyleProperties() {
        const nullableValue = "";
        this.top = nullableValue;
        this.left = nullableValue;
        this.height = nullableValue;
        this.width = nullableValue;
        this.minWidth = nullableValue;
    }
    onModelChanging(newModel) {
    }
    setupModel(model) {
        if (!!this.model) {
            this.model.onVisibilityChanged.remove(this.onModelIsVisibleChangedCallback);
        }
        this.onModelChanging(model);
        this._model = model;
        model.onVisibilityChanged.add(this.onModelIsVisibleChangedCallback);
        this.onModelIsVisibleChangedCallback();
    }
    get model() {
        return this._model;
    }
    set model(model) {
        this.setupModel(model);
    }
    constructor(model) {
        super();
        this.popupSelector = ".sv-popup";
        this.fixedPopupContainer = ".sv-popup";
        this.containerSelector = ".sv-popup__container";
        this.scrollingContentSelector = ".sv-popup__scrolling-content";
        this.visibilityAnimation = new AnimationBoolean(this, (val) => {
            if (this._isVisible !== val) {
                if (!val) {
                    this.updateOnHiding();
                    this.updateIsVisible(val);
                    this.updateAfterHiding();
                    this._isPositionSetValue = false;
                }
                else {
                    this.updateBeforeShowing();
                    this.updateIsVisible(val);
                }
            }
        }, () => this._isVisible);
        this.onVisibilityChanged = new EventBase();
        this.onModelIsVisibleChangedCallback = () => {
            this.isVisible = this.model.isVisible;
        };
        this._isPositionSetValue = false;
        this.model = model;
        this.locale = this.model.locale;
    }
    get title() {
        return this.model.title;
    }
    get contentComponentName() {
        return this.model.contentComponentName;
    }
    get contentComponentData() {
        return this.model.contentComponentData;
    }
    get isModal() {
        return this.model.isModal;
    }
    get isFocusedContent() {
        return this.model.isFocusedContent;
    }
    get isFocusedContainer() {
        return this.model.isFocusedContainer;
    }
    get showFooter() {
        return this.getShowFooter();
    }
    get showHeader() {
        return this.getShowHeader();
    }
    get popupHeaderTemplate() {
        return this.getPopupHeaderTemplate();
    }
    get isOverlay() {
        return this.model.displayMode === "overlay";
    }
    get styleClass() {
        return this.getStyleClass().toString();
    }
    get cancelButtonText() {
        return this.getLocalizationString("modalCancelButtonText");
    }
    get footerToolbar() {
        if (!this.footerToolbarValue) {
            this.createFooterActionBar();
        }
        return this.footerToolbarValue;
    }
    onKeyDown(event) {
        if (event.key === "Tab" || event.keyCode === 9) {
            this.trapFocus(event);
        }
        else if (event.key === "Escape" || event.keyCode === 27) {
            this.hidePopup();
        }
    }
    trapFocus(event) {
        const focusableElements = this.container.querySelectorAll(FOCUS_INPUT_SELECTOR);
        const firstFocusableElement = focusableElements[0];
        const lastFocusableElement = focusableElements[focusableElements.length - 1];
        if (event.shiftKey) {
            if (settings.environment.root.activeElement === firstFocusableElement) {
                lastFocusableElement.focus();
                event.preventDefault();
            }
        }
        else {
            if (settings.environment.root.activeElement === lastFocusableElement) {
                firstFocusableElement.focus();
                event.preventDefault();
            }
        }
    }
    switchFocus() {
        if (this.isFocusedContent) {
            this.focusFirstInput();
        }
        else if (this.isFocusedContainer) {
            this.focusContainer();
        }
    }
    get isPositionSet() {
        return this._isPositionSetValue;
    }
    updateOnShowing() {
        this.prevActiveElement = settings.environment.root.activeElement;
        if (this.isOverlay) {
            this.resetDimensionsAndPositionStyleProperties();
        }
        this.switchFocus();
        this._isPositionSetValue = true;
    }
    updateOnHiding() {
        if (this.isFocusedContent && this.prevActiveElement) {
            this.prevActiveElement.focus({ preventScroll: true });
        }
    }
    focusContainer() {
        if (!this.container)
            return;
        const popup = this.container.querySelector(this.popupSelector);
        popup === null || popup === void 0 ? void 0 : popup.focus();
    }
    focusFirstInput() {
        setTimeout(() => {
            if (!this.container)
                return;
            var el = this.container.querySelector(this.model.focusFirstInputSelector || FOCUS_INPUT_SELECTOR);
            if (!!el)
                el.focus();
            else
                this.focusContainer();
        }, 100);
    }
    clickOutside(event) {
        this.hidePopup();
        event === null || event === void 0 ? void 0 : event.stopPropagation();
    }
    cancel() {
        this.model.onCancel();
        this.hidePopup();
    }
    dispose() {
        super.dispose();
        if (this.model) {
            this.model.onVisibilityChanged.remove(this.onModelIsVisibleChangedCallback);
        }
        if (!!this.createdContainer) {
            this.createdContainer.remove();
            this.createdContainer = undefined;
        }
        if (!!this.footerToolbarValue) {
            this.footerToolbarValue.dispose();
        }
        this.resetComponentElement();
    }
    initializePopupContainer() {
        if (!this.container) {
            const container = DomDocumentHelper.createElement("div");
            this.createdContainer = container;
            getElement(settings.environment.popupMountContainer).appendChild(container);
        }
    }
    setComponentElement(componentRoot) {
        if (!!componentRoot) {
            this.containerElement = componentRoot;
        }
    }
    resetComponentElement() {
        this.containerElement = undefined;
        this.prevActiveElement = undefined;
    }
    preventScrollOuside(event, deltaY) {
        let currentElement = event.target;
        while (currentElement !== this.container) {
            if (DomDocumentHelper.getComputedStyle(currentElement).overflowY === "auto" && currentElement.scrollHeight !== currentElement.offsetHeight) {
                const { scrollHeight, scrollTop, clientHeight } = currentElement;
                if (!(deltaY > 0 && Math.abs(scrollHeight - clientHeight - scrollTop) < 1) && !(deltaY < 0 && scrollTop <= 0)) {
                    return;
                }
            }
            currentElement = currentElement.parentElement;
        }
        if (event.cancelable) {
            event.preventDefault();
        }
    }
}
__decorate([
    property({ defaultValue: "0px" })
], PopupBaseViewModel.prototype, "top", void 0);
__decorate([
    property({ defaultValue: "0px" })
], PopupBaseViewModel.prototype, "left", void 0);
__decorate([
    property({ defaultValue: "auto" })
], PopupBaseViewModel.prototype, "height", void 0);
__decorate([
    property({ defaultValue: "auto" })
], PopupBaseViewModel.prototype, "width", void 0);
__decorate([
    property({ defaultValue: "auto" })
], PopupBaseViewModel.prototype, "minWidth", void 0);
__decorate([
    property({ defaultValue: false })
], PopupBaseViewModel.prototype, "_isVisible", void 0);
__decorate([
    property()
], PopupBaseViewModel.prototype, "locale", void 0);

class Rect {
    constructor(x, y, width, height) {
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
    }
    get left() {
        return this.x;
    }
    get top() {
        return this.y;
    }
    get right() {
        return this.x + this.width;
    }
    get bottom() {
        return this.y + this.height;
    }
}
class PopupUtils {
    static calculatePosition(targetRect, height, width, verticalPosition, horizontalPosition, positionMode = "flex") {
        let currentLeft = targetRect.left;
        let currentTop = targetRect.top;
        if (positionMode === "flex") {
            if (horizontalPosition == "center")
                currentLeft = (targetRect.left + targetRect.right - width) / 2;
            else if (horizontalPosition == "left")
                currentLeft = targetRect.left - width;
            else
                currentLeft = targetRect.right;
        }
        if (verticalPosition == "middle")
            currentTop = (targetRect.top + targetRect.bottom - height) / 2;
        else if (verticalPosition == "top")
            currentTop = targetRect.top - height;
        else
            currentTop = targetRect.bottom;
        if (horizontalPosition != "center" && verticalPosition != "middle") {
            if (verticalPosition == "top") {
                currentTop = currentTop + targetRect.height;
            }
            else {
                currentTop = currentTop - targetRect.height;
            }
        }
        return { left: Math.round(currentLeft), top: Math.round(currentTop) };
    }
    static getCorrectedVerticalDimensions(top, height, windowHeight, verticalPosition, canShrink = true, margins = { top: 0, bottom: 0 }) {
        let result;
        const maxHeight = windowHeight - PopupUtils.bottomIndent;
        if (verticalPosition === "top") {
            result = { height: height, top: top };
        }
        if (top < -margins.top) {
            result = { height: canShrink ? height + top : height, top: -margins.top };
        }
        else if (height + top > windowHeight) {
            let newHeight = Math.min(height, maxHeight - top);
            result = { height: canShrink ? newHeight : height, top: canShrink ? top : top - (height - newHeight) };
        }
        if (result) {
            result.height = Math.min(result.height, maxHeight);
            result.top = Math.max(result.top, -margins.top);
        }
        return result;
    }
    static updateHorizontalDimensions(left, width, windowWidth, horizontalPosition, positionMode = "flex", margins = { left: 0, right: 0 }) {
        width += (margins.left + margins.right);
        let newWidth = undefined, newLeft = left;
        if (horizontalPosition === "center") {
            if (positionMode === "fixed") {
                if (left + width > windowWidth) {
                    newWidth = windowWidth - left;
                }
                newLeft -= margins.left;
            }
            else {
                if (left < 0) {
                    newLeft = margins.left;
                    newWidth = Math.min(width, windowWidth);
                }
                else if (width + left > windowWidth) {
                    newLeft = windowWidth - width;
                    newLeft = Math.max(newLeft, margins.left);
                    newWidth = Math.min(width, windowWidth);
                }
            }
        }
        if (horizontalPosition === "left") {
            if (left < 0) {
                newLeft = margins.left;
                newWidth = Math.min(width, windowWidth);
            }
        }
        if (horizontalPosition === "right") {
            if (width + left > windowWidth) {
                newWidth = windowWidth - left;
            }
        }
        return { width: newWidth - margins.left - margins.right, left: newLeft };
    }
    static updateVerticalPosition(targetRect, height, horizontalPosition, verticalPosition, windowHeight) {
        if (verticalPosition === "middle")
            return verticalPosition;
        let deltaTop = height - (targetRect.top + (horizontalPosition !== "center" ? targetRect.height : 0));
        let deltaBottom = height + targetRect.bottom - (horizontalPosition !== "center" ? targetRect.height : 0) - windowHeight;
        if (deltaTop > 0 && deltaBottom <= 0 && verticalPosition == "top") {
            verticalPosition = "bottom";
        }
        else if (deltaBottom > 0 && deltaTop <= 0 && verticalPosition == "bottom") {
            verticalPosition = "top";
        }
        else if (deltaBottom > 0 && deltaTop > 0) {
            verticalPosition = deltaTop < deltaBottom ? "top" : "bottom";
        }
        return verticalPosition;
    }
    static updateHorizontalPosition(targetRect, width, horizontalPosition, windowWidth) {
        if (horizontalPosition === "center")
            return horizontalPosition;
        let deltaLeft = width - targetRect.left;
        let deltaRight = width + targetRect.right - windowWidth;
        if (deltaLeft > 0 && deltaRight <= 0 && horizontalPosition == "left") {
            horizontalPosition = "right";
        }
        else if (deltaRight > 0 && deltaLeft <= 0 && horizontalPosition == "right") {
            horizontalPosition = "left";
        }
        else if (deltaRight > 0 && deltaLeft > 0) {
            horizontalPosition = deltaLeft < deltaRight ? "left" : "right";
        }
        return horizontalPosition;
    }
    static calculatePopupDirection(verticalPosition, horizontalPosition) {
        var popupDirection;
        if (horizontalPosition == "center" && verticalPosition != "middle") {
            popupDirection = verticalPosition;
        }
        else if (horizontalPosition != "center") {
            popupDirection = horizontalPosition;
        }
        return popupDirection;
    }
    //called when showPointer  is true
    static calculatePointerTarget(targetRect, top, left, verticalPosition, horizontalPosition, marginLeft = 0, marginRight = 0) {
        var targetPos = {};
        if (horizontalPosition != "center") {
            targetPos.top = targetRect.top + targetRect.height / 2;
            targetPos.left = targetRect[horizontalPosition];
        }
        else if (verticalPosition != "middle") {
            targetPos.top = targetRect[verticalPosition];
            targetPos.left = targetRect.left + targetRect.width / 2;
        }
        targetPos.left = Math.round(targetPos.left - left);
        targetPos.top = Math.round(targetPos.top - top);
        if (horizontalPosition == "left") {
            targetPos.left -= marginLeft + marginRight;
        }
        if (horizontalPosition === "center") {
            targetPos.left -= marginLeft;
        }
        return targetPos;
    }
}
PopupUtils.bottomIndent = 16;

class PopupDropdownViewModel extends PopupBaseViewModel {
    createFooterActionBar() {
        super.createFooterActionBar();
        this.footerToolbar.updateCallback = (isResetInitialized) => {
            this.footerToolbarValue.actions.forEach(action => action.cssClasses = {
                item: "sd-action sv-menu-popup__button"
            });
        };
        this.footerToolbar.containerCss = "sv-menu-footer-action-bar";
        let footerActions = [
            {
                id: "cancel",
                visibleIndex: 10,
                title: this.cancelButtonText,
                innerCss: "sv-popup__button--cancel",
                action: () => { this.cancel(); }
            }
        ];
        footerActions = this.model.updateFooterActions(footerActions);
        this.footerToolbarValue.setItems(footerActions);
    }
    getAvailableAreaRect() {
        const areaElement = this.model.getAreaCallback ? this.model.getAreaCallback(this.container) : undefined;
        if (areaElement) {
            const areaRect = areaElement.getBoundingClientRect();
            return new Rect(areaRect.x, areaRect.y, areaRect.width, areaRect.height);
        }
        return new Rect(0, 0, DomWindowHelper.getInnerWidth(), DomWindowHelper.getInnerHeight());
    }
    getTargetElementRect(areaRect) {
        const componentRoot = this.container;
        let targetElement = this.model.getTargetCallback ? this.model.getTargetCallback(componentRoot) : undefined;
        if (!!componentRoot && !!componentRoot.parentElement && !this.isModal && !targetElement) {
            targetElement = componentRoot.parentElement;
        }
        if (!targetElement)
            return null;
        const rect = targetElement.getBoundingClientRect();
        return new Rect(rect.left - areaRect.left, rect.top - areaRect.top, rect.width, rect.height);
    }
    _updatePosition() {
        var _a, _b, _c;
        const area = this.getAvailableAreaRect();
        const targetElementRect = this.getTargetElementRect(area);
        if (!targetElementRect)
            return;
        const popupContainer = (_a = this.container) === null || _a === void 0 ? void 0 : _a.querySelector(this.containerSelector);
        if (!popupContainer)
            return;
        const fixedPopupContainer = (_b = this.container) === null || _b === void 0 ? void 0 : _b.querySelector(this.fixedPopupContainer);
        const scrollContent = popupContainer.querySelector(this.scrollingContentSelector);
        const popupComputedStyle = DomDocumentHelper.getComputedStyle(popupContainer);
        const marginLeft = (parseFloat(popupComputedStyle.marginLeft) || 0);
        const marginRight = (parseFloat(popupComputedStyle.marginRight) || 0);
        const marginTop = (parseFloat(popupComputedStyle.marginTop) || 0);
        const marginBottom = (parseFloat(popupComputedStyle.marginBottom) || 0);
        let height = popupContainer.offsetHeight - scrollContent.offsetHeight + scrollContent.scrollHeight;
        const width = popupContainer.getBoundingClientRect().width;
        this.model.setWidthByTarget && (this.minWidth = targetElementRect.width + "px");
        let verticalPosition = this.model.verticalPosition;
        let actualHorizontalPosition = this.getActualHorizontalPosition();
        if (DomWindowHelper.isAvailable()) {
            const heightValues = [height, DomWindowHelper.getInnerHeight() * 0.9, (_c = DomWindowHelper.getVisualViewport()) === null || _c === void 0 ? void 0 : _c.height];
            height = Math.ceil(Math.min(...heightValues.filter((each) => typeof each === "number")));
            verticalPosition = PopupUtils.updateVerticalPosition(targetElementRect, height, this.model.horizontalPosition, this.model.verticalPosition, area.height);
            actualHorizontalPosition = PopupUtils.updateHorizontalPosition(targetElementRect, width, actualHorizontalPosition, area.width);
        }
        this.popupDirection = PopupUtils.calculatePopupDirection(verticalPosition, actualHorizontalPosition);
        const pos = PopupUtils.calculatePosition(targetElementRect, height, width + marginLeft + marginRight, verticalPosition, actualHorizontalPosition, this.model.positionMode);
        if (DomWindowHelper.isAvailable()) {
            const newVerticalDimensions = PopupUtils.getCorrectedVerticalDimensions(pos.top, height, area.height, verticalPosition, this.model.canShrink, { top: marginTop, bottom: marginBottom });
            if (!!newVerticalDimensions) {
                this.height = newVerticalDimensions.height + "px";
                pos.top = newVerticalDimensions.top;
            }
            if (this.model.setWidthByTarget) {
                this.width = targetElementRect.width + "px";
                pos.left = targetElementRect.left;
            }
            else {
                const newHorizontalDimensions = PopupUtils.updateHorizontalDimensions(pos.left, width, DomWindowHelper.getInnerWidth(), actualHorizontalPosition, this.model.positionMode, { left: marginLeft, right: marginRight });
                if (!!newHorizontalDimensions) {
                    this.width = newHorizontalDimensions.width ? newHorizontalDimensions.width + "px" : undefined;
                    pos.left = newHorizontalDimensions.left;
                }
            }
        }
        if (!!fixedPopupContainer) {
            const rect = fixedPopupContainer.getBoundingClientRect();
            pos.top -= rect.top;
            pos.left -= rect.left;
        }
        if (this.showHeader) {
            this.pointerTarget = PopupUtils.calculatePointerTarget(targetElementRect, pos.top, pos.left, verticalPosition, actualHorizontalPosition, marginLeft, marginRight);
            this.pointerTarget.top += "px";
            this.pointerTarget.left += "px";
        }
        pos.left += area.left;
        pos.top += area.top;
        this.left = pos.left + "px";
        this.top = pos.top + "px";
    }
    getActualHorizontalPosition() {
        let actualHorizontalPosition = this.model.horizontalPosition;
        if (DomDocumentHelper.isAvailable()) {
            let isRtl = DomDocumentHelper.getComputedStyle(DomDocumentHelper.getBody()).direction == "rtl";
            if (isRtl) {
                if (this.model.horizontalPosition === "left") {
                    actualHorizontalPosition = "right";
                }
                else if (this.model.horizontalPosition === "right") {
                    actualHorizontalPosition = "left";
                }
            }
        }
        return actualHorizontalPosition;
    }
    getStyleClass() {
        const displayMode = this.model.getDisplayMode();
        return super.getStyleClass()
            .append("sv-popup--menu-phone", displayMode === "menu-overlay")
            .append("sv-popup--menu-tablet", displayMode === "menu-popup-overlay")
            .append("sv-popup--menu-popup", displayMode === "menu-popup")
            .append("sv-popup--show-pointer", displayMode === "menu-popup" && this.showHeader)
            .append(`sv-popup--${this.popupDirection}`, displayMode === "menu-popup" && (this.showHeader || this.popupDirection == "top" || this.popupDirection == "bottom"));
    }
    getShowHeader() {
        return this.model.showPointer && !this.isOverlay;
    }
    getPopupHeaderTemplate() {
        return "popup-pointer";
    }
    constructor(model) {
        super(model);
        this.scrollEventCallBack = (event) => {
            if (this.isOverlay && IsTouch) {
                event.stopPropagation();
                event.preventDefault();
                return;
            }
            this.hidePopup();
        };
        this.resizeEventCallback = () => {
            if (!DomWindowHelper.isAvailable())
                return;
            const visualViewport = DomWindowHelper.getVisualViewport();
            const documentElement = DomDocumentHelper.getDocumentElement();
            if (!!documentElement && !!visualViewport) {
                documentElement.style.setProperty("--sv-popup-overlay-height", `${visualViewport.height * visualViewport.scale}px`);
            }
        };
        this.resizeWindowCallback = () => {
            if (!this.isOverlay) {
                this.updatePosition(true, SurveyModel.platform === "vue" || SurveyModel.platform === "vue3" || SurveyModel.platform == "react" || SurveyModel.platform == "js-ui");
            }
        };
        this.clientY = 0;
        this.touchStartEventCallback = (event) => {
            this.clientY = event.touches[0].clientY;
        };
        this.touchMoveEventCallback = (event) => {
            this.preventScrollOuside(event, this.clientY - event.changedTouches[0].clientY);
        };
        this.model.onRecalculatePosition.add(this.recalculatePositionHandler);
    }
    setComponentElement(componentRoot) {
        super.setComponentElement(componentRoot);
    }
    resetComponentElement() {
        super.resetComponentElement();
    }
    updateOnShowing() {
        const { root } = settings.environment;
        this.prevActiveElement = root.activeElement;
        if (this.isOverlay) {
            this.resetDimensionsAndPositionStyleProperties();
        }
        else {
            this.updatePosition(true, false);
        }
        this.switchFocus();
        DomWindowHelper.addEventListener("resize", this.resizeWindowCallback);
        if (this.shouldCreateResizeCallback) {
            DomWindowHelper.getVisualViewport().addEventListener("resize", this.resizeEventCallback);
            if (this.container) {
                this.container.addEventListener("touchstart", this.touchStartEventCallback);
                this.container.addEventListener("touchmove", this.touchMoveEventCallback);
            }
            this.resizeEventCallback();
        }
        DomWindowHelper.addEventListener("scroll", this.scrollEventCallBack);
        this._isPositionSetValue = true;
    }
    get shouldCreateResizeCallback() {
        return !!DomWindowHelper.getVisualViewport() && this.isOverlay;
    }
    updatePosition(isResetHeight, isDelayUpdating = true) {
        if (isResetHeight) {
            this.height = "auto";
        }
        if (isDelayUpdating) {
            setTimeout(() => {
                this._updatePosition();
            }, 1);
        }
        else {
            this._updatePosition();
        }
    }
    updateOnHiding() {
        super.updateOnHiding();
        DomWindowHelper.removeEventListener("resize", this.resizeWindowCallback);
        if (this.shouldCreateResizeCallback) {
            DomWindowHelper.getVisualViewport().removeEventListener("resize", this.resizeEventCallback);
            if (this.container) {
                this.container.removeEventListener("touchstart", this.touchStartEventCallback);
                this.container.removeEventListener("touchmove", this.touchMoveEventCallback);
            }
        }
        DomWindowHelper.removeEventListener("scroll", this.scrollEventCallBack);
        if (!this.isDisposed) {
            this.top = undefined;
            this.left = undefined;
            this.height = undefined;
            this.width = undefined;
            this.minWidth = undefined;
        }
    }
    onModelChanging(newModel) {
        if (!!this.model) {
            this.model.onRecalculatePosition.remove(this.recalculatePositionHandler);
        }
        if (!this.recalculatePositionHandler) {
            this.recalculatePositionHandler = (_, options) => {
                if (!this.isOverlay) {
                    this.updatePosition(options.isResetHeight);
                }
            };
        }
        super.onModelChanging(newModel);
        newModel.onRecalculatePosition.add(this.recalculatePositionHandler);
    }
    dispose() {
        super.dispose();
        this.updateOnHiding();
        if (!!this.model) {
            this.model.onRecalculatePosition.remove(this.recalculatePositionHandler);
            this.recalculatePositionHandler = undefined;
        }
        this.resetComponentElement();
    }
}
PopupDropdownViewModel.tabletSizeBreakpoint = 600;
__decorate([
    property({ defaultValue: "left" })
], PopupDropdownViewModel.prototype, "popupDirection", void 0);
__decorate([
    property({ defaultValue: { left: "0px", top: "0px" } })
], PopupDropdownViewModel.prototype, "pointerTarget", void 0);

class PopupModalViewModel extends PopupBaseViewModel {
    getStyleClass() {
        const displayMode = this.model.getDisplayMode();
        return super.getStyleClass()
            .append("sv-popup--modal-popup", displayMode === "modal-popup")
            .append("sv-popup--modal-overlay", displayMode === "modal-overlay");
    }
    getShowFooter() {
        return true;
    }
    createFooterActionBar() {
        super.createFooterActionBar();
        this.footerToolbar.updateCallback = (isResetInitialized) => {
            this.footerToolbarValue.actions.forEach(action => action.cssClasses = {
                item: "sv-popup__body-footer-item sv-popup__button sv-modal-popup__button sd-btn sd-btn--small"
            });
        };
        this.footerToolbar.containerCss = "sv-modal-footer-action-bar";
        let footerActions = [
            {
                id: "cancel",
                visibleIndex: 10,
                title: this.cancelButtonText,
                innerCss: "sv-popup__button--cancel",
                action: () => { this.cancel(); }
            },
            {
                id: "apply",
                visibleIndex: 20,
                title: this.applyButtonText,
                innerCss: "sv-popup__button--apply sd-btn--action",
                action: () => { this.apply(); }
            }
        ];
        footerActions = this.model.updateFooterActions(footerActions);
        this.footerToolbarValue.setItems(footerActions);
    }
    constructor(model) {
        super(model);
        this.onScrollOutsideCallback = (event) => {
            this.preventScrollOuside(event, event.deltaY);
        };
    }
    get applyButtonText() {
        return this.getLocalizationString("modalApplyButtonText");
    }
    apply() {
        if (!!this.model.onApply && !this.model.onApply())
            return;
        this.hidePopup();
    }
    clickOutside() {
        return;
    }
    onKeyDown(event) {
        if (event.key === "Escape" || event.keyCode === 27) {
            this.model.onCancel();
        }
        super.onKeyDown(event);
    }
    updateOnShowing() {
        if (this.container) {
            this.container.addEventListener("wheel", this.onScrollOutsideCallback, { passive: false });
        }
        super.updateOnShowing();
    }
    updateOnHiding() {
        if (this.container) {
            this.container.removeEventListener("wheel", this.onScrollOutsideCallback);
        }
        super.updateOnHiding();
    }
}

function createPopupModalViewModel(options, rootElement) {
    var _a;
    const popupOptions = Object.assign({}, options);
    popupOptions.verticalPosition = "top";
    popupOptions.horizontalPosition = "left";
    popupOptions.showPointer = false;
    popupOptions.isModal = true;
    popupOptions.displayMode = options.displayMode || "popup";
    const popupModel = new PopupModel(options.componentName, options.data, popupOptions);
    popupModel.isFocusedContent = (_a = options.isFocusedContent) !== null && _a !== void 0 ? _a : true;
    const popupViewModel = new PopupModalViewModel(popupModel);
    if (!!rootElement && !!rootElement.appendChild) {
        var container = DomDocumentHelper.createElement("div");
        rootElement.appendChild(container);
        popupViewModel.setComponentElement(container);
    }
    if (!popupViewModel.container) {
        popupViewModel.initializePopupContainer();
    }
    const onVisibilityChangedCallback = (sender, options) => {
        if (!options.isVisible) {
            if (!!container) {
                popupViewModel.resetComponentElement();
            }
        }
        popupViewModel.onVisibilityChanged.remove(onVisibilityChangedCallback);
    };
    popupViewModel.onVisibilityChanged.add(onVisibilityChangedCallback);
    return popupViewModel;
}
function createPopupViewModel(model) {
    if (model.isModal) {
        return new PopupModalViewModel(model);
    }
    else {
        return new PopupDropdownViewModel(model);
    }
}

class ButtonGroupItemValue extends ItemValue {
    constructor(value, text = null, typeName = "buttongroupitemvalue") {
        super(value, text, typeName);
        this.typeName = typeName;
    }
    getType() {
        return !!this.typeName ? this.typeName : "buttongroupitemvalue";
    }
}
__decorate([
    property()
], ButtonGroupItemValue.prototype, "iconName", void 0);
__decorate([
    property()
], ButtonGroupItemValue.prototype, "iconSize", void 0);
__decorate([
    property()
], ButtonGroupItemValue.prototype, "showCaption", void 0);
/**
 * A Model for a button group question.
 */
class QuestionButtonGroupModel extends QuestionCheckboxBase {
    constructor(name) {
        super(name);
        this._allowClear = true;
        this.createLocalizableString("buttongroupOptionsCaption", this, false, true);
        this.createLocalizableString("readOnlyText", this, true);
        this.registerPropertyChangedHandlers(["value", "renderAs", "placeholder", "choices", "visibleChoices"], () => {
            this.updateReadOnlyText();
        });
        this.updateReadOnlyText();
    }
    locStrsChanged() {
        var _a;
        super.locStrsChanged();
        this.updateReadOnlyText();
        (_a = this.dropdownListModelValue) === null || _a === void 0 ? void 0 : _a.locStrsChanged();
    }
    updateReadOnlyText() {
        this.readOnlyText = this.displayValue || this.placeholder;
    }
    getType() {
        return "buttongroup";
    }
    getItemValueType() {
        return "buttongroupitemvalue";
    }
    supportOther() {
        return false;
    }
    //methods for mobile view
    getControlClass() {
        this.isEmpty();
        return new CssClassBuilder()
            .append(this.cssClasses.control)
            .append(this.cssClasses.controlEmpty, this.isEmpty())
            .append(this.cssClasses.onError, this.hasCssError())
            .append(this.cssClasses.controlDisabled, this.isDisabledStyle)
            .append(this.cssClasses.controlReadOnly, this.isReadOnlyStyle)
            .append(this.cssClasses.controlPreview, this.isPreviewStyle)
            .toString();
    }
    getFirstInputElementId() {
        return this.inputId + "_0";
    }
    getInputId(index) {
        return this.inputId + "_" + index;
    }
    get placeholder() {
        return this.getLocalizableStringText("buttongroupOptionsCaption");
    }
    set placeholder(val) {
        this.setLocalizableStringText("buttongroupOptionsCaption", val);
    }
    get locPlaceholder() {
        return this.getLocalizableString("buttongroupOptionsCaption");
    }
    get allowClear() {
        return this._allowClear;
    }
    set allowClear(newVal) {
        this._allowClear = newVal;
    }
    get searchEnabled() {
        return false;
    }
    isItemSelected(item) {
        return item.value == this.value;
    }
    get readOnlyText() {
        return this.getLocalizableStringText("readOnlyText");
    }
    set readOnlyText(val) {
        this.setLocalizableStringText("readOnlyText", val);
    }
    get locReadOnlyText() {
        return this.getLocalizableString("readOnlyText");
    }
    get showSelectedItemLocText() {
        return !this.readOnly && !this.inputHasValue && !!this.selectedItemLocText;
    }
    get selectedItemLocText() {
        var _a;
        return (_a = this.selectedItem) === null || _a === void 0 ? void 0 : _a.locText;
    }
    set dropdownListModel(val) {
        this.dropdownListModelValue = val;
        this.updateElementCss();
    }
    get dropdownListModel() {
        if (this.renderAs === "dropdown") {
            this.onBeforeSetCompactRenderer();
        }
        return this.dropdownListModelValue;
    }
    get selectedItem() { return this.getSingleSelectedItem(); }
    onBlurCore(event) {
        var _a;
        (_a = this.dropdownListModel) === null || _a === void 0 ? void 0 : _a.onBlur(event);
        super.onBlurCore(event);
    }
    updateCssClasses(res, css) {
        super.updateCssClasses(res, css);
        updateListCssValues(res, css);
    }
    calcCssClasses(css) {
        const classes = super.calcCssClasses(css);
        if (this.dropdownListModelValue) {
            this.dropdownListModelValue.updateCssClasses(classes.popup, classes.list);
        }
        return classes;
    }
    // responsiveness
    needResponsiveWidth() {
        return true;
    }
    supportResponsiveness() {
        return true;
    }
    getCompactRenderAs() {
        return "dropdown";
    }
    getObservedElementSelector() {
        return ".sd-button-group-scrollable-container";
    }
    onBeforeSetCompactRenderer() {
        if (!this.dropdownListModelValue) {
            this.dropdownListModelValue = new DropdownListModel(this);
        }
    }
    dispose() {
        super.dispose();
        if (!!this.dropdownListModelValue) {
            this.dropdownListModelValue.dispose();
            this.dropdownListModelValue = undefined;
        }
    }
}
__decorate([
    property({ defaultValue: false })
], QuestionButtonGroupModel.prototype, "inputHasValue", void 0);
Serializer.addClass("buttongroup", [
    {
        name: "choices:buttongroupitemvalue[]",
    },
], function () {
    return new QuestionButtonGroupModel("");
}, "checkboxbase");
Serializer.addClass("buttongroupitemvalue", [
    { name: "showCaption:boolean", default: true },
    { name: "iconName:text" },
    { name: "iconSize:number" },
], (value) => new ButtonGroupItemValue(value), "itemvalue");
// QuestionFactory.Instance.registerQuestion("buttongroup", name => {
//   var q = new QuestionButtonGroupModel(name);
//   q.choices = QuestionFactory.DefaultChoices;
//   return q;
// });
class ButtonGroupItemModel {
    constructor(question, item, index) {
        this.question = question;
        this.item = item;
        this.index = index;
    }
    get value() {
        return this.item.value;
    }
    get iconName() {
        return this.item.iconName;
    }
    get iconSize() {
        return this.item.iconSize || 24;
    }
    get caption() {
        return this.item.locText;
    }
    get showCaption() {
        return this.item.showCaption || this.item.showCaption === undefined;
    }
    get isRequired() {
        return this.question.isRequired;
    }
    get selected() {
        return this.question.isItemSelected(this.item);
    }
    get readOnly() {
        return this.question.isInputReadOnly || !this.item.isEnabled;
    }
    get name() {
        return this.question.name + "_" + this.question.id;
    }
    get id() {
        return this.question.inputId + "_" + this.index;
    }
    get hasErrors() {
        return this.question.errors.length > 0;
    }
    get describedBy() {
        return this.question.errors.length > 0
            ? this.question.id + "_errors"
            : null;
    }
    get labelClass() {
        return new CssClassBuilder()
            .append(this.question.cssClasses.item)
            .append(this.question.cssClasses.itemSelected, this.selected)
            .append(this.question.cssClasses.itemHover, !this.readOnly && !this.selected)
            .append(this.question.cssClasses.itemDisabled, this.question.isReadOnly || !this.item.isEnabled)
            .toString();
    }
    get css() {
        return {
            label: this.labelClass,
            icon: this.question.cssClasses.itemIcon,
            control: this.question.cssClasses.itemControl,
            caption: this.question.cssClasses.itemCaption,
            decorator: this.question.cssClasses.itemDecorator,
        };
    }
    onChange() {
        this.question.renderedValue = this.item.value;
    }
}

/**
 * A base class for classes that implement input masks:
 *
 * - [`InputMaskNumeric`](https://surveyjs.io/form-library/documentation/inputmasknumeric)
 * - [`InputMaskCurrency`](https://surveyjs.io/form-library/documentation/inputmaskcurrency)
 * - [`InputMaskDateTime`](https://surveyjs.io/form-library/documentation/inputmaskdatetime)
 * - [`InputMaskPattern`](https://surveyjs.io/form-library/documentation/inputmaskpattern)
 */
class InputMaskBase extends Base {
    getSurvey(live = false) {
        var _a;
        return (_a = this.owner) === null || _a === void 0 ? void 0 : _a.getSurvey();
    }
    getType() {
        return "masksettings";
    }
    setData(json) {
        const properties = Serializer.getProperties(this.getType());
        properties.forEach(property => {
            const currentValue = json[property.name];
            this[property.name] = currentValue !== undefined ? currentValue : property.getDefaultValue(this);
        });
    }
    getData() {
        const res = {};
        const properties = Serializer.getProperties(this.getType());
        properties.forEach(property => {
            const currentValue = this[property.name];
            if (!property.isDefaultValue(currentValue)) {
                res[property.name] = currentValue;
            }
        });
        return res;
    }
    processInput(args) {
        return { value: args.prevValue, caretPosition: args.selectionEnd, cancelPreventDefault: false };
    }
    getUnmaskedValue(src) { return src; }
    getMaskedValue(src) { return src; }
    getTextAlignment() { return "auto"; }
    getTypeForExpressions() {
        return "text";
    }
}
__decorate([
    property()
], InputMaskBase.prototype, "saveMaskedValue", void 0);
Serializer.addClass("masksettings", [
    {
        name: "saveMaskedValue:boolean",
        visibleIf: function (obj) {
            if (!obj)
                return false;
            return obj.getType() !== "masksettings";
        },
    },
], function () {
    return new InputMaskBase();
});

function getLiterals(pattern) {
    const result = [];
    let prevCharIsEscaped = false;
    const definitionsKeys = Object.keys(settings.maskSettings.patternDefinitions);
    for (let index = 0; index < pattern.length; index++) {
        const currentChar = pattern[index];
        if (currentChar === settings.maskSettings.patternEscapeChar) {
            prevCharIsEscaped = true;
        }
        else if (prevCharIsEscaped) {
            prevCharIsEscaped = false;
            result.push({ type: "fixed", value: currentChar });
        }
        else {
            result.push({ type: definitionsKeys.indexOf(currentChar) !== -1 ? "regex" : "const", value: currentChar });
        }
    }
    return result;
}
function getFirstMatch(str, strIndex, literal) {
    const currentDefinition = settings.maskSettings.patternDefinitions[literal.value];
    while (strIndex < str.length) {
        if (str[strIndex].match(currentDefinition)) {
            return strIndex;
        }
        strIndex++;
    }
    return strIndex;
}
function getMaskedValueByPattern(src, pattern, matchWholeMask) {
    const input = (src === undefined || src === null) ? "" : src;
    let result = "";
    let strIndex = 0;
    const literals = (typeof pattern === "string") ? getLiterals(pattern) : pattern;
    for (let maskIndex = 0; maskIndex < literals.length; maskIndex++) {
        switch (literals[maskIndex].type) {
            case "regex":
                if (strIndex < input.length) {
                    strIndex = getFirstMatch(input, strIndex, literals[maskIndex]);
                }
                if (strIndex < input.length) {
                    result += input[strIndex];
                }
                else if (matchWholeMask) {
                    result += settings.maskSettings.patternPlaceholderChar;
                }
                else {
                    return result;
                }
                strIndex++;
                break;
            case "const":
            case "fixed":
                result += literals[maskIndex].value;
                if (literals[maskIndex].value === input[strIndex]) {
                    strIndex++;
                }
                break;
        }
    }
    return result;
}
function getUnmaskedValueByPattern(str, pattern, matchWholeMask, skipFixedChar = false) {
    let result = "";
    if (!str)
        return result;
    let literals = (typeof pattern === "string") ? getLiterals(pattern) : pattern;
    for (let index = 0; index < literals.length; index++) {
        if (literals[index].type === "fixed" && !skipFixedChar) {
            result += literals[index].value;
        }
        if (literals[index].type === "regex") {
            const currentDefinition = settings.maskSettings.patternDefinitions[literals[index].value];
            if (!!str[index] && str[index].match(currentDefinition)) {
                result += str[index];
            }
            else if (matchWholeMask) {
                result = "";
                break;
            }
            else {
                break;
            }
        }
    }
    return result;
}
/**
 * A class that describes an input mask of the `"pattern"` [`maskType`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#maskType).
 *
 * The following code shows how to specify the properties of this class within a survey JSON schema:
 *
 * ```js
 * const surveyJson = {
 *   "elements": [{
 *     "name": "textquestion1"
 *     "type": "text",
 *     "maskType": "pattern",
 *     "maskSettings": {
 *       // Specify the properties of a pattern input mask here
 *     }
 *   }]
 * }
 * ```
 *
 * [View Demo](https://surveyjs.io/form-library/examples/masked-input-fields/ (linkStyle))
 */
class InputMaskPattern extends InputMaskBase {
    constructor() {
        super(...arguments);
        this.literals = [];
    }
    updateLiterals() {
        this.literals = getLiterals(this.pattern || "");
    }
    onPropertyValueChanged(name, oldValue, newValue) {
        super.onPropertyValueChanged(name, oldValue, newValue);
        if (name === "pattern") {
            this.updateLiterals();
        }
    }
    getType() {
        return "patternmask";
    }
    fromJSON(json, options) {
        super.fromJSON(json, options);
        this.updateLiterals();
    }
    _getMaskedValue(src, matchWholeMask = false) {
        const input = (src === undefined || src === null) ? "" : src;
        return getMaskedValueByPattern(input, this.literals, matchWholeMask);
    }
    _getUnmaskedValue(src, matchWholeMask = false) {
        const input = (src === undefined || src === null) ? "" : src;
        return getUnmaskedValueByPattern(input, this.literals, matchWholeMask);
    }
    processInput(args) {
        const result = { value: args.prevValue, caretPosition: args.selectionEnd, cancelPreventDefault: false };
        if (!args.insertedChars && args.selectionStart === args.selectionEnd) {
            return result;
        }
        const leftPart = args.prevValue.slice(0, args.selectionStart) + (args.insertedChars || "");
        const leftPartUnmasked = getUnmaskedValueByPattern(args.prevValue.slice(0, args.selectionStart), this.literals.slice(0, args.selectionStart), false);
        const rightPartUnmasked = getUnmaskedValueByPattern(args.prevValue.slice(args.selectionEnd), this.literals.slice(args.selectionEnd), false, true);
        result.value = this._getMaskedValue(leftPartUnmasked + (args.insertedChars || "") + rightPartUnmasked, true);
        if (!args.insertedChars && args.inputDirection === "backward") {
            result.caretPosition = args.selectionStart;
        }
        else {
            result.caretPosition = this._getMaskedValue(leftPart).length;
        }
        return result;
    }
    getMaskedValue(src) {
        return this._getMaskedValue(src, true);
    }
    getUnmaskedValue(src) {
        return this._getUnmaskedValue(src, true);
    }
}
__decorate([
    property()
], InputMaskPattern.prototype, "pattern", void 0);
Serializer.addClass("patternmask", [
    { name: "pattern" },
], function () {
    return new InputMaskPattern();
}, "masksettings");

function splitString(str, reverse = true, n = 3) {
    let arr = [];
    if (reverse) {
        for (let i = str.length - n; i > -n; i -= n) {
            arr.push(str.substring(i, i + n));
        }
        arr = arr.reverse();
    }
    else {
        for (let i = 0; i < str.length; i += n) {
            arr.push(str.substring(i, i + n));
        }
    }
    return arr;
}
/**
 * A class that describes an input mask of the `"numeric"` [`maskType`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#maskType).
 *
 * The following code shows how to specify the properties of this class within a survey JSON schema:
 *
 * ```js
 * const surveyJson = {
 *   "elements": [{
 *     "name": "textquestion1"
 *     "type": "text",
 *     "maskType": "numeric",
 *     "maskSettings": {
 *       // Specify the properties of a numeric input mask here
 *     }
 *   }]
 * }
 * ```
 *
 * [View Demo](https://surveyjs.io/form-library/examples/masked-input-fields/ (linkStyle))
 */
class InputMaskNumeric extends InputMaskBase {
    calccaretPosition(leftPart, args, maskedValue) {
        const leftPartMaskedLength = !!leftPart ? this.displayNumber(this.parseNumber(leftPart), false).length : 0;
        let validCharIndex = 0;
        let result = args.selectionStart;
        // let result = 0;
        const isDeleteKeyOperation = !args.insertedChars && args.inputDirection === "forward";
        for (let index = 0; index < maskedValue.length; index++) {
            const currentChar = maskedValue[index];
            if (currentChar !== this.thousandsSeparator) {
                validCharIndex++;
            }
            if (validCharIndex === (leftPartMaskedLength + (isDeleteKeyOperation ? 1 : 0))) {
                if (isDeleteKeyOperation) {
                    result = index;
                }
                else {
                    result = index + 1;
                }
                break;
            }
            // if (validCharIndex === leftPartMaskedLength) {
            //   result = index + 1;
            //   break;
            // }
        }
        return result;
    }
    numericalCompositionIsEmpty(number) {
        return !number.integralPart && !number.fractionalPart;
    }
    displayNumber(parsedNumber, insertThousandsSeparator = true, matchWholeMask = false) {
        let displayIntegralPart = parsedNumber.integralPart;
        if (insertThousandsSeparator && !!displayIntegralPart) {
            displayIntegralPart = splitString(displayIntegralPart).join(this.thousandsSeparator);
        }
        let displayFractionalPart = parsedNumber.fractionalPart;
        const minusSign = parsedNumber.isNegative ? "-" : "";
        if (displayFractionalPart === "") {
            if (matchWholeMask) {
                return (!displayIntegralPart || displayIntegralPart === "0") ? displayIntegralPart : minusSign + displayIntegralPart;
            }
            else {
                const displayDecimalSeparator = parsedNumber.hasDecimalSeparator && !matchWholeMask ? this.decimalSeparator : "";
                const src = displayIntegralPart + displayDecimalSeparator;
                return src === "0" ? src : minusSign + src;
            }
        }
        else {
            displayIntegralPart = displayIntegralPart || "0";
            displayFractionalPart = displayFractionalPart.substring(0, this.precision);
            return [minusSign + displayIntegralPart, displayFractionalPart].join(this.decimalSeparator);
        }
    }
    convertNumber(parsedNumber) {
        let value;
        const minusSign = parsedNumber.isNegative ? "-" : "";
        if (!!parsedNumber.fractionalPart) {
            value = parseFloat(minusSign + (parsedNumber.integralPart || "0") + "." + parsedNumber.fractionalPart.substring(0, this.precision));
        }
        else {
            value = parseInt(minusSign + parsedNumber.integralPart || "0");
        }
        return value;
    }
    validateNumber(number, matchWholeMask) {
        const min = this.min || Number.MIN_SAFE_INTEGER;
        const max = this.max || Number.MAX_SAFE_INTEGER;
        if (this.numericalCompositionIsEmpty(number))
            return true;
        if (this.min !== undefined || this.max !== undefined) {
            let value = this.convertNumber(number);
            if (Number.isNaN(value)) {
                return true;
            }
            if (value >= min && value <= max)
                return true;
            if (!matchWholeMask) {
                if (!number.hasDecimalSeparator && value != 0) {
                    let test_high = value;
                    let test_low = value;
                    if (value > 0) {
                        if (value + 1 > min && value <= max)
                            return true;
                        while (true) {
                            test_high = test_high * 10 + 9;
                            test_low = test_low * 10;
                            if (test_low > max) {
                                break;
                            }
                            if (test_high > min) {
                                return true;
                            }
                        }
                        return false;
                    }
                    if (value < 0) {
                        if (value >= min && value - 1 < max)
                            return true;
                        while (true) {
                            test_high = test_high * 10;
                            test_low = test_low * 10 - 9;
                            if (test_high < min) {
                                break;
                            }
                            if (test_low < max) {
                                return true;
                            }
                        }
                        return false;
                    }
                }
                else {
                    const delta = Math.pow(0.1, (number.fractionalPart || "").length);
                    if (value >= 0)
                        return value + delta > min && value <= max;
                    if (value < 0)
                        return value >= min && value - delta < max;
                }
                return value >= 0 && value <= max || value < 0 && value >= min;
            }
            return false;
        }
        return true;
    }
    parseNumber(src) {
        const result = { integralPart: "", fractionalPart: "", hasDecimalSeparator: false, isNegative: false };
        const input = (src === undefined || src === null) ? "" : src.toString();
        let minusCharCount = 0;
        for (let inputIndex = 0; inputIndex < input.length; inputIndex++) {
            const currentChar = input[inputIndex];
            switch (currentChar) {
                case "-": {
                    if (this.allowNegativeValues && (this.min === undefined || this.min < 0)) {
                        minusCharCount++;
                    }
                    break;
                }
                case this.decimalSeparator: {
                    if (this.precision > 0) {
                        result.hasDecimalSeparator = true;
                    }
                    break;
                }
                case this.thousandsSeparator: {
                    break;
                }
                default: {
                    if (currentChar.match(numberDefinition)) {
                        if (result.hasDecimalSeparator) {
                            result.fractionalPart += currentChar;
                        }
                        else {
                            result.integralPart += currentChar;
                        }
                    }
                }
            }
        }
        result.isNegative = minusCharCount % 2 !== 0;
        if (result.integralPart.length > 1 && result.integralPart[0] === "0") {
            result.integralPart = result.integralPart.slice(1);
        }
        return result;
    }
    getNumberMaskedValue(src, matchWholeMask = false) {
        const parsedNumber = this.parseNumber(src);
        if (!this.validateNumber(parsedNumber, matchWholeMask)) {
            return null;
        }
        const displayText = this.displayNumber(parsedNumber, true, matchWholeMask);
        return displayText;
    }
    getNumberUnmaskedValue(str) {
        const parsedNumber = this.parseNumber(str);
        if (this.numericalCompositionIsEmpty(parsedNumber))
            return undefined;
        return this.convertNumber(parsedNumber);
    }
    getTextAlignment() {
        return "right";
    }
    getMaskedValue(src) {
        let input = (src === undefined || src === null) ? "" : src.toString();
        input = input.replace(".", this.decimalSeparator);
        return this.getNumberMaskedValue(input, true);
    }
    getUnmaskedValue(src) {
        return this.getNumberUnmaskedValue(src);
    }
    processInput(args) {
        const result = { value: args.prevValue, caretPosition: args.selectionEnd, cancelPreventDefault: false };
        const leftPart = args.prevValue.slice(0, args.selectionStart) + (args.insertedChars || "");
        const rightPart = args.prevValue.slice(args.selectionEnd);
        const src = leftPart + rightPart;
        const parsedNumber = this.parseNumber(src);
        if (!this.validateNumber(parsedNumber, false)) {
            return result;
        }
        const maskedValue = this.getNumberMaskedValue(src);
        const caretPosition = this.calccaretPosition(leftPart, args, maskedValue);
        result.value = maskedValue;
        result.caretPosition = caretPosition;
        return result;
    }
    getType() {
        return "numericmask";
    }
    isValueUndefined(value) {
        return value === "" || super.isValueUndefined(value);
    }
}
__decorate([
    property()
], InputMaskNumeric.prototype, "allowNegativeValues", void 0);
__decorate([
    property()
], InputMaskNumeric.prototype, "decimalSeparator", void 0);
__decorate([
    property()
], InputMaskNumeric.prototype, "precision", void 0);
__decorate([
    property()
], InputMaskNumeric.prototype, "thousandsSeparator", void 0);
__decorate([
    property()
], InputMaskNumeric.prototype, "min", void 0);
__decorate([
    property()
], InputMaskNumeric.prototype, "max", void 0);
Serializer.addClass("numericmask", [
    { name: "allowNegativeValues:boolean", default: true },
    { name: "decimalSeparator", default: ".", maxLength: 1 },
    { name: "thousandsSeparator", default: ",", maxLength: 1 },
    { name: "precision:number", default: 2, minValue: 0 },
    { name: "min:number" },
    { name: "max:number" },
], function () {
    return new InputMaskNumeric();
}, "masksettings");

function getMaxCountLexem(currentLexemType, count) {
    switch (currentLexemType) {
        case "hour":
        case "minute":
        case "second":
        case "day":
        case "month": {
            return 2;
        }
        case "timeMarker":
        case "year": {
            return count;
        }
        default: {
            return 1;
        }
    }
}
function trimDatePart(lexem, data) {
    let result = data;
    if (lexem.count < lexem.maxCount && ((lexem.type === "day" && parseInt(data[0]) === 0) || (lexem.type === "month" && parseInt(data[0]) === 0))) {
        result = data.slice(1, data.length);
    }
    return result;
}
function getDateTimeLexems(pattern) {
    const result = [];
    let prevLexemType;
    const createOrUpdateLexem = (currentLexemType, currentChar, upperCase = false) => {
        if (!!prevLexemType && prevLexemType === currentLexemType) {
            result[result.length - 1].count++;
            const maxCount = getMaxCountLexem(currentLexemType, result[result.length - 1].count);
            result[result.length - 1].maxCount = maxCount;
        }
        else {
            const maxCount = getMaxCountLexem(currentLexemType, 1);
            // result.push({ type: currentLexemType, value: currentChar, count: 1, data: { value: "", isCompleted: false, isCorrect: false }, maxCount: maxCount });
            result.push({ type: currentLexemType, value: currentChar, count: 1, maxCount: maxCount, upperCase: upperCase });
        }
    };
    for (let index = 0; index < pattern.length; index++) {
        const currentChar = pattern[index];
        switch (currentChar) {
            case "m":
                createOrUpdateLexem("month", currentChar);
                break;
            case "d":
                createOrUpdateLexem("day", currentChar);
                break;
            case "y":
                createOrUpdateLexem("year", currentChar);
                break;
            case "h":
                createOrUpdateLexem("hour", currentChar, false);
                break;
            case "H":
                createOrUpdateLexem("hour", currentChar, true);
                break;
            case "M":
                createOrUpdateLexem("minute", currentChar);
                break;
            case "s":
                createOrUpdateLexem("second", currentChar);
                break;
            case "t":
                createOrUpdateLexem("timeMarker", currentChar);
                break;
            case "T":
                createOrUpdateLexem("timeMarker", currentChar, true);
                break;
            default:
                result.push({ type: "separator", value: currentChar, count: 1, maxCount: 1, upperCase: false });
                break;
        }
        prevLexemType = result[result.length - 1].type;
    }
    return result;
}
/**
 * A class that describes an input mask of the `"datetime"` [`maskType`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#maskType).
 *
 * The following code shows how to specify the properties of this class within a survey JSON schema:
 *
 * ```js
 * const surveyJson = {
 *   "elements": [{
 *     "name": "textquestion1"
 *     "type": "text",
 *     "maskType": "datetime",
 *     "maskSettings": {
 *       // Specify the properties of a date-time input mask here
 *     }
 *   }]
 * }
 * ```
 *
 * [View Demo](https://surveyjs.io/form-library/examples/masked-input-fields/ (linkStyle))
 */
class InputMaskDateTime extends InputMaskPattern {
    constructor() {
        super(...arguments);
        this.defaultDate = "1970-01-01T";
        this.turnOfTheCentury = 68;
        this.twelve = 12;
        this.lexems = [];
        this.inputDateTimeData = [];
        this.validBeginningOfNumbers = {
            hour: 1,
            hourU: 2,
            minute: 5,
            second: 5,
            day: 3,
            month: 1,
        };
    }
    get hasDatePart() {
        return this.lexems.some(l => l.type === "day" || l.type === "month" || l.type === "year");
    }
    get hasTimePart() {
        return this.lexems.some(l => l.type === "hour" || l.type === "minute" || l.type === "second");
    }
    get is12Hours() {
        return this.lexems.filter(l => l.type === "hour" && !l.upperCase).length > 0;
    }
    getType() {
        return "datetimemask";
    }
    getTypeForExpressions() {
        return this.hasTimePart ? "datetime-local" : "datetime";
    }
    updateLiterals() {
        this.lexems = getDateTimeLexems(this.pattern || "");
    }
    leaveOnlyNumbers(input) {
        let result = "";
        for (let index = 0; index < input.length; index++) {
            if (input[index].match(numberDefinition)) {
                result += input[index];
            }
        }
        return result;
    }
    getMaskedStrFromISO(str) {
        let date = new Date(str);
        this.initInputDateTimeData();
        if (!this.hasTimePart) {
            date = new Date(str + "T00:00:00");
        }
        if (!this.hasDatePart) {
            date = new Date(this.defaultDate + str);
        }
        if (!isNaN(date)) {
            this.lexems.forEach((lexem, index) => {
                let inputData = this.inputDateTimeData[index];
                inputData.isCompleted = true;
                switch (lexem.type) {
                    case "hour": {
                        if (!this.is12Hours) {
                            inputData.value = date.getHours().toString();
                        }
                        else {
                            inputData.value = ((date.getHours() - 1) % this.twelve + 1).toString();
                        }
                        break;
                    }
                    case "minute": {
                        inputData.value = date.getMinutes().toString();
                        break;
                    }
                    case "second": {
                        inputData.value = date.getSeconds().toString();
                        break;
                    }
                    case "timeMarker": {
                        const marker = (date.getHours() >= this.twelve) ? "pm" : "am";
                        inputData.value = lexem.upperCase ? marker.toUpperCase() : marker;
                        break;
                    }
                    case "day": {
                        inputData.value = date.getDate().toString();
                        break;
                    }
                    case "month": {
                        inputData.value = (date.getMonth() + 1).toString();
                        break;
                    }
                    case "year": {
                        let year = date.getFullYear();
                        if (lexem.count == 2)
                            year = year % 100;
                        inputData.value = year.toString();
                        break;
                    }
                }
            });
        }
        return this.getFormatedString(true);
    }
    initInputDateTimeData() {
        this.inputDateTimeData = [];
        this.lexems.forEach(lexem => {
            this.inputDateTimeData.push({ lexem: lexem, isCompleted: false, value: undefined });
        });
    }
    getISO_8601Format(dateTime) {
        const date = [];
        const time = [];
        if (dateTime.year !== undefined) {
            const year = this.getPlaceholder(4, dateTime.year.toString(), "0") + dateTime.year;
            date.push(year);
        }
        if (dateTime.month !== undefined && dateTime.year !== undefined) {
            const month = this.getPlaceholder(2, dateTime.month.toString(), "0") + dateTime.month;
            date.push(month);
        }
        if (dateTime.day !== undefined && dateTime.month !== undefined && dateTime.year !== undefined) {
            const day = this.getPlaceholder(2, dateTime.day.toString(), "0") + dateTime.day;
            date.push(day);
        }
        if (dateTime.hour !== undefined) {
            const hour = this.getPlaceholder(2, dateTime.hour.toString(), "0") + dateTime.hour;
            time.push(hour);
        }
        if (dateTime.minute !== undefined && dateTime.hour !== undefined) {
            const minute = this.getPlaceholder(2, dateTime.minute.toString(), "0") + dateTime.minute;
            time.push(minute);
        }
        if (dateTime.second !== undefined && dateTime.minute !== undefined && dateTime.hour !== undefined) {
            const second = this.getPlaceholder(2, dateTime.second.toString(), "0") + dateTime.second;
            time.push(second);
        }
        const result = [];
        if (date.length > 0) {
            result.push(date.join("-"));
        }
        if (time.length > 1) {
            result.push(time.join(":"));
        }
        return result.join("T");
    }
    isYearValid(dateTime) {
        if (dateTime.min === undefined && dateTime.max === undefined)
            return false;
        const data = dateTime.year.toString();
        const minYearPart = dateTime.min.toISOString().slice(0, data.length);
        const maxYearPart = dateTime.max.toISOString().slice(0, data.length);
        return dateTime.year >= parseInt(minYearPart) && dateTime.year <= parseInt(maxYearPart);
    }
    createIDateTimeCompositionWithDefaults(dateTime, isUpperLimit) {
        const checkOnlyLeapYears = dateTime.day == 29 && dateTime.month == 2;
        let minYear = dateTime.min.getFullYear();
        let maxYear = dateTime.max.getFullYear();
        if (checkOnlyLeapYears) {
            minYear = Math.ceil(minYear / 4) * 4;
            maxYear = Math.floor(maxYear / 4) * 4;
            if (minYear > maxYear) {
                minYear = undefined;
                maxYear = undefined;
            }
        }
        const year = dateTime.year !== undefined ? dateTime.year : isUpperLimit ? maxYear : minYear;
        const month = dateTime.month !== undefined ? dateTime.month : (isUpperLimit && this.hasDatePart ? 12 : 1);
        const day = dateTime.day !== undefined ? dateTime.day : (isUpperLimit && this.hasDatePart ? this.getMaxDateForMonth(year, month) : 1);
        const hour = dateTime.hour !== undefined ? dateTime.hour : (isUpperLimit ? 23 : 0);
        const minute = dateTime.minute !== undefined ? dateTime.minute : (isUpperLimit ? 59 : 0);
        const second = dateTime.second !== undefined ? dateTime.second : (isUpperLimit ? 59 : 0);
        return { year: year, month: month, day: day, hour: hour, minute: minute, second: second };
    }
    getMaxDateForMonth(year, month) {
        if (month == 2)
            return year % 4 == 0 && year % 100 != 0 || year % 400 == 0 ? 29 : 28;
        return [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31][month - 1];
    }
    isDateValid(dateTime) {
        const date = new Date(this.getISO_8601Format(this.createIDateTimeCompositionWithDefaults(dateTime, false)));
        const dateH = new Date(this.getISO_8601Format(this.createIDateTimeCompositionWithDefaults(dateTime, true)));
        return !isNaN(date) &&
            (date.getDate() === dateTime.day || dateTime.day === undefined) &&
            (date.getMonth() === dateTime.month - 1 || dateTime.month === undefined) &&
            (date.getFullYear() === dateTime.year || dateTime.year === undefined) &&
            dateH >= dateTime.min && date <= dateTime.max;
    }
    getPlaceholder(lexemLength, str, char) {
        const paddingsLength = lexemLength - (str || "").length;
        const paddings = paddingsLength > 0 ? char.repeat(paddingsLength) : "";
        return paddings;
    }
    isDateValid12(dateTime12) {
        if (!this.is12Hours)
            return this.isDateValid(dateTime12);
        if (this.is12Hours && dateTime12.hour > this.twelve) {
            return false;
        }
        if (!dateTime12.timeMarker) {
            if (this.isDateValid(dateTime12))
                return true;
            dateTime12.hour += this.twelve;
            return this.isDateValid(dateTime12);
        }
        else if (dateTime12.timeMarker[0].toLowerCase() === "p") {
            if (dateTime12.hour !== this.twelve) {
                dateTime12.hour += this.twelve;
            }
            return this.isDateValid(dateTime12);
        }
        else {
            if (dateTime12.hour === this.twelve) {
                dateTime12.hour = 0;
            }
            return this.isDateValid(dateTime12);
        }
    }
    updateTimeMarkerInputDateTimeData(newItem, dateTime) {
        let data = newItem.value;
        if (!data)
            return;
        const propertyName = "timeMarker";
        const tempDateTime = Object.assign({}, dateTime);
        tempDateTime[propertyName] = data;
        if (this.isDateValid12(tempDateTime)) {
            newItem.isCompleted = true;
        }
        else {
            data = data.slice(0, data.length - 1);
        }
        newItem.value = data || undefined;
        dateTime[propertyName] = data || undefined;
        return;
    }
    updateInputDateTimeData(newItem, dateTime) {
        let data = newItem.value;
        if (!data)
            return;
        const propertyName = newItem.lexem.type;
        const tempDateTime = Object.assign({}, dateTime);
        tempDateTime[propertyName] = parseInt(this.parseTwoDigitYear(newItem));
        if (data.length === newItem.lexem.maxCount) {
            if (this.isDateValid12(tempDateTime)) {
                newItem.isCompleted = true;
                newItem.value = data || undefined;
                dateTime[propertyName] = parseInt(data) > 0 ? parseInt(data) : undefined;
                return;
            }
            else {
                data = data.slice(0, data.length - 1);
            }
        }
        tempDateTime[propertyName] = parseInt(data);
        const firstDigit = parseInt(data[0]);
        const validBeginningOfNumber = this.validBeginningOfNumbers[propertyName + (newItem.lexem.upperCase ? "U" : "")];
        if ((propertyName === "year" && !this.isYearValid(tempDateTime))) {
            data = data.slice(0, data.length - 1);
            newItem.isCompleted = false;
        }
        else if (validBeginningOfNumber !== undefined && firstDigit > validBeginningOfNumber) {
            if (this.isDateValid12(tempDateTime)) {
                newItem.isCompleted = true;
            }
            else {
                data = data.slice(0, data.length - 1);
            }
        }
        else if (validBeginningOfNumber !== undefined && firstDigit !== 0 && firstDigit <= validBeginningOfNumber) {
            this.checkValidationDateTimePart(tempDateTime, propertyName, newItem);
            if (newItem.isCompleted && !this.isDateValid12(tempDateTime)) {
                data = data.slice(0, data.length - 1);
            }
        }
        newItem.value = data || undefined;
        dateTime[propertyName] = parseInt(data) > 0 ? parseInt(data) : undefined;
    }
    checkValidationDateTimePart(dateTime, propertyName, newItem) {
        const prevValue = dateTime[propertyName];
        let tempValue = prevValue * 10;
        let maxValue = 10;
        if (propertyName === "month")
            maxValue = 3;
        if (propertyName === "hour")
            maxValue = this.is12Hours ? 3 : 5;
        newItem.isCompleted = true;
        for (let index = 0; index < maxValue; index++) {
            dateTime[propertyName] = tempValue + index;
            if (this.isDateValid12(dateTime)) {
                newItem.isCompleted = false;
                break;
            }
        }
        dateTime[propertyName] = prevValue;
    }
    getCorrectDatePartFormat(inputData, matchWholeMask) {
        const lexem = inputData.lexem;
        let dataStr = inputData.value || "";
        if (!!dataStr && lexem.type === "timeMarker") {
            if (matchWholeMask) {
                dataStr = dataStr + this.getPlaceholder(lexem.count, dataStr, lexem.value);
            }
            return dataStr;
        }
        if (!!dataStr && inputData.isCompleted) {
            dataStr = parseInt(dataStr).toString();
        }
        if (!!dataStr && inputData.isCompleted) {
            const zeroPaddings = this.getPlaceholder(lexem.count, dataStr, "0");
            dataStr = zeroPaddings + dataStr;
        }
        else {
            // !!!
            dataStr = trimDatePart(lexem, dataStr);
            if (matchWholeMask) {
                dataStr += this.getPlaceholder(lexem.count, dataStr, lexem.value);
            }
        }
        return dataStr;
    }
    createIDateTimeComposition() {
        let isoMin, isoMax;
        if (this.hasDatePart) {
            isoMin = this.min || "0001-01-01";
            isoMax = this.max || "9996-12-31";
        }
        else {
            isoMin = this.defaultDate + (this.min || "00:00:00");
            isoMax = this.defaultDate + (this.max || "23:59:59");
        }
        const tempDateTime = {
            hour: undefined,
            minute: undefined,
            second: undefined,
            day: undefined,
            month: undefined,
            year: undefined,
            min: new Date(isoMin),
            max: new Date(isoMax)
        };
        return tempDateTime;
    }
    parseTwoDigitYear(data) {
        const inputData = data.value;
        if (data.lexem.type !== "year" || data.lexem.count > 2)
            return inputData;
        if (!!this.max && this.max.length >= 4) {
            this.turnOfTheCentury = parseInt(this.max.slice(2, 4));
        }
        const year = parseInt(inputData);
        const result = (year > this.turnOfTheCentury ? "19" : "20") + inputData;
        return result;
    }
    getFormatedString(matchWholeMask) {
        let result = "";
        let prevSeparator = "";
        let prevIsCompleted = false;
        let lastItemWithDataIndex = this.inputDateTimeData.length - 1;
        if (!matchWholeMask) {
            const arr = this.inputDateTimeData.filter(item => !!item.value);
            lastItemWithDataIndex = this.inputDateTimeData.indexOf(arr[arr.length - 1]);
        }
        for (let index = 0; index < this.inputDateTimeData.length; index++) {
            const inputData = this.inputDateTimeData[index];
            switch (inputData.lexem.type) {
                case "timeMarker":
                case "hour":
                case "minute":
                case "second":
                case "day":
                case "month":
                case "year":
                    if (inputData.value === undefined && !matchWholeMask) {
                        result += (prevIsCompleted ? prevSeparator : "");
                        return result;
                    }
                    else {
                        const _matchWholeMask = matchWholeMask || lastItemWithDataIndex > index;
                        const data = this.getCorrectDatePartFormat(inputData, _matchWholeMask);
                        result += (prevSeparator + data);
                        prevIsCompleted = inputData.isCompleted;
                    }
                    break;
                case "separator":
                    prevSeparator = inputData.lexem.value;
                    break;
            }
        }
        return result;
    }
    cleanTimeMarker(str, upperCase) {
        let result = "";
        str = str.toUpperCase();
        for (let i = 0; i < str.length; i++) {
            if (!result && (str[i] == "P" || str[i] == "A") || result && str[i] == "M")
                result += str[i];
        }
        if (upperCase) {
            result = result.toUpperCase();
        }
        else {
            result = result.toLowerCase();
        }
        return result;
    }
    setInputDateTimeData(numberParts) {
        let numberPartsArrayIndex = 0;
        this.initInputDateTimeData();
        this.lexems.forEach((lexem, index) => {
            if (numberParts.length > 0 && numberPartsArrayIndex < numberParts.length) {
                if (lexem.type === "separator")
                    return;
                const inputData = this.inputDateTimeData[index];
                const currentPart = numberParts[numberPartsArrayIndex];
                let _data;
                if (lexem.type === "timeMarker") {
                    _data = this.cleanTimeMarker(currentPart, lexem.upperCase);
                }
                else {
                    _data = this.leaveOnlyNumbers(currentPart);
                }
                inputData.value = _data.slice(0, lexem.maxCount);
                numberPartsArrayIndex++;
            }
        });
    }
    _getMaskedValue(src, matchWholeMask = true) {
        let input = (src === undefined || src === null) ? "" : src.toString();
        const inputParts = this.getParts(input);
        this.setInputDateTimeData(inputParts);
        const tempDateTime = this.createIDateTimeComposition();
        this.inputDateTimeData.forEach(itemData => {
            if (itemData.lexem.type === "timeMarker") {
                this.updateTimeMarkerInputDateTimeData(itemData, tempDateTime);
            }
            else {
                this.updateInputDateTimeData(itemData, tempDateTime);
            }
        });
        const result = this.getFormatedString(matchWholeMask);
        return result;
    }
    getParts(input) {
        const inputParts = [];
        const lexemsWithValue = this.lexems.filter(l => l.type !== "separator");
        const separators = this.lexems.filter(l => l.type === "separator").map(s => s.value);
        let curPart = "";
        let foundSeparator = false;
        let foundPseudoSeparator = false;
        for (let i = 0; i < input.length; i++) {
            const inputChar = input[i];
            if (inputChar.match(numberDefinition) || inputChar === lexemsWithValue[inputParts.length].value) {
                foundSeparator = false;
                foundPseudoSeparator = false;
                curPart += inputChar;
            }
            else if (lexemsWithValue[inputParts.length].type === "timeMarker") {
                foundSeparator = false;
                foundPseudoSeparator = false;
                curPart += inputChar;
            }
            else {
                if (separators.indexOf(inputChar) !== -1) {
                    if (!foundPseudoSeparator) {
                        foundSeparator = true;
                        inputParts.push(curPart);
                        curPart = "";
                    }
                }
                else {
                    if (!foundSeparator) {
                        foundPseudoSeparator = true;
                        inputParts.push(curPart);
                        curPart = "";
                    }
                }
            }
            if (inputParts.length >= lexemsWithValue.length) {
                foundSeparator = false;
                break;
            }
        }
        if (curPart != "" || foundSeparator) {
            inputParts.push(curPart);
        }
        return inputParts;
    }
    getUnmaskedValue(src) {
        var _a;
        let input = (src === undefined || src === null) ? "" : src.toString();
        const inputParts = this.getParts(input);
        this.setInputDateTimeData(inputParts);
        const timeMarker = (_a = this.inputDateTimeData.filter(idtd => idtd.lexem.type === "timeMarker")[0]) === null || _a === void 0 ? void 0 : _a.value.toLowerCase()[0];
        const tempDateTime = this.createIDateTimeComposition();
        let uncompleted = false;
        this.inputDateTimeData.forEach(inputData => {
            let str = inputData.value;
            if (inputData.lexem.type == "timeMarker" || inputData.lexem.type == "separator")
                return;
            if (!str || str.length < inputData.lexem.count) {
                uncompleted = true;
                return;
            }
            let value = parseInt(this.parseTwoDigitYear(inputData));
            if (inputData.lexem.type == "hour" && timeMarker === "p" && value != this.twelve)
                value += this.twelve;
            tempDateTime[inputData.lexem.type] = value;
        });
        return uncompleted ? "" : this.getISO_8601Format(tempDateTime);
    }
    getMaskedValue(src) {
        return this.getMaskedStrFromISO(src);
    }
    processInput(args) {
        const result = { value: args.prevValue, caretPosition: args.selectionEnd, cancelPreventDefault: false };
        const leftPart = args.prevValue.slice(0, args.selectionStart);
        const rightPart = args.prevValue.slice(args.selectionEnd);
        result.value = this._getMaskedValue(leftPart + (args.insertedChars || "") + rightPart);
        if (!args.insertedChars && args.inputDirection === "backward") {
            result.caretPosition = args.selectionStart;
        }
        else {
            result.caretPosition = this._getMaskedValue(leftPart + (args.insertedChars || ""), false).length;
        }
        return result;
    }
}
__decorate([
    property()
], InputMaskDateTime.prototype, "min", void 0);
__decorate([
    property()
], InputMaskDateTime.prototype, "max", void 0);
Serializer.addClass("datetimemask", [
    {
        name: "min",
        type: "datetime",
        enableIf: (obj) => {
            return !!obj.pattern;
        }
    },
    {
        name: "max",
        type: "datetime",
        enableIf: (obj) => {
            return !!obj.pattern;
        }
    }
], function () {
    return new InputMaskDateTime();
}, "patternmask");

/**
 * A class that describes an input mask of the `"currency"` [`maskType`](https://surveyjs.io/form-library/documentation/api-reference/text-entry-question-model#maskType).
 *
 * The following code shows how to specify the properties of this class within a survey JSON schema:
 *
 * ```js
 * const surveyJson = {
 *   "elements": [{
 *     "name": "textquestion1"
 *     "type": "text",
 *     "maskType": "currency",
 *     "maskSettings": {
 *       // Specify the properties of a currency input mask here
 *     }
 *   }]
 * }
 * ```
 *
 * [View Demo](https://surveyjs.io/form-library/examples/masked-input-fields/ (linkStyle))
 */
class InputMaskCurrency extends InputMaskNumeric {
    getType() {
        return "currencymask";
    }
    wrapText(str) {
        const prefixValue = this.prefix || "";
        const suffixValue = this.suffix || "";
        let result = str;
        if (!result)
            return result;
        if (result.indexOf(prefixValue) === -1) {
            result = prefixValue + result;
        }
        if (result.indexOf(suffixValue) === -1) {
            result += suffixValue;
        }
        return result;
    }
    unwrapInputArgs(args) {
        let result = args.prevValue;
        if (!result)
            return;
        if (this.prefix && result.indexOf(this.prefix) !== -1) {
            result = result.slice(result.indexOf(this.prefix) + this.prefix.length);
            const preffixPadding = (this.prefix || "").length;
            args.selectionStart = Math.max((args.selectionStart - preffixPadding), 0);
            args.selectionEnd -= preffixPadding;
        }
        if (this.suffix && result.indexOf(this.suffix) !== -1) {
            result = result.slice(0, result.indexOf(this.suffix));
        }
        args.prevValue = result;
    }
    processInput(args) {
        this.unwrapInputArgs(args);
        const result = super.processInput(args);
        const preffixPadding = (this.prefix || "").length;
        if (!!result.value) {
            result.caretPosition += preffixPadding;
        }
        result.value = this.wrapText(result.value);
        return result;
    }
    getMaskedValue(src) {
        const result = super.getMaskedValue(src);
        return this.wrapText(result);
    }
}
__decorate([
    property()
], InputMaskCurrency.prototype, "prefix", void 0);
__decorate([
    property()
], InputMaskCurrency.prototype, "suffix", void 0);
Serializer.addClass("currencymask", [
    { name: "prefix" },
    { name: "suffix" },
], () => {
    return new InputMaskCurrency();
}, "numericmask");

// styles
// import "../../src/main.scss";
//import "../../src/modern.scss";
var Version;
var ReleaseDate;
// eslint-disable-next-line @typescript-eslint/ban-ts-comment
//@ts-ignore
Version = `${"2.2.2"}`;
settings.version = Version;
// eslint-disable-next-line @typescript-eslint/ban-ts-comment
//@ts-ignore
ReleaseDate = `${"2025-06-25"}`;
function checkLibraryVersion(ver, libraryName) {
    if (Version != ver) {
        const str = "survey-core has version '" + Version + "' and " + libraryName
            + " has version '" + ver + "'. SurveyJS libraries should have the same versions to work correctly.";
        /* eslint no-console: ["error", { allow: ["error"] }] */
        console.error(str);
    }
}
function setLicenseKey(key) {
    slk(key);
}
function slk(key) {
    _slk(key, lic, ReleaseDate);
}
function hasLicense(index) {
    return lic[index.toString()] === true;
}
const lic = {};
function _slk(k, lh, rd) {
    if (!k)
        return;
    const en = (s) => {
        var e = {}, i, b = 0, x, l = 0, a, r = "", w = String.fromCharCode, L = s.length;
        var A = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
        for (i = 0; i < 64; i++) {
            e[A.charAt(i)] = i;
        }
        for (x = 0; x < L; x++) {
            let c = e[s.charAt(x)];
            b = (b << 6) + c;
            l += 6;
            while (l >= 8) {
                ((a = (b >>> (l -= 8)) & 0xff) || (x < (L - 2))) && (r += w(a));
            }
        }
        return r;
    };
    let v = en(k);
    if (!v)
        return;
    let index = v.indexOf(";");
    if (index < 0)
        return;
    if (!checkPrefix(v.substring(0, index)))
        return;
    v = v.substring(index + 1);
    v.split(",").forEach(s => {
        let i = s.indexOf("=");
        if (i > 0) {
            lh[s.substring(0, i)] = new Date(rd) <= new Date(s.substring(i + 1));
        }
    });
}
function checkPrefix(prefix) {
    if (!prefix)
        return true;
    const s = "domains:";
    const index = prefix.indexOf(s);
    if (index < 0)
        return true;
    const ds = prefix.substring(index + s.length).toLowerCase().split(",");
    if (!Array.isArray(ds) || ds.length === 0)
        return true;
    const location = DomWindowHelper.getLocation();
    if (!!location && !!location.hostname) {
        const hn = location.hostname.toLowerCase();
        ds.push("localhost");
        for (let i = 0; i < ds.length; i++) {
            if (hn.indexOf(ds[i]) > -1)
                return true;
        }
        return false;
    }
    return true;
}

class SvgIconRegistry {
    constructor() {
        this.icons = {};
        this.iconPrefix = "icon-";
        this.onIconsChanged = new EventBase();
    }
    processId(iconId, iconPrefix) {
        if (iconId.indexOf(iconPrefix) == 0) {
            iconId = iconId.substring(iconPrefix.length);
        }
        iconId = renamedIcons[iconId] || iconId;
        return iconId;
    }
    registerIconFromSymbol(iconId, iconSymbolSvg) {
        this.icons[iconId] = iconSymbolSvg;
    }
    registerIconFromSvgViaElement(iconId, iconSvg, iconPrefix = this.iconPrefix) {
        if (!DomDocumentHelper.isAvailable())
            return;
        iconId = this.processId(iconId, iconPrefix);
        let divSvg = DomDocumentHelper.createElement("div");
        divSvg.innerHTML = iconSvg;
        let symbol = DomDocumentHelper.createElement("symbol");
        let svg = divSvg.querySelector("svg");
        symbol.innerHTML = svg.innerHTML;
        for (var i = 0; i < svg.attributes.length; i++) {
            symbol.setAttributeNS("http://www.w3.org/2000/svg", svg.attributes[i].name, svg.attributes[i].value);
        }
        symbol.id = iconPrefix + iconId;
        this.registerIconFromSymbol(iconId, symbol.outerHTML);
    }
    registerIconFromSvg(iconId, iconSvg, iconPrefix = this.iconPrefix) {
        iconId = this.processId(iconId, iconPrefix);
        const startStr = "<svg ";
        const endStr = "</svg>";
        iconSvg = iconSvg.trim();
        const str = iconSvg.toLowerCase();
        if (str.substring(0, startStr.length) === startStr &&
            str.substring(str.length - endStr.length, str.length) === endStr) {
            this.registerIconFromSymbol(iconId, "<symbol " +
                "id=\"" + iconPrefix + iconId + "\" " +
                iconSvg.substring(startStr.length, str.length - endStr.length) +
                "</symbol>");
            return true;
        }
        else {
            return false;
        }
    }
    // TODO: remove in V2
    registerIconsFromFolder(r) {
        r.keys().forEach((key) => {
            this.registerIconFromSvg(key.substring(2, key.length - 4).toLowerCase(), r(key));
        });
    }
    registerIcons(icons) {
        for (const iconId in icons) {
            this.registerIconFromSvg(iconId, icons[iconId]);
        }
        this.updateMarkup();
    }
    registerIcon(id, svg, iconSetVersion = "v2") {
        this.registerIconFromSvg(id, svg);
        addIconsToThemeSet(iconSetVersion, { [id]: svg });
    }
    iconsRenderedHtml() {
        return Object.keys(this.icons).map(icon => this.icons[icon]).join("");
    }
    updateMarkup() {
        this.onIconsChanged.fire(this, {});
    }
}
const SvgRegistry = new SvgIconRegistry();
const SvgThemeSets = {};
function addIconsToThemeSet(name, iconsData) {
    if (!SvgThemeSets[name]) {
        SvgThemeSets[name] = {};
    }
    const set = SvgThemeSets[name];
    for (const iconId in iconsData) {
        set[iconId] = iconsData[iconId];
    }
}

export { Action, ActionContainer, ActionDropdownViewModel, AdaptiveActionContainer, AnimationBoolean, AnimationGroup, AnimationGroupUtils, AnimationProperty, AnimationPropertyUtils, AnimationTab, AnimationUtils, AnswerCountValidator, AnswerRequiredError, ArrayChanges, ArrayOperand, Base, BaseAction, BinaryOperand, ButtonGroupItemModel, ButtonGroupItemValue, CalculatedValue, CharacterCounter, ChoicesRestful, ChoicesRestfull, ComponentCollection, ComponentQuestionJSON, ComputedUpdater, ConditionRunner, ConditionsParser, Const, Cover, CoverCell, CssClassBuilder, CustomError, CustomWidgetCollection, DefaultTitleModel, DragDropChoices, DragDropCore, DragDropRankingSelectToRank, DragOrClickHelper, DropdownListModel, DropdownMultiSelectListModel, ElementFactory, EmailValidator, Event, EventBase, ExceedSizeError, ExpressionExecutor, ExpressionRunner, ExpressionValidator, FlowPanelModel, FunctionFactory, FunctionOperand, Helpers, HtmlConditionItem, ImageItemValue, InputMaskBase, InputMaskCurrency, InputMaskDateTime, InputMaskNumeric, InputMaskPattern, IsMobile, IsTouch, ItemValue, JsonError, JsonIncorrectTypeError, JsonMetadata, JsonMetadataClass, JsonMissingTypeError, JsonMissingTypeErrorBase, JsonObject, JsonObjectProperty, JsonRequiredPropertyError, JsonUnknownPropertyError, ListModel, LocalizableString, LocalizableStrings, MatrixCells, MatrixDropdownCell, MatrixDropdownColumn, MatrixDropdownRowModel, MatrixDropdownRowModelBase, MatrixDynamicRowModel, MatrixRowModel, SurveyModel as Model, MultiSelectListModel, MultipleTextCell, MultipleTextEditorModel, MultipleTextErrorCell, MultipleTextItemModel, MutlipleTextErrorRow, MutlipleTextRow, Notifier, NumericValidator, OneAnswerRequiredError, Operand, PageModel, PanelModel, PanelModelBase, PopupBaseViewModel, PopupDropdownViewModel, PopupModalViewModel, PopupModel, PopupSurveyModel, ProcessValue, ProgressButtons, ProgressButtonsResponsivityManager, Question, QuestionBooleanModel, QuestionButtonGroupModel, QuestionCheckboxBase, QuestionCheckboxModel, QuestionCommentModel, QuestionCompositeModel, QuestionCustomModel, QuestionCustomWidget, QuestionDropdownModel, QuestionEmptyModel, QuestionExpressionModel, QuestionFactory, QuestionFileModel, QuestionFilePage, QuestionHtmlModel, QuestionImageModel, QuestionImagePickerModel, QuestionMatrixBaseModel, QuestionMatrixDropdownModel, QuestionMatrixDropdownModelBase, QuestionMatrixDropdownRenderedCell, QuestionMatrixDropdownRenderedErrorRow, QuestionMatrixDropdownRenderedRow, QuestionMatrixDropdownRenderedTable, QuestionMatrixDynamicModel, QuestionMatrixModel, QuestionMultipleTextModel, QuestionNonValue, QuestionPanelDynamicItem, QuestionPanelDynamicModel, QuestionRadiogroupModel, QuestionRankingModel, QuestionRatingModel, QuestionRowModel, QuestionSelectBase, QuestionSignaturePadModel, QuestionSingleInputSummary, QuestionSingleInputSummaryItem, QuestionSliderModel, QuestionTagboxModel, QuestionTextBase, QuestionTextModel, RegexValidator, ReleaseDate, RenderedRatingItem, RendererFactory, RequreNumericError, ResponsivityManager, ScrollViewModel, Serializer, SurveyElement, SurveyElementCore, SurveyError, SurveyModel, SurveyProgressModel, SurveyTimer, SurveyTimerModel, SurveyTrigger, SurveyTriggerComplete, SurveyTriggerCopyValue, SurveyTriggerRunExpression, SurveyTriggerSetValue, SurveyTriggerSkip, SurveyTriggerVisible, SurveyValidator, SurveyWindowModel, SvgIconRegistry, SvgRegistry, SvgThemeSets, TOCModel, TextAreaModel, TextPreProcessor, TextValidator, Trigger, UnaryOperand, UrlConditionItem, ValidatorResult, ValidatorRunner, Variable, Version, VerticalResponsivityManager, _setIsTablet, _setIsTouch, activateLazyRenderingChecks, addIconsToThemeSet, checkLibraryVersion, chooseFiles, classesToSelector, cleanHtmlElementAfterAnimation, confirmAction, confirmActionAsync, createDropdownActionModel, createDropdownActionModelAdvanced, createPopupModalViewModel, createPopupModelWithListModel, createPopupViewModel, createSvg, createTOCListModel, defaultActionBarCss, defaultCss, defaultThemeName, detectIEOrEdge, doKey2ClickBlur, doKey2ClickDown, doKey2ClickUp, englishStrings, getActionDropdownButtonTarget, getElement, getIconNameFromProxy, getLocaleString, getLocaleStrings, getOriginalEvent, getTocRootCss, hasLicense, increaseHeightByContent, loadFileFromBase64, matrixDropdownColumnTypes, prepareElementForVerticalAnimation, property, propertyArray, registerFunction, renamedIcons, sanitizeEditableContent, setLicenseKey, settings, setupLocale, slk, surveyCss, surveyLocalization, surveyStrings, tryFocusPage, unwrap };
//# sourceMappingURL=survey-core.mjs.map
